import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessCustomPage = new cloudflare.ZeroTrustAccessCustomPage("example_zero_trust_access_custom_page", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     customHtml: "<html><body><h1>Access Denied</h1></body></html>",
 *     name: "name",
 *     type: "identity_denied",
 *     appCount: 0,
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/accessCustomPage:AccessCustomPage example '<account_id>/<custom_page_id>'
 * ```
 *
 * @deprecated cloudflare.index/accesscustompage.AccessCustomPage has been deprecated in favor of cloudflare.index/zerotrustaccesscustompage.ZeroTrustAccessCustomPage
 */
export declare class AccessCustomPage extends pulumi.CustomResource {
    /**
     * Get an existing AccessCustomPage resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AccessCustomPageState, opts?: pulumi.CustomResourceOptions): AccessCustomPage;
    /**
     * Returns true if the given object is an instance of AccessCustomPage.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AccessCustomPage;
    /**
     * Identifier.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Number of apps the custom page is assigned to.
     */
    readonly appCount: pulumi.Output<number | undefined>;
    readonly createdAt: pulumi.Output<string>;
    /**
     * Custom page HTML.
     */
    readonly customHtml: pulumi.Output<string>;
    /**
     * Custom page name.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Custom page type.
     * Available values: "identityDenied", "forbidden".
     */
    readonly type: pulumi.Output<string>;
    /**
     * UUID.
     */
    readonly uid: pulumi.Output<string>;
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a AccessCustomPage resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    /** @deprecated cloudflare.index/accesscustompage.AccessCustomPage has been deprecated in favor of cloudflare.index/zerotrustaccesscustompage.ZeroTrustAccessCustomPage */
    constructor(name: string, args: AccessCustomPageArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AccessCustomPage resources.
 */
export interface AccessCustomPageState {
    /**
     * Identifier.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Number of apps the custom page is assigned to.
     */
    appCount?: pulumi.Input<number>;
    createdAt?: pulumi.Input<string>;
    /**
     * Custom page HTML.
     */
    customHtml?: pulumi.Input<string>;
    /**
     * Custom page name.
     */
    name?: pulumi.Input<string>;
    /**
     * Custom page type.
     * Available values: "identityDenied", "forbidden".
     */
    type?: pulumi.Input<string>;
    /**
     * UUID.
     */
    uid?: pulumi.Input<string>;
    updatedAt?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a AccessCustomPage resource.
 */
export interface AccessCustomPageArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Number of apps the custom page is assigned to.
     */
    appCount?: pulumi.Input<number>;
    /**
     * Custom page HTML.
     */
    customHtml: pulumi.Input<string>;
    /**
     * Custom page name.
     */
    name: pulumi.Input<string>;
    /**
     * Custom page type.
     * Available values: "identityDenied", "forbidden".
     */
    type: pulumi.Input<string>;
}
