import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessTag = new cloudflare.ZeroTrustAccessTag("example_zero_trust_access_tag", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     name: "engineers",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/accessTag:AccessTag example '<account_id>/<tag_name>'
 * ```
 *
 * @deprecated cloudflare.index/accesstag.AccessTag has been deprecated in favor of cloudflare.index/zerotrustaccesstag.ZeroTrustAccessTag
 */
export declare class AccessTag extends pulumi.CustomResource {
    /**
     * Get an existing AccessTag resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AccessTagState, opts?: pulumi.CustomResourceOptions): AccessTag;
    /**
     * Returns true if the given object is an instance of AccessTag.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AccessTag;
    /**
     * Identifier.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * The number of applications that have this tag
     */
    readonly appCount: pulumi.Output<number>;
    readonly createdAt: pulumi.Output<string>;
    /**
     * The name of the tag
     */
    readonly name: pulumi.Output<string>;
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a AccessTag resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    /** @deprecated cloudflare.index/accesstag.AccessTag has been deprecated in favor of cloudflare.index/zerotrustaccesstag.ZeroTrustAccessTag */
    constructor(name: string, args: AccessTagArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AccessTag resources.
 */
export interface AccessTagState {
    /**
     * Identifier.
     */
    accountId?: pulumi.Input<string>;
    /**
     * The number of applications that have this tag
     */
    appCount?: pulumi.Input<number>;
    createdAt?: pulumi.Input<string>;
    /**
     * The name of the tag
     */
    name?: pulumi.Input<string>;
    updatedAt?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a AccessTag resource.
 */
export interface AccessTagArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * The name of the tag
     */
    name: pulumi.Input<string>;
}
