import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccount = new cloudflare.Account("example_account", {
 *     name: "name",
 *     type: "standard",
 *     unit: {
 *         id: "f267e341f3dd4697bd3b9f71dd96247f",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/account:Account example '<account_id>'
 * ```
 */
export declare class Account extends pulumi.CustomResource {
    /**
     * Get an existing Account resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AccountState, opts?: pulumi.CustomResourceOptions): Account;
    /**
     * Returns true if the given object is an instance of Account.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Account;
    /**
     * Timestamp for the creation of the account
     */
    readonly createdOn: pulumi.Output<string>;
    /**
     * Account name
     */
    readonly name: pulumi.Output<string>;
    /**
     * Account settings
     */
    readonly settings: pulumi.Output<outputs.AccountSettings>;
    /**
     * the type of account being created. For self-serve customers, use standard. for enterprise customers, use enterprise.
     * Available values: "standard", "enterprise".
     */
    readonly type: pulumi.Output<string>;
    /**
     * information related to the tenant unit, and optionally, an id of the unit to create the account on. see https://developers.cloudflare.com/tenant/how-to/manage-accounts/
     */
    readonly unit: pulumi.Output<outputs.AccountUnit | undefined>;
    /**
     * Create a Account resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AccountArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Account resources.
 */
export interface AccountState {
    /**
     * Timestamp for the creation of the account
     */
    createdOn?: pulumi.Input<string>;
    /**
     * Account name
     */
    name?: pulumi.Input<string>;
    /**
     * Account settings
     */
    settings?: pulumi.Input<inputs.AccountSettings>;
    /**
     * the type of account being created. For self-serve customers, use standard. for enterprise customers, use enterprise.
     * Available values: "standard", "enterprise".
     */
    type?: pulumi.Input<string>;
    /**
     * information related to the tenant unit, and optionally, an id of the unit to create the account on. see https://developers.cloudflare.com/tenant/how-to/manage-accounts/
     */
    unit?: pulumi.Input<inputs.AccountUnit>;
}
/**
 * The set of arguments for constructing a Account resource.
 */
export interface AccountArgs {
    /**
     * Account name
     */
    name: pulumi.Input<string>;
    /**
     * Account settings
     */
    settings?: pulumi.Input<inputs.AccountSettings>;
    /**
     * the type of account being created. For self-serve customers, use standard. for enterprise customers, use enterprise.
     * Available values: "standard", "enterprise".
     */
    type: pulumi.Input<string>;
    /**
     * information related to the tenant unit, and optionally, an id of the unit to create the account on. see https://developers.cloudflare.com/tenant/how-to/manage-accounts/
     */
    unit?: pulumi.Input<inputs.AccountUnit>;
}
