import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountDnsSettingsInternalView = new cloudflare.AccountDnsSettingsInternalView("example_account_dns_settings_internal_view", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     name: "my view",
 *     zones: ["372e67954025e0ba6aaa6d586b9e0b59"],
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/accountDnsSettingsInternalView:AccountDnsSettingsInternalView example '<account_id>/<view_id>'
 * ```
 */
export declare class AccountDnsSettingsInternalView extends pulumi.CustomResource {
    /**
     * Get an existing AccountDnsSettingsInternalView resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AccountDnsSettingsInternalViewState, opts?: pulumi.CustomResourceOptions): AccountDnsSettingsInternalView;
    /**
     * Returns true if the given object is an instance of AccountDnsSettingsInternalView.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AccountDnsSettingsInternalView;
    /**
     * Identifier.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * When the view was created.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * When the view was last modified.
     */
    readonly modifiedTime: pulumi.Output<string>;
    /**
     * The name of the view.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The list of zones linked to this view.
     */
    readonly zones: pulumi.Output<string[]>;
    /**
     * Create a AccountDnsSettingsInternalView resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AccountDnsSettingsInternalViewArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AccountDnsSettingsInternalView resources.
 */
export interface AccountDnsSettingsInternalViewState {
    /**
     * Identifier.
     */
    accountId?: pulumi.Input<string>;
    /**
     * When the view was created.
     */
    createdTime?: pulumi.Input<string>;
    /**
     * When the view was last modified.
     */
    modifiedTime?: pulumi.Input<string>;
    /**
     * The name of the view.
     */
    name?: pulumi.Input<string>;
    /**
     * The list of zones linked to this view.
     */
    zones?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a AccountDnsSettingsInternalView resource.
 */
export interface AccountDnsSettingsInternalViewArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * The name of the view.
     */
    name: pulumi.Input<string>;
    /**
     * The list of zones linked to this view.
     */
    zones: pulumi.Input<pulumi.Input<string>[]>;
}
