import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 */
export declare class AccountSubscription extends pulumi.CustomResource {
    /**
     * Get an existing AccountSubscription resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AccountSubscriptionState, opts?: pulumi.CustomResourceOptions): AccountSubscription;
    /**
     * Returns true if the given object is an instance of AccountSubscription.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AccountSubscription;
    /**
     * Identifier
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * The monetary unit in which pricing information is displayed.
     */
    readonly currency: pulumi.Output<string>;
    /**
     * The end of the current period and also when the next billing is due.
     */
    readonly currentPeriodEnd: pulumi.Output<string>;
    /**
     * When the current billing period started. May match initial*period*start if this is the first period.
     */
    readonly currentPeriodStart: pulumi.Output<string>;
    /**
     * How often the subscription is renewed automatically.
     * Available values: "weekly", "monthly", "quarterly", "yearly".
     */
    readonly frequency: pulumi.Output<string | undefined>;
    /**
     * The price of the subscription that will be billed, in US dollars.
     */
    readonly price: pulumi.Output<number>;
    /**
     * The rate plan applied to the subscription.
     */
    readonly ratePlan: pulumi.Output<outputs.AccountSubscriptionRatePlan | undefined>;
    /**
     * The state that the subscription is in.
     * Available values: "Trial", "Provisioned", "Paid", "AwaitingPayment", "Cancelled", "Failed", "Expired".
     */
    readonly state: pulumi.Output<string>;
    /**
     * Subscription identifier tag.
     */
    readonly subscriptionIdentifier: pulumi.Output<string | undefined>;
    /**
     * Create a AccountSubscription resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AccountSubscriptionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AccountSubscription resources.
 */
export interface AccountSubscriptionState {
    /**
     * Identifier
     */
    accountId?: pulumi.Input<string>;
    /**
     * The monetary unit in which pricing information is displayed.
     */
    currency?: pulumi.Input<string>;
    /**
     * The end of the current period and also when the next billing is due.
     */
    currentPeriodEnd?: pulumi.Input<string>;
    /**
     * When the current billing period started. May match initial*period*start if this is the first period.
     */
    currentPeriodStart?: pulumi.Input<string>;
    /**
     * How often the subscription is renewed automatically.
     * Available values: "weekly", "monthly", "quarterly", "yearly".
     */
    frequency?: pulumi.Input<string>;
    /**
     * The price of the subscription that will be billed, in US dollars.
     */
    price?: pulumi.Input<number>;
    /**
     * The rate plan applied to the subscription.
     */
    ratePlan?: pulumi.Input<inputs.AccountSubscriptionRatePlan>;
    /**
     * The state that the subscription is in.
     * Available values: "Trial", "Provisioned", "Paid", "AwaitingPayment", "Cancelled", "Failed", "Expired".
     */
    state?: pulumi.Input<string>;
    /**
     * Subscription identifier tag.
     */
    subscriptionIdentifier?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a AccountSubscription resource.
 */
export interface AccountSubscriptionArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * How often the subscription is renewed automatically.
     * Available values: "weekly", "monthly", "quarterly", "yearly".
     */
    frequency?: pulumi.Input<string>;
    /**
     * The rate plan applied to the subscription.
     */
    ratePlan?: pulumi.Input<inputs.AccountSubscriptionRatePlan>;
    /**
     * Subscription identifier tag.
     */
    subscriptionIdentifier?: pulumi.Input<string>;
}
