import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAddressMap = new cloudflare.AddressMap("example_address_map", {
 *     accountId: "258def64c72dae45f3e4c8516e2111f2",
 *     description: "My Ecommerce zones",
 *     enabled: true,
 *     ips: ["192.0.2.1"],
 *     memberships: [{
 *         identifier: "023e105f4ecef8ad9ca31a8372d0c353",
 *         kind: "zone",
 *     }],
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/addressMap:AddressMap example '<account_id>/<address_map_id>'
 * ```
 */
export declare class AddressMap extends pulumi.CustomResource {
    /**
     * Get an existing AddressMap resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AddressMapState, opts?: pulumi.CustomResourceOptions): AddressMap;
    /**
     * Returns true if the given object is an instance of AddressMap.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AddressMap;
    /**
     * Identifier of a Cloudflare account.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * If set to false, then the Address Map cannot be deleted via API. This is true for Cloudflare-managed maps.
     */
    readonly canDelete: pulumi.Output<boolean>;
    /**
     * If set to false, then the IPs on the Address Map cannot be modified via the API. This is true for Cloudflare-managed maps.
     */
    readonly canModifyIps: pulumi.Output<boolean>;
    readonly createdAt: pulumi.Output<string>;
    /**
     * If you have legacy TLS clients which do not send the TLS server name indicator, then you can specify one default SNI on the map. If Cloudflare receives a TLS handshake from a client without an SNI, it will respond with the default SNI on those IPs. The default SNI can be any valid zone or subdomain owned by the account.
     */
    readonly defaultSni: pulumi.Output<string | undefined>;
    /**
     * An optional description field which may be used to describe the types of IPs or zones on the map.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Whether the Address Map is enabled or not. Cloudflare's DNS will not respond with IP addresses on an Address Map until the map is enabled.
     */
    readonly enabled: pulumi.Output<boolean>;
    readonly ips: pulumi.Output<string[] | undefined>;
    /**
     * Zones and Accounts which will be assigned IPs on this Address Map. A zone membership will take priority over an account membership.
     */
    readonly memberships: pulumi.Output<outputs.AddressMapMembership[]>;
    readonly modifiedAt: pulumi.Output<string>;
    /**
     * Create a AddressMap resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AddressMapArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AddressMap resources.
 */
export interface AddressMapState {
    /**
     * Identifier of a Cloudflare account.
     */
    accountId?: pulumi.Input<string>;
    /**
     * If set to false, then the Address Map cannot be deleted via API. This is true for Cloudflare-managed maps.
     */
    canDelete?: pulumi.Input<boolean>;
    /**
     * If set to false, then the IPs on the Address Map cannot be modified via the API. This is true for Cloudflare-managed maps.
     */
    canModifyIps?: pulumi.Input<boolean>;
    createdAt?: pulumi.Input<string>;
    /**
     * If you have legacy TLS clients which do not send the TLS server name indicator, then you can specify one default SNI on the map. If Cloudflare receives a TLS handshake from a client without an SNI, it will respond with the default SNI on those IPs. The default SNI can be any valid zone or subdomain owned by the account.
     */
    defaultSni?: pulumi.Input<string>;
    /**
     * An optional description field which may be used to describe the types of IPs or zones on the map.
     */
    description?: pulumi.Input<string>;
    /**
     * Whether the Address Map is enabled or not. Cloudflare's DNS will not respond with IP addresses on an Address Map until the map is enabled.
     */
    enabled?: pulumi.Input<boolean>;
    ips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Zones and Accounts which will be assigned IPs on this Address Map. A zone membership will take priority over an account membership.
     */
    memberships?: pulumi.Input<pulumi.Input<inputs.AddressMapMembership>[]>;
    modifiedAt?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a AddressMap resource.
 */
export interface AddressMapArgs {
    /**
     * Identifier of a Cloudflare account.
     */
    accountId: pulumi.Input<string>;
    /**
     * If you have legacy TLS clients which do not send the TLS server name indicator, then you can specify one default SNI on the map. If Cloudflare receives a TLS handshake from a client without an SNI, it will respond with the default SNI on those IPs. The default SNI can be any valid zone or subdomain owned by the account.
     */
    defaultSni?: pulumi.Input<string>;
    /**
     * An optional description field which may be used to describe the types of IPs or zones on the map.
     */
    description?: pulumi.Input<string>;
    /**
     * Whether the Address Map is enabled or not. Cloudflare's DNS will not respond with IP addresses on an Address Map until the map is enabled.
     */
    enabled?: pulumi.Input<boolean>;
    ips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Zones and Accounts which will be assigned IPs on this Address Map. A zone membership will take priority over an account membership.
     */
    memberships?: pulumi.Input<pulumi.Input<inputs.AddressMapMembership>[]>;
}
