import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleApiShieldDiscoveryOperation = new cloudflare.ApiShieldDiscoveryOperation("example_api_shield_discovery_operation", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     operationId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 *     state: "review",
 * });
 * ```
 */
export declare class ApiShieldDiscoveryOperation extends pulumi.CustomResource {
    /**
     * Get an existing ApiShieldDiscoveryOperation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ApiShieldDiscoveryOperationState, opts?: pulumi.CustomResourceOptions): ApiShieldDiscoveryOperation;
    /**
     * Returns true if the given object is an instance of ApiShieldDiscoveryOperation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApiShieldDiscoveryOperation;
    /**
     * UUID.
     */
    readonly operationId: pulumi.Output<string>;
    /**
     * Mark state of operation in API Discovery * `review` - Mark operation as for review * `ignored` - Mark operation as
     * ignored Available values: "review", "ignored".
     */
    readonly state: pulumi.Output<string | undefined>;
    /**
     * Identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a ApiShieldDiscoveryOperation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApiShieldDiscoveryOperationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ApiShieldDiscoveryOperation resources.
 */
export interface ApiShieldDiscoveryOperationState {
    /**
     * UUID.
     */
    operationId?: pulumi.Input<string>;
    /**
     * Mark state of operation in API Discovery * `review` - Mark operation as for review * `ignored` - Mark operation as
     * ignored Available values: "review", "ignored".
     */
    state?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ApiShieldDiscoveryOperation resource.
 */
export interface ApiShieldDiscoveryOperationArgs {
    /**
     * UUID.
     */
    operationId: pulumi.Input<string>;
    /**
     * Mark state of operation in API Discovery * `review` - Mark operation as for review * `ignored` - Mark operation as
     * ignored Available values: "review", "ignored".
     */
    state?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
