import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleApiShieldSchemaValidationSettings = new cloudflare.ApiShieldSchemaValidationSettings("example_api_shield_schema_validation_settings", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     validationDefaultMitigationAction: "block",
 *     validationOverrideMitigationAction: "none",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/apiShieldSchemaValidationSettings:ApiShieldSchemaValidationSettings example '<zone_id>'
 * ```
 */
export declare class ApiShieldSchemaValidationSettings extends pulumi.CustomResource {
    /**
     * Get an existing ApiShieldSchemaValidationSettings resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ApiShieldSchemaValidationSettingsState, opts?: pulumi.CustomResourceOptions): ApiShieldSchemaValidationSettings;
    /**
     * Returns true if the given object is an instance of ApiShieldSchemaValidationSettings.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApiShieldSchemaValidationSettings;
    /**
     * The default mitigation action used when there is no mitigation action defined on the operation
     */
    readonly validationDefaultMitigationAction: pulumi.Output<string>;
    /**
     * When set, this overrides both zone level and operation level mitigation actions. - `none` will skip running schema
     * validation entirely for the request - `null` indicates that no override is in place To clear any override, use the
     * special value `disableOverride` or `null` Available values: "none", "disableOverride".
     */
    readonly validationOverrideMitigationAction: pulumi.Output<string | undefined>;
    /**
     * Identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a ApiShieldSchemaValidationSettings resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApiShieldSchemaValidationSettingsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ApiShieldSchemaValidationSettings resources.
 */
export interface ApiShieldSchemaValidationSettingsState {
    /**
     * The default mitigation action used when there is no mitigation action defined on the operation
     */
    validationDefaultMitigationAction?: pulumi.Input<string>;
    /**
     * When set, this overrides both zone level and operation level mitigation actions. - `none` will skip running schema
     * validation entirely for the request - `null` indicates that no override is in place To clear any override, use the
     * special value `disableOverride` or `null` Available values: "none", "disableOverride".
     */
    validationOverrideMitigationAction?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ApiShieldSchemaValidationSettings resource.
 */
export interface ApiShieldSchemaValidationSettingsArgs {
    /**
     * The default mitigation action used when there is no mitigation action defined on the operation
     */
    validationDefaultMitigationAction: pulumi.Input<string>;
    /**
     * When set, this overrides both zone level and operation level mitigation actions. - `none` will skip running schema
     * validation entirely for the request - `null` indicates that no override is in place To clear any override, use the
     * special value `disableOverride` or `null` Available values: "none", "disableOverride".
     */
    validationOverrideMitigationAction?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
