import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/apiToken:ApiToken example '<token_id>'
 * ```
 */
export declare class ApiToken extends pulumi.CustomResource {
    /**
     * Get an existing ApiToken resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ApiTokenState, opts?: pulumi.CustomResourceOptions): ApiToken;
    /**
     * Returns true if the given object is an instance of ApiToken.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApiToken;
    readonly condition: pulumi.Output<outputs.ApiTokenCondition | undefined>;
    /**
     * The expiration time on or after which the JWT MUST NOT be accepted for processing.
     */
    readonly expiresOn: pulumi.Output<string | undefined>;
    /**
     * The time on which the token was created.
     */
    readonly issuedOn: pulumi.Output<string>;
    /**
     * Last time the token was used.
     */
    readonly lastUsedOn: pulumi.Output<string>;
    /**
     * Last time the token was modified.
     */
    readonly modifiedOn: pulumi.Output<string>;
    /**
     * Token name.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The time before which the token MUST NOT be accepted for processing.
     */
    readonly notBefore: pulumi.Output<string | undefined>;
    /**
     * List of access policies assigned to the token.
     */
    readonly policies: pulumi.Output<outputs.ApiTokenPolicy[]>;
    /**
     * Status of the token.
     * Available values: "active", "disabled", "expired".
     */
    readonly status: pulumi.Output<string | undefined>;
    /**
     * The token value.
     */
    readonly value: pulumi.Output<string>;
    /**
     * Create a ApiToken resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApiTokenArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ApiToken resources.
 */
export interface ApiTokenState {
    condition?: pulumi.Input<inputs.ApiTokenCondition>;
    /**
     * The expiration time on or after which the JWT MUST NOT be accepted for processing.
     */
    expiresOn?: pulumi.Input<string>;
    /**
     * The time on which the token was created.
     */
    issuedOn?: pulumi.Input<string>;
    /**
     * Last time the token was used.
     */
    lastUsedOn?: pulumi.Input<string>;
    /**
     * Last time the token was modified.
     */
    modifiedOn?: pulumi.Input<string>;
    /**
     * Token name.
     */
    name?: pulumi.Input<string>;
    /**
     * The time before which the token MUST NOT be accepted for processing.
     */
    notBefore?: pulumi.Input<string>;
    /**
     * List of access policies assigned to the token.
     */
    policies?: pulumi.Input<pulumi.Input<inputs.ApiTokenPolicy>[]>;
    /**
     * Status of the token.
     * Available values: "active", "disabled", "expired".
     */
    status?: pulumi.Input<string>;
    /**
     * The token value.
     */
    value?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ApiToken resource.
 */
export interface ApiTokenArgs {
    condition?: pulumi.Input<inputs.ApiTokenCondition>;
    /**
     * The expiration time on or after which the JWT MUST NOT be accepted for processing.
     */
    expiresOn?: pulumi.Input<string>;
    /**
     * Token name.
     */
    name: pulumi.Input<string>;
    /**
     * The time before which the token MUST NOT be accepted for processing.
     */
    notBefore?: pulumi.Input<string>;
    /**
     * List of access policies assigned to the token.
     */
    policies: pulumi.Input<pulumi.Input<inputs.ApiTokenPolicy>[]>;
    /**
     * Status of the token.
     * Available values: "active", "disabled", "expired".
     */
    status?: pulumi.Input<string>;
}
