import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleArgoSmartRouting = new cloudflare.ArgoSmartRouting("example_argo_smart_routing", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     value: "on",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/argoSmartRouting:ArgoSmartRouting example '<zone_id>'
 * ```
 */
export declare class ArgoSmartRouting extends pulumi.CustomResource {
    /**
     * Get an existing ArgoSmartRouting resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ArgoSmartRoutingState, opts?: pulumi.CustomResourceOptions): ArgoSmartRouting;
    /**
     * Returns true if the given object is an instance of ArgoSmartRouting.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ArgoSmartRouting;
    /**
     * Enables Argo Smart Routing.
     * Available values: "on", "off".
     */
    readonly value: pulumi.Output<string>;
    /**
     * Identifier
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a ArgoSmartRouting resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ArgoSmartRoutingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ArgoSmartRouting resources.
 */
export interface ArgoSmartRoutingState {
    /**
     * Enables Argo Smart Routing.
     * Available values: "on", "off".
     */
    value?: pulumi.Input<string>;
    /**
     * Identifier
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ArgoSmartRouting resource.
 */
export interface ArgoSmartRoutingArgs {
    /**
     * Enables Argo Smart Routing.
     * Available values: "on", "off".
     */
    value: pulumi.Input<string>;
    /**
     * Identifier
     */
    zoneId: pulumi.Input<string>;
}
