import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAuthenticatedOriginPullsSettings = new cloudflare.AuthenticatedOriginPullsSettings("example_authenticated_origin_pulls_settings", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     enabled: true,
 * });
 * ```
 */
export declare class AuthenticatedOriginPullsSettings extends pulumi.CustomResource {
    /**
     * Get an existing AuthenticatedOriginPullsSettings resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AuthenticatedOriginPullsSettingsState, opts?: pulumi.CustomResourceOptions): AuthenticatedOriginPullsSettings;
    /**
     * Returns true if the given object is an instance of AuthenticatedOriginPullsSettings.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AuthenticatedOriginPullsSettings;
    /**
     * Indicates whether zone-level authenticated origin pulls is enabled.
     */
    readonly enabled: pulumi.Output<boolean>;
    /**
     * Identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a AuthenticatedOriginPullsSettings resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AuthenticatedOriginPullsSettingsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AuthenticatedOriginPullsSettings resources.
 */
export interface AuthenticatedOriginPullsSettingsState {
    /**
     * Indicates whether zone-level authenticated origin pulls is enabled.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * Identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a AuthenticatedOriginPullsSettings resource.
 */
export interface AuthenticatedOriginPullsSettingsArgs {
    /**
     * Indicates whether zone-level authenticated origin pulls is enabled.
     */
    enabled: pulumi.Input<boolean>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
