import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleByoIpPrefix = new cloudflare.ByoIpPrefix("example_byo_ip_prefix", {
 *     accountId: "258def64c72dae45f3e4c8516e2111f2",
 *     asn: 209242,
 *     cidr: "192.0.2.0/24",
 *     loaDocumentId: "d933b1530bc56c9953cf8ce166da8004",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/byoIpPrefix:ByoIpPrefix example '<account_id>/<prefix_id>'
 * ```
 */
export declare class ByoIpPrefix extends pulumi.CustomResource {
    /**
     * Get an existing ByoIpPrefix resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ByoIpPrefixState, opts?: pulumi.CustomResourceOptions): ByoIpPrefix;
    /**
     * Returns true if the given object is an instance of ByoIpPrefix.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ByoIpPrefix;
    /**
     * Identifier of a Cloudflare account.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Prefix advertisement status to the Internet. This field is only not 'null' if on demand is enabled.
     */
    readonly advertised: pulumi.Output<boolean>;
    /**
     * Last time the advertisement status was changed. This field is only not 'null' if on demand is enabled.
     */
    readonly advertisedModifiedAt: pulumi.Output<string>;
    /**
     * Approval state of the prefix (P = pending, V = active).
     */
    readonly approved: pulumi.Output<string>;
    /**
     * Autonomous System Number (ASN) the prefix will be advertised under.
     */
    readonly asn: pulumi.Output<number>;
    /**
     * IP Prefix in Classless Inter-Domain Routing format.
     */
    readonly cidr: pulumi.Output<string>;
    readonly createdAt: pulumi.Output<string>;
    /**
     * Description of the prefix.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Identifier for the uploaded LOA document.
     */
    readonly loaDocumentId: pulumi.Output<string>;
    readonly modifiedAt: pulumi.Output<string>;
    /**
     * Whether advertisement of the prefix to the Internet may be dynamically enabled or disabled.
     */
    readonly onDemandEnabled: pulumi.Output<boolean>;
    /**
     * Whether advertisement status of the prefix is locked, meaning it cannot be changed.
     */
    readonly onDemandLocked: pulumi.Output<boolean>;
    /**
     * Create a ByoIpPrefix resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ByoIpPrefixArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ByoIpPrefix resources.
 */
export interface ByoIpPrefixState {
    /**
     * Identifier of a Cloudflare account.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Prefix advertisement status to the Internet. This field is only not 'null' if on demand is enabled.
     */
    advertised?: pulumi.Input<boolean>;
    /**
     * Last time the advertisement status was changed. This field is only not 'null' if on demand is enabled.
     */
    advertisedModifiedAt?: pulumi.Input<string>;
    /**
     * Approval state of the prefix (P = pending, V = active).
     */
    approved?: pulumi.Input<string>;
    /**
     * Autonomous System Number (ASN) the prefix will be advertised under.
     */
    asn?: pulumi.Input<number>;
    /**
     * IP Prefix in Classless Inter-Domain Routing format.
     */
    cidr?: pulumi.Input<string>;
    createdAt?: pulumi.Input<string>;
    /**
     * Description of the prefix.
     */
    description?: pulumi.Input<string>;
    /**
     * Identifier for the uploaded LOA document.
     */
    loaDocumentId?: pulumi.Input<string>;
    modifiedAt?: pulumi.Input<string>;
    /**
     * Whether advertisement of the prefix to the Internet may be dynamically enabled or disabled.
     */
    onDemandEnabled?: pulumi.Input<boolean>;
    /**
     * Whether advertisement status of the prefix is locked, meaning it cannot be changed.
     */
    onDemandLocked?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a ByoIpPrefix resource.
 */
export interface ByoIpPrefixArgs {
    /**
     * Identifier of a Cloudflare account.
     */
    accountId: pulumi.Input<string>;
    /**
     * Autonomous System Number (ASN) the prefix will be advertised under.
     */
    asn: pulumi.Input<number>;
    /**
     * IP Prefix in Classless Inter-Domain Routing format.
     */
    cidr: pulumi.Input<string>;
    /**
     * Description of the prefix.
     */
    description?: pulumi.Input<string>;
    /**
     * Identifier for the uploaded LOA document.
     */
    loaDocumentId: pulumi.Input<string>;
}
