import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCallsTurnApp = new cloudflare.CallsTurnApp("example_calls_turn_app", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     name: "my-turn-key",
 * });
 * ```
 */
export declare class CallsTurnApp extends pulumi.CustomResource {
    /**
     * Get an existing CallsTurnApp resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CallsTurnAppState, opts?: pulumi.CustomResourceOptions): CallsTurnApp;
    /**
     * Returns true if the given object is an instance of CallsTurnApp.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CallsTurnApp;
    /**
     * The account identifier tag.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * The date and time the item was created.
     */
    readonly created: pulumi.Output<string>;
    /**
     * Bearer token
     */
    readonly key: pulumi.Output<string>;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    readonly keyId: pulumi.Output<string | undefined>;
    /**
     * The date and time the item was last modified.
     */
    readonly modified: pulumi.Output<string>;
    /**
     * A short description of a TURN key, not shown to end users.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    readonly uid: pulumi.Output<string>;
    /**
     * Create a CallsTurnApp resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CallsTurnAppArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CallsTurnApp resources.
 */
export interface CallsTurnAppState {
    /**
     * The account identifier tag.
     */
    accountId?: pulumi.Input<string>;
    /**
     * The date and time the item was created.
     */
    created?: pulumi.Input<string>;
    /**
     * Bearer token
     */
    key?: pulumi.Input<string>;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    keyId?: pulumi.Input<string>;
    /**
     * The date and time the item was last modified.
     */
    modified?: pulumi.Input<string>;
    /**
     * A short description of a TURN key, not shown to end users.
     */
    name?: pulumi.Input<string>;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    uid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a CallsTurnApp resource.
 */
export interface CallsTurnAppArgs {
    /**
     * The account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    keyId?: pulumi.Input<string>;
    /**
     * A short description of a TURN key, not shown to end users.
     */
    name?: pulumi.Input<string>;
}
