import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCloudforceOneRequest = new cloudflare.CloudforceOneRequest("example_cloudforce_one_request", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     content: "What regions were most effected by the recent DoS?",
 *     priority: "routine",
 *     requestType: "Victomology",
 *     summary: "DoS attack",
 *     tlp: "clear",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/cloudforceOneRequest:CloudforceOneRequest example '<account_id>/<request_id>'
 * ```
 */
export declare class CloudforceOneRequest extends pulumi.CustomResource {
    /**
     * Get an existing CloudforceOneRequest resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CloudforceOneRequestState, opts?: pulumi.CustomResourceOptions): CloudforceOneRequest;
    /**
     * Returns true if the given object is an instance of CloudforceOneRequest.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CloudforceOneRequest;
    /**
     * Identifier.
     */
    readonly accountId: pulumi.Output<string>;
    readonly completed: pulumi.Output<string>;
    /**
     * Request content.
     */
    readonly content: pulumi.Output<string | undefined>;
    readonly created: pulumi.Output<string>;
    /**
     * Tokens for the request messages.
     */
    readonly messageTokens: pulumi.Output<number>;
    /**
     * Priority for analyzing the request.
     */
    readonly priority: pulumi.Output<string | undefined>;
    /**
     * Readable Request ID.
     */
    readonly readableId: pulumi.Output<string>;
    /**
     * Requested information from request.
     */
    readonly request: pulumi.Output<string>;
    /**
     * Requested information from request.
     */
    readonly requestType: pulumi.Output<string | undefined>;
    /**
     * Request Status.
     * Available values: "open", "accepted", "reported", "approved", "completed", "declined".
     */
    readonly status: pulumi.Output<string>;
    /**
     * Brief description of the request.
     */
    readonly summary: pulumi.Output<string | undefined>;
    /**
     * The CISA defined Traffic Light Protocol (TLP).
     * Available values: "clear", "amber", "amber-strict", "green", "red".
     */
    readonly tlp: pulumi.Output<string | undefined>;
    /**
     * Tokens for the request.
     */
    readonly tokens: pulumi.Output<number>;
    readonly updated: pulumi.Output<string>;
    /**
     * Create a CloudforceOneRequest resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CloudforceOneRequestArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CloudforceOneRequest resources.
 */
export interface CloudforceOneRequestState {
    /**
     * Identifier.
     */
    accountId?: pulumi.Input<string>;
    completed?: pulumi.Input<string>;
    /**
     * Request content.
     */
    content?: pulumi.Input<string>;
    created?: pulumi.Input<string>;
    /**
     * Tokens for the request messages.
     */
    messageTokens?: pulumi.Input<number>;
    /**
     * Priority for analyzing the request.
     */
    priority?: pulumi.Input<string>;
    /**
     * Readable Request ID.
     */
    readableId?: pulumi.Input<string>;
    /**
     * Requested information from request.
     */
    request?: pulumi.Input<string>;
    /**
     * Requested information from request.
     */
    requestType?: pulumi.Input<string>;
    /**
     * Request Status.
     * Available values: "open", "accepted", "reported", "approved", "completed", "declined".
     */
    status?: pulumi.Input<string>;
    /**
     * Brief description of the request.
     */
    summary?: pulumi.Input<string>;
    /**
     * The CISA defined Traffic Light Protocol (TLP).
     * Available values: "clear", "amber", "amber-strict", "green", "red".
     */
    tlp?: pulumi.Input<string>;
    /**
     * Tokens for the request.
     */
    tokens?: pulumi.Input<number>;
    updated?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a CloudforceOneRequest resource.
 */
export interface CloudforceOneRequestArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Request content.
     */
    content?: pulumi.Input<string>;
    /**
     * Priority for analyzing the request.
     */
    priority?: pulumi.Input<string>;
    /**
     * Requested information from request.
     */
    requestType?: pulumi.Input<string>;
    /**
     * Brief description of the request.
     */
    summary?: pulumi.Input<string>;
    /**
     * The CISA defined Traffic Light Protocol (TLP).
     * Available values: "clear", "amber", "amber-strict", "green", "red".
     */
    tlp?: pulumi.Input<string>;
}
