import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCloudforceOneRequestAsset = new cloudflare.CloudforceOneRequestAsset("example_cloudforce_one_request_asset", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     requestId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 *     page: 0,
 *     perPage: 10,
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/cloudforceOneRequestAsset:CloudforceOneRequestAsset example '<account_id>/<request_id>/<asset_id>'
 * ```
 */
export declare class CloudforceOneRequestAsset extends pulumi.CustomResource {
    /**
     * Get an existing CloudforceOneRequestAsset resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CloudforceOneRequestAssetState, opts?: pulumi.CustomResourceOptions): CloudforceOneRequestAsset;
    /**
     * Returns true if the given object is an instance of CloudforceOneRequestAsset.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CloudforceOneRequestAsset;
    /**
     * Identifier.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Defines the asset creation time.
     */
    readonly created: pulumi.Output<string>;
    /**
     * Asset description.
     */
    readonly description: pulumi.Output<string>;
    /**
     * Asset file type.
     */
    readonly fileType: pulumi.Output<string>;
    /**
     * Asset name.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Page number of results.
     */
    readonly page: pulumi.Output<number>;
    /**
     * Number of results per page.
     */
    readonly perPage: pulumi.Output<number>;
    /**
     * UUID.
     */
    readonly requestId: pulumi.Output<string>;
    /**
     * Asset file to upload.
     */
    readonly source: pulumi.Output<string | undefined>;
    /**
     * Create a CloudforceOneRequestAsset resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CloudforceOneRequestAssetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CloudforceOneRequestAsset resources.
 */
export interface CloudforceOneRequestAssetState {
    /**
     * Identifier.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Defines the asset creation time.
     */
    created?: pulumi.Input<string>;
    /**
     * Asset description.
     */
    description?: pulumi.Input<string>;
    /**
     * Asset file type.
     */
    fileType?: pulumi.Input<string>;
    /**
     * Asset name.
     */
    name?: pulumi.Input<string>;
    /**
     * Page number of results.
     */
    page?: pulumi.Input<number>;
    /**
     * Number of results per page.
     */
    perPage?: pulumi.Input<number>;
    /**
     * UUID.
     */
    requestId?: pulumi.Input<string>;
    /**
     * Asset file to upload.
     */
    source?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a CloudforceOneRequestAsset resource.
 */
export interface CloudforceOneRequestAssetArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Page number of results.
     */
    page: pulumi.Input<number>;
    /**
     * Number of results per page.
     */
    perPage: pulumi.Input<number>;
    /**
     * UUID.
     */
    requestId: pulumi.Input<string>;
    /**
     * Asset file to upload.
     */
    source?: pulumi.Input<string>;
}
