import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCloudforceOneRequestMessage = new cloudflare.CloudforceOneRequestMessage("example_cloudforce_one_request_message", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     requestId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 *     content: "Can you elaborate on the type of DoS that occurred?",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/cloudforceOneRequestMessage:CloudforceOneRequestMessage example '<account_id>/<request_id>'
 * ```
 */
export declare class CloudforceOneRequestMessage extends pulumi.CustomResource {
    /**
     * Get an existing CloudforceOneRequestMessage resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CloudforceOneRequestMessageState, opts?: pulumi.CustomResourceOptions): CloudforceOneRequestMessage;
    /**
     * Returns true if the given object is an instance of CloudforceOneRequestMessage.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CloudforceOneRequestMessage;
    /**
     * Identifier.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Author of message.
     */
    readonly author: pulumi.Output<string>;
    /**
     * Content of message.
     */
    readonly content: pulumi.Output<string | undefined>;
    /**
     * Defines the message creation time.
     */
    readonly created: pulumi.Output<string>;
    /**
     * Whether the message is a follow-on request.
     */
    readonly isFollowOnRequest: pulumi.Output<boolean>;
    /**
     * UUID.
     */
    readonly requestId: pulumi.Output<string>;
    /**
     * Defines the message last updated time.
     */
    readonly updated: pulumi.Output<string>;
    /**
     * Create a CloudforceOneRequestMessage resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CloudforceOneRequestMessageArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CloudforceOneRequestMessage resources.
 */
export interface CloudforceOneRequestMessageState {
    /**
     * Identifier.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Author of message.
     */
    author?: pulumi.Input<string>;
    /**
     * Content of message.
     */
    content?: pulumi.Input<string>;
    /**
     * Defines the message creation time.
     */
    created?: pulumi.Input<string>;
    /**
     * Whether the message is a follow-on request.
     */
    isFollowOnRequest?: pulumi.Input<boolean>;
    /**
     * UUID.
     */
    requestId?: pulumi.Input<string>;
    /**
     * Defines the message last updated time.
     */
    updated?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a CloudforceOneRequestMessage resource.
 */
export interface CloudforceOneRequestMessageArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Content of message.
     */
    content?: pulumi.Input<string>;
    /**
     * UUID.
     */
    requestId: pulumi.Input<string>;
}
