import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleContentScanningExpression = new cloudflare.ContentScanningExpression("example_content_scanning_expression", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bodies: [{
 *         payload: "lookup_json_string(http.request.body.raw, \"file\")",
 *     }],
 * });
 * ```
 */
export declare class ContentScanningExpression extends pulumi.CustomResource {
    /**
     * Get an existing ContentScanningExpression resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ContentScanningExpressionState, opts?: pulumi.CustomResourceOptions): ContentScanningExpression;
    /**
     * Returns true if the given object is an instance of ContentScanningExpression.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ContentScanningExpression;
    readonly bodies: pulumi.Output<outputs.ContentScanningExpressionBody[]>;
    /**
     * Defines the ruleset expression to use in matching content objects.
     */
    readonly payload: pulumi.Output<string>;
    /**
     * Defines an identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a ContentScanningExpression resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ContentScanningExpressionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ContentScanningExpression resources.
 */
export interface ContentScanningExpressionState {
    bodies?: pulumi.Input<pulumi.Input<inputs.ContentScanningExpressionBody>[]>;
    /**
     * Defines the ruleset expression to use in matching content objects.
     */
    payload?: pulumi.Input<string>;
    /**
     * Defines an identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ContentScanningExpression resource.
 */
export interface ContentScanningExpressionArgs {
    bodies: pulumi.Input<pulumi.Input<inputs.ContentScanningExpressionBody>[]>;
    /**
     * Defines an identifier.
     */
    zoneId: pulumi.Input<string>;
}
