import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCustomHostnameFallbackOrigin = new cloudflare.CustomHostnameFallbackOrigin("example_custom_hostname_fallback_origin", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     origin: "fallback.example.com",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/customHostnameFallbackOrigin:CustomHostnameFallbackOrigin example '<zone_id>'
 * ```
 */
export declare class CustomHostnameFallbackOrigin extends pulumi.CustomResource {
    /**
     * Get an existing CustomHostnameFallbackOrigin resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CustomHostnameFallbackOriginState, opts?: pulumi.CustomResourceOptions): CustomHostnameFallbackOrigin;
    /**
     * Returns true if the given object is an instance of CustomHostnameFallbackOrigin.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CustomHostnameFallbackOrigin;
    /**
     * This is the time the fallback origin was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * These are errors that were encountered while trying to activate a fallback origin.
     */
    readonly errors: pulumi.Output<string[]>;
    /**
     * Your origin hostname that requests to your custom hostnames will be sent to.
     */
    readonly origin: pulumi.Output<string>;
    /**
     * Status of the fallback origin's activation.
     * Available values: "initializing", "pending*deployment", "pending*deletion", "active", "deployment*timed*out", "deletion*timed*out".
     */
    readonly status: pulumi.Output<string>;
    /**
     * This is the time the fallback origin was updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a CustomHostnameFallbackOrigin resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CustomHostnameFallbackOriginArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CustomHostnameFallbackOrigin resources.
 */
export interface CustomHostnameFallbackOriginState {
    /**
     * This is the time the fallback origin was created.
     */
    createdAt?: pulumi.Input<string>;
    /**
     * These are errors that were encountered while trying to activate a fallback origin.
     */
    errors?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Your origin hostname that requests to your custom hostnames will be sent to.
     */
    origin?: pulumi.Input<string>;
    /**
     * Status of the fallback origin's activation.
     * Available values: "initializing", "pending*deployment", "pending*deletion", "active", "deployment*timed*out", "deletion*timed*out".
     */
    status?: pulumi.Input<string>;
    /**
     * This is the time the fallback origin was updated.
     */
    updatedAt?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a CustomHostnameFallbackOrigin resource.
 */
export interface CustomHostnameFallbackOriginArgs {
    /**
     * Your origin hostname that requests to your custom hostnames will be sent to.
     */
    origin: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
