import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * !> When a D1 Database is replaced all the data is lost. Please ensure you have a
 *    backup of your data before replacing a D1 Database.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleD1Database = new cloudflare.D1Database("example_d1_database", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     name: "my-database",
 *     primaryLocationHint: "wnam",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/d1Database:D1Database example '<account_id>/<database_id>'
 * ```
 */
export declare class D1Database extends pulumi.CustomResource {
    /**
     * Get an existing D1Database resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: D1DatabaseState, opts?: pulumi.CustomResourceOptions): D1Database;
    /**
     * Returns true if the given object is an instance of D1Database.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is D1Database;
    /**
     * Account identifier tag.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Specifies the timestamp the resource was created as an ISO8601 string.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The D1 database's size, in bytes.
     */
    readonly fileSize: pulumi.Output<number>;
    /**
     * D1 database name.
     */
    readonly name: pulumi.Output<string>;
    readonly numTables: pulumi.Output<number>;
    /**
     * Specify the region to create the D1 primary, if available. If this option is omitted, the D1 will be created as close as possible to the current user.
     * Available values: "wnam", "enam", "weur", "eeur", "apac", "oc".
     */
    readonly primaryLocationHint: pulumi.Output<string | undefined>;
    /**
     * Configuration for D1 read replication.
     */
    readonly readReplication: pulumi.Output<outputs.D1DatabaseReadReplication | undefined>;
    /**
     * D1 database identifier (UUID).
     */
    readonly uuid: pulumi.Output<string>;
    readonly version: pulumi.Output<string>;
    /**
     * Create a D1Database resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: D1DatabaseArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering D1Database resources.
 */
export interface D1DatabaseState {
    /**
     * Account identifier tag.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Specifies the timestamp the resource was created as an ISO8601 string.
     */
    createdAt?: pulumi.Input<string>;
    /**
     * The D1 database's size, in bytes.
     */
    fileSize?: pulumi.Input<number>;
    /**
     * D1 database name.
     */
    name?: pulumi.Input<string>;
    numTables?: pulumi.Input<number>;
    /**
     * Specify the region to create the D1 primary, if available. If this option is omitted, the D1 will be created as close as possible to the current user.
     * Available values: "wnam", "enam", "weur", "eeur", "apac", "oc".
     */
    primaryLocationHint?: pulumi.Input<string>;
    /**
     * Configuration for D1 read replication.
     */
    readReplication?: pulumi.Input<inputs.D1DatabaseReadReplication>;
    /**
     * D1 database identifier (UUID).
     */
    uuid?: pulumi.Input<string>;
    version?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a D1Database resource.
 */
export interface D1DatabaseArgs {
    /**
     * Account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * D1 database name.
     */
    name: pulumi.Input<string>;
    /**
     * Specify the region to create the D1 primary, if available. If this option is omitted, the D1 will be created as close as possible to the current user.
     * Available values: "wnam", "enam", "weur", "eeur", "apac", "oc".
     */
    primaryLocationHint?: pulumi.Input<string>;
    /**
     * Configuration for D1 read replication.
     */
    readReplication?: pulumi.Input<inputs.D1DatabaseReadReplication>;
}
