import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/deviceManagedNetworks:DeviceManagedNetworks example '<account_id>/<network_id>'
 * ```
 *
 * @deprecated cloudflare.index/devicemanagednetworks.DeviceManagedNetworks has been deprecated in favor of cloudflare.index/zerotrustdevicemanagednetworks.ZeroTrustDeviceManagedNetworks
 */
export declare class DeviceManagedNetworks extends pulumi.CustomResource {
    /**
     * Get an existing DeviceManagedNetworks resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DeviceManagedNetworksState, opts?: pulumi.CustomResourceOptions): DeviceManagedNetworks;
    /**
     * Returns true if the given object is an instance of DeviceManagedNetworks.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DeviceManagedNetworks;
    readonly accountId: pulumi.Output<string>;
    /**
     * The configuration object containing information for the WARP client to detect the managed network.
     */
    readonly config: pulumi.Output<outputs.DeviceManagedNetworksConfig>;
    /**
     * The name of the device managed network. This name must be unique.
     */
    readonly name: pulumi.Output<string>;
    /**
     * API UUID.
     */
    readonly networkId: pulumi.Output<string>;
    /**
     * The type of device managed network.
     * Available values: "tls".
     */
    readonly type: pulumi.Output<string>;
    /**
     * Create a DeviceManagedNetworks resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    /** @deprecated cloudflare.index/devicemanagednetworks.DeviceManagedNetworks has been deprecated in favor of cloudflare.index/zerotrustdevicemanagednetworks.ZeroTrustDeviceManagedNetworks */
    constructor(name: string, args: DeviceManagedNetworksArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering DeviceManagedNetworks resources.
 */
export interface DeviceManagedNetworksState {
    accountId?: pulumi.Input<string>;
    /**
     * The configuration object containing information for the WARP client to detect the managed network.
     */
    config?: pulumi.Input<inputs.DeviceManagedNetworksConfig>;
    /**
     * The name of the device managed network. This name must be unique.
     */
    name?: pulumi.Input<string>;
    /**
     * API UUID.
     */
    networkId?: pulumi.Input<string>;
    /**
     * The type of device managed network.
     * Available values: "tls".
     */
    type?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a DeviceManagedNetworks resource.
 */
export interface DeviceManagedNetworksArgs {
    accountId: pulumi.Input<string>;
    /**
     * The configuration object containing information for the WARP client to detect the managed network.
     */
    config: pulumi.Input<inputs.DeviceManagedNetworksConfig>;
    /**
     * The name of the device managed network. This name must be unique.
     */
    name: pulumi.Input<string>;
    /**
     * The type of device managed network.
     * Available values: "tls".
     */
    type: pulumi.Input<string>;
}
