import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDlpPredefinedProfile = new cloudflare.ZeroTrustDlpPredefinedProfile("example_zero_trust_dlp_predefined_profile", {
 *     accountId: "account_id",
 *     profileId: "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
 *     entries: [{
 *         id: "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
 *         enabled: true,
 *     }],
 *     aiContextEnabled: true,
 *     allowedMatchCount: 0,
 *     confidenceThreshold: "confidence_threshold",
 *     contextAwareness: {
 *         enabled: true,
 *         skip: {
 *             files: true,
 *         },
 *     },
 *     ocrEnabled: true,
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/dlpPredefinedProfile:DlpPredefinedProfile example '<account_id>/<profile_id>'
 * ```
 *
 * @deprecated cloudflare.index/dlppredefinedprofile.DlpPredefinedProfile has been deprecated in favor of cloudflare.index/zerotrustdlppredefinedprofile.ZeroTrustDlpPredefinedProfile
 */
export declare class DlpPredefinedProfile extends pulumi.CustomResource {
    /**
     * Get an existing DlpPredefinedProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DlpPredefinedProfileState, opts?: pulumi.CustomResourceOptions): DlpPredefinedProfile;
    /**
     * Returns true if the given object is an instance of DlpPredefinedProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DlpPredefinedProfile;
    readonly accountId: pulumi.Output<string>;
    readonly aiContextEnabled: pulumi.Output<boolean | undefined>;
    readonly allowedMatchCount: pulumi.Output<number | undefined>;
    readonly confidenceThreshold: pulumi.Output<string | undefined>;
    /**
     * Scan the context of predefined entries to only return matches surrounded by keywords.
     */
    readonly contextAwareness: pulumi.Output<outputs.DlpPredefinedProfileContextAwareness | undefined>;
    /**
     * When the profile was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The description of the profile.
     */
    readonly description: pulumi.Output<string>;
    readonly entries: pulumi.Output<outputs.DlpPredefinedProfileEntry[]>;
    /**
     * The name of the profile.
     */
    readonly name: pulumi.Output<string>;
    readonly ocrEnabled: pulumi.Output<boolean | undefined>;
    /**
     * Whether this profile can be accessed by anyone.
     */
    readonly openAccess: pulumi.Output<boolean>;
    readonly profileId: pulumi.Output<string>;
    /**
     * Available values: "custom", "predefined", "integration".
     */
    readonly type: pulumi.Output<string>;
    /**
     * When the profile was lasted updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a DlpPredefinedProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    /** @deprecated cloudflare.index/dlppredefinedprofile.DlpPredefinedProfile has been deprecated in favor of cloudflare.index/zerotrustdlppredefinedprofile.ZeroTrustDlpPredefinedProfile */
    constructor(name: string, args: DlpPredefinedProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering DlpPredefinedProfile resources.
 */
export interface DlpPredefinedProfileState {
    accountId?: pulumi.Input<string>;
    aiContextEnabled?: pulumi.Input<boolean>;
    allowedMatchCount?: pulumi.Input<number>;
    confidenceThreshold?: pulumi.Input<string>;
    /**
     * Scan the context of predefined entries to only return matches surrounded by keywords.
     */
    contextAwareness?: pulumi.Input<inputs.DlpPredefinedProfileContextAwareness>;
    /**
     * When the profile was created.
     */
    createdAt?: pulumi.Input<string>;
    /**
     * The description of the profile.
     */
    description?: pulumi.Input<string>;
    entries?: pulumi.Input<pulumi.Input<inputs.DlpPredefinedProfileEntry>[]>;
    /**
     * The name of the profile.
     */
    name?: pulumi.Input<string>;
    ocrEnabled?: pulumi.Input<boolean>;
    /**
     * Whether this profile can be accessed by anyone.
     */
    openAccess?: pulumi.Input<boolean>;
    profileId?: pulumi.Input<string>;
    /**
     * Available values: "custom", "predefined", "integration".
     */
    type?: pulumi.Input<string>;
    /**
     * When the profile was lasted updated.
     */
    updatedAt?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a DlpPredefinedProfile resource.
 */
export interface DlpPredefinedProfileArgs {
    accountId: pulumi.Input<string>;
    aiContextEnabled?: pulumi.Input<boolean>;
    allowedMatchCount?: pulumi.Input<number>;
    confidenceThreshold?: pulumi.Input<string>;
    /**
     * Scan the context of predefined entries to only return matches surrounded by keywords.
     */
    contextAwareness?: pulumi.Input<inputs.DlpPredefinedProfileContextAwareness>;
    entries: pulumi.Input<pulumi.Input<inputs.DlpPredefinedProfileEntry>[]>;
    ocrEnabled?: pulumi.Input<boolean>;
    profileId: pulumi.Input<string>;
}
