import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleDnsZoneTransfersIncoming = new cloudflare.DnsZoneTransfersIncoming("example_dns_zone_transfers_incoming", {
 *     zoneId: "269d8f4853475ca241c4e730be286b20",
 *     autoRefreshSeconds: 86400,
 *     name: "www.example.com.",
 *     peers: [
 *         "23ff594956f20c2a721606e94745a8aa",
 *         "00920f38ce07c2e2f4df50b1f61d4194",
 *     ],
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/dnsZoneTransfersIncoming:DnsZoneTransfersIncoming example '<zone_id>'
 * ```
 */
export declare class DnsZoneTransfersIncoming extends pulumi.CustomResource {
    /**
     * Get an existing DnsZoneTransfersIncoming resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DnsZoneTransfersIncomingState, opts?: pulumi.CustomResourceOptions): DnsZoneTransfersIncoming;
    /**
     * Returns true if the given object is an instance of DnsZoneTransfersIncoming.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DnsZoneTransfersIncoming;
    /**
     * How often should a secondary zone auto refresh regardless of DNS NOTIFY.
     * Not applicable for primary zones.
     */
    readonly autoRefreshSeconds: pulumi.Output<number>;
    /**
     * The time for a specific event.
     */
    readonly checkedTime: pulumi.Output<string>;
    /**
     * The time for a specific event.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * The time for a specific event.
     */
    readonly modifiedTime: pulumi.Output<string>;
    /**
     * Zone name.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A list of peer tags.
     */
    readonly peers: pulumi.Output<string[]>;
    /**
     * The serial number of the SOA for the given zone.
     */
    readonly soaSerial: pulumi.Output<number>;
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a DnsZoneTransfersIncoming resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DnsZoneTransfersIncomingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering DnsZoneTransfersIncoming resources.
 */
export interface DnsZoneTransfersIncomingState {
    /**
     * How often should a secondary zone auto refresh regardless of DNS NOTIFY.
     * Not applicable for primary zones.
     */
    autoRefreshSeconds?: pulumi.Input<number>;
    /**
     * The time for a specific event.
     */
    checkedTime?: pulumi.Input<string>;
    /**
     * The time for a specific event.
     */
    createdTime?: pulumi.Input<string>;
    /**
     * The time for a specific event.
     */
    modifiedTime?: pulumi.Input<string>;
    /**
     * Zone name.
     */
    name?: pulumi.Input<string>;
    /**
     * A list of peer tags.
     */
    peers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The serial number of the SOA for the given zone.
     */
    soaSerial?: pulumi.Input<number>;
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a DnsZoneTransfersIncoming resource.
 */
export interface DnsZoneTransfersIncomingArgs {
    /**
     * How often should a secondary zone auto refresh regardless of DNS NOTIFY.
     * Not applicable for primary zones.
     */
    autoRefreshSeconds: pulumi.Input<number>;
    /**
     * Zone name.
     */
    name: pulumi.Input<string>;
    /**
     * A list of peer tags.
     */
    peers: pulumi.Input<pulumi.Input<string>[]>;
    zoneId: pulumi.Input<string>;
}
