import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleDnsZoneTransfersPeer = new cloudflare.DnsZoneTransfersPeer("example_dns_zone_transfers_peer", {
 *     accountId: "01a7362d577a6c3019a474fd6f485823",
 *     name: "my-peer-1",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/dnsZoneTransfersPeer:DnsZoneTransfersPeer example '<account_id>/<peer_id>'
 * ```
 */
export declare class DnsZoneTransfersPeer extends pulumi.CustomResource {
    /**
     * Get an existing DnsZoneTransfersPeer resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DnsZoneTransfersPeerState, opts?: pulumi.CustomResourceOptions): DnsZoneTransfersPeer;
    /**
     * Returns true if the given object is an instance of DnsZoneTransfersPeer.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DnsZoneTransfersPeer;
    readonly accountId: pulumi.Output<string>;
    /**
     * IPv4/IPv6 address of primary or secondary nameserver, depending on what zone this peer is linked to. For primary zones this IP defines the IP of the secondary nameserver Cloudflare will NOTIFY upon zone changes. For secondary zones this IP defines the IP of the primary nameserver Cloudflare will send AXFR/IXFR requests to.
     */
    readonly ip: pulumi.Output<string | undefined>;
    /**
     * Enable IXFR transfer protocol, default is AXFR. Only applicable to secondary zones.
     */
    readonly ixfrEnable: pulumi.Output<boolean | undefined>;
    /**
     * The name of the peer.
     */
    readonly name: pulumi.Output<string>;
    /**
     * DNS port of primary or secondary nameserver, depending on what zone this peer is linked to.
     */
    readonly port: pulumi.Output<number | undefined>;
    /**
     * TSIG authentication will be used for zone transfer if configured.
     */
    readonly tsigId: pulumi.Output<string | undefined>;
    /**
     * Create a DnsZoneTransfersPeer resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DnsZoneTransfersPeerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering DnsZoneTransfersPeer resources.
 */
export interface DnsZoneTransfersPeerState {
    accountId?: pulumi.Input<string>;
    /**
     * IPv4/IPv6 address of primary or secondary nameserver, depending on what zone this peer is linked to. For primary zones this IP defines the IP of the secondary nameserver Cloudflare will NOTIFY upon zone changes. For secondary zones this IP defines the IP of the primary nameserver Cloudflare will send AXFR/IXFR requests to.
     */
    ip?: pulumi.Input<string>;
    /**
     * Enable IXFR transfer protocol, default is AXFR. Only applicable to secondary zones.
     */
    ixfrEnable?: pulumi.Input<boolean>;
    /**
     * The name of the peer.
     */
    name?: pulumi.Input<string>;
    /**
     * DNS port of primary or secondary nameserver, depending on what zone this peer is linked to.
     */
    port?: pulumi.Input<number>;
    /**
     * TSIG authentication will be used for zone transfer if configured.
     */
    tsigId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a DnsZoneTransfersPeer resource.
 */
export interface DnsZoneTransfersPeerArgs {
    accountId: pulumi.Input<string>;
    /**
     * IPv4/IPv6 address of primary or secondary nameserver, depending on what zone this peer is linked to. For primary zones this IP defines the IP of the secondary nameserver Cloudflare will NOTIFY upon zone changes. For secondary zones this IP defines the IP of the primary nameserver Cloudflare will send AXFR/IXFR requests to.
     */
    ip?: pulumi.Input<string>;
    /**
     * Enable IXFR transfer protocol, default is AXFR. Only applicable to secondary zones.
     */
    ixfrEnable?: pulumi.Input<boolean>;
    /**
     * The name of the peer.
     */
    name: pulumi.Input<string>;
    /**
     * DNS port of primary or secondary nameserver, depending on what zone this peer is linked to.
     */
    port?: pulumi.Input<number>;
    /**
     * TSIG authentication will be used for zone transfer if configured.
     */
    tsigId?: pulumi.Input<string>;
}
