import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/emailRoutingRule:EmailRoutingRule example '<zone_id>/<rule_identifier>'
 * ```
 */
export declare class EmailRoutingRule extends pulumi.CustomResource {
    /**
     * Get an existing EmailRoutingRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: EmailRoutingRuleState, opts?: pulumi.CustomResourceOptions): EmailRoutingRule;
    /**
     * Returns true if the given object is an instance of EmailRoutingRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EmailRoutingRule;
    /**
     * List actions patterns.
     */
    readonly actions: pulumi.Output<outputs.EmailRoutingRuleAction[]>;
    /**
     * Routing rule status.
     */
    readonly enabled: pulumi.Output<boolean>;
    /**
     * Matching patterns to forward to your actions.
     */
    readonly matchers: pulumi.Output<outputs.EmailRoutingRuleMatcher[]>;
    /**
     * Routing rule name.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * Priority of the routing rule.
     */
    readonly priority: pulumi.Output<number>;
    /**
     * Routing rule tag. (Deprecated, replaced by routing rule identifier)
     *
     * @deprecated This attribute is deprecated.
     */
    readonly tag: pulumi.Output<string>;
    /**
     * Identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a EmailRoutingRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EmailRoutingRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering EmailRoutingRule resources.
 */
export interface EmailRoutingRuleState {
    /**
     * List actions patterns.
     */
    actions?: pulumi.Input<pulumi.Input<inputs.EmailRoutingRuleAction>[]>;
    /**
     * Routing rule status.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * Matching patterns to forward to your actions.
     */
    matchers?: pulumi.Input<pulumi.Input<inputs.EmailRoutingRuleMatcher>[]>;
    /**
     * Routing rule name.
     */
    name?: pulumi.Input<string>;
    /**
     * Priority of the routing rule.
     */
    priority?: pulumi.Input<number>;
    /**
     * Routing rule tag. (Deprecated, replaced by routing rule identifier)
     *
     * @deprecated This attribute is deprecated.
     */
    tag?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a EmailRoutingRule resource.
 */
export interface EmailRoutingRuleArgs {
    /**
     * List actions patterns.
     */
    actions: pulumi.Input<pulumi.Input<inputs.EmailRoutingRuleAction>[]>;
    /**
     * Routing rule status.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * Matching patterns to forward to your actions.
     */
    matchers: pulumi.Input<pulumi.Input<inputs.EmailRoutingRuleMatcher>[]>;
    /**
     * Routing rule name.
     */
    name?: pulumi.Input<string>;
    /**
     * Priority of the routing rule.
     */
    priority?: pulumi.Input<number>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
