import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailRoutingSettings = new cloudflare.EmailRoutingSettings("example_email_routing_settings", {zoneId: "023e105f4ecef8ad9ca31a8372d0c353"});
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/emailRoutingSettings:EmailRoutingSettings example '<zone_id>'
 * ```
 */
export declare class EmailRoutingSettings extends pulumi.CustomResource {
    /**
     * Get an existing EmailRoutingSettings resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: EmailRoutingSettingsState, opts?: pulumi.CustomResourceOptions): EmailRoutingSettings;
    /**
     * Returns true if the given object is an instance of EmailRoutingSettings.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EmailRoutingSettings;
    /**
     * The date and time the settings have been created.
     */
    readonly created: pulumi.Output<string>;
    /**
     * State of the zone settings for Email Routing.
     */
    readonly enabled: pulumi.Output<boolean>;
    /**
     * The date and time the settings have been modified.
     */
    readonly modified: pulumi.Output<string>;
    /**
     * Domain of your zone.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Flag to check if the user skipped the configuration wizard.
     */
    readonly skipWizard: pulumi.Output<boolean>;
    /**
     * Show the state of your account, and the type or configuration error.
     * Available values: "ready", "unconfigured", "misconfigured", "misconfigured/locked", "unlocked".
     */
    readonly status: pulumi.Output<string>;
    /**
     * Email Routing settings tag. (Deprecated, replaced by Email Routing settings identifier)
     *
     * @deprecated This attribute is deprecated.
     */
    readonly tag: pulumi.Output<string>;
    /**
     * Identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a EmailRoutingSettings resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EmailRoutingSettingsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering EmailRoutingSettings resources.
 */
export interface EmailRoutingSettingsState {
    /**
     * The date and time the settings have been created.
     */
    created?: pulumi.Input<string>;
    /**
     * State of the zone settings for Email Routing.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * The date and time the settings have been modified.
     */
    modified?: pulumi.Input<string>;
    /**
     * Domain of your zone.
     */
    name?: pulumi.Input<string>;
    /**
     * Flag to check if the user skipped the configuration wizard.
     */
    skipWizard?: pulumi.Input<boolean>;
    /**
     * Show the state of your account, and the type or configuration error.
     * Available values: "ready", "unconfigured", "misconfigured", "misconfigured/locked", "unlocked".
     */
    status?: pulumi.Input<string>;
    /**
     * Email Routing settings tag. (Deprecated, replaced by Email Routing settings identifier)
     *
     * @deprecated This attribute is deprecated.
     */
    tag?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a EmailRoutingSettings resource.
 */
export interface EmailRoutingSettingsArgs {
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
