import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityBlockSender = new cloudflare.EmailSecurityBlockSender("example_email_security_block_sender", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     isRegex: true,
 *     pattern: "x",
 *     patternType: "EMAIL",
 *     comments: "comments",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/emailSecurityBlockSender:EmailSecurityBlockSender example '<account_id>/<pattern_id>'
 * ```
 */
export declare class EmailSecurityBlockSender extends pulumi.CustomResource {
    /**
     * Get an existing EmailSecurityBlockSender resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: EmailSecurityBlockSenderState, opts?: pulumi.CustomResourceOptions): EmailSecurityBlockSender;
    /**
     * Returns true if the given object is an instance of EmailSecurityBlockSender.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EmailSecurityBlockSender;
    /**
     * Account Identifier
     */
    readonly accountId: pulumi.Output<string>;
    readonly comments: pulumi.Output<string | undefined>;
    readonly createdAt: pulumi.Output<string>;
    readonly isRegex: pulumi.Output<boolean>;
    readonly lastModified: pulumi.Output<string>;
    readonly pattern: pulumi.Output<string>;
    /**
     * Available values: "EMAIL", "DOMAIN", "IP", "UNKNOWN".
     */
    readonly patternType: pulumi.Output<string>;
    /**
     * Create a EmailSecurityBlockSender resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EmailSecurityBlockSenderArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering EmailSecurityBlockSender resources.
 */
export interface EmailSecurityBlockSenderState {
    /**
     * Account Identifier
     */
    accountId?: pulumi.Input<string>;
    comments?: pulumi.Input<string>;
    createdAt?: pulumi.Input<string>;
    isRegex?: pulumi.Input<boolean>;
    lastModified?: pulumi.Input<string>;
    pattern?: pulumi.Input<string>;
    /**
     * Available values: "EMAIL", "DOMAIN", "IP", "UNKNOWN".
     */
    patternType?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a EmailSecurityBlockSender resource.
 */
export interface EmailSecurityBlockSenderArgs {
    /**
     * Account Identifier
     */
    accountId: pulumi.Input<string>;
    comments?: pulumi.Input<string>;
    isRegex: pulumi.Input<boolean>;
    pattern: pulumi.Input<string>;
    /**
     * Available values: "EMAIL", "DOMAIN", "IP", "UNKNOWN".
     */
    patternType: pulumi.Input<string>;
}
