import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityTrustedDomains = new cloudflare.EmailSecurityTrustedDomains("example_email_security_trusted_domains", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     isRecent: true,
 *     isRegex: true,
 *     isSimilarity: true,
 *     pattern: "x",
 *     comments: "comments",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/emailSecurityTrustedDomains:EmailSecurityTrustedDomains example '<account_id>/<trusted_domain_id>'
 * ```
 */
export declare class EmailSecurityTrustedDomains extends pulumi.CustomResource {
    /**
     * Get an existing EmailSecurityTrustedDomains resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: EmailSecurityTrustedDomainsState, opts?: pulumi.CustomResourceOptions): EmailSecurityTrustedDomains;
    /**
     * Returns true if the given object is an instance of EmailSecurityTrustedDomains.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EmailSecurityTrustedDomains;
    /**
     * Account Identifier
     */
    readonly accountId: pulumi.Output<string>;
    readonly bodies: pulumi.Output<outputs.EmailSecurityTrustedDomainsBody[] | undefined>;
    readonly comments: pulumi.Output<string | undefined>;
    readonly createdAt: pulumi.Output<string>;
    /**
     * Select to prevent recently registered domains from triggering a
     * Suspicious or Malicious disposition.
     */
    readonly isRecent: pulumi.Output<boolean | undefined>;
    readonly isRegex: pulumi.Output<boolean | undefined>;
    /**
     * Select for partner or other approved domains that have similar
     * spelling to your connected domains. Prevents listed domains from
     * triggering a Spoof disposition.
     */
    readonly isSimilarity: pulumi.Output<boolean | undefined>;
    readonly lastModified: pulumi.Output<string>;
    readonly pattern: pulumi.Output<string | undefined>;
    /**
     * Create a EmailSecurityTrustedDomains resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EmailSecurityTrustedDomainsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering EmailSecurityTrustedDomains resources.
 */
export interface EmailSecurityTrustedDomainsState {
    /**
     * Account Identifier
     */
    accountId?: pulumi.Input<string>;
    bodies?: pulumi.Input<pulumi.Input<inputs.EmailSecurityTrustedDomainsBody>[]>;
    comments?: pulumi.Input<string>;
    createdAt?: pulumi.Input<string>;
    /**
     * Select to prevent recently registered domains from triggering a
     * Suspicious or Malicious disposition.
     */
    isRecent?: pulumi.Input<boolean>;
    isRegex?: pulumi.Input<boolean>;
    /**
     * Select for partner or other approved domains that have similar
     * spelling to your connected domains. Prevents listed domains from
     * triggering a Spoof disposition.
     */
    isSimilarity?: pulumi.Input<boolean>;
    lastModified?: pulumi.Input<string>;
    pattern?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a EmailSecurityTrustedDomains resource.
 */
export interface EmailSecurityTrustedDomainsArgs {
    /**
     * Account Identifier
     */
    accountId: pulumi.Input<string>;
    bodies?: pulumi.Input<pulumi.Input<inputs.EmailSecurityTrustedDomainsBody>[]>;
    comments?: pulumi.Input<string>;
    /**
     * Select to prevent recently registered domains from triggering a
     * Suspicious or Malicious disposition.
     */
    isRecent?: pulumi.Input<boolean>;
    isRegex?: pulumi.Input<boolean>;
    /**
     * Select for partner or other approved domains that have similar
     * spelling to your connected domains. Prevents listed domains from
     * triggering a Spoof disposition.
     */
    isSimilarity?: pulumi.Input<boolean>;
    pattern?: pulumi.Input<string>;
}
