import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccount = cloudflare.getAccount({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 * });
 * ```
 */
export declare function getAccount(args?: GetAccountArgs, opts?: pulumi.InvokeOptions): Promise<GetAccountResult>;
/**
 * A collection of arguments for invoking getAccount.
 */
export interface GetAccountArgs {
    /**
     * Account identifier tag.
     */
    accountId?: string;
    filter?: inputs.GetAccountFilter;
}
/**
 * A collection of values returned by getAccount.
 */
export interface GetAccountResult {
    /**
     * Account identifier tag.
     */
    readonly accountId?: string;
    /**
     * Timestamp for the creation of the account
     */
    readonly createdOn: string;
    readonly filter?: outputs.GetAccountFilter;
    /**
     * Account identifier tag.
     */
    readonly id: string;
    /**
     * Account name
     */
    readonly name: string;
    /**
     * Account settings
     */
    readonly settings: outputs.GetAccountSettings;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccount = cloudflare.getAccount({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 * });
 * ```
 */
export declare function getAccountOutput(args?: GetAccountOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAccountResult>;
/**
 * A collection of arguments for invoking getAccount.
 */
export interface GetAccountOutputArgs {
    /**
     * Account identifier tag.
     */
    accountId?: pulumi.Input<string>;
    filter?: pulumi.Input<inputs.GetAccountFilterArgs>;
}
