import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountMembers = cloudflare.getAccountMembers({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     direction: "desc",
 *     order: "status",
 *     status: "accepted",
 * });
 * ```
 */
export declare function getAccountMembers(args: GetAccountMembersArgs, opts?: pulumi.InvokeOptions): Promise<GetAccountMembersResult>;
/**
 * A collection of arguments for invoking getAccountMembers.
 */
export interface GetAccountMembersArgs {
    /**
     * Account identifier tag.
     */
    accountId: string;
    /**
     * Direction to order results.
     * Available values: "asc", "desc".
     */
    direction?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Field to order results by.
     * Available values: "user.first*name", "user.last*name", "user.email", "status".
     */
    order?: string;
    /**
     * A member's status in the account.
     * Available values: "accepted", "pending", "rejected".
     */
    status?: string;
}
/**
 * A collection of values returned by getAccountMembers.
 */
export interface GetAccountMembersResult {
    /**
     * Account identifier tag.
     */
    readonly accountId: string;
    /**
     * Direction to order results.
     * Available values: "asc", "desc".
     */
    readonly direction?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * Field to order results by.
     * Available values: "user.first*name", "user.last*name", "user.email", "status".
     */
    readonly order?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetAccountMembersResult[];
    /**
     * A member's status in the account.
     * Available values: "accepted", "pending", "rejected".
     */
    readonly status?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountMembers = cloudflare.getAccountMembers({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     direction: "desc",
 *     order: "status",
 *     status: "accepted",
 * });
 * ```
 */
export declare function getAccountMembersOutput(args: GetAccountMembersOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAccountMembersResult>;
/**
 * A collection of arguments for invoking getAccountMembers.
 */
export interface GetAccountMembersOutputArgs {
    /**
     * Account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * Direction to order results.
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Field to order results by.
     * Available values: "user.first*name", "user.last*name", "user.email", "status".
     */
    order?: pulumi.Input<string>;
    /**
     * A member's status in the account.
     * Available values: "accepted", "pending", "rejected".
     */
    status?: pulumi.Input<string>;
}
