import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountPermissionGroup = cloudflare.getAccountPermissionGroup({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     permissionGroupId: "6d7f2f5f5b1d4a0e9081fdc98d432fd1",
 * });
 * ```
 */
export declare function getAccountPermissionGroup(args: GetAccountPermissionGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetAccountPermissionGroupResult>;
/**
 * A collection of arguments for invoking getAccountPermissionGroup.
 */
export interface GetAccountPermissionGroupArgs {
    /**
     * Account identifier tag.
     */
    accountId: string;
    /**
     * Permission Group identifier tag.
     */
    permissionGroupId: string;
}
/**
 * A collection of values returned by getAccountPermissionGroup.
 */
export interface GetAccountPermissionGroupResult {
    /**
     * Account identifier tag.
     */
    readonly accountId: string;
    /**
     * Identifier of the group.
     */
    readonly id: string;
    /**
     * Attributes associated to the permission group.
     */
    readonly meta: outputs.GetAccountPermissionGroupMeta;
    /**
     * Name of the group.
     */
    readonly name: string;
    /**
     * Permission Group identifier tag.
     */
    readonly permissionGroupId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountPermissionGroup = cloudflare.getAccountPermissionGroup({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     permissionGroupId: "6d7f2f5f5b1d4a0e9081fdc98d432fd1",
 * });
 * ```
 */
export declare function getAccountPermissionGroupOutput(args: GetAccountPermissionGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAccountPermissionGroupResult>;
/**
 * A collection of arguments for invoking getAccountPermissionGroup.
 */
export interface GetAccountPermissionGroupOutputArgs {
    /**
     * Account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * Permission Group identifier tag.
     */
    permissionGroupId: pulumi.Input<string>;
}
