import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountPermissionGroups = cloudflare.getAccountPermissionGroups({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     id: "6d7f2f5f5b1d4a0e9081fdc98d432fd1",
 *     label: "labelOfThePermissionGroup",
 *     name: "NameOfThePermissionGroup",
 * });
 * ```
 */
export declare function getAccountPermissionGroups(args: GetAccountPermissionGroupsArgs, opts?: pulumi.InvokeOptions): Promise<GetAccountPermissionGroupsResult>;
/**
 * A collection of arguments for invoking getAccountPermissionGroups.
 */
export interface GetAccountPermissionGroupsArgs {
    /**
     * Account identifier tag.
     */
    accountId: string;
    /**
     * ID of the permission group to be fetched.
     */
    id?: string;
    /**
     * Label of the permission group to be fetched.
     */
    label?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Name of the permission group to be fetched.
     */
    name?: string;
}
/**
 * A collection of values returned by getAccountPermissionGroups.
 */
export interface GetAccountPermissionGroupsResult {
    /**
     * Account identifier tag.
     */
    readonly accountId: string;
    /**
     * ID of the permission group to be fetched.
     */
    readonly id?: string;
    /**
     * Label of the permission group to be fetched.
     */
    readonly label?: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * Name of the permission group to be fetched.
     */
    readonly name?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetAccountPermissionGroupsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountPermissionGroups = cloudflare.getAccountPermissionGroups({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     id: "6d7f2f5f5b1d4a0e9081fdc98d432fd1",
 *     label: "labelOfThePermissionGroup",
 *     name: "NameOfThePermissionGroup",
 * });
 * ```
 */
export declare function getAccountPermissionGroupsOutput(args: GetAccountPermissionGroupsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAccountPermissionGroupsResult>;
/**
 * A collection of arguments for invoking getAccountPermissionGroups.
 */
export interface GetAccountPermissionGroupsOutputArgs {
    /**
     * Account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * ID of the permission group to be fetched.
     */
    id?: pulumi.Input<string>;
    /**
     * Label of the permission group to be fetched.
     */
    label?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Name of the permission group to be fetched.
     */
    name?: pulumi.Input<string>;
}
