import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountRole = cloudflare.getAccountRole({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     roleId: "3536bcfad5faccb999b47003c79917fb",
 * });
 * ```
 */
export declare function getAccountRole(args: GetAccountRoleArgs, opts?: pulumi.InvokeOptions): Promise<GetAccountRoleResult>;
/**
 * A collection of arguments for invoking getAccountRole.
 */
export interface GetAccountRoleArgs {
    /**
     * Account identifier tag.
     */
    accountId: string;
    /**
     * Role identifier tag.
     */
    roleId: string;
}
/**
 * A collection of values returned by getAccountRole.
 */
export interface GetAccountRoleResult {
    /**
     * Account identifier tag.
     */
    readonly accountId: string;
    /**
     * Description of role's permissions.
     */
    readonly description: string;
    /**
     * Role identifier tag.
     */
    readonly id: string;
    /**
     * Role name.
     */
    readonly name: string;
    readonly permissions: outputs.GetAccountRolePermissions;
    /**
     * Role identifier tag.
     */
    readonly roleId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountRole = cloudflare.getAccountRole({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     roleId: "3536bcfad5faccb999b47003c79917fb",
 * });
 * ```
 */
export declare function getAccountRoleOutput(args: GetAccountRoleOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAccountRoleResult>;
/**
 * A collection of arguments for invoking getAccountRole.
 */
export interface GetAccountRoleOutputArgs {
    /**
     * Account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * Role identifier tag.
     */
    roleId: pulumi.Input<string>;
}
