import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountRoles = cloudflare.getAccountRoles({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 * });
 * ```
 */
export declare function getAccountRoles(args: GetAccountRolesArgs, opts?: pulumi.InvokeOptions): Promise<GetAccountRolesResult>;
/**
 * A collection of arguments for invoking getAccountRoles.
 */
export interface GetAccountRolesArgs {
    /**
     * Account identifier tag.
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getAccountRoles.
 */
export interface GetAccountRolesResult {
    /**
     * Account identifier tag.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetAccountRolesResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountRoles = cloudflare.getAccountRoles({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 * });
 * ```
 */
export declare function getAccountRolesOutput(args: GetAccountRolesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAccountRolesResult>;
/**
 * A collection of arguments for invoking getAccountRoles.
 */
export interface GetAccountRolesOutputArgs {
    /**
     * Account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
