import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountSubscription = cloudflare.getAccountSubscription({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getAccountSubscription(args: GetAccountSubscriptionArgs, opts?: pulumi.InvokeOptions): Promise<GetAccountSubscriptionResult>;
/**
 * A collection of arguments for invoking getAccountSubscription.
 */
export interface GetAccountSubscriptionArgs {
    /**
     * Identifier
     */
    accountId: string;
}
/**
 * A collection of values returned by getAccountSubscription.
 */
export interface GetAccountSubscriptionResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * The monetary unit in which pricing information is displayed.
     */
    readonly currency: string;
    /**
     * The end of the current period and also when the next billing is due.
     */
    readonly currentPeriodEnd: string;
    /**
     * When the current billing period started. May match initial*period*start if this is the first period.
     */
    readonly currentPeriodStart: string;
    /**
     * How often the subscription is renewed automatically.
     * Available values: "weekly", "monthly", "quarterly", "yearly".
     */
    readonly frequency: string;
    /**
     * Subscription identifier tag.
     */
    readonly id: string;
    /**
     * The price of the subscription that will be billed, in US dollars.
     */
    readonly price: number;
    /**
     * The rate plan applied to the subscription.
     */
    readonly ratePlan: outputs.GetAccountSubscriptionRatePlan;
    /**
     * The state that the subscription is in.
     * Available values: "Trial", "Provisioned", "Paid", "AwaitingPayment", "Cancelled", "Failed", "Expired".
     */
    readonly state: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountSubscription = cloudflare.getAccountSubscription({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getAccountSubscriptionOutput(args: GetAccountSubscriptionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAccountSubscriptionResult>;
/**
 * A collection of arguments for invoking getAccountSubscription.
 */
export interface GetAccountSubscriptionOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
}
