import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountTokens = cloudflare.getAccountTokens({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     direction: "desc",
 * });
 * ```
 */
export declare function getAccountTokens(args: GetAccountTokensArgs, opts?: pulumi.InvokeOptions): Promise<GetAccountTokensResult>;
/**
 * A collection of arguments for invoking getAccountTokens.
 */
export interface GetAccountTokensArgs {
    /**
     * Account identifier tag.
     */
    accountId: string;
    /**
     * Direction to order results.
     * Available values: "asc", "desc".
     */
    direction?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getAccountTokens.
 */
export interface GetAccountTokensResult {
    /**
     * Account identifier tag.
     */
    readonly accountId: string;
    /**
     * Direction to order results.
     * Available values: "asc", "desc".
     */
    readonly direction?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetAccountTokensResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAccountTokens = cloudflare.getAccountTokens({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     direction: "desc",
 * });
 * ```
 */
export declare function getAccountTokensOutput(args: GetAccountTokensOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAccountTokensResult>;
/**
 * A collection of arguments for invoking getAccountTokens.
 */
export interface GetAccountTokensOutputArgs {
    /**
     * Account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * Direction to order results.
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
