import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAddressMap = cloudflare.getAddressMap({
 *     accountId: "258def64c72dae45f3e4c8516e2111f2",
 *     addressMapId: "055817b111884e0227e1be16a0be6ee0",
 * });
 * ```
 */
export declare function getAddressMap(args: GetAddressMapArgs, opts?: pulumi.InvokeOptions): Promise<GetAddressMapResult>;
/**
 * A collection of arguments for invoking getAddressMap.
 */
export interface GetAddressMapArgs {
    /**
     * Identifier of a Cloudflare account.
     */
    accountId: string;
    /**
     * Identifier of an Address Map.
     */
    addressMapId?: string;
}
/**
 * A collection of values returned by getAddressMap.
 */
export interface GetAddressMapResult {
    /**
     * Identifier of a Cloudflare account.
     */
    readonly accountId: string;
    /**
     * Identifier of an Address Map.
     */
    readonly addressMapId?: string;
    /**
     * If set to false, then the Address Map cannot be deleted via API. This is true for Cloudflare-managed maps.
     */
    readonly canDelete: boolean;
    /**
     * If set to false, then the IPs on the Address Map cannot be modified via the API. This is true for Cloudflare-managed maps.
     */
    readonly canModifyIps: boolean;
    readonly createdAt: string;
    /**
     * If you have legacy TLS clients which do not send the TLS server name indicator, then you can specify one default SNI on the map. If Cloudflare receives a TLS handshake from a client without an SNI, it will respond with the default SNI on those IPs. The default SNI can be any valid zone or subdomain owned by the account.
     */
    readonly defaultSni: string;
    /**
     * An optional description field which may be used to describe the types of IPs or zones on the map.
     */
    readonly description: string;
    /**
     * Whether the Address Map is enabled or not. Cloudflare's DNS will not respond with IP addresses on an Address Map until the map is enabled.
     */
    readonly enabled: boolean;
    /**
     * Identifier of an Address Map.
     */
    readonly id: string;
    /**
     * The set of IPs on the Address Map.
     */
    readonly ips: outputs.GetAddressMapIp[];
    /**
     * Zones and Accounts which will be assigned IPs on this Address Map. A zone membership will take priority over an account membership.
     */
    readonly memberships: outputs.GetAddressMapMembership[];
    readonly modifiedAt: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAddressMap = cloudflare.getAddressMap({
 *     accountId: "258def64c72dae45f3e4c8516e2111f2",
 *     addressMapId: "055817b111884e0227e1be16a0be6ee0",
 * });
 * ```
 */
export declare function getAddressMapOutput(args: GetAddressMapOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAddressMapResult>;
/**
 * A collection of arguments for invoking getAddressMap.
 */
export interface GetAddressMapOutputArgs {
    /**
     * Identifier of a Cloudflare account.
     */
    accountId: pulumi.Input<string>;
    /**
     * Identifier of an Address Map.
     */
    addressMapId?: pulumi.Input<string>;
}
