import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAddressMaps = cloudflare.getAddressMaps({
 *     accountId: "258def64c72dae45f3e4c8516e2111f2",
 * });
 * ```
 */
export declare function getAddressMaps(args: GetAddressMapsArgs, opts?: pulumi.InvokeOptions): Promise<GetAddressMapsResult>;
/**
 * A collection of arguments for invoking getAddressMaps.
 */
export interface GetAddressMapsArgs {
    /**
     * Identifier of a Cloudflare account.
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getAddressMaps.
 */
export interface GetAddressMapsResult {
    /**
     * Identifier of a Cloudflare account.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetAddressMapsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleAddressMaps = cloudflare.getAddressMaps({
 *     accountId: "258def64c72dae45f3e4c8516e2111f2",
 * });
 * ```
 */
export declare function getAddressMapsOutput(args: GetAddressMapsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAddressMapsResult>;
/**
 * A collection of arguments for invoking getAddressMaps.
 */
export interface GetAddressMapsOutputArgs {
    /**
     * Identifier of a Cloudflare account.
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
