import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleApiShield = cloudflare.getApiShield({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     properties: ["auth_id_characteristics"],
 * });
 * ```
 */
export declare function getApiShield(args: GetApiShieldArgs, opts?: pulumi.InvokeOptions): Promise<GetApiShieldResult>;
/**
 * A collection of arguments for invoking getApiShield.
 */
export interface GetApiShieldArgs {
    /**
     * Requests information about certain properties.
     */
    properties?: string[];
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getApiShield.
 */
export interface GetApiShieldResult {
    readonly authIdCharacteristics: outputs.GetApiShieldAuthIdCharacteristic[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Requests information about certain properties.
     */
    readonly properties?: string[];
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleApiShield = cloudflare.getApiShield({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     properties: ["auth_id_characteristics"],
 * });
 * ```
 */
export declare function getApiShieldOutput(args: GetApiShieldOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApiShieldResult>;
/**
 * A collection of arguments for invoking getApiShield.
 */
export interface GetApiShieldOutputArgs {
    /**
     * Requests information about certain properties.
     */
    properties?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
