import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 */
export declare function getApiShieldOperation(args: GetApiShieldOperationArgs, opts?: pulumi.InvokeOptions): Promise<GetApiShieldOperationResult>;
/**
 * A collection of arguments for invoking getApiShieldOperation.
 */
export interface GetApiShieldOperationArgs {
    /**
     * Add feature(s) to the results. The feature name that is given here corresponds to the resulting feature object. Have a look at the top-level object description for more details on the specific meaning.
     */
    feature?: string[];
    filter?: inputs.GetApiShieldOperationFilter;
    /**
     * UUID.
     */
    operationId?: string;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getApiShieldOperation.
 */
export interface GetApiShieldOperationResult {
    /**
     * The endpoint which can contain path parameter templates in curly braces, each will be replaced from left to right with {varN}, starting with {var1}, during insertion. This will further be Cloudflare-normalized upon insertion. See: https://developers.cloudflare.com/rules/normalization/how-it-works/.
     */
    readonly endpoint: string;
    /**
     * Add feature(s) to the results. The feature name that is given here corresponds to the resulting feature object. Have a look at the top-level object description for more details on the specific meaning.
     */
    readonly feature?: string[];
    readonly features: outputs.GetApiShieldOperationFeatures;
    readonly filter?: outputs.GetApiShieldOperationFilter;
    /**
     * RFC3986-compliant host.
     */
    readonly host: string;
    /**
     * UUID.
     */
    readonly id: string;
    readonly lastUpdated: string;
    /**
     * The HTTP method used to access the endpoint.
     * Available values: "GET", "POST", "HEAD", "OPTIONS", "PUT", "DELETE", "CONNECT", "PATCH", "TRACE".
     */
    readonly method: string;
    /**
     * UUID.
     */
    readonly operationId: string;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 */
export declare function getApiShieldOperationOutput(args: GetApiShieldOperationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApiShieldOperationResult>;
/**
 * A collection of arguments for invoking getApiShieldOperation.
 */
export interface GetApiShieldOperationOutputArgs {
    /**
     * Add feature(s) to the results. The feature name that is given here corresponds to the resulting feature object. Have a look at the top-level object description for more details on the specific meaning.
     */
    feature?: pulumi.Input<pulumi.Input<string>[]>;
    filter?: pulumi.Input<inputs.GetApiShieldOperationFilterArgs>;
    /**
     * UUID.
     */
    operationId?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
