import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleApiShieldOperations = cloudflare.getApiShieldOperations({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "desc",
 *     endpoint: "/api/v1",
 *     features: ["thresholds"],
 *     hosts: ["api.cloudflare.com"],
 *     methods: ["GET"],
 *     order: "method",
 * });
 * ```
 */
export declare function getApiShieldOperations(args: GetApiShieldOperationsArgs, opts?: pulumi.InvokeOptions): Promise<GetApiShieldOperationsResult>;
/**
 * A collection of arguments for invoking getApiShieldOperations.
 */
export interface GetApiShieldOperationsArgs {
    /**
     * Direction to order results.
     * Available values: "asc", "desc".
     */
    direction?: string;
    /**
     * Filter results to only include endpoints containing this pattern.
     */
    endpoint?: string;
    /**
     * Add feature(s) to the results. The feature name that is given here corresponds to the resulting feature object. Have a look at the top-level object description for more details on the specific meaning.
     */
    features?: string[];
    /**
     * Filter results to only include the specified hosts.
     */
    hosts?: string[];
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Filter results to only include the specified HTTP methods.
     */
    methods?: string[];
    /**
     * Field to order by. When requesting a feature, the feature keys are available for ordering as well, e.g., `thresholds.suggested_threshold`.
     * Available values: "method", "host", "endpoint", "thresholds.$key".
     */
    order?: string;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getApiShieldOperations.
 */
export interface GetApiShieldOperationsResult {
    /**
     * Direction to order results.
     * Available values: "asc", "desc".
     */
    readonly direction?: string;
    /**
     * Filter results to only include endpoints containing this pattern.
     */
    readonly endpoint?: string;
    /**
     * Add feature(s) to the results. The feature name that is given here corresponds to the resulting feature object. Have a look at the top-level object description for more details on the specific meaning.
     */
    readonly features?: string[];
    /**
     * Filter results to only include the specified hosts.
     */
    readonly hosts?: string[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * Filter results to only include the specified HTTP methods.
     */
    readonly methods?: string[];
    /**
     * Field to order by. When requesting a feature, the feature keys are available for ordering as well, e.g., `thresholds.suggested_threshold`.
     * Available values: "method", "host", "endpoint", "thresholds.$key".
     */
    readonly order?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetApiShieldOperationsResult[];
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleApiShieldOperations = cloudflare.getApiShieldOperations({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "desc",
 *     endpoint: "/api/v1",
 *     features: ["thresholds"],
 *     hosts: ["api.cloudflare.com"],
 *     methods: ["GET"],
 *     order: "method",
 * });
 * ```
 */
export declare function getApiShieldOperationsOutput(args: GetApiShieldOperationsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApiShieldOperationsResult>;
/**
 * A collection of arguments for invoking getApiShieldOperations.
 */
export interface GetApiShieldOperationsOutputArgs {
    /**
     * Direction to order results.
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    /**
     * Filter results to only include endpoints containing this pattern.
     */
    endpoint?: pulumi.Input<string>;
    /**
     * Add feature(s) to the results. The feature name that is given here corresponds to the resulting feature object. Have a look at the top-level object description for more details on the specific meaning.
     */
    features?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Filter results to only include the specified hosts.
     */
    hosts?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Filter results to only include the specified HTTP methods.
     */
    methods?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Field to order by. When requesting a feature, the feature keys are available for ordering as well, e.g., `thresholds.suggested_threshold`.
     * Available values: "method", "host", "endpoint", "thresholds.$key".
     */
    order?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
