import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleApiShieldSchema = cloudflare.getApiShieldSchema({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     schemaId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 *     omitSource: true,
 * });
 * ```
 */
export declare function getApiShieldSchema(args: GetApiShieldSchemaArgs, opts?: pulumi.InvokeOptions): Promise<GetApiShieldSchemaResult>;
/**
 * A collection of arguments for invoking getApiShieldSchema.
 */
export interface GetApiShieldSchemaArgs {
    /**
     * Omit the source-files of schemas and only retrieve their meta-data.
     */
    omitSource?: boolean;
    schemaId: string;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getApiShieldSchema.
 */
export interface GetApiShieldSchemaResult {
    readonly createdAt: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Kind of schema
     * Available values: "openapiV3".
     */
    readonly kind: string;
    /**
     * Name of the schema
     */
    readonly name: string;
    /**
     * Omit the source-files of schemas and only retrieve their meta-data.
     */
    readonly omitSource: boolean;
    readonly schemaId: string;
    /**
     * Source of the schema
     */
    readonly source: string;
    /**
     * Flag whether schema is enabled for validation.
     */
    readonly validationEnabled: boolean;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleApiShieldSchema = cloudflare.getApiShieldSchema({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     schemaId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 *     omitSource: true,
 * });
 * ```
 */
export declare function getApiShieldSchemaOutput(args: GetApiShieldSchemaOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApiShieldSchemaResult>;
/**
 * A collection of arguments for invoking getApiShieldSchema.
 */
export interface GetApiShieldSchemaOutputArgs {
    /**
     * Omit the source-files of schemas and only retrieve their meta-data.
     */
    omitSource?: pulumi.Input<boolean>;
    schemaId: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
