import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleApiShieldSchemas = cloudflare.getApiShieldSchemas({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     validationEnabled: true,
 * });
 * ```
 */
export declare function getApiShieldSchemas(args: GetApiShieldSchemasArgs, opts?: pulumi.InvokeOptions): Promise<GetApiShieldSchemasResult>;
/**
 * A collection of arguments for invoking getApiShieldSchemas.
 */
export interface GetApiShieldSchemasArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Omit the source-files of schemas and only retrieve their meta-data.
     */
    omitSource?: boolean;
    /**
     * Flag whether schema is enabled for validation.
     */
    validationEnabled?: boolean;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getApiShieldSchemas.
 */
export interface GetApiShieldSchemasResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * Omit the source-files of schemas and only retrieve their meta-data.
     */
    readonly omitSource: boolean;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetApiShieldSchemasResult[];
    /**
     * Flag whether schema is enabled for validation.
     */
    readonly validationEnabled?: boolean;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleApiShieldSchemas = cloudflare.getApiShieldSchemas({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     validationEnabled: true,
 * });
 * ```
 */
export declare function getApiShieldSchemasOutput(args: GetApiShieldSchemasOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApiShieldSchemasResult>;
/**
 * A collection of arguments for invoking getApiShieldSchemas.
 */
export interface GetApiShieldSchemasOutputArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Omit the source-files of schemas and only retrieve their meta-data.
     */
    omitSource?: pulumi.Input<boolean>;
    /**
     * Flag whether schema is enabled for validation.
     */
    validationEnabled?: pulumi.Input<boolean>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
