import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleApiTokens = cloudflare.getApiTokens({
 *     direction: "desc",
 * });
 * ```
 */
export declare function getApiTokens(args?: GetApiTokensArgs, opts?: pulumi.InvokeOptions): Promise<GetApiTokensResult>;
/**
 * A collection of arguments for invoking getApiTokens.
 */
export interface GetApiTokensArgs {
    /**
     * Direction to order results.
     * Available values: "asc", "desc".
     */
    direction?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getApiTokens.
 */
export interface GetApiTokensResult {
    /**
     * Direction to order results.
     * Available values: "asc", "desc".
     */
    readonly direction?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetApiTokensResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleApiTokens = cloudflare.getApiTokens({
 *     direction: "desc",
 * });
 * ```
 */
export declare function getApiTokensOutput(args?: GetApiTokensOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApiTokensResult>;
/**
 * A collection of arguments for invoking getApiTokens.
 */
export interface GetApiTokensOutputArgs {
    /**
     * Direction to order results.
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
