import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleBotManagement = cloudflare.getBotManagement({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getBotManagement(args: GetBotManagementArgs, opts?: pulumi.InvokeOptions): Promise<GetBotManagementResult>;
/**
 * A collection of arguments for invoking getBotManagement.
 */
export interface GetBotManagementArgs {
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getBotManagement.
 */
export interface GetBotManagementResult {
    /**
     * Enable rule to block AI Scrapers and Crawlers.
     * Available values: "block", "disabled".
     */
    readonly aiBotsProtection: string;
    /**
     * Automatically update to the newest bot detection models created by Cloudflare as they are released. [Learn more.](https://developers.cloudflare.com/bots/reference/machine-learning-models#model-versions-and-release-notes)
     */
    readonly autoUpdateModel: boolean;
    /**
     * Enable rule to punish AI Scrapers and Crawlers via a link maze.
     * Available values: "enabled", "disabled".
     */
    readonly crawlerProtection: string;
    /**
     * Use lightweight, invisible JavaScript detections to improve Bot Management. [Learn more about JavaScript Detections](https://developers.cloudflare.com/bots/reference/javascript-detections/).
     */
    readonly enableJs: boolean;
    /**
     * Whether to enable Bot Fight Mode.
     */
    readonly fightMode: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Whether to optimize Super Bot Fight Mode protections for Wordpress.
     */
    readonly optimizeWordpress: boolean;
    /**
     * Super Bot Fight Mode (SBFM) action to take on definitely automated requests.
     * Available values: "allow", "block", "managedChallenge".
     */
    readonly sbfmDefinitelyAutomated: string;
    /**
     * Super Bot Fight Mode (SBFM) action to take on likely automated requests.
     * Available values: "allow", "block", "managedChallenge".
     */
    readonly sbfmLikelyAutomated: string;
    /**
     * Super Bot Fight Mode (SBFM) to enable static resource protection.
     * Enable if static resources on your application need bot protection.
     * Note: Static resource protection can also result in legitimate traffic being blocked.
     */
    readonly sbfmStaticResourceProtection: boolean;
    /**
     * Super Bot Fight Mode (SBFM) action to take on verified bots requests.
     * Available values: "allow", "block".
     */
    readonly sbfmVerifiedBots: string;
    /**
     * A read-only field that shows which unauthorized settings are currently active on the zone. These settings typically result from upgrades or downgrades.
     */
    readonly staleZoneConfiguration: outputs.GetBotManagementStaleZoneConfiguration;
    /**
     * Whether to disable tracking the highest bot score for a session in the Bot Management cookie.
     */
    readonly suppressSessionScore: boolean;
    /**
     * A read-only field that indicates whether the zone currently is running the latest ML model.
     */
    readonly usingLatestModel: boolean;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleBotManagement = cloudflare.getBotManagement({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getBotManagementOutput(args: GetBotManagementOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetBotManagementResult>;
/**
 * A collection of arguments for invoking getBotManagement.
 */
export interface GetBotManagementOutputArgs {
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
