import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleByoIpPrefixes = cloudflare.getByoIpPrefixes({
 *     accountId: "258def64c72dae45f3e4c8516e2111f2",
 * });
 * ```
 */
export declare function getByoIpPrefixes(args: GetByoIpPrefixesArgs, opts?: pulumi.InvokeOptions): Promise<GetByoIpPrefixesResult>;
/**
 * A collection of arguments for invoking getByoIpPrefixes.
 */
export interface GetByoIpPrefixesArgs {
    /**
     * Identifier of a Cloudflare account.
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getByoIpPrefixes.
 */
export interface GetByoIpPrefixesResult {
    /**
     * Identifier of a Cloudflare account.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetByoIpPrefixesResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleByoIpPrefixes = cloudflare.getByoIpPrefixes({
 *     accountId: "258def64c72dae45f3e4c8516e2111f2",
 * });
 * ```
 */
export declare function getByoIpPrefixesOutput(args: GetByoIpPrefixesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetByoIpPrefixesResult>;
/**
 * A collection of arguments for invoking getByoIpPrefixes.
 */
export interface GetByoIpPrefixesOutputArgs {
    /**
     * Identifier of a Cloudflare account.
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
