import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCallsSfuApp = cloudflare.getCallsSfuApp({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     appId: "2a95132c15732412d22c1476fa83f27a",
 * });
 * ```
 */
export declare function getCallsSfuApp(args: GetCallsSfuAppArgs, opts?: pulumi.InvokeOptions): Promise<GetCallsSfuAppResult>;
/**
 * A collection of arguments for invoking getCallsSfuApp.
 */
export interface GetCallsSfuAppArgs {
    /**
     * The account identifier tag.
     */
    accountId: string;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    appId: string;
}
/**
 * A collection of values returned by getCallsSfuApp.
 */
export interface GetCallsSfuAppResult {
    /**
     * The account identifier tag.
     */
    readonly accountId: string;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    readonly appId: string;
    /**
     * The date and time the item was created.
     */
    readonly created: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The date and time the item was last modified.
     */
    readonly modified: string;
    /**
     * A short description of Calls app, not shown to end users.
     */
    readonly name: string;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    readonly uid: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCallsSfuApp = cloudflare.getCallsSfuApp({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     appId: "2a95132c15732412d22c1476fa83f27a",
 * });
 * ```
 */
export declare function getCallsSfuAppOutput(args: GetCallsSfuAppOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCallsSfuAppResult>;
/**
 * A collection of arguments for invoking getCallsSfuApp.
 */
export interface GetCallsSfuAppOutputArgs {
    /**
     * The account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    appId: pulumi.Input<string>;
}
