import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCallsSfuApps = cloudflare.getCallsSfuApps({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getCallsSfuApps(args: GetCallsSfuAppsArgs, opts?: pulumi.InvokeOptions): Promise<GetCallsSfuAppsResult>;
/**
 * A collection of arguments for invoking getCallsSfuApps.
 */
export interface GetCallsSfuAppsArgs {
    /**
     * The account identifier tag.
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getCallsSfuApps.
 */
export interface GetCallsSfuAppsResult {
    /**
     * The account identifier tag.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetCallsSfuAppsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCallsSfuApps = cloudflare.getCallsSfuApps({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getCallsSfuAppsOutput(args: GetCallsSfuAppsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCallsSfuAppsResult>;
/**
 * A collection of arguments for invoking getCallsSfuApps.
 */
export interface GetCallsSfuAppsOutputArgs {
    /**
     * The account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
