import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCallsTurnApp = cloudflare.getCallsTurnApp({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     keyId: "2a95132c15732412d22c1476fa83f27a",
 * });
 * ```
 */
export declare function getCallsTurnApp(args: GetCallsTurnAppArgs, opts?: pulumi.InvokeOptions): Promise<GetCallsTurnAppResult>;
/**
 * A collection of arguments for invoking getCallsTurnApp.
 */
export interface GetCallsTurnAppArgs {
    /**
     * The account identifier tag.
     */
    accountId: string;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    keyId: string;
}
/**
 * A collection of values returned by getCallsTurnApp.
 */
export interface GetCallsTurnAppResult {
    /**
     * The account identifier tag.
     */
    readonly accountId: string;
    /**
     * The date and time the item was created.
     */
    readonly created: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    readonly keyId: string;
    /**
     * The date and time the item was last modified.
     */
    readonly modified: string;
    /**
     * A short description of Calls app, not shown to end users.
     */
    readonly name: string;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    readonly uid: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCallsTurnApp = cloudflare.getCallsTurnApp({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     keyId: "2a95132c15732412d22c1476fa83f27a",
 * });
 * ```
 */
export declare function getCallsTurnAppOutput(args: GetCallsTurnAppOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCallsTurnAppResult>;
/**
 * A collection of arguments for invoking getCallsTurnApp.
 */
export interface GetCallsTurnAppOutputArgs {
    /**
     * The account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * A Cloudflare-generated unique identifier for a item.
     */
    keyId: pulumi.Input<string>;
}
