import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCallsTurnApps = cloudflare.getCallsTurnApps({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getCallsTurnApps(args: GetCallsTurnAppsArgs, opts?: pulumi.InvokeOptions): Promise<GetCallsTurnAppsResult>;
/**
 * A collection of arguments for invoking getCallsTurnApps.
 */
export interface GetCallsTurnAppsArgs {
    /**
     * The account identifier tag.
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getCallsTurnApps.
 */
export interface GetCallsTurnAppsResult {
    /**
     * The account identifier tag.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetCallsTurnAppsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCallsTurnApps = cloudflare.getCallsTurnApps({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getCallsTurnAppsOutput(args: GetCallsTurnAppsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCallsTurnAppsResult>;
/**
 * A collection of arguments for invoking getCallsTurnApps.
 */
export interface GetCallsTurnAppsOutputArgs {
    /**
     * The account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
