import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCertificatePacks = cloudflare.getCertificatePacks({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     status: "all",
 * });
 * ```
 */
export declare function getCertificatePacks(args: GetCertificatePacksArgs, opts?: pulumi.InvokeOptions): Promise<GetCertificatePacksResult>;
/**
 * A collection of arguments for invoking getCertificatePacks.
 */
export interface GetCertificatePacksArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Include Certificate Packs of all statuses, not just active ones.
     * Available values: "all".
     */
    status?: string;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getCertificatePacks.
 */
export interface GetCertificatePacksResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetCertificatePacksResult[];
    /**
     * Include Certificate Packs of all statuses, not just active ones.
     * Available values: "all".
     */
    readonly status?: string;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCertificatePacks = cloudflare.getCertificatePacks({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     status: "all",
 * });
 * ```
 */
export declare function getCertificatePacksOutput(args: GetCertificatePacksOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCertificatePacksResult>;
/**
 * A collection of arguments for invoking getCertificatePacks.
 */
export interface GetCertificatePacksOutputArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Include Certificate Packs of all statuses, not just active ones.
     * Available values: "all".
     */
    status?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
