import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCloudforceOneRequestMessage = cloudflare.getCloudforceOneRequestMessage({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     requestId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 *     page: 0,
 *     perPage: 10,
 *     after: "2022-04-01T05:20:00Z",
 *     before: "2024-01-01T00:00:00Z",
 *     sortBy: "created",
 *     sortOrder: "asc",
 * });
 * ```
 */
export declare function getCloudforceOneRequestMessage(args: GetCloudforceOneRequestMessageArgs, opts?: pulumi.InvokeOptions): Promise<GetCloudforceOneRequestMessageResult>;
/**
 * A collection of arguments for invoking getCloudforceOneRequestMessage.
 */
export interface GetCloudforceOneRequestMessageArgs {
    /**
     * Identifier.
     */
    accountId: string;
    /**
     * Retrieve mes  ges created after this time.
     */
    after?: string;
    /**
     * Retrieve messages created before this time.
     */
    before?: string;
    /**
     * Page number of results.
     */
    page: number;
    /**
     * Number of results per page.
     */
    perPage: number;
    /**
     * UUID.
     */
    requestId: string;
    /**
     * Field to sort results by.
     */
    sortBy?: string;
    /**
     * Sort order (asc or desc).
     * Available values: "asc", "desc".
     */
    sortOrder?: string;
}
/**
 * A collection of values returned by getCloudforceOneRequestMessage.
 */
export interface GetCloudforceOneRequestMessageResult {
    /**
     * Identifier.
     */
    readonly accountId: string;
    /**
     * Retrieve mes  ges created after this time.
     */
    readonly after?: string;
    /**
     * Author of message.
     */
    readonly author: string;
    /**
     * Retrieve messages created before this time.
     */
    readonly before?: string;
    /**
     * Content of message.
     */
    readonly content: string;
    /**
     * Defines the message creation time.
     */
    readonly created: string;
    /**
     * Message ID.
     */
    readonly id: number;
    /**
     * Whether the message is a follow-on request.
     */
    readonly isFollowOnRequest: boolean;
    /**
     * Page number of results.
     */
    readonly page: number;
    /**
     * Number of results per page.
     */
    readonly perPage: number;
    /**
     * UUID.
     */
    readonly requestId: string;
    /**
     * Field to sort results by.
     */
    readonly sortBy?: string;
    /**
     * Sort order (asc or desc).
     * Available values: "asc", "desc".
     */
    readonly sortOrder?: string;
    /**
     * Defines the message last updated time.
     */
    readonly updated: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCloudforceOneRequestMessage = cloudflare.getCloudforceOneRequestMessage({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     requestId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 *     page: 0,
 *     perPage: 10,
 *     after: "2022-04-01T05:20:00Z",
 *     before: "2024-01-01T00:00:00Z",
 *     sortBy: "created",
 *     sortOrder: "asc",
 * });
 * ```
 */
export declare function getCloudforceOneRequestMessageOutput(args: GetCloudforceOneRequestMessageOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCloudforceOneRequestMessageResult>;
/**
 * A collection of arguments for invoking getCloudforceOneRequestMessage.
 */
export interface GetCloudforceOneRequestMessageOutputArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Retrieve mes  ges created after this time.
     */
    after?: pulumi.Input<string>;
    /**
     * Retrieve messages created before this time.
     */
    before?: pulumi.Input<string>;
    /**
     * Page number of results.
     */
    page: pulumi.Input<number>;
    /**
     * Number of results per page.
     */
    perPage: pulumi.Input<number>;
    /**
     * UUID.
     */
    requestId: pulumi.Input<string>;
    /**
     * Field to sort results by.
     */
    sortBy?: pulumi.Input<string>;
    /**
     * Sort order (asc or desc).
     * Available values: "asc", "desc".
     */
    sortOrder?: pulumi.Input<string>;
}
