import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCustomHostnameFallbackOrigin = cloudflare.getCustomHostnameFallbackOrigin({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getCustomHostnameFallbackOrigin(args: GetCustomHostnameFallbackOriginArgs, opts?: pulumi.InvokeOptions): Promise<GetCustomHostnameFallbackOriginResult>;
/**
 * A collection of arguments for invoking getCustomHostnameFallbackOrigin.
 */
export interface GetCustomHostnameFallbackOriginArgs {
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getCustomHostnameFallbackOrigin.
 */
export interface GetCustomHostnameFallbackOriginResult {
    /**
     * This is the time the fallback origin was created.
     */
    readonly createdAt: string;
    /**
     * These are errors that were encountered while trying to activate a fallback origin.
     */
    readonly errors: string[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Your origin hostname that requests to your custom hostnames will be sent to.
     */
    readonly origin: string;
    /**
     * Status of the fallback origin's activation.
     * Available values: "initializing", "pending*deployment", "pending*deletion", "active", "deployment*timed*out", "deletion*timed*out".
     */
    readonly status: string;
    /**
     * This is the time the fallback origin was updated.
     */
    readonly updatedAt: string;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCustomHostnameFallbackOrigin = cloudflare.getCustomHostnameFallbackOrigin({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getCustomHostnameFallbackOriginOutput(args: GetCustomHostnameFallbackOriginOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCustomHostnameFallbackOriginResult>;
/**
 * A collection of arguments for invoking getCustomHostnameFallbackOrigin.
 */
export interface GetCustomHostnameFallbackOriginOutputArgs {
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
