import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCustomPages = cloudflare.getCustomPages({
 *     identifier: "023e105f4ecef8ad9ca31a8372d0c353",
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 * });
 * ```
 */
export declare function getCustomPages(args: GetCustomPagesArgs, opts?: pulumi.InvokeOptions): Promise<GetCustomPagesResult>;
/**
 * A collection of arguments for invoking getCustomPages.
 */
export interface GetCustomPagesArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: string;
    /**
     * Identifier
     */
    identifier: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: string;
}
/**
 * A collection of values returned by getCustomPages.
 */
export interface GetCustomPagesResult {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    readonly accountId?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Identifier
     */
    readonly identifier: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    readonly zoneId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCustomPages = cloudflare.getCustomPages({
 *     identifier: "023e105f4ecef8ad9ca31a8372d0c353",
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 * });
 * ```
 */
export declare function getCustomPagesOutput(args: GetCustomPagesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCustomPagesResult>;
/**
 * A collection of arguments for invoking getCustomPages.
 */
export interface GetCustomPagesOutputArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Identifier
     */
    identifier: pulumi.Input<string>;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: pulumi.Input<string>;
}
