import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCustomSsls = cloudflare.getCustomSsls({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     status: "active",
 * });
 * ```
 */
export declare function getCustomSsls(args: GetCustomSslsArgs, opts?: pulumi.InvokeOptions): Promise<GetCustomSslsResult>;
/**
 * A collection of arguments for invoking getCustomSsls.
 */
export interface GetCustomSslsArgs {
    /**
     * Whether to match all search requirements or at least one (any).
     * Available values: "any", "all".
     */
    match?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Status of the zone's custom SSL.
     * Available values: "active", "expired", "deleted", "pending", "initializing".
     */
    status?: string;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getCustomSsls.
 */
export interface GetCustomSslsResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Whether to match all search requirements or at least one (any).
     * Available values: "any", "all".
     */
    readonly match: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetCustomSslsResult[];
    /**
     * Status of the zone's custom SSL.
     * Available values: "active", "expired", "deleted", "pending", "initializing".
     */
    readonly status?: string;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleCustomSsls = cloudflare.getCustomSsls({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     status: "active",
 * });
 * ```
 */
export declare function getCustomSslsOutput(args: GetCustomSslsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCustomSslsResult>;
/**
 * A collection of arguments for invoking getCustomSsls.
 */
export interface GetCustomSslsOutputArgs {
    /**
     * Whether to match all search requirements or at least one (any).
     * Available values: "any", "all".
     */
    match?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Status of the zone's custom SSL.
     * Available values: "active", "expired", "deleted", "pending", "initializing".
     */
    status?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
