import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleD1Database = cloudflare.getD1Database({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     databaseId: "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
 * });
 * ```
 */
export declare function getD1Database(args: GetD1DatabaseArgs, opts?: pulumi.InvokeOptions): Promise<GetD1DatabaseResult>;
/**
 * A collection of arguments for invoking getD1Database.
 */
export interface GetD1DatabaseArgs {
    /**
     * Account identifier tag.
     */
    accountId: string;
    /**
     * D1 database identifier (UUID).
     */
    databaseId?: string;
    filter?: inputs.GetD1DatabaseFilter;
}
/**
 * A collection of values returned by getD1Database.
 */
export interface GetD1DatabaseResult {
    /**
     * Account identifier tag.
     */
    readonly accountId: string;
    /**
     * Specifies the timestamp the resource was created as an ISO8601 string.
     */
    readonly createdAt: string;
    /**
     * D1 database identifier (UUID).
     */
    readonly databaseId?: string;
    /**
     * The D1 database's size, in bytes.
     */
    readonly fileSize: number;
    readonly filter?: outputs.GetD1DatabaseFilter;
    /**
     * D1 database identifier (UUID).
     */
    readonly id: string;
    /**
     * D1 database name.
     */
    readonly name: string;
    readonly numTables: number;
    /**
     * Configuration for D1 read replication.
     */
    readonly readReplication: outputs.GetD1DatabaseReadReplication;
    /**
     * D1 database identifier (UUID).
     */
    readonly uuid: string;
    readonly version: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleD1Database = cloudflare.getD1Database({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     databaseId: "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
 * });
 * ```
 */
export declare function getD1DatabaseOutput(args: GetD1DatabaseOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetD1DatabaseResult>;
/**
 * A collection of arguments for invoking getD1Database.
 */
export interface GetD1DatabaseOutputArgs {
    /**
     * Account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * D1 database identifier (UUID).
     */
    databaseId?: pulumi.Input<string>;
    filter?: pulumi.Input<inputs.GetD1DatabaseFilterArgs>;
}
