import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleDnsFirewalls = cloudflare.getDnsFirewalls({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getDnsFirewalls(args: GetDnsFirewallsArgs, opts?: pulumi.InvokeOptions): Promise<GetDnsFirewallsResult>;
/**
 * A collection of arguments for invoking getDnsFirewalls.
 */
export interface GetDnsFirewallsArgs {
    /**
     * Identifier.
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getDnsFirewalls.
 */
export interface GetDnsFirewallsResult {
    /**
     * Identifier.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetDnsFirewallsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleDnsFirewalls = cloudflare.getDnsFirewalls({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getDnsFirewallsOutput(args: GetDnsFirewallsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDnsFirewallsResult>;
/**
 * A collection of arguments for invoking getDnsFirewalls.
 */
export interface GetDnsFirewallsOutputArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
