import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleDnsRecord = cloudflare.getDnsRecord({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     dnsRecordId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getDnsRecord(args: GetDnsRecordArgs, opts?: pulumi.InvokeOptions): Promise<GetDnsRecordResult>;
/**
 * A collection of arguments for invoking getDnsRecord.
 */
export interface GetDnsRecordArgs {
    /**
     * Identifier.
     */
    dnsRecordId?: string;
    filter?: inputs.GetDnsRecordFilter;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getDnsRecord.
 */
export interface GetDnsRecordResult {
    /**
     * Comments or notes about the DNS record. This field has no effect on DNS responses.
     */
    readonly comment: string;
    /**
     * When the record comment was last modified. Omitted if there is no comment.
     */
    readonly commentModifiedOn: string;
    /**
     * A valid IPv4 address.
     */
    readonly content: string;
    /**
     * When the record was created.
     */
    readonly createdOn: string;
    /**
     * Components of a CAA record.
     */
    readonly data: outputs.GetDnsRecordData;
    /**
     * Identifier.
     */
    readonly dnsRecordId?: string;
    readonly filter?: outputs.GetDnsRecordFilter;
    /**
     * Identifier.
     */
    readonly id: string;
    /**
     * Extra Cloudflare-specific information about the record.
     */
    readonly meta: string;
    /**
     * When the record was last modified.
     */
    readonly modifiedOn: string;
    /**
     * DNS record name (or @ for the zone apex) in Punycode.
     */
    readonly name: string;
    /**
     * Required for MX, SRV and URI records; unused by other record types. Records with lower priorities are preferred.
     */
    readonly priority: number;
    /**
     * Whether the record can be proxied by Cloudflare or not.
     */
    readonly proxiable: boolean;
    /**
     * Whether the record is receiving the performance and security benefits of Cloudflare.
     */
    readonly proxied: boolean;
    /**
     * Settings for the DNS record.
     */
    readonly settings: outputs.GetDnsRecordSettings;
    /**
     * Custom tags for the DNS record. This field has no effect on DNS responses.
     */
    readonly tags: string[];
    /**
     * When the record tags were last modified. Omitted if there are no tags.
     */
    readonly tagsModifiedOn: string;
    /**
     * Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'. Value must be between 60 and 86400, with the minimum reduced to 30 for Enterprise zones.
     */
    readonly ttl: number;
    /**
     * Record type.
     * Available values: "A", "AAAA", "CAA", "CERT", "CNAME", "DNSKEY", "DS", "HTTPS", "LOC", "MX", "NAPTR", "NS", "OPENPGPKEY", "PTR", "SMIMEA", "SRV", "SSHFP", "SVCB", "TLSA", "TXT", "URI".
     */
    readonly type: string;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleDnsRecord = cloudflare.getDnsRecord({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     dnsRecordId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getDnsRecordOutput(args: GetDnsRecordOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDnsRecordResult>;
/**
 * A collection of arguments for invoking getDnsRecord.
 */
export interface GetDnsRecordOutputArgs {
    /**
     * Identifier.
     */
    dnsRecordId?: pulumi.Input<string>;
    filter?: pulumi.Input<inputs.GetDnsRecordFilterArgs>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
