import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleDnsZoneTransfersPeer = cloudflare.getDnsZoneTransfersPeer({
 *     accountId: "01a7362d577a6c3019a474fd6f485823",
 *     peerId: "23ff594956f20c2a721606e94745a8aa",
 * });
 * ```
 */
export declare function getDnsZoneTransfersPeer(args: GetDnsZoneTransfersPeerArgs, opts?: pulumi.InvokeOptions): Promise<GetDnsZoneTransfersPeerResult>;
/**
 * A collection of arguments for invoking getDnsZoneTransfersPeer.
 */
export interface GetDnsZoneTransfersPeerArgs {
    accountId: string;
    peerId?: string;
}
/**
 * A collection of values returned by getDnsZoneTransfersPeer.
 */
export interface GetDnsZoneTransfersPeerResult {
    readonly accountId: string;
    /**
     * The ID of this resource.
     */
    readonly id: string;
    /**
     * IPv4/IPv6 address of primary or secondary nameserver, depending on what zone this peer is linked to. For primary zones this IP defines the IP of the secondary nameserver Cloudflare will NOTIFY upon zone changes. For secondary zones this IP defines the IP of the primary nameserver Cloudflare will send AXFR/IXFR requests to.
     */
    readonly ip: string;
    /**
     * Enable IXFR transfer protocol, default is AXFR. Only applicable to secondary zones.
     */
    readonly ixfrEnable: boolean;
    /**
     * The name of the peer.
     */
    readonly name: string;
    readonly peerId?: string;
    /**
     * DNS port of primary or secondary nameserver, depending on what zone this peer is linked to.
     */
    readonly port: number;
    /**
     * TSIG authentication will be used for zone transfer if configured.
     */
    readonly tsigId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleDnsZoneTransfersPeer = cloudflare.getDnsZoneTransfersPeer({
 *     accountId: "01a7362d577a6c3019a474fd6f485823",
 *     peerId: "23ff594956f20c2a721606e94745a8aa",
 * });
 * ```
 */
export declare function getDnsZoneTransfersPeerOutput(args: GetDnsZoneTransfersPeerOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDnsZoneTransfersPeerResult>;
/**
 * A collection of arguments for invoking getDnsZoneTransfersPeer.
 */
export interface GetDnsZoneTransfersPeerOutputArgs {
    accountId: pulumi.Input<string>;
    peerId?: pulumi.Input<string>;
}
