import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailRoutingAddresses = cloudflare.getEmailRoutingAddresses({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getEmailRoutingAddresses(args: GetEmailRoutingAddressesArgs, opts?: pulumi.InvokeOptions): Promise<GetEmailRoutingAddressesResult>;
/**
 * A collection of arguments for invoking getEmailRoutingAddresses.
 */
export interface GetEmailRoutingAddressesArgs {
    /**
     * Identifier.
     */
    accountId: string;
    /**
     * Sorts results in an ascending or descending order.
     * Available values: "asc", "desc".
     */
    direction?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Filter by verified destination addresses.
     */
    verified?: boolean;
}
/**
 * A collection of values returned by getEmailRoutingAddresses.
 */
export interface GetEmailRoutingAddressesResult {
    /**
     * Identifier.
     */
    readonly accountId: string;
    /**
     * Sorts results in an ascending or descending order.
     * Available values: "asc", "desc".
     */
    readonly direction: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetEmailRoutingAddressesResult[];
    /**
     * Filter by verified destination addresses.
     */
    readonly verified: boolean;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailRoutingAddresses = cloudflare.getEmailRoutingAddresses({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getEmailRoutingAddressesOutput(args: GetEmailRoutingAddressesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEmailRoutingAddressesResult>;
/**
 * A collection of arguments for invoking getEmailRoutingAddresses.
 */
export interface GetEmailRoutingAddressesOutputArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Sorts results in an ascending or descending order.
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Filter by verified destination addresses.
     */
    verified?: pulumi.Input<boolean>;
}
