import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailRoutingRule = cloudflare.getEmailRoutingRule({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     ruleIdentifier: "a7e6fb77503c41d8a7f3113c6918f10c",
 * });
 * ```
 */
export declare function getEmailRoutingRule(args: GetEmailRoutingRuleArgs, opts?: pulumi.InvokeOptions): Promise<GetEmailRoutingRuleResult>;
/**
 * A collection of arguments for invoking getEmailRoutingRule.
 */
export interface GetEmailRoutingRuleArgs {
    filter?: inputs.GetEmailRoutingRuleFilter;
    /**
     * Routing rule identifier.
     */
    ruleIdentifier?: string;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getEmailRoutingRule.
 */
export interface GetEmailRoutingRuleResult {
    /**
     * List actions patterns.
     */
    readonly actions: outputs.GetEmailRoutingRuleAction[];
    /**
     * Routing rule status.
     */
    readonly enabled: boolean;
    readonly filter?: outputs.GetEmailRoutingRuleFilter;
    /**
     * Routing rule identifier.
     */
    readonly id: string;
    /**
     * Matching patterns to forward to your actions.
     */
    readonly matchers: outputs.GetEmailRoutingRuleMatcher[];
    /**
     * Routing rule name.
     */
    readonly name: string;
    /**
     * Priority of the routing rule.
     */
    readonly priority: number;
    /**
     * Routing rule identifier.
     */
    readonly ruleIdentifier?: string;
    /**
     * Routing rule tag. (Deprecated, replaced by routing rule identifier)
     *
     * @deprecated This attribute is deprecated.
     */
    readonly tag: string;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailRoutingRule = cloudflare.getEmailRoutingRule({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     ruleIdentifier: "a7e6fb77503c41d8a7f3113c6918f10c",
 * });
 * ```
 */
export declare function getEmailRoutingRuleOutput(args: GetEmailRoutingRuleOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEmailRoutingRuleResult>;
/**
 * A collection of arguments for invoking getEmailRoutingRule.
 */
export interface GetEmailRoutingRuleOutputArgs {
    filter?: pulumi.Input<inputs.GetEmailRoutingRuleFilterArgs>;
    /**
     * Routing rule identifier.
     */
    ruleIdentifier?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
