import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailRoutingRules = cloudflare.getEmailRoutingRules({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     enabled: true,
 * });
 * ```
 */
export declare function getEmailRoutingRules(args: GetEmailRoutingRulesArgs, opts?: pulumi.InvokeOptions): Promise<GetEmailRoutingRulesResult>;
/**
 * A collection of arguments for invoking getEmailRoutingRules.
 */
export interface GetEmailRoutingRulesArgs {
    /**
     * Filter by enabled routing rules.
     */
    enabled?: boolean;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getEmailRoutingRules.
 */
export interface GetEmailRoutingRulesResult {
    /**
     * Filter by enabled routing rules.
     */
    readonly enabled?: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetEmailRoutingRulesResult[];
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailRoutingRules = cloudflare.getEmailRoutingRules({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     enabled: true,
 * });
 * ```
 */
export declare function getEmailRoutingRulesOutput(args: GetEmailRoutingRulesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEmailRoutingRulesResult>;
/**
 * A collection of arguments for invoking getEmailRoutingRules.
 */
export interface GetEmailRoutingRulesOutputArgs {
    /**
     * Filter by enabled routing rules.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
