import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailRoutingSettings = cloudflare.getEmailRoutingSettings({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getEmailRoutingSettings(args: GetEmailRoutingSettingsArgs, opts?: pulumi.InvokeOptions): Promise<GetEmailRoutingSettingsResult>;
/**
 * A collection of arguments for invoking getEmailRoutingSettings.
 */
export interface GetEmailRoutingSettingsArgs {
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getEmailRoutingSettings.
 */
export interface GetEmailRoutingSettingsResult {
    /**
     * The date and time the settings have been created.
     */
    readonly created: string;
    /**
     * State of the zone settings for Email Routing.
     */
    readonly enabled: boolean;
    /**
     * Email Routing settings identifier.
     */
    readonly id: string;
    /**
     * The date and time the settings have been modified.
     */
    readonly modified: string;
    /**
     * Domain of your zone.
     */
    readonly name: string;
    /**
     * Flag to check if the user skipped the configuration wizard.
     */
    readonly skipWizard: boolean;
    /**
     * Show the state of your account, and the type or configuration error.
     * Available values: "ready", "unconfigured", "misconfigured", "misconfigured/locked", "unlocked".
     */
    readonly status: string;
    /**
     * Email Routing settings tag. (Deprecated, replaced by Email Routing settings identifier)
     *
     * @deprecated This attribute is deprecated.
     */
    readonly tag: string;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailRoutingSettings = cloudflare.getEmailRoutingSettings({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getEmailRoutingSettingsOutput(args: GetEmailRoutingSettingsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEmailRoutingSettingsResult>;
/**
 * A collection of arguments for invoking getEmailRoutingSettings.
 */
export interface GetEmailRoutingSettingsOutputArgs {
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
