import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityBlockSender = cloudflare.getEmailSecurityBlockSender({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     patternId: 2402,
 * });
 * ```
 */
export declare function getEmailSecurityBlockSender(args: GetEmailSecurityBlockSenderArgs, opts?: pulumi.InvokeOptions): Promise<GetEmailSecurityBlockSenderResult>;
/**
 * A collection of arguments for invoking getEmailSecurityBlockSender.
 */
export interface GetEmailSecurityBlockSenderArgs {
    /**
     * Account Identifier
     */
    accountId: string;
    filter?: inputs.GetEmailSecurityBlockSenderFilter;
    /**
     * The unique identifier for the allow policy.
     */
    patternId?: number;
}
/**
 * A collection of values returned by getEmailSecurityBlockSender.
 */
export interface GetEmailSecurityBlockSenderResult {
    /**
     * Account Identifier
     */
    readonly accountId: string;
    readonly comments: string;
    readonly createdAt: string;
    readonly filter?: outputs.GetEmailSecurityBlockSenderFilter;
    /**
     * The unique identifier for the allow policy.
     */
    readonly id: number;
    readonly isRegex: boolean;
    readonly lastModified: string;
    readonly pattern: string;
    /**
     * The unique identifier for the allow policy.
     */
    readonly patternId?: number;
    /**
     * Available values: "EMAIL", "DOMAIN", "IP", "UNKNOWN".
     */
    readonly patternType: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityBlockSender = cloudflare.getEmailSecurityBlockSender({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     patternId: 2402,
 * });
 * ```
 */
export declare function getEmailSecurityBlockSenderOutput(args: GetEmailSecurityBlockSenderOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEmailSecurityBlockSenderResult>;
/**
 * A collection of arguments for invoking getEmailSecurityBlockSender.
 */
export interface GetEmailSecurityBlockSenderOutputArgs {
    /**
     * Account Identifier
     */
    accountId: pulumi.Input<string>;
    filter?: pulumi.Input<inputs.GetEmailSecurityBlockSenderFilterArgs>;
    /**
     * The unique identifier for the allow policy.
     */
    patternId?: pulumi.Input<number>;
}
