import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityBlockSenders = cloudflare.getEmailSecurityBlockSenders({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "asc",
 *     order: "pattern",
 *     patternType: "EMAIL",
 *     search: "search",
 * });
 * ```
 */
export declare function getEmailSecurityBlockSenders(args: GetEmailSecurityBlockSendersArgs, opts?: pulumi.InvokeOptions): Promise<GetEmailSecurityBlockSendersResult>;
/**
 * A collection of arguments for invoking getEmailSecurityBlockSenders.
 */
export interface GetEmailSecurityBlockSendersArgs {
    /**
     * Account Identifier
     */
    accountId: string;
    /**
     * The sorting direction.
     * Available values: "asc", "desc".
     */
    direction?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * The field to sort by.
     * Available values: "pattern", "createdAt".
     */
    order?: string;
    /**
     * Available values: "EMAIL", "DOMAIN", "IP", "UNKNOWN".
     */
    patternType?: string;
    /**
     * Allows searching in multiple properties of a record simultaneously.
     * This parameter is intended for human users, not automation. Its exact
     * behavior is intentionally left unspecified and is subject to change
     * in the future.
     */
    search?: string;
}
/**
 * A collection of values returned by getEmailSecurityBlockSenders.
 */
export interface GetEmailSecurityBlockSendersResult {
    /**
     * Account Identifier
     */
    readonly accountId: string;
    /**
     * The sorting direction.
     * Available values: "asc", "desc".
     */
    readonly direction?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The field to sort by.
     * Available values: "pattern", "createdAt".
     */
    readonly order?: string;
    /**
     * Available values: "EMAIL", "DOMAIN", "IP", "UNKNOWN".
     */
    readonly patternType?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetEmailSecurityBlockSendersResult[];
    /**
     * Allows searching in multiple properties of a record simultaneously.
     * This parameter is intended for human users, not automation. Its exact
     * behavior is intentionally left unspecified and is subject to change
     * in the future.
     */
    readonly search?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityBlockSenders = cloudflare.getEmailSecurityBlockSenders({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "asc",
 *     order: "pattern",
 *     patternType: "EMAIL",
 *     search: "search",
 * });
 * ```
 */
export declare function getEmailSecurityBlockSendersOutput(args: GetEmailSecurityBlockSendersOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEmailSecurityBlockSendersResult>;
/**
 * A collection of arguments for invoking getEmailSecurityBlockSenders.
 */
export interface GetEmailSecurityBlockSendersOutputArgs {
    /**
     * Account Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * The sorting direction.
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * The field to sort by.
     * Available values: "pattern", "createdAt".
     */
    order?: pulumi.Input<string>;
    /**
     * Available values: "EMAIL", "DOMAIN", "IP", "UNKNOWN".
     */
    patternType?: pulumi.Input<string>;
    /**
     * Allows searching in multiple properties of a record simultaneously.
     * This parameter is intended for human users, not automation. Its exact
     * behavior is intentionally left unspecified and is subject to change
     * in the future.
     */
    search?: pulumi.Input<string>;
}
