import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityImpersonationRegistries = cloudflare.getEmailSecurityImpersonationRegistries({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "asc",
 *     order: "name",
 *     provenance: "A1S_INTERNAL",
 *     search: "search",
 * });
 * ```
 */
export declare function getEmailSecurityImpersonationRegistries(args: GetEmailSecurityImpersonationRegistriesArgs, opts?: pulumi.InvokeOptions): Promise<GetEmailSecurityImpersonationRegistriesResult>;
/**
 * A collection of arguments for invoking getEmailSecurityImpersonationRegistries.
 */
export interface GetEmailSecurityImpersonationRegistriesArgs {
    /**
     * Account Identifier
     */
    accountId: string;
    /**
     * The sorting direction.
     * Available values: "asc", "desc".
     */
    direction?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * The field to sort by.
     * Available values: "name", "email", "createdAt".
     */
    order?: string;
    /**
     * Available values: "A1S*INTERNAL", "SNOOPY-CASB*OFFICE*365", "SNOOPY-OFFICE*365", "SNOOPY-GOOGLE_DIRECTORY".
     */
    provenance?: string;
    /**
     * Allows searching in multiple properties of a record simultaneously.
     * This parameter is intended for human users, not automation. Its exact
     * behavior is intentionally left unspecified and is subject to change
     * in the future.
     */
    search?: string;
}
/**
 * A collection of values returned by getEmailSecurityImpersonationRegistries.
 */
export interface GetEmailSecurityImpersonationRegistriesResult {
    /**
     * Account Identifier
     */
    readonly accountId: string;
    /**
     * The sorting direction.
     * Available values: "asc", "desc".
     */
    readonly direction?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The field to sort by.
     * Available values: "name", "email", "createdAt".
     */
    readonly order?: string;
    /**
     * Available values: "A1S*INTERNAL", "SNOOPY-CASB*OFFICE*365", "SNOOPY-OFFICE*365", "SNOOPY-GOOGLE_DIRECTORY".
     */
    readonly provenance?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetEmailSecurityImpersonationRegistriesResult[];
    /**
     * Allows searching in multiple properties of a record simultaneously.
     * This parameter is intended for human users, not automation. Its exact
     * behavior is intentionally left unspecified and is subject to change
     * in the future.
     */
    readonly search?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityImpersonationRegistries = cloudflare.getEmailSecurityImpersonationRegistries({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "asc",
 *     order: "name",
 *     provenance: "A1S_INTERNAL",
 *     search: "search",
 * });
 * ```
 */
export declare function getEmailSecurityImpersonationRegistriesOutput(args: GetEmailSecurityImpersonationRegistriesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEmailSecurityImpersonationRegistriesResult>;
/**
 * A collection of arguments for invoking getEmailSecurityImpersonationRegistries.
 */
export interface GetEmailSecurityImpersonationRegistriesOutputArgs {
    /**
     * Account Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * The sorting direction.
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * The field to sort by.
     * Available values: "name", "email", "createdAt".
     */
    order?: pulumi.Input<string>;
    /**
     * Available values: "A1S*INTERNAL", "SNOOPY-CASB*OFFICE*365", "SNOOPY-OFFICE*365", "SNOOPY-GOOGLE_DIRECTORY".
     */
    provenance?: pulumi.Input<string>;
    /**
     * Allows searching in multiple properties of a record simultaneously.
     * This parameter is intended for human users, not automation. Its exact
     * behavior is intentionally left unspecified and is subject to change
     * in the future.
     */
    search?: pulumi.Input<string>;
}
