import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityImpersonationRegistry = cloudflare.getEmailSecurityImpersonationRegistry({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     displayNameId: 2403,
 * });
 * ```
 */
export declare function getEmailSecurityImpersonationRegistry(args: GetEmailSecurityImpersonationRegistryArgs, opts?: pulumi.InvokeOptions): Promise<GetEmailSecurityImpersonationRegistryResult>;
/**
 * A collection of arguments for invoking getEmailSecurityImpersonationRegistry.
 */
export interface GetEmailSecurityImpersonationRegistryArgs {
    /**
     * Account Identifier
     */
    accountId: string;
    displayNameId?: number;
    filter?: inputs.GetEmailSecurityImpersonationRegistryFilter;
}
/**
 * A collection of values returned by getEmailSecurityImpersonationRegistry.
 */
export interface GetEmailSecurityImpersonationRegistryResult {
    /**
     * Account Identifier
     */
    readonly accountId: string;
    readonly comments: string;
    readonly createdAt: string;
    readonly directoryId: number;
    readonly directoryNodeId: number;
    readonly displayNameId?: number;
    readonly email: string;
    /**
     * @deprecated This attribute is deprecated.
     */
    readonly externalDirectoryNodeId: string;
    readonly filter?: outputs.GetEmailSecurityImpersonationRegistryFilter;
    /**
     * The ID of this resource.
     */
    readonly id: number;
    readonly isEmailRegex: boolean;
    readonly lastModified: string;
    readonly name: string;
    readonly provenance: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityImpersonationRegistry = cloudflare.getEmailSecurityImpersonationRegistry({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     displayNameId: 2403,
 * });
 * ```
 */
export declare function getEmailSecurityImpersonationRegistryOutput(args: GetEmailSecurityImpersonationRegistryOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEmailSecurityImpersonationRegistryResult>;
/**
 * A collection of arguments for invoking getEmailSecurityImpersonationRegistry.
 */
export interface GetEmailSecurityImpersonationRegistryOutputArgs {
    /**
     * Account Identifier
     */
    accountId: pulumi.Input<string>;
    displayNameId?: pulumi.Input<number>;
    filter?: pulumi.Input<inputs.GetEmailSecurityImpersonationRegistryFilterArgs>;
}
