import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityTrustedDomains = cloudflare.getEmailSecurityTrustedDomains({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     trustedDomainId: 2401,
 * });
 * ```
 */
export declare function getEmailSecurityTrustedDomains(args: GetEmailSecurityTrustedDomainsArgs, opts?: pulumi.InvokeOptions): Promise<GetEmailSecurityTrustedDomainsResult>;
/**
 * A collection of arguments for invoking getEmailSecurityTrustedDomains.
 */
export interface GetEmailSecurityTrustedDomainsArgs {
    /**
     * Account Identifier
     */
    accountId: string;
    filter?: inputs.GetEmailSecurityTrustedDomainsFilter;
    /**
     * The unique identifier for the trusted domain.
     */
    trustedDomainId?: number;
}
/**
 * A collection of values returned by getEmailSecurityTrustedDomains.
 */
export interface GetEmailSecurityTrustedDomainsResult {
    /**
     * Account Identifier
     */
    readonly accountId: string;
    readonly comments: string;
    readonly createdAt: string;
    readonly filter?: outputs.GetEmailSecurityTrustedDomainsFilter;
    /**
     * The unique identifier for the trusted domain.
     */
    readonly id: number;
    /**
     * Select to prevent recently registered domains from triggering a
     * Suspicious or Malicious disposition.
     */
    readonly isRecent: boolean;
    readonly isRegex: boolean;
    /**
     * Select for partner or other approved domains that have similar
     * spelling to your connected domains. Prevents listed domains from
     * triggering a Spoof disposition.
     */
    readonly isSimilarity: boolean;
    readonly lastModified: string;
    readonly pattern: string;
    /**
     * The unique identifier for the trusted domain.
     */
    readonly trustedDomainId?: number;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityTrustedDomains = cloudflare.getEmailSecurityTrustedDomains({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     trustedDomainId: 2401,
 * });
 * ```
 */
export declare function getEmailSecurityTrustedDomainsOutput(args: GetEmailSecurityTrustedDomainsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEmailSecurityTrustedDomainsResult>;
/**
 * A collection of arguments for invoking getEmailSecurityTrustedDomains.
 */
export interface GetEmailSecurityTrustedDomainsOutputArgs {
    /**
     * Account Identifier
     */
    accountId: pulumi.Input<string>;
    filter?: pulumi.Input<inputs.GetEmailSecurityTrustedDomainsFilterArgs>;
    /**
     * The unique identifier for the trusted domain.
     */
    trustedDomainId?: pulumi.Input<number>;
}
