import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityTrustedDomainsList = cloudflare.getEmailSecurityTrustedDomainsList({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "asc",
 *     isRecent: true,
 *     isSimilarity: true,
 *     order: "pattern",
 *     search: "search",
 * });
 * ```
 */
export declare function getEmailSecurityTrustedDomainsList(args: GetEmailSecurityTrustedDomainsListArgs, opts?: pulumi.InvokeOptions): Promise<GetEmailSecurityTrustedDomainsListResult>;
/**
 * A collection of arguments for invoking getEmailSecurityTrustedDomainsList.
 */
export interface GetEmailSecurityTrustedDomainsListArgs {
    /**
     * Account Identifier
     */
    accountId: string;
    /**
     * The sorting direction.
     * Available values: "asc", "desc".
     */
    direction?: string;
    isRecent?: boolean;
    isSimilarity?: boolean;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * The field to sort by.
     * Available values: "pattern", "createdAt".
     */
    order?: string;
    /**
     * Allows searching in multiple properties of a record simultaneously.
     * This parameter is intended for human users, not automation. Its exact
     * behavior is intentionally left unspecified and is subject to change
     * in the future.
     */
    search?: string;
}
/**
 * A collection of values returned by getEmailSecurityTrustedDomainsList.
 */
export interface GetEmailSecurityTrustedDomainsListResult {
    /**
     * Account Identifier
     */
    readonly accountId: string;
    /**
     * The sorting direction.
     * Available values: "asc", "desc".
     */
    readonly direction?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly isRecent?: boolean;
    readonly isSimilarity?: boolean;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The field to sort by.
     * Available values: "pattern", "createdAt".
     */
    readonly order?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetEmailSecurityTrustedDomainsListResult[];
    /**
     * Allows searching in multiple properties of a record simultaneously.
     * This parameter is intended for human users, not automation. Its exact
     * behavior is intentionally left unspecified and is subject to change
     * in the future.
     */
    readonly search?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleEmailSecurityTrustedDomainsList = cloudflare.getEmailSecurityTrustedDomainsList({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "asc",
 *     isRecent: true,
 *     isSimilarity: true,
 *     order: "pattern",
 *     search: "search",
 * });
 * ```
 */
export declare function getEmailSecurityTrustedDomainsListOutput(args: GetEmailSecurityTrustedDomainsListOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEmailSecurityTrustedDomainsListResult>;
/**
 * A collection of arguments for invoking getEmailSecurityTrustedDomainsList.
 */
export interface GetEmailSecurityTrustedDomainsListOutputArgs {
    /**
     * Account Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * The sorting direction.
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    isRecent?: pulumi.Input<boolean>;
    isSimilarity?: pulumi.Input<boolean>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * The field to sort by.
     * Available values: "pattern", "createdAt".
     */
    order?: pulumi.Input<string>;
    /**
     * Allows searching in multiple properties of a record simultaneously.
     * This parameter is intended for human users, not automation. Its exact
     * behavior is intentionally left unspecified and is subject to change
     * in the future.
     */
    search?: pulumi.Input<string>;
}
