import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleHealthchecks = cloudflare.getHealthchecks({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getHealthchecks(args: GetHealthchecksArgs, opts?: pulumi.InvokeOptions): Promise<GetHealthchecksResult>;
/**
 * A collection of arguments for invoking getHealthchecks.
 */
export interface GetHealthchecksArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Identifier
     */
    zoneId: string;
}
/**
 * A collection of values returned by getHealthchecks.
 */
export interface GetHealthchecksResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetHealthchecksResult[];
    /**
     * Identifier
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleHealthchecks = cloudflare.getHealthchecks({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getHealthchecksOutput(args: GetHealthchecksOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetHealthchecksResult>;
/**
 * A collection of arguments for invoking getHealthchecks.
 */
export interface GetHealthchecksOutputArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Identifier
     */
    zoneId: pulumi.Input<string>;
}
