import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleHyperdriveConfigs = cloudflare.getHyperdriveConfigs({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getHyperdriveConfigs(args: GetHyperdriveConfigsArgs, opts?: pulumi.InvokeOptions): Promise<GetHyperdriveConfigsResult>;
/**
 * A collection of arguments for invoking getHyperdriveConfigs.
 */
export interface GetHyperdriveConfigsArgs {
    /**
     * Define configurations using a unique string identifier.
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getHyperdriveConfigs.
 */
export interface GetHyperdriveConfigsResult {
    /**
     * Define configurations using a unique string identifier.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetHyperdriveConfigsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleHyperdriveConfigs = cloudflare.getHyperdriveConfigs({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getHyperdriveConfigsOutput(args: GetHyperdriveConfigsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetHyperdriveConfigsResult>;
/**
 * A collection of arguments for invoking getHyperdriveConfigs.
 */
export interface GetHyperdriveConfigsOutputArgs {
    /**
     * Define configurations using a unique string identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
