import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleImageVariant = cloudflare.getImageVariant({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     variantId: "hero",
 * });
 * ```
 */
export declare function getImageVariant(args: GetImageVariantArgs, opts?: pulumi.InvokeOptions): Promise<GetImageVariantResult>;
/**
 * A collection of arguments for invoking getImageVariant.
 */
export interface GetImageVariantArgs {
    /**
     * Account identifier tag.
     */
    accountId: string;
    variantId: string;
}
/**
 * A collection of values returned by getImageVariant.
 */
export interface GetImageVariantResult {
    /**
     * Account identifier tag.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly variant: outputs.GetImageVariantVariant;
    readonly variantId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleImageVariant = cloudflare.getImageVariant({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     variantId: "hero",
 * });
 * ```
 */
export declare function getImageVariantOutput(args: GetImageVariantOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetImageVariantResult>;
/**
 * A collection of arguments for invoking getImageVariant.
 */
export interface GetImageVariantOutputArgs {
    /**
     * Account identifier tag.
     */
    accountId: pulumi.Input<string>;
    variantId: pulumi.Input<string>;
}
