import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleIpRanges = cloudflare.getIpRanges({
 *     networks: "networks",
 * });
 * ```
 */
export declare function getIpRanges(args?: GetIpRangesArgs, opts?: pulumi.InvokeOptions): Promise<GetIpRangesResult>;
/**
 * A collection of arguments for invoking getIpRanges.
 */
export interface GetIpRangesArgs {
    /**
     * Specified as `jdcloud` to list IPs used by JD Cloud data centers.
     */
    networks?: string;
}
/**
 * A collection of values returned by getIpRanges.
 */
export interface GetIpRangesResult {
    /**
     * A digest of the IP data. Useful for determining if the data has changed.
     */
    readonly etag: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * List of Cloudflare IPv4 CIDR addresses.
     */
    readonly ipv4Cidrs: string[];
    /**
     * List of Cloudflare IPv6 CIDR addresses.
     */
    readonly ipv6Cidrs: string[];
    /**
     * List IPv4 and IPv6 CIDRs, only populated if `?networks=jdcloud` is used.
     */
    readonly jdcloudCidrs: string[];
    /**
     * Specified as `jdcloud` to list IPs used by JD Cloud data centers.
     */
    readonly networks?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleIpRanges = cloudflare.getIpRanges({
 *     networks: "networks",
 * });
 * ```
 */
export declare function getIpRangesOutput(args?: GetIpRangesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIpRangesResult>;
/**
 * A collection of arguments for invoking getIpRanges.
 */
export interface GetIpRangesOutputArgs {
    /**
     * Specified as `jdcloud` to list IPs used by JD Cloud data centers.
     */
    networks?: pulumi.Input<string>;
}
