import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleLoadBalancerMonitors = cloudflare.getLoadBalancerMonitors({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getLoadBalancerMonitors(args: GetLoadBalancerMonitorsArgs, opts?: pulumi.InvokeOptions): Promise<GetLoadBalancerMonitorsResult>;
/**
 * A collection of arguments for invoking getLoadBalancerMonitors.
 */
export interface GetLoadBalancerMonitorsArgs {
    /**
     * Identifier
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getLoadBalancerMonitors.
 */
export interface GetLoadBalancerMonitorsResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetLoadBalancerMonitorsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleLoadBalancerMonitors = cloudflare.getLoadBalancerMonitors({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getLoadBalancerMonitorsOutput(args: GetLoadBalancerMonitorsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLoadBalancerMonitorsResult>;
/**
 * A collection of arguments for invoking getLoadBalancerMonitors.
 */
export interface GetLoadBalancerMonitorsOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
