import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleLoadBalancerPools = cloudflare.getLoadBalancerPools({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     monitor: "monitor",
 * });
 * ```
 */
export declare function getLoadBalancerPools(args: GetLoadBalancerPoolsArgs, opts?: pulumi.InvokeOptions): Promise<GetLoadBalancerPoolsResult>;
/**
 * A collection of arguments for invoking getLoadBalancerPools.
 */
export interface GetLoadBalancerPoolsArgs {
    /**
     * Identifier
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * The ID of the Monitor to use for checking the health of origins within this pool.
     */
    monitor?: string;
}
/**
 * A collection of values returned by getLoadBalancerPools.
 */
export interface GetLoadBalancerPoolsResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The ID of the Monitor to use for checking the health of origins within this pool.
     */
    readonly monitor?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetLoadBalancerPoolsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleLoadBalancerPools = cloudflare.getLoadBalancerPools({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     monitor: "monitor",
 * });
 * ```
 */
export declare function getLoadBalancerPoolsOutput(args: GetLoadBalancerPoolsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLoadBalancerPoolsResult>;
/**
 * A collection of arguments for invoking getLoadBalancerPools.
 */
export interface GetLoadBalancerPoolsOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * The ID of the Monitor to use for checking the health of origins within this pool.
     */
    monitor?: pulumi.Input<string>;
}
