import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMagicNetworkMonitoringConfiguration = cloudflare.getMagicNetworkMonitoringConfiguration({
 *     accountId: "6f91088a406011ed95aed352566e8d4c",
 * });
 * ```
 */
export declare function getMagicNetworkMonitoringConfiguration(args: GetMagicNetworkMonitoringConfigurationArgs, opts?: pulumi.InvokeOptions): Promise<GetMagicNetworkMonitoringConfigurationResult>;
/**
 * A collection of arguments for invoking getMagicNetworkMonitoringConfiguration.
 */
export interface GetMagicNetworkMonitoringConfigurationArgs {
    accountId: string;
}
/**
 * A collection of values returned by getMagicNetworkMonitoringConfiguration.
 */
export interface GetMagicNetworkMonitoringConfigurationResult {
    readonly accountId: string;
    /**
     * Fallback sampling rate of flow messages being sent in packets per second. This should match the packet sampling rate configured on the router.
     */
    readonly defaultSampling: number;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The account name.
     */
    readonly name: string;
    readonly routerIps: string[];
    readonly warpDevices: outputs.GetMagicNetworkMonitoringConfigurationWarpDevice[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMagicNetworkMonitoringConfiguration = cloudflare.getMagicNetworkMonitoringConfiguration({
 *     accountId: "6f91088a406011ed95aed352566e8d4c",
 * });
 * ```
 */
export declare function getMagicNetworkMonitoringConfigurationOutput(args: GetMagicNetworkMonitoringConfigurationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMagicNetworkMonitoringConfigurationResult>;
/**
 * A collection of arguments for invoking getMagicNetworkMonitoringConfiguration.
 */
export interface GetMagicNetworkMonitoringConfigurationOutputArgs {
    accountId: pulumi.Input<string>;
}
