import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMagicNetworkMonitoringRule = cloudflare.getMagicNetworkMonitoringRule({
 *     accountId: "6f91088a406011ed95aed352566e8d4c",
 *     ruleId: "2890e6fa406311ed9b5a23f70f6fb8cf",
 * });
 * ```
 */
export declare function getMagicNetworkMonitoringRule(args: GetMagicNetworkMonitoringRuleArgs, opts?: pulumi.InvokeOptions): Promise<GetMagicNetworkMonitoringRuleResult>;
/**
 * A collection of arguments for invoking getMagicNetworkMonitoringRule.
 */
export interface GetMagicNetworkMonitoringRuleArgs {
    accountId: string;
    /**
     * The id of the rule. Must be unique.
     */
    ruleId?: string;
}
/**
 * A collection of values returned by getMagicNetworkMonitoringRule.
 */
export interface GetMagicNetworkMonitoringRuleResult {
    readonly accountId: string;
    /**
     * Toggle on if you would like Cloudflare to automatically advertise the IP Prefixes within the rule via Magic Transit when the rule is triggered. Only available for users of Magic Transit.
     */
    readonly automaticAdvertisement: boolean;
    /**
     * The number of bits per second for the rule. When this value is exceeded for the set duration, an alert notification is sent. Minimum of 1 and no maximum.
     */
    readonly bandwidthThreshold: number;
    /**
     * The amount of time that the rule threshold must be exceeded to send an alert notification. The final value must be equivalent to one of the following 8 values ["1m","5m","10m","15m","20m","30m","45m","60m"].
     * Available values: "1m", "5m", "10m", "15m", "20m", "30m", "45m", "60m".
     */
    readonly duration: string;
    /**
     * The id of the rule. Must be unique.
     */
    readonly id: string;
    /**
     * The name of the rule. Must be unique. Supports characters A-Z, a-z, 0-9, underscore (_), dash (-), period (.), and tilde (~). You can’t have a space in the rule name. Max 256 characters.
     */
    readonly name: string;
    /**
     * The number of packets per second for the rule. When this value is exceeded for the set duration, an alert notification is sent. Minimum of 1 and no maximum.
     */
    readonly packetThreshold: number;
    /**
     * Prefix match type to be applied for a prefix auto advertisement when using an advancedDdos rule.
     * Available values: "exact", "subnet", "supernet".
     */
    readonly prefixMatch: string;
    readonly prefixes: string[];
    /**
     * The id of the rule. Must be unique.
     */
    readonly ruleId?: string;
    /**
     * MNM rule type.
     * Available values: "threshold", "zscore", "advancedDdos".
     */
    readonly type: string;
    /**
     * Level of sensitivity set for zscore rules.
     * Available values: "low", "medium", "high".
     */
    readonly zscoreSensitivity: string;
    /**
     * Target of the zscore rule analysis.
     * Available values: "bits", "packets".
     */
    readonly zscoreTarget: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMagicNetworkMonitoringRule = cloudflare.getMagicNetworkMonitoringRule({
 *     accountId: "6f91088a406011ed95aed352566e8d4c",
 *     ruleId: "2890e6fa406311ed9b5a23f70f6fb8cf",
 * });
 * ```
 */
export declare function getMagicNetworkMonitoringRuleOutput(args: GetMagicNetworkMonitoringRuleOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMagicNetworkMonitoringRuleResult>;
/**
 * A collection of arguments for invoking getMagicNetworkMonitoringRule.
 */
export interface GetMagicNetworkMonitoringRuleOutputArgs {
    accountId: pulumi.Input<string>;
    /**
     * The id of the rule. Must be unique.
     */
    ruleId?: pulumi.Input<string>;
}
