import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMagicTransitConnectors = cloudflare.getMagicTransitConnectors({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getMagicTransitConnectors(args: GetMagicTransitConnectorsArgs, opts?: pulumi.InvokeOptions): Promise<GetMagicTransitConnectorsResult>;
/**
 * A collection of arguments for invoking getMagicTransitConnectors.
 */
export interface GetMagicTransitConnectorsArgs {
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getMagicTransitConnectors.
 */
export interface GetMagicTransitConnectorsResult {
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetMagicTransitConnectorsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMagicTransitConnectors = cloudflare.getMagicTransitConnectors({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getMagicTransitConnectorsOutput(args: GetMagicTransitConnectorsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMagicTransitConnectorsResult>;
/**
 * A collection of arguments for invoking getMagicTransitConnectors.
 */
export interface GetMagicTransitConnectorsOutputArgs {
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
