import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMagicTransitSite = cloudflare.getMagicTransitSite({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     siteId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getMagicTransitSite(args: GetMagicTransitSiteArgs, opts?: pulumi.InvokeOptions): Promise<GetMagicTransitSiteResult>;
/**
 * A collection of arguments for invoking getMagicTransitSite.
 */
export interface GetMagicTransitSiteArgs {
    /**
     * Identifier
     */
    accountId: string;
    filter?: inputs.GetMagicTransitSiteFilter;
    /**
     * Identifier
     */
    siteId?: string;
}
/**
 * A collection of values returned by getMagicTransitSite.
 */
export interface GetMagicTransitSiteResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * Magic Connector identifier tag.
     */
    readonly connectorId: string;
    readonly description: string;
    readonly filter?: outputs.GetMagicTransitSiteFilter;
    /**
     * Site high availability mode. If set to true, the site can have two connectors and runs in high availability mode.
     */
    readonly haMode: boolean;
    /**
     * Identifier
     */
    readonly id: string;
    /**
     * Location of site in latitude and longitude.
     */
    readonly location: outputs.GetMagicTransitSiteLocation;
    /**
     * The name of the site.
     */
    readonly name: string;
    /**
     * Magic Connector identifier tag. Used when high availability mode is on.
     */
    readonly secondaryConnectorId: string;
    /**
     * Identifier
     */
    readonly siteId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMagicTransitSite = cloudflare.getMagicTransitSite({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     siteId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getMagicTransitSiteOutput(args: GetMagicTransitSiteOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMagicTransitSiteResult>;
/**
 * A collection of arguments for invoking getMagicTransitSite.
 */
export interface GetMagicTransitSiteOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    filter?: pulumi.Input<inputs.GetMagicTransitSiteFilterArgs>;
    /**
     * Identifier
     */
    siteId?: pulumi.Input<string>;
}
