import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMagicTransitSiteLan = cloudflare.getMagicTransitSiteLan({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     siteId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     lanId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getMagicTransitSiteLan(args: GetMagicTransitSiteLanArgs, opts?: pulumi.InvokeOptions): Promise<GetMagicTransitSiteLanResult>;
/**
 * A collection of arguments for invoking getMagicTransitSiteLan.
 */
export interface GetMagicTransitSiteLanArgs {
    /**
     * Identifier
     */
    accountId: string;
    /**
     * Identifier
     */
    lanId?: string;
    /**
     * Identifier
     */
    siteId: string;
}
/**
 * A collection of values returned by getMagicTransitSiteLan.
 */
export interface GetMagicTransitSiteLanResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * mark true to use this LAN for HA probing. only works for site with HA turned on. only one LAN can be set as the ha_link.
     */
    readonly haLink: boolean;
    /**
     * Identifier
     */
    readonly id: string;
    /**
     * Identifier
     */
    readonly lanId?: string;
    readonly name: string;
    readonly nat: outputs.GetMagicTransitSiteLanNat;
    readonly physport: number;
    readonly routedSubnets: outputs.GetMagicTransitSiteLanRoutedSubnet[];
    /**
     * Identifier
     */
    readonly siteId: string;
    /**
     * If the site is not configured in high availability mode, this configuration is optional (if omitted, use DHCP). However, if in high availability mode, static*address is required along with secondary and virtual address.
     */
    readonly staticAddressing: outputs.GetMagicTransitSiteLanStaticAddressing;
    /**
     * VLAN ID. Use zero for untagged.
     */
    readonly vlanTag: number;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMagicTransitSiteLan = cloudflare.getMagicTransitSiteLan({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     siteId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     lanId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getMagicTransitSiteLanOutput(args: GetMagicTransitSiteLanOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMagicTransitSiteLanResult>;
/**
 * A collection of arguments for invoking getMagicTransitSiteLan.
 */
export interface GetMagicTransitSiteLanOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * Identifier
     */
    lanId?: pulumi.Input<string>;
    /**
     * Identifier
     */
    siteId: pulumi.Input<string>;
}
