import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMagicTransitSites = cloudflare.getMagicTransitSites({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     connectorid: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getMagicTransitSites(args: GetMagicTransitSitesArgs, opts?: pulumi.InvokeOptions): Promise<GetMagicTransitSitesResult>;
/**
 * A collection of arguments for invoking getMagicTransitSites.
 */
export interface GetMagicTransitSitesArgs {
    /**
     * Identifier
     */
    accountId: string;
    /**
     * Identifier
     */
    connectorid?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getMagicTransitSites.
 */
export interface GetMagicTransitSitesResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * Identifier
     */
    readonly connectorid?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetMagicTransitSitesResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMagicTransitSites = cloudflare.getMagicTransitSites({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     connectorid: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getMagicTransitSitesOutput(args: GetMagicTransitSitesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMagicTransitSitesResult>;
/**
 * A collection of arguments for invoking getMagicTransitSites.
 */
export interface GetMagicTransitSitesOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * Identifier
     */
    connectorid?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
