import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleManagedTransforms = cloudflare.getManagedTransforms({
 *     zoneId: "9f1839b6152d298aca64c4e906b6d074",
 * });
 * ```
 */
export declare function getManagedTransforms(args: GetManagedTransformsArgs, opts?: pulumi.InvokeOptions): Promise<GetManagedTransformsResult>;
/**
 * A collection of arguments for invoking getManagedTransforms.
 */
export interface GetManagedTransformsArgs {
    /**
     * The unique ID of the zone.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getManagedTransforms.
 */
export interface GetManagedTransformsResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The list of Managed Request Transforms.
     */
    readonly managedRequestHeaders: outputs.GetManagedTransformsManagedRequestHeader[];
    /**
     * The list of Managed Response Transforms.
     */
    readonly managedResponseHeaders: outputs.GetManagedTransformsManagedResponseHeader[];
    /**
     * The unique ID of the zone.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleManagedTransforms = cloudflare.getManagedTransforms({
 *     zoneId: "9f1839b6152d298aca64c4e906b6d074",
 * });
 * ```
 */
export declare function getManagedTransformsOutput(args: GetManagedTransformsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetManagedTransformsResult>;
/**
 * A collection of arguments for invoking getManagedTransforms.
 */
export interface GetManagedTransformsOutputArgs {
    /**
     * The unique ID of the zone.
     */
    zoneId: pulumi.Input<string>;
}
