import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMtlsCertificate = cloudflare.getMtlsCertificate({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     mtlsCertificateId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getMtlsCertificate(args: GetMtlsCertificateArgs, opts?: pulumi.InvokeOptions): Promise<GetMtlsCertificateResult>;
/**
 * A collection of arguments for invoking getMtlsCertificate.
 */
export interface GetMtlsCertificateArgs {
    /**
     * Identifier.
     */
    accountId: string;
    /**
     * Identifier.
     */
    mtlsCertificateId?: string;
}
/**
 * A collection of values returned by getMtlsCertificate.
 */
export interface GetMtlsCertificateResult {
    /**
     * Identifier.
     */
    readonly accountId: string;
    /**
     * Indicates whether the certificate is a CA or leaf certificate.
     */
    readonly ca: boolean;
    /**
     * The uploaded root CA certificate.
     */
    readonly certificates: string;
    /**
     * When the certificate expires.
     */
    readonly expiresOn: string;
    /**
     * Identifier.
     */
    readonly id: string;
    /**
     * The certificate authority that issued the certificate.
     */
    readonly issuer: string;
    /**
     * Identifier.
     */
    readonly mtlsCertificateId?: string;
    /**
     * Optional unique name for the certificate. Only used for human readability.
     */
    readonly name: string;
    /**
     * The certificate serial number.
     */
    readonly serialNumber: string;
    /**
     * The type of hash used for the certificate.
     */
    readonly signature: string;
    /**
     * This is the time the certificate was uploaded.
     */
    readonly uploadedOn: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMtlsCertificate = cloudflare.getMtlsCertificate({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     mtlsCertificateId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getMtlsCertificateOutput(args: GetMtlsCertificateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMtlsCertificateResult>;
/**
 * A collection of arguments for invoking getMtlsCertificate.
 */
export interface GetMtlsCertificateOutputArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Identifier.
     */
    mtlsCertificateId?: pulumi.Input<string>;
}
