import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMtlsCertificates = cloudflare.getMtlsCertificates({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getMtlsCertificates(args: GetMtlsCertificatesArgs, opts?: pulumi.InvokeOptions): Promise<GetMtlsCertificatesResult>;
/**
 * A collection of arguments for invoking getMtlsCertificates.
 */
export interface GetMtlsCertificatesArgs {
    /**
     * Identifier.
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getMtlsCertificates.
 */
export interface GetMtlsCertificatesResult {
    /**
     * Identifier.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetMtlsCertificatesResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleMtlsCertificates = cloudflare.getMtlsCertificates({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getMtlsCertificatesOutput(args: GetMtlsCertificatesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMtlsCertificatesResult>;
/**
 * A collection of arguments for invoking getMtlsCertificates.
 */
export interface GetMtlsCertificatesOutputArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
