import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleNotificationPolicies = cloudflare.getNotificationPolicies({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getNotificationPolicies(args: GetNotificationPoliciesArgs, opts?: pulumi.InvokeOptions): Promise<GetNotificationPoliciesResult>;
/**
 * A collection of arguments for invoking getNotificationPolicies.
 */
export interface GetNotificationPoliciesArgs {
    /**
     * The account id
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getNotificationPolicies.
 */
export interface GetNotificationPoliciesResult {
    /**
     * The account id
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetNotificationPoliciesResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleNotificationPolicies = cloudflare.getNotificationPolicies({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getNotificationPoliciesOutput(args: GetNotificationPoliciesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetNotificationPoliciesResult>;
/**
 * A collection of arguments for invoking getNotificationPolicies.
 */
export interface GetNotificationPoliciesOutputArgs {
    /**
     * The account id
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
