import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleObservatoryScheduledTest = cloudflare.getObservatoryScheduledTest({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     url: "example.com",
 *     region: "us-central1",
 * });
 * ```
 */
export declare function getObservatoryScheduledTest(args: GetObservatoryScheduledTestArgs, opts?: pulumi.InvokeOptions): Promise<GetObservatoryScheduledTestResult>;
/**
 * A collection of arguments for invoking getObservatoryScheduledTest.
 */
export interface GetObservatoryScheduledTestArgs {
    /**
     * A test region.
     * Available values: "asia-east1", "asia-northeast1", "asia-northeast2", "asia-south1", "asia-southeast1", "australia-southeast1", "europe-north1", "europe-southwest1", "europe-west1", "europe-west2", "europe-west3", "europe-west4", "europe-west8", "europe-west9", "me-west1", "southamerica-east1", "us-central1", "us-east1", "us-east4", "us-south1", "us-west1".
     */
    region?: string;
    /**
     * A URL.
     */
    url: string;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getObservatoryScheduledTest.
 */
export interface GetObservatoryScheduledTestResult {
    /**
     * The frequency of the test.
     * Available values: "DAILY", "WEEKLY".
     */
    readonly frequency: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A test region.
     * Available values: "asia-east1", "asia-northeast1", "asia-northeast2", "asia-south1", "asia-southeast1", "australia-southeast1", "europe-north1", "europe-southwest1", "europe-west1", "europe-west2", "europe-west3", "europe-west4", "europe-west8", "europe-west9", "me-west1", "southamerica-east1", "us-central1", "us-east1", "us-east4", "us-south1", "us-west1".
     */
    readonly region: string;
    /**
     * A URL.
     */
    readonly url: string;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleObservatoryScheduledTest = cloudflare.getObservatoryScheduledTest({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     url: "example.com",
 *     region: "us-central1",
 * });
 * ```
 */
export declare function getObservatoryScheduledTestOutput(args: GetObservatoryScheduledTestOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetObservatoryScheduledTestResult>;
/**
 * A collection of arguments for invoking getObservatoryScheduledTest.
 */
export interface GetObservatoryScheduledTestOutputArgs {
    /**
     * A test region.
     * Available values: "asia-east1", "asia-northeast1", "asia-northeast2", "asia-south1", "asia-southeast1", "australia-southeast1", "europe-north1", "europe-southwest1", "europe-west1", "europe-west2", "europe-west3", "europe-west4", "europe-west8", "europe-west9", "me-west1", "southamerica-east1", "us-central1", "us-east1", "us-east4", "us-south1", "us-west1".
     */
    region?: pulumi.Input<string>;
    /**
     * A URL.
     */
    url: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
