import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleOriginCaCertificates = cloudflare.getOriginCaCertificates({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     limit: 10,
 *     offset: 10,
 * });
 * ```
 */
export declare function getOriginCaCertificates(args: GetOriginCaCertificatesArgs, opts?: pulumi.InvokeOptions): Promise<GetOriginCaCertificatesResult>;
/**
 * A collection of arguments for invoking getOriginCaCertificates.
 */
export interface GetOriginCaCertificatesArgs {
    /**
     * Limit to the number of records returned.
     */
    limit?: number;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Offset the results
     */
    offset?: number;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getOriginCaCertificates.
 */
export interface GetOriginCaCertificatesResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Limit to the number of records returned.
     */
    readonly limit?: number;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * Offset the results
     */
    readonly offset?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetOriginCaCertificatesResult[];
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleOriginCaCertificates = cloudflare.getOriginCaCertificates({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     limit: 10,
 *     offset: 10,
 * });
 * ```
 */
export declare function getOriginCaCertificatesOutput(args: GetOriginCaCertificatesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetOriginCaCertificatesResult>;
/**
 * A collection of arguments for invoking getOriginCaCertificates.
 */
export interface GetOriginCaCertificatesOutputArgs {
    /**
     * Limit to the number of records returned.
     */
    limit?: pulumi.Input<number>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Offset the results
     */
    offset?: pulumi.Input<number>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
