import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const examplePageShieldCookiesList = cloudflare.getPageShieldCookiesList({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "asc",
 *     domain: "example.com",
 *     "export": "csv",
 *     hosts: "blog.cloudflare.com,www.example*,*cloudflare.com",
 *     httpOnly: true,
 *     name: "session_id",
 *     orderBy: "first_seen_at",
 *     page: "2",
 *     pageUrl: "example.com/page,*&#47;checkout,example.com/*,*checkout*",
 *     path: "/",
 *     perPage: 100,
 *     sameSite: "strict",
 *     secure: true,
 *     type: "first_party",
 * });
 * ```
 */
export declare function getPageShieldCookiesList(args: GetPageShieldCookiesListArgs, opts?: pulumi.InvokeOptions): Promise<GetPageShieldCookiesListResult>;
/**
 * A collection of arguments for invoking getPageShieldCookiesList.
 */
export interface GetPageShieldCookiesListArgs {
    /**
     * The direction used to sort returned cookies.'
     * Available values: "asc", "desc".
     */
    direction?: string;
    /**
     * Filters the returned cookies that match the specified domain attribute
     */
    domain?: string;
    /**
     * Export the list of cookies as a file.
     * Available values: "csv".
     */
    export?: string;
    /**
     * Includes cookies that match one or more URL-encoded hostnames separated by commas.
     */
    hosts?: string;
    httpOnly?: boolean;
    maxItems?: number;
    name?: string;
    orderBy?: string;
    page?: string;
    pageUrl?: string;
    path?: string;
    perPage?: number;
    sameSite?: string;
    secure?: boolean;
    type?: string;
    /**
     * Identifier
     */
    zoneId: string;
}
/**
 * A collection of values returned by getPageShieldCookiesList.
 */
export interface GetPageShieldCookiesListResult {
    /**
     * The direction used to sort returned cookies.'
     * Available values: "asc", "desc".
     */
    readonly direction?: string;
    /**
     * Filters the returned cookies that match the specified domain attribute
     */
    readonly domain?: string;
    /**
     * Export the list of cookies as a file.
     * Available values: "csv".
     */
    readonly export?: string;
    /**
     * Includes cookies that match one or more URL-encoded hostnames separated by commas.
     */
    readonly hosts?: string;
    readonly httpOnly?: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly maxItems?: number;
    readonly name?: string;
    readonly orderBy?: string;
    readonly page?: string;
    readonly pageUrl?: string;
    readonly path?: string;
    readonly perPage?: number;
    readonly results: outputs.GetPageShieldCookiesListResult[];
    readonly sameSite?: string;
    readonly secure?: boolean;
    readonly type?: string;
    /**
     * Identifier
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const examplePageShieldCookiesList = cloudflare.getPageShieldCookiesList({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "asc",
 *     domain: "example.com",
 *     "export": "csv",
 *     hosts: "blog.cloudflare.com,www.example*,*cloudflare.com",
 *     httpOnly: true,
 *     name: "session_id",
 *     orderBy: "first_seen_at",
 *     page: "2",
 *     pageUrl: "example.com/page,*&#47;checkout,example.com/*,*checkout*",
 *     path: "/",
 *     perPage: 100,
 *     sameSite: "strict",
 *     secure: true,
 *     type: "first_party",
 * });
 * ```
 */
export declare function getPageShieldCookiesListOutput(args: GetPageShieldCookiesListOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPageShieldCookiesListResult>;
/**
 * A collection of arguments for invoking getPageShieldCookiesList.
 */
export interface GetPageShieldCookiesListOutputArgs {
    /**
     * The direction used to sort returned cookies.'
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    /**
     * Filters the returned cookies that match the specified domain attribute
     */
    domain?: pulumi.Input<string>;
    /**
     * Export the list of cookies as a file.
     * Available values: "csv".
     */
    export?: pulumi.Input<string>;
    /**
     * Includes cookies that match one or more URL-encoded hostnames separated by commas.
     */
    hosts?: pulumi.Input<string>;
    httpOnly?: pulumi.Input<boolean>;
    maxItems?: pulumi.Input<number>;
    name?: pulumi.Input<string>;
    orderBy?: pulumi.Input<string>;
    page?: pulumi.Input<string>;
    pageUrl?: pulumi.Input<string>;
    path?: pulumi.Input<string>;
    perPage?: pulumi.Input<number>;
    sameSite?: pulumi.Input<string>;
    secure?: pulumi.Input<boolean>;
    type?: pulumi.Input<string>;
    /**
     * Identifier
     */
    zoneId: pulumi.Input<string>;
}
