import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const examplePagesDomain = cloudflare.getPagesDomain({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     projectName: "this-is-my-project-01",
 *     domainName: "this-is-my-domain-01.com",
 * });
 * ```
 */
export declare function getPagesDomain(args: GetPagesDomainArgs, opts?: pulumi.InvokeOptions): Promise<GetPagesDomainResult>;
/**
 * A collection of arguments for invoking getPagesDomain.
 */
export interface GetPagesDomainArgs {
    /**
     * Identifier
     */
    accountId: string;
    /**
     * Name of the domain.
     */
    domainName?: string;
    /**
     * Name of the project.
     */
    projectName: string;
}
/**
 * A collection of values returned by getPagesDomain.
 */
export interface GetPagesDomainResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * Available values: "google", "letsEncrypt".
     */
    readonly certificateAuthority: string;
    readonly createdOn: string;
    readonly domainId: string;
    /**
     * Name of the domain.
     */
    readonly domainName?: string;
    /**
     * Name of the domain.
     */
    readonly id: string;
    readonly name: string;
    /**
     * Name of the project.
     */
    readonly projectName: string;
    /**
     * Available values: "initializing", "pending", "active", "deactivated", "blocked", "error".
     */
    readonly status: string;
    readonly validationData: outputs.GetPagesDomainValidationData;
    readonly verificationData: outputs.GetPagesDomainVerificationData;
    readonly zoneTag: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const examplePagesDomain = cloudflare.getPagesDomain({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     projectName: "this-is-my-project-01",
 *     domainName: "this-is-my-domain-01.com",
 * });
 * ```
 */
export declare function getPagesDomainOutput(args: GetPagesDomainOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPagesDomainResult>;
/**
 * A collection of arguments for invoking getPagesDomain.
 */
export interface GetPagesDomainOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the domain.
     */
    domainName?: pulumi.Input<string>;
    /**
     * Name of the project.
     */
    projectName: pulumi.Input<string>;
}
