import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const examplePagesDomains = cloudflare.getPagesDomains({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     projectName: "this-is-my-project-01",
 * });
 * ```
 */
export declare function getPagesDomains(args: GetPagesDomainsArgs, opts?: pulumi.InvokeOptions): Promise<GetPagesDomainsResult>;
/**
 * A collection of arguments for invoking getPagesDomains.
 */
export interface GetPagesDomainsArgs {
    /**
     * Identifier
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Name of the project.
     */
    projectName: string;
}
/**
 * A collection of values returned by getPagesDomains.
 */
export interface GetPagesDomainsResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * Name of the project.
     */
    readonly projectName: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetPagesDomainsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const examplePagesDomains = cloudflare.getPagesDomains({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     projectName: "this-is-my-project-01",
 * });
 * ```
 */
export declare function getPagesDomainsOutput(args: GetPagesDomainsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPagesDomainsResult>;
/**
 * A collection of arguments for invoking getPagesDomains.
 */
export interface GetPagesDomainsOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Name of the project.
     */
    projectName: pulumi.Input<string>;
}
