import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const examplePagesProjects = cloudflare.getPagesProjects({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getPagesProjects(args: GetPagesProjectsArgs, opts?: pulumi.InvokeOptions): Promise<GetPagesProjectsResult>;
/**
 * A collection of arguments for invoking getPagesProjects.
 */
export interface GetPagesProjectsArgs {
    /**
     * Identifier
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getPagesProjects.
 */
export interface GetPagesProjectsResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetPagesProjectsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const examplePagesProjects = cloudflare.getPagesProjects({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getPagesProjectsOutput(args: GetPagesProjectsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPagesProjectsResult>;
/**
 * A collection of arguments for invoking getPagesProjects.
 */
export interface GetPagesProjectsOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
