import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleQueue = cloudflare.getQueue({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     queueId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getQueue(args: GetQueueArgs, opts?: pulumi.InvokeOptions): Promise<GetQueueResult>;
/**
 * A collection of arguments for invoking getQueue.
 */
export interface GetQueueArgs {
    /**
     * A Resource identifier.
     */
    accountId: string;
    /**
     * A Resource identifier.
     */
    queueId?: string;
}
/**
 * A collection of values returned by getQueue.
 */
export interface GetQueueResult {
    /**
     * A Resource identifier.
     */
    readonly accountId: string;
    readonly consumers: outputs.GetQueueConsumer[];
    readonly consumersTotalCount: number;
    readonly createdOn: string;
    /**
     * A Resource identifier.
     */
    readonly id: string;
    readonly modifiedOn: string;
    readonly producers: outputs.GetQueueProducer[];
    readonly producersTotalCount: number;
    /**
     * A Resource identifier.
     */
    readonly queueId: string;
    readonly queueName: string;
    readonly settings: outputs.GetQueueSettings;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleQueue = cloudflare.getQueue({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     queueId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getQueueOutput(args: GetQueueOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetQueueResult>;
/**
 * A collection of arguments for invoking getQueue.
 */
export interface GetQueueOutputArgs {
    /**
     * A Resource identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * A Resource identifier.
     */
    queueId?: pulumi.Input<string>;
}
