import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleQueueConsumer = cloudflare.getQueueConsumer({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     queueId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getQueueConsumer(args: GetQueueConsumerArgs, opts?: pulumi.InvokeOptions): Promise<GetQueueConsumerResult>;
/**
 * A collection of arguments for invoking getQueueConsumer.
 */
export interface GetQueueConsumerArgs {
    /**
     * A Resource identifier.
     */
    accountId: string;
    /**
     * A Resource identifier.
     */
    queueId: string;
}
/**
 * A collection of values returned by getQueueConsumer.
 */
export interface GetQueueConsumerResult {
    /**
     * A Resource identifier.
     */
    readonly accountId: string;
    /**
     * A Resource identifier.
     */
    readonly consumerId: string;
    readonly createdOn: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A Resource identifier.
     */
    readonly queueId: string;
    /**
     * Name of a Worker
     */
    readonly script: string;
    /**
     * Name of a Worker
     */
    readonly scriptName: string;
    readonly settings: outputs.GetQueueConsumerSettings;
    /**
     * Available values: "worker", "httpPull".
     */
    readonly type: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleQueueConsumer = cloudflare.getQueueConsumer({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     queueId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getQueueConsumerOutput(args: GetQueueConsumerOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetQueueConsumerResult>;
/**
 * A collection of arguments for invoking getQueueConsumer.
 */
export interface GetQueueConsumerOutputArgs {
    /**
     * A Resource identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * A Resource identifier.
     */
    queueId: pulumi.Input<string>;
}
