import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2Bucket = cloudflare.getR2Bucket({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 * });
 * ```
 */
export declare function getR2Bucket(args: GetR2BucketArgs, opts?: pulumi.InvokeOptions): Promise<GetR2BucketResult>;
/**
 * A collection of arguments for invoking getR2Bucket.
 */
export interface GetR2BucketArgs {
    /**
     * Account ID.
     */
    accountId: string;
    /**
     * Name of the bucket.
     */
    bucketName: string;
}
/**
 * A collection of values returned by getR2Bucket.
 */
export interface GetR2BucketResult {
    /**
     * Account ID.
     */
    readonly accountId: string;
    /**
     * Name of the bucket.
     */
    readonly bucketName: string;
    /**
     * Creation timestamp.
     */
    readonly creationDate: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Jurisdiction where objects in this bucket are guaranteed to be stored.
     * Available values: "default", "eu", "fedramp".
     */
    readonly jurisdiction: string;
    /**
     * Location of the bucket.
     * Available values: "apac", "eeur", "enam", "weur", "wnam", "oc".
     */
    readonly location: string;
    /**
     * Name of the bucket.
     */
    readonly name: string;
    /**
     * Storage class for newly uploaded objects, unless specified otherwise.
     * Available values: "Standard", "InfrequentAccess".
     */
    readonly storageClass: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2Bucket = cloudflare.getR2Bucket({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 * });
 * ```
 */
export declare function getR2BucketOutput(args: GetR2BucketOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetR2BucketResult>;
/**
 * A collection of arguments for invoking getR2Bucket.
 */
export interface GetR2BucketOutputArgs {
    /**
     * Account ID.
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName: pulumi.Input<string>;
}
