import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2BucketCors = cloudflare.getR2BucketCors({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 * });
 * ```
 */
export declare function getR2BucketCors(args: GetR2BucketCorsArgs, opts?: pulumi.InvokeOptions): Promise<GetR2BucketCorsResult>;
/**
 * A collection of arguments for invoking getR2BucketCors.
 */
export interface GetR2BucketCorsArgs {
    /**
     * Account ID.
     */
    accountId: string;
    /**
     * Name of the bucket.
     */
    bucketName: string;
}
/**
 * A collection of values returned by getR2BucketCors.
 */
export interface GetR2BucketCorsResult {
    /**
     * Account ID.
     */
    readonly accountId: string;
    /**
     * Name of the bucket.
     */
    readonly bucketName: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly rules: outputs.GetR2BucketCorsRule[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2BucketCors = cloudflare.getR2BucketCors({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 * });
 * ```
 */
export declare function getR2BucketCorsOutput(args: GetR2BucketCorsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetR2BucketCorsResult>;
/**
 * A collection of arguments for invoking getR2BucketCors.
 */
export interface GetR2BucketCorsOutputArgs {
    /**
     * Account ID.
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName: pulumi.Input<string>;
}
