import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2BucketEventNotification = cloudflare.getR2BucketEventNotification({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 *     queueId: "queue_id",
 * });
 * ```
 */
export declare function getR2BucketEventNotification(args: GetR2BucketEventNotificationArgs, opts?: pulumi.InvokeOptions): Promise<GetR2BucketEventNotificationResult>;
/**
 * A collection of arguments for invoking getR2BucketEventNotification.
 */
export interface GetR2BucketEventNotificationArgs {
    /**
     * Account ID.
     */
    accountId: string;
    /**
     * Name of the bucket.
     */
    bucketName: string;
    /**
     * Queue ID.
     */
    queueId: string;
}
/**
 * A collection of values returned by getR2BucketEventNotification.
 */
export interface GetR2BucketEventNotificationResult {
    /**
     * Transition to abort ongoing multipart uploads.
     */
    readonly abortMultipartUploadsTransition: outputs.GetR2BucketEventNotificationAbortMultipartUploadsTransition;
    /**
     * Account ID.
     */
    readonly accountId: string;
    /**
     * Name of the bucket.
     */
    readonly bucketName: string;
    /**
     * Conditions that apply to all transitions of this rule.
     */
    readonly conditions: outputs.GetR2BucketEventNotificationConditions;
    /**
     * Transition to delete objects.
     */
    readonly deleteObjectsTransition: outputs.GetR2BucketEventNotificationDeleteObjectsTransition;
    /**
     * Whether or not this rule is in effect.
     */
    readonly enabled: boolean;
    /**
     * Unique identifier for this rule.
     */
    readonly id: string;
    /**
     * Queue ID.
     */
    readonly queueId: string;
    /**
     * Transitions to change the storage class of objects.
     */
    readonly storageClassTransitions: outputs.GetR2BucketEventNotificationStorageClassTransition[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2BucketEventNotification = cloudflare.getR2BucketEventNotification({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 *     queueId: "queue_id",
 * });
 * ```
 */
export declare function getR2BucketEventNotificationOutput(args: GetR2BucketEventNotificationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetR2BucketEventNotificationResult>;
/**
 * A collection of arguments for invoking getR2BucketEventNotification.
 */
export interface GetR2BucketEventNotificationOutputArgs {
    /**
     * Account ID.
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName: pulumi.Input<string>;
    /**
     * Queue ID.
     */
    queueId: pulumi.Input<string>;
}
