import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2BucketLock = cloudflare.getR2BucketLock({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 * });
 * ```
 */
export declare function getR2BucketLock(args: GetR2BucketLockArgs, opts?: pulumi.InvokeOptions): Promise<GetR2BucketLockResult>;
/**
 * A collection of arguments for invoking getR2BucketLock.
 */
export interface GetR2BucketLockArgs {
    /**
     * Account ID.
     */
    accountId: string;
    /**
     * Name of the bucket.
     */
    bucketName: string;
}
/**
 * A collection of values returned by getR2BucketLock.
 */
export interface GetR2BucketLockResult {
    /**
     * Account ID.
     */
    readonly accountId: string;
    /**
     * Name of the bucket.
     */
    readonly bucketName: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly rules: outputs.GetR2BucketLockRule[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2BucketLock = cloudflare.getR2BucketLock({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 * });
 * ```
 */
export declare function getR2BucketLockOutput(args: GetR2BucketLockOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetR2BucketLockResult>;
/**
 * A collection of arguments for invoking getR2BucketLock.
 */
export interface GetR2BucketLockOutputArgs {
    /**
     * Account ID.
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName: pulumi.Input<string>;
}
