import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2BucketSippy = cloudflare.getR2BucketSippy({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 * });
 * ```
 */
export declare function getR2BucketSippy(args: GetR2BucketSippyArgs, opts?: pulumi.InvokeOptions): Promise<GetR2BucketSippyResult>;
/**
 * A collection of arguments for invoking getR2BucketSippy.
 */
export interface GetR2BucketSippyArgs {
    /**
     * Account ID.
     */
    accountId: string;
    /**
     * Name of the bucket.
     */
    bucketName: string;
}
/**
 * A collection of values returned by getR2BucketSippy.
 */
export interface GetR2BucketSippyResult {
    /**
     * Account ID.
     */
    readonly accountId: string;
    /**
     * Name of the bucket.
     */
    readonly bucketName: string;
    /**
     * Details about the configured destination bucket.
     */
    readonly destination: outputs.GetR2BucketSippyDestination;
    /**
     * State of Sippy for this bucket.
     */
    readonly enabled: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Details about the configured source bucket.
     */
    readonly source: outputs.GetR2BucketSippySource;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2BucketSippy = cloudflare.getR2BucketSippy({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 * });
 * ```
 */
export declare function getR2BucketSippyOutput(args: GetR2BucketSippyOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetR2BucketSippyResult>;
/**
 * A collection of arguments for invoking getR2BucketSippy.
 */
export interface GetR2BucketSippyOutputArgs {
    /**
     * Account ID.
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName: pulumi.Input<string>;
}
