import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2CustomDomain = cloudflare.getR2CustomDomain({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 *     domain: "example-domain/custom-domain.com",
 * });
 * ```
 */
export declare function getR2CustomDomain(args: GetR2CustomDomainArgs, opts?: pulumi.InvokeOptions): Promise<GetR2CustomDomainResult>;
/**
 * A collection of arguments for invoking getR2CustomDomain.
 */
export interface GetR2CustomDomainArgs {
    /**
     * Account ID.
     */
    accountId: string;
    /**
     * Name of the bucket.
     */
    bucketName: string;
    /**
     * Name of the custom domain.
     */
    domain: string;
}
/**
 * A collection of values returned by getR2CustomDomain.
 */
export interface GetR2CustomDomainResult {
    /**
     * Account ID.
     */
    readonly accountId: string;
    /**
     * Name of the bucket.
     */
    readonly bucketName: string;
    /**
     * Name of the custom domain.
     */
    readonly domain: string;
    /**
     * Whether this bucket is publicly accessible at the specified custom domain.
     */
    readonly enabled: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Minimum TLS Version the custom domain will accept for incoming connections. If not set, defaults to 1.0.
     * Available values: "1.0", "1.1", "1.2", "1.3".
     */
    readonly minTls: string;
    readonly status: outputs.GetR2CustomDomainStatus;
    /**
     * Zone ID of the custom domain resides in.
     */
    readonly zoneId: string;
    /**
     * Zone that the custom domain resides in.
     */
    readonly zoneName: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2CustomDomain = cloudflare.getR2CustomDomain({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 *     domain: "example-domain/custom-domain.com",
 * });
 * ```
 */
export declare function getR2CustomDomainOutput(args: GetR2CustomDomainOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetR2CustomDomainResult>;
/**
 * A collection of arguments for invoking getR2CustomDomain.
 */
export interface GetR2CustomDomainOutputArgs {
    /**
     * Account ID.
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName: pulumi.Input<string>;
    /**
     * Name of the custom domain.
     */
    domain: pulumi.Input<string>;
}
