import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleRateLimits = cloudflare.getRateLimits({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getRateLimits(args: GetRateLimitsArgs, opts?: pulumi.InvokeOptions): Promise<GetRateLimitsResult>;
/**
 * A collection of arguments for invoking getRateLimits.
 */
export interface GetRateLimitsArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Defines an identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getRateLimits.
 */
export interface GetRateLimitsResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetRateLimitsResult[];
    /**
     * Defines an identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleRateLimits = cloudflare.getRateLimits({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getRateLimitsOutput(args: GetRateLimitsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRateLimitsResult>;
/**
 * A collection of arguments for invoking getRateLimits.
 */
export interface GetRateLimitsOutputArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Defines an identifier.
     */
    zoneId: pulumi.Input<string>;
}
