import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleRegionalHostname = cloudflare.getRegionalHostname({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     hostname: "foo.example.com",
 * });
 * ```
 */
export declare function getRegionalHostname(args: GetRegionalHostnameArgs, opts?: pulumi.InvokeOptions): Promise<GetRegionalHostnameResult>;
/**
 * A collection of arguments for invoking getRegionalHostname.
 */
export interface GetRegionalHostnameArgs {
    /**
     * DNS hostname to be regionalized, must be a subdomain of the zone. Wildcards are supported for one level, e.g `*.example.com`
     */
    hostname?: string;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getRegionalHostname.
 */
export interface GetRegionalHostnameResult {
    /**
     * When the regional hostname was created
     */
    readonly createdOn: string;
    /**
     * DNS hostname to be regionalized, must be a subdomain of the zone. Wildcards are supported for one level, e.g `*.example.com`
     */
    readonly hostname: string;
    /**
     * DNS hostname to be regionalized, must be a subdomain of the zone. Wildcards are supported for one level, e.g `*.example.com`
     */
    readonly id: string;
    /**
     * Identifying key for the region
     */
    readonly regionKey: string;
    /**
     * Configure which routing method to use for the regional hostname
     */
    readonly routing: string;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleRegionalHostname = cloudflare.getRegionalHostname({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     hostname: "foo.example.com",
 * });
 * ```
 */
export declare function getRegionalHostnameOutput(args: GetRegionalHostnameOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRegionalHostnameResult>;
/**
 * A collection of arguments for invoking getRegionalHostname.
 */
export interface GetRegionalHostnameOutputArgs {
    /**
     * DNS hostname to be regionalized, must be a subdomain of the zone. Wildcards are supported for one level, e.g `*.example.com`
     */
    hostname?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
