import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleRegistrarDomains = cloudflare.getRegistrarDomains({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getRegistrarDomains(args: GetRegistrarDomainsArgs, opts?: pulumi.InvokeOptions): Promise<GetRegistrarDomainsResult>;
/**
 * A collection of arguments for invoking getRegistrarDomains.
 */
export interface GetRegistrarDomainsArgs {
    /**
     * Identifier
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getRegistrarDomains.
 */
export interface GetRegistrarDomainsResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetRegistrarDomainsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleRegistrarDomains = cloudflare.getRegistrarDomains({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getRegistrarDomainsOutput(args: GetRegistrarDomainsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRegistrarDomainsResult>;
/**
 * A collection of arguments for invoking getRegistrarDomains.
 */
export interface GetRegistrarDomainsOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
