import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleResourceGroup = cloudflare.getResourceGroup({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     resourceGroupId: "6d7f2f5f5b1d4a0e9081fdc98d432fd1",
 * });
 * ```
 */
export declare function getResourceGroup(args: GetResourceGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetResourceGroupResult>;
/**
 * A collection of arguments for invoking getResourceGroup.
 */
export interface GetResourceGroupArgs {
    /**
     * Account identifier tag.
     */
    accountId: string;
    /**
     * Resource Group identifier tag.
     */
    resourceGroupId: string;
}
/**
 * A collection of values returned by getResourceGroup.
 */
export interface GetResourceGroupResult {
    /**
     * Account identifier tag.
     */
    readonly accountId: string;
    /**
     * Identifier of the group.
     */
    readonly id: string;
    /**
     * Attributes associated to the resource group.
     */
    readonly meta: outputs.GetResourceGroupMeta;
    /**
     * Name of the resource group.
     */
    readonly name: string;
    /**
     * Resource Group identifier tag.
     */
    readonly resourceGroupId: string;
    /**
     * The scope associated to the resource group
     */
    readonly scopes: outputs.GetResourceGroupScope[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleResourceGroup = cloudflare.getResourceGroup({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     resourceGroupId: "6d7f2f5f5b1d4a0e9081fdc98d432fd1",
 * });
 * ```
 */
export declare function getResourceGroupOutput(args: GetResourceGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetResourceGroupResult>;
/**
 * A collection of arguments for invoking getResourceGroup.
 */
export interface GetResourceGroupOutputArgs {
    /**
     * Account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * Resource Group identifier tag.
     */
    resourceGroupId: pulumi.Input<string>;
}
