import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleResourceGroups = cloudflare.getResourceGroups({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     id: "6d7f2f5f5b1d4a0e9081fdc98d432fd1",
 *     name: "NameOfTheResourceGroup",
 * });
 * ```
 */
export declare function getResourceGroups(args: GetResourceGroupsArgs, opts?: pulumi.InvokeOptions): Promise<GetResourceGroupsResult>;
/**
 * A collection of arguments for invoking getResourceGroups.
 */
export interface GetResourceGroupsArgs {
    /**
     * Account identifier tag.
     */
    accountId: string;
    /**
     * ID of the resource group to be fetched.
     */
    id?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Name of the resource group to be fetched.
     */
    name?: string;
}
/**
 * A collection of values returned by getResourceGroups.
 */
export interface GetResourceGroupsResult {
    /**
     * Account identifier tag.
     */
    readonly accountId: string;
    /**
     * ID of the resource group to be fetched.
     */
    readonly id?: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * Name of the resource group to be fetched.
     */
    readonly name?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetResourceGroupsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleResourceGroups = cloudflare.getResourceGroups({
 *     accountId: "eb78d65290b24279ba6f44721b3ea3c4",
 *     id: "6d7f2f5f5b1d4a0e9081fdc98d432fd1",
 *     name: "NameOfTheResourceGroup",
 * });
 * ```
 */
export declare function getResourceGroupsOutput(args: GetResourceGroupsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetResourceGroupsResult>;
/**
 * A collection of arguments for invoking getResourceGroups.
 */
export interface GetResourceGroupsOutputArgs {
    /**
     * Account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * ID of the resource group to be fetched.
     */
    id?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Name of the resource group to be fetched.
     */
    name?: pulumi.Input<string>;
}
