import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleSnippetsList = cloudflare.getSnippetsList({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getSnippetsList(args: GetSnippetsListArgs, opts?: pulumi.InvokeOptions): Promise<GetSnippetsListResult>;
/**
 * A collection of arguments for invoking getSnippetsList.
 */
export interface GetSnippetsListArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Identifier
     */
    zoneId: string;
}
/**
 * A collection of values returned by getSnippetsList.
 */
export interface GetSnippetsListResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetSnippetsListResult[];
    /**
     * Identifier
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleSnippetsList = cloudflare.getSnippetsList({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getSnippetsListOutput(args: GetSnippetsListOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSnippetsListResult>;
/**
 * A collection of arguments for invoking getSnippetsList.
 */
export interface GetSnippetsListOutputArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Identifier
     */
    zoneId: pulumi.Input<string>;
}
