import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleSpectrumApplications = cloudflare.getSpectrumApplications({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getSpectrumApplications(args: GetSpectrumApplicationsArgs, opts?: pulumi.InvokeOptions): Promise<GetSpectrumApplicationsResult>;
/**
 * A collection of arguments for invoking getSpectrumApplications.
 */
export interface GetSpectrumApplicationsArgs {
    /**
     * Sets the direction by which results are ordered.
     * Available values: "asc", "desc".
     */
    direction?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Application field by which results are ordered.
     * Available values: "protocol", "app*id", "created*on", "modifiedOn", "dns".
     */
    order?: string;
    /**
     * Zone identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getSpectrumApplications.
 */
export interface GetSpectrumApplicationsResult {
    /**
     * Sets the direction by which results are ordered.
     * Available values: "asc", "desc".
     */
    readonly direction: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * Application field by which results are ordered.
     * Available values: "protocol", "app*id", "created*on", "modifiedOn", "dns".
     */
    readonly order: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetSpectrumApplicationsResult[];
    /**
     * Zone identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleSpectrumApplications = cloudflare.getSpectrumApplications({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getSpectrumApplicationsOutput(args: GetSpectrumApplicationsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSpectrumApplicationsResult>;
/**
 * A collection of arguments for invoking getSpectrumApplications.
 */
export interface GetSpectrumApplicationsOutputArgs {
    /**
     * Sets the direction by which results are ordered.
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Application field by which results are ordered.
     * Available values: "protocol", "app*id", "created*on", "modifiedOn", "dns".
     */
    order?: pulumi.Input<string>;
    /**
     * Zone identifier.
     */
    zoneId: pulumi.Input<string>;
}
