import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleStreamAudioTrack = cloudflare.getStreamAudioTrack({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     identifier: "ea95132c15732412d22c1476fa83f27a",
 * });
 * ```
 */
export declare function getStreamAudioTrack(args: GetStreamAudioTrackArgs, opts?: pulumi.InvokeOptions): Promise<GetStreamAudioTrackResult>;
/**
 * A collection of arguments for invoking getStreamAudioTrack.
 */
export interface GetStreamAudioTrackArgs {
    /**
     * The account identifier tag.
     */
    accountId: string;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    identifier: string;
}
/**
 * A collection of values returned by getStreamAudioTrack.
 */
export interface GetStreamAudioTrackResult {
    /**
     * The account identifier tag.
     */
    readonly accountId: string;
    /**
     * Denotes whether the audio track will be played by default in a player.
     */
    readonly default: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    readonly identifier: string;
    /**
     * A string to uniquely identify the track amongst other audio track labels for the specified video.
     */
    readonly label: string;
    /**
     * Specifies the processing status of the video.
     * Available values: "queued", "ready", "error".
     */
    readonly status: string;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    readonly uid: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleStreamAudioTrack = cloudflare.getStreamAudioTrack({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     identifier: "ea95132c15732412d22c1476fa83f27a",
 * });
 * ```
 */
export declare function getStreamAudioTrackOutput(args: GetStreamAudioTrackOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStreamAudioTrackResult>;
/**
 * A collection of arguments for invoking getStreamAudioTrack.
 */
export interface GetStreamAudioTrackOutputArgs {
    /**
     * The account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    identifier: pulumi.Input<string>;
}
