import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleStreamCaptionLanguage = cloudflare.getStreamCaptionLanguage({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     identifier: "ea95132c15732412d22c1476fa83f27a",
 *     language: "tr",
 * });
 * ```
 */
export declare function getStreamCaptionLanguage(args: GetStreamCaptionLanguageArgs, opts?: pulumi.InvokeOptions): Promise<GetStreamCaptionLanguageResult>;
/**
 * A collection of arguments for invoking getStreamCaptionLanguage.
 */
export interface GetStreamCaptionLanguageArgs {
    /**
     * Identifier.
     */
    accountId: string;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    identifier: string;
    /**
     * The language tag in BCP 47 format.
     */
    language: string;
}
/**
 * A collection of values returned by getStreamCaptionLanguage.
 */
export interface GetStreamCaptionLanguageResult {
    /**
     * Identifier.
     */
    readonly accountId: string;
    /**
     * Whether the caption was generated via AI.
     */
    readonly generated: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    readonly identifier: string;
    /**
     * The language label displayed in the native language to users.
     */
    readonly label: string;
    /**
     * The language tag in BCP 47 format.
     */
    readonly language: string;
    /**
     * The status of a generated caption.
     * Available values: "ready", "inprogress", "error".
     */
    readonly status: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleStreamCaptionLanguage = cloudflare.getStreamCaptionLanguage({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     identifier: "ea95132c15732412d22c1476fa83f27a",
 *     language: "tr",
 * });
 * ```
 */
export declare function getStreamCaptionLanguageOutput(args: GetStreamCaptionLanguageOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStreamCaptionLanguageResult>;
/**
 * A collection of arguments for invoking getStreamCaptionLanguage.
 */
export interface GetStreamCaptionLanguageOutputArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    identifier: pulumi.Input<string>;
    /**
     * The language tag in BCP 47 format.
     */
    language: pulumi.Input<string>;
}
