import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleStreamDownload = cloudflare.getStreamDownload({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     identifier: "ea95132c15732412d22c1476fa83f27a",
 * });
 * ```
 */
export declare function getStreamDownload(args: GetStreamDownloadArgs, opts?: pulumi.InvokeOptions): Promise<GetStreamDownloadResult>;
/**
 * A collection of arguments for invoking getStreamDownload.
 */
export interface GetStreamDownloadArgs {
    /**
     * Identifier.
     */
    accountId: string;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    identifier: string;
}
/**
 * A collection of values returned by getStreamDownload.
 */
export interface GetStreamDownloadResult {
    /**
     * Identifier.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    readonly identifier: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleStreamDownload = cloudflare.getStreamDownload({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     identifier: "ea95132c15732412d22c1476fa83f27a",
 * });
 * ```
 */
export declare function getStreamDownloadOutput(args: GetStreamDownloadOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStreamDownloadResult>;
/**
 * A collection of arguments for invoking getStreamDownload.
 */
export interface GetStreamDownloadOutputArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    identifier: pulumi.Input<string>;
}
