import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleStreamWatermarks = cloudflare.getStreamWatermarks({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getStreamWatermarks(args: GetStreamWatermarksArgs, opts?: pulumi.InvokeOptions): Promise<GetStreamWatermarksResult>;
/**
 * A collection of arguments for invoking getStreamWatermarks.
 */
export interface GetStreamWatermarksArgs {
    /**
     * The account identifier tag.
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getStreamWatermarks.
 */
export interface GetStreamWatermarksResult {
    /**
     * The account identifier tag.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetStreamWatermarksResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleStreamWatermarks = cloudflare.getStreamWatermarks({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getStreamWatermarksOutput(args: GetStreamWatermarksOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStreamWatermarksResult>;
/**
 * A collection of arguments for invoking getStreamWatermarks.
 */
export interface GetStreamWatermarksOutputArgs {
    /**
     * The account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
