import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleStreams = cloudflare.getStreams({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     creator: "creator-id_abcde12345",
 *     end: "2014-01-02T02:20:00Z",
 *     search: "puppy.mp4",
 *     start: "2014-01-02T02:20:00Z",
 *     status: "inprogress",
 *     type: "live",
 * });
 * ```
 */
export declare function getStreams(args: GetStreamsArgs, opts?: pulumi.InvokeOptions): Promise<GetStreamsResult>;
/**
 * A collection of arguments for invoking getStreams.
 */
export interface GetStreamsArgs {
    /**
     * The account identifier tag.
     */
    accountId: string;
    /**
     * Lists videos in ascending order of creation.
     */
    asc?: boolean;
    /**
     * A user-defined identifier for the media creator.
     */
    creator?: string;
    /**
     * Lists videos created before the specified date.
     */
    end?: string;
    /**
     * Includes the total number of videos associated with the submitted query parameters.
     */
    includeCounts?: boolean;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Searches over the `name` key in the `meta` field. This field can be set with or after the upload request.
     */
    search?: string;
    /**
     * Lists videos created after the specified date.
     */
    start?: string;
    /**
     * Specifies the processing status for all quality levels for a video.
     * Available values: "pendingupload", "downloading", "queued", "inprogress", "ready", "error".
     */
    status?: string;
    /**
     * Specifies whether the video is `vod` or `live`.
     */
    type?: string;
}
/**
 * A collection of values returned by getStreams.
 */
export interface GetStreamsResult {
    /**
     * The account identifier tag.
     */
    readonly accountId: string;
    /**
     * Lists videos in ascending order of creation.
     */
    readonly asc: boolean;
    /**
     * A user-defined identifier for the media creator.
     */
    readonly creator?: string;
    /**
     * Lists videos created before the specified date.
     */
    readonly end?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Includes the total number of videos associated with the submitted query parameters.
     */
    readonly includeCounts: boolean;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetStreamsResult[];
    /**
     * Searches over the `name` key in the `meta` field. This field can be set with or after the upload request.
     */
    readonly search?: string;
    /**
     * Lists videos created after the specified date.
     */
    readonly start?: string;
    /**
     * Specifies the processing status for all quality levels for a video.
     * Available values: "pendingupload", "downloading", "queued", "inprogress", "ready", "error".
     */
    readonly status?: string;
    /**
     * Specifies whether the video is `vod` or `live`.
     */
    readonly type?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleStreams = cloudflare.getStreams({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     creator: "creator-id_abcde12345",
 *     end: "2014-01-02T02:20:00Z",
 *     search: "puppy.mp4",
 *     start: "2014-01-02T02:20:00Z",
 *     status: "inprogress",
 *     type: "live",
 * });
 * ```
 */
export declare function getStreamsOutput(args: GetStreamsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStreamsResult>;
/**
 * A collection of arguments for invoking getStreams.
 */
export interface GetStreamsOutputArgs {
    /**
     * The account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * Lists videos in ascending order of creation.
     */
    asc?: pulumi.Input<boolean>;
    /**
     * A user-defined identifier for the media creator.
     */
    creator?: pulumi.Input<string>;
    /**
     * Lists videos created before the specified date.
     */
    end?: pulumi.Input<string>;
    /**
     * Includes the total number of videos associated with the submitted query parameters.
     */
    includeCounts?: pulumi.Input<boolean>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Searches over the `name` key in the `meta` field. This field can be set with or after the upload request.
     */
    search?: pulumi.Input<string>;
    /**
     * Lists videos created after the specified date.
     */
    start?: pulumi.Input<string>;
    /**
     * Specifies the processing status for all quality levels for a video.
     * Available values: "pendingupload", "downloading", "queued", "inprogress", "ready", "error".
     */
    status?: pulumi.Input<string>;
    /**
     * Specifies whether the video is `vod` or `live`.
     */
    type?: pulumi.Input<string>;
}
