import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleTieredCache = cloudflare.getTieredCache({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getTieredCache(args: GetTieredCacheArgs, opts?: pulumi.InvokeOptions): Promise<GetTieredCacheResult>;
/**
 * A collection of arguments for invoking getTieredCache.
 */
export interface GetTieredCacheArgs {
    /**
     * Identifier
     */
    zoneId: string;
}
/**
 * A collection of values returned by getTieredCache.
 */
export interface GetTieredCacheResult {
    /**
     * Whether the setting is editable
     */
    readonly editable: boolean;
    /**
     * ID of the zone setting.
     * Available values: "tiered*cache*smart*topology*enable".
     */
    readonly id: string;
    /**
     * Last time this setting was modified.
     */
    readonly modifiedOn: string;
    /**
     * The value of the feature
     * Available values: "on", "off".
     */
    readonly value: string;
    /**
     * Identifier
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleTieredCache = cloudflare.getTieredCache({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getTieredCacheOutput(args: GetTieredCacheOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTieredCacheResult>;
/**
 * A collection of arguments for invoking getTieredCache.
 */
export interface GetTieredCacheOutputArgs {
    /**
     * Identifier
     */
    zoneId: pulumi.Input<string>;
}
