import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleTotalTls = cloudflare.getTotalTls({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getTotalTls(args: GetTotalTlsArgs, opts?: pulumi.InvokeOptions): Promise<GetTotalTlsResult>;
/**
 * A collection of arguments for invoking getTotalTls.
 */
export interface GetTotalTlsArgs {
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getTotalTls.
 */
export interface GetTotalTlsResult {
    /**
     * The Certificate Authority that Total TLS certificates will be issued through.
     * Available values: "google", "lets*encrypt", "ssl*com".
     */
    readonly certificateAuthority: string;
    /**
     * If enabled, Total TLS will order a hostname specific TLS certificate for any proxied A, AAAA, or CNAME record in your zone.
     */
    readonly enabled: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The validity period in days for the certificates ordered via Total TLS.
     * Available values: 90.
     */
    readonly validityPeriod: number;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleTotalTls = cloudflare.getTotalTls({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getTotalTlsOutput(args: GetTotalTlsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTotalTlsResult>;
/**
 * A collection of arguments for invoking getTotalTls.
 */
export interface GetTotalTlsOutputArgs {
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
