import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleTurnstileWidgets = cloudflare.getTurnstileWidgets({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "asc",
 *     order: "id",
 * });
 * ```
 */
export declare function getTurnstileWidgets(args: GetTurnstileWidgetsArgs, opts?: pulumi.InvokeOptions): Promise<GetTurnstileWidgetsResult>;
/**
 * A collection of arguments for invoking getTurnstileWidgets.
 */
export interface GetTurnstileWidgetsArgs {
    /**
     * Identifier
     */
    accountId: string;
    /**
     * Direction to order widgets.
     * Available values: "asc", "desc".
     */
    direction?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Field to order widgets by.
     * Available values: "id", "sitekey", "name", "created*on", "modified*on".
     */
    order?: string;
}
/**
 * A collection of values returned by getTurnstileWidgets.
 */
export interface GetTurnstileWidgetsResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * Direction to order widgets.
     * Available values: "asc", "desc".
     */
    readonly direction?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * Field to order widgets by.
     * Available values: "id", "sitekey", "name", "created*on", "modified*on".
     */
    readonly order?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetTurnstileWidgetsResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleTurnstileWidgets = cloudflare.getTurnstileWidgets({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "asc",
 *     order: "id",
 * });
 * ```
 */
export declare function getTurnstileWidgetsOutput(args: GetTurnstileWidgetsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTurnstileWidgetsResult>;
/**
 * A collection of arguments for invoking getTurnstileWidgets.
 */
export interface GetTurnstileWidgetsOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * Direction to order widgets.
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Field to order widgets by.
     * Available values: "id", "sitekey", "name", "created*on", "modified*on".
     */
    order?: pulumi.Input<string>;
}
