import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleUserAgentBlockingRules = cloudflare.getUserAgentBlockingRules({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     description: "abusive",
 *     descriptionSearch: "abusive",
 *     uaSearch: "Safari",
 * });
 * ```
 */
export declare function getUserAgentBlockingRules(args: GetUserAgentBlockingRulesArgs, opts?: pulumi.InvokeOptions): Promise<GetUserAgentBlockingRulesResult>;
/**
 * A collection of arguments for invoking getUserAgentBlockingRules.
 */
export interface GetUserAgentBlockingRulesArgs {
    /**
     * A string to search for in the description of existing rules.
     */
    description?: string;
    /**
     * A string to search for in the description of existing rules.
     */
    descriptionSearch?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * A string to search for in the user agent values of existing rules.
     */
    uaSearch?: string;
    /**
     * Defines an identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getUserAgentBlockingRules.
 */
export interface GetUserAgentBlockingRulesResult {
    /**
     * A string to search for in the description of existing rules.
     */
    readonly description?: string;
    /**
     * A string to search for in the description of existing rules.
     */
    readonly descriptionSearch?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetUserAgentBlockingRulesResult[];
    /**
     * A string to search for in the user agent values of existing rules.
     */
    readonly uaSearch?: string;
    /**
     * Defines an identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleUserAgentBlockingRules = cloudflare.getUserAgentBlockingRules({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     description: "abusive",
 *     descriptionSearch: "abusive",
 *     uaSearch: "Safari",
 * });
 * ```
 */
export declare function getUserAgentBlockingRulesOutput(args: GetUserAgentBlockingRulesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetUserAgentBlockingRulesResult>;
/**
 * A collection of arguments for invoking getUserAgentBlockingRules.
 */
export interface GetUserAgentBlockingRulesOutputArgs {
    /**
     * A string to search for in the description of existing rules.
     */
    description?: pulumi.Input<string>;
    /**
     * A string to search for in the description of existing rules.
     */
    descriptionSearch?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * A string to search for in the user agent values of existing rules.
     */
    uaSearch?: pulumi.Input<string>;
    /**
     * Defines an identifier.
     */
    zoneId: pulumi.Input<string>;
}
