import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWaitingRoomRules = cloudflare.getWaitingRoomRules({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     waitingRoomId: "699d98642c564d2e855e9661899b7252",
 * });
 * ```
 */
export declare function getWaitingRoomRules(args: GetWaitingRoomRulesArgs, opts?: pulumi.InvokeOptions): Promise<GetWaitingRoomRulesResult>;
/**
 * A collection of arguments for invoking getWaitingRoomRules.
 */
export interface GetWaitingRoomRulesArgs {
    waitingRoomId: string;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getWaitingRoomRules.
 */
export interface GetWaitingRoomRulesResult {
    /**
     * The action to take when the expression matches.
     * Available values: "bypass*waiting*room".
     */
    readonly action: string;
    /**
     * The description of the rule.
     */
    readonly description: string;
    /**
     * When set to true, the rule is enabled.
     */
    readonly enabled: boolean;
    /**
     * Criteria defining when there is a match for the current rule.
     */
    readonly expression: string;
    /**
     * The ID of the rule.
     */
    readonly id: string;
    readonly lastUpdated: string;
    /**
     * The version of the rule.
     */
    readonly version: string;
    readonly waitingRoomId: string;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWaitingRoomRules = cloudflare.getWaitingRoomRules({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     waitingRoomId: "699d98642c564d2e855e9661899b7252",
 * });
 * ```
 */
export declare function getWaitingRoomRulesOutput(args: GetWaitingRoomRulesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWaitingRoomRulesResult>;
/**
 * A collection of arguments for invoking getWaitingRoomRules.
 */
export interface GetWaitingRoomRulesOutputArgs {
    waitingRoomId: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
