import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWeb3Hostname = cloudflare.getWeb3Hostname({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     identifier: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getWeb3Hostname(args: GetWeb3HostnameArgs, opts?: pulumi.InvokeOptions): Promise<GetWeb3HostnameResult>;
/**
 * A collection of arguments for invoking getWeb3Hostname.
 */
export interface GetWeb3HostnameArgs {
    /**
     * Specify the identifier of the hostname.
     */
    identifier?: string;
    /**
     * Specify the identifier of the hostname.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getWeb3Hostname.
 */
export interface GetWeb3HostnameResult {
    readonly createdOn: string;
    /**
     * Specify an optional description of the hostname.
     */
    readonly description: string;
    /**
     * Specify the DNSLink value used if the target is ipfs.
     */
    readonly dnslink: string;
    /**
     * Specify the identifier of the hostname.
     */
    readonly id: string;
    /**
     * Specify the identifier of the hostname.
     */
    readonly identifier?: string;
    readonly modifiedOn: string;
    /**
     * Specify the hostname that points to the target gateway via CNAME.
     */
    readonly name: string;
    /**
     * Specifies the status of the hostname's activation.
     * Available values: "active", "pending", "deleting", "error".
     */
    readonly status: string;
    /**
     * Specify the target gateway of the hostname.
     * Available values: "ethereum", "ipfs", "ipfs*universal*path".
     */
    readonly target: string;
    /**
     * Specify the identifier of the hostname.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWeb3Hostname = cloudflare.getWeb3Hostname({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     identifier: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getWeb3HostnameOutput(args: GetWeb3HostnameOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWeb3HostnameResult>;
/**
 * A collection of arguments for invoking getWeb3Hostname.
 */
export interface GetWeb3HostnameOutputArgs {
    /**
     * Specify the identifier of the hostname.
     */
    identifier?: pulumi.Input<string>;
    /**
     * Specify the identifier of the hostname.
     */
    zoneId: pulumi.Input<string>;
}
