import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWeb3Hostnames = cloudflare.getWeb3Hostnames({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getWeb3Hostnames(args: GetWeb3HostnamesArgs, opts?: pulumi.InvokeOptions): Promise<GetWeb3HostnamesResult>;
/**
 * A collection of arguments for invoking getWeb3Hostnames.
 */
export interface GetWeb3HostnamesArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Specify the identifier of the hostname.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getWeb3Hostnames.
 */
export interface GetWeb3HostnamesResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetWeb3HostnamesResult[];
    /**
     * Specify the identifier of the hostname.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWeb3Hostnames = cloudflare.getWeb3Hostnames({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getWeb3HostnamesOutput(args: GetWeb3HostnamesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWeb3HostnamesResult>;
/**
 * A collection of arguments for invoking getWeb3Hostnames.
 */
export interface GetWeb3HostnamesOutputArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Specify the identifier of the hostname.
     */
    zoneId: pulumi.Input<string>;
}
