import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWebAnalyticsSites = cloudflare.getWebAnalyticsSites({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     orderBy: "host",
 * });
 * ```
 */
export declare function getWebAnalyticsSites(args: GetWebAnalyticsSitesArgs, opts?: pulumi.InvokeOptions): Promise<GetWebAnalyticsSitesResult>;
/**
 * A collection of arguments for invoking getWebAnalyticsSites.
 */
export interface GetWebAnalyticsSitesArgs {
    /**
     * Identifier.
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * The property used to sort the list of results.
     * Available values: "host", "created".
     */
    orderBy?: string;
}
/**
 * A collection of values returned by getWebAnalyticsSites.
 */
export interface GetWebAnalyticsSitesResult {
    /**
     * Identifier.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The property used to sort the list of results.
     * Available values: "host", "created".
     */
    readonly orderBy?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetWebAnalyticsSitesResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWebAnalyticsSites = cloudflare.getWebAnalyticsSites({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     orderBy: "host",
 * });
 * ```
 */
export declare function getWebAnalyticsSitesOutput(args: GetWebAnalyticsSitesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWebAnalyticsSitesResult>;
/**
 * A collection of arguments for invoking getWebAnalyticsSites.
 */
export interface GetWebAnalyticsSitesOutputArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * The property used to sort the list of results.
     * Available values: "host", "created".
     */
    orderBy?: pulumi.Input<string>;
}
