import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersCronTrigger = cloudflare.getWorkersCronTrigger({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     scriptName: "this-is_my_script-01",
 * });
 * ```
 */
export declare function getWorkersCronTrigger(args: GetWorkersCronTriggerArgs, opts?: pulumi.InvokeOptions): Promise<GetWorkersCronTriggerResult>;
/**
 * A collection of arguments for invoking getWorkersCronTrigger.
 */
export interface GetWorkersCronTriggerArgs {
    /**
     * Identifier.
     */
    accountId: string;
    /**
     * Name of the script, used in URLs and route configuration.
     */
    scriptName: string;
}
/**
 * A collection of values returned by getWorkersCronTrigger.
 */
export interface GetWorkersCronTriggerResult {
    /**
     * Identifier.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly schedules: outputs.GetWorkersCronTriggerSchedule[];
    /**
     * Name of the script, used in URLs and route configuration.
     */
    readonly scriptName: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersCronTrigger = cloudflare.getWorkersCronTrigger({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     scriptName: "this-is_my_script-01",
 * });
 * ```
 */
export declare function getWorkersCronTriggerOutput(args: GetWorkersCronTriggerOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWorkersCronTriggerResult>;
/**
 * A collection of arguments for invoking getWorkersCronTrigger.
 */
export interface GetWorkersCronTriggerOutputArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the script, used in URLs and route configuration.
     */
    scriptName: pulumi.Input<string>;
}
