import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersCustomDomain = cloudflare.getWorkersCustomDomain({
 *     accountId: "9a7806061c88ada191ed06f989cc3dac",
 *     domainId: "dbe10b4bc17c295377eabd600e1787fd",
 * });
 * ```
 */
export declare function getWorkersCustomDomain(args: GetWorkersCustomDomainArgs, opts?: pulumi.InvokeOptions): Promise<GetWorkersCustomDomainResult>;
/**
 * A collection of arguments for invoking getWorkersCustomDomain.
 */
export interface GetWorkersCustomDomainArgs {
    /**
     * Identifer of the account.
     */
    accountId: string;
    /**
     * Identifer of the Worker Domain.
     */
    domainId?: string;
    filter?: inputs.GetWorkersCustomDomainFilter;
}
/**
 * A collection of values returned by getWorkersCustomDomain.
 */
export interface GetWorkersCustomDomainResult {
    /**
     * Identifer of the account.
     */
    readonly accountId: string;
    /**
     * Identifer of the Worker Domain.
     */
    readonly domainId?: string;
    /**
     * Worker environment associated with the zone and hostname.
     */
    readonly environment: string;
    readonly filter?: outputs.GetWorkersCustomDomainFilter;
    /**
     * Hostname of the Worker Domain.
     */
    readonly hostname: string;
    /**
     * Identifer of the Worker Domain.
     */
    readonly id: string;
    /**
     * Worker service associated with the zone and hostname.
     */
    readonly service: string;
    /**
     * Identifier of the zone.
     */
    readonly zoneId: string;
    /**
     * Name of the zone.
     */
    readonly zoneName: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersCustomDomain = cloudflare.getWorkersCustomDomain({
 *     accountId: "9a7806061c88ada191ed06f989cc3dac",
 *     domainId: "dbe10b4bc17c295377eabd600e1787fd",
 * });
 * ```
 */
export declare function getWorkersCustomDomainOutput(args: GetWorkersCustomDomainOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWorkersCustomDomainResult>;
/**
 * A collection of arguments for invoking getWorkersCustomDomain.
 */
export interface GetWorkersCustomDomainOutputArgs {
    /**
     * Identifer of the account.
     */
    accountId: pulumi.Input<string>;
    /**
     * Identifer of the Worker Domain.
     */
    domainId?: pulumi.Input<string>;
    filter?: pulumi.Input<inputs.GetWorkersCustomDomainFilterArgs>;
}
