import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersDeployment = cloudflare.getWorkersDeployment({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     scriptName: "this-is_my_script-01",
 * });
 * ```
 */
export declare function getWorkersDeployment(args: GetWorkersDeploymentArgs, opts?: pulumi.InvokeOptions): Promise<GetWorkersDeploymentResult>;
/**
 * A collection of arguments for invoking getWorkersDeployment.
 */
export interface GetWorkersDeploymentArgs {
    /**
     * Identifier.
     */
    accountId: string;
    /**
     * Name of the script.
     */
    scriptName: string;
}
/**
 * A collection of values returned by getWorkersDeployment.
 */
export interface GetWorkersDeploymentResult {
    /**
     * Identifier.
     */
    readonly accountId: string;
    readonly deployments: outputs.GetWorkersDeploymentDeployment[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Name of the script.
     */
    readonly scriptName: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersDeployment = cloudflare.getWorkersDeployment({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     scriptName: "this-is_my_script-01",
 * });
 * ```
 */
export declare function getWorkersDeploymentOutput(args: GetWorkersDeploymentOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWorkersDeploymentResult>;
/**
 * A collection of arguments for invoking getWorkersDeployment.
 */
export interface GetWorkersDeploymentOutputArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the script.
     */
    scriptName: pulumi.Input<string>;
}
