import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersKv = cloudflare.getWorkersKv({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     namespaceId: "0f2ac74b498b48028cb68387c421e279",
 *     keyName: "My-Key",
 * });
 * ```
 */
export declare function getWorkersKv(args: GetWorkersKvArgs, opts?: pulumi.InvokeOptions): Promise<GetWorkersKvResult>;
/**
 * A collection of arguments for invoking getWorkersKv.
 */
export interface GetWorkersKvArgs {
    /**
     * Identifier
     */
    accountId: string;
    /**
     * A key's name. The name may be at most 512 bytes. All printable, non-whitespace characters are valid. Use percent-encoding to define key names as part of a URL.
     */
    keyName: string;
    /**
     * Namespace identifier tag.
     */
    namespaceId: string;
}
/**
 * A collection of values returned by getWorkersKv.
 */
export interface GetWorkersKvResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A key's name. The name may be at most 512 bytes. All printable, non-whitespace characters are valid. Use percent-encoding to define key names as part of a URL.
     */
    readonly keyName: string;
    /**
     * Namespace identifier tag.
     */
    readonly namespaceId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersKv = cloudflare.getWorkersKv({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     namespaceId: "0f2ac74b498b48028cb68387c421e279",
 *     keyName: "My-Key",
 * });
 * ```
 */
export declare function getWorkersKvOutput(args: GetWorkersKvOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWorkersKvResult>;
/**
 * A collection of arguments for invoking getWorkersKv.
 */
export interface GetWorkersKvOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * A key's name. The name may be at most 512 bytes. All printable, non-whitespace characters are valid. Use percent-encoding to define key names as part of a URL.
     */
    keyName: pulumi.Input<string>;
    /**
     * Namespace identifier tag.
     */
    namespaceId: pulumi.Input<string>;
}
