import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersKvNamespace = cloudflare.getWorkersKvNamespace({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     namespaceId: "0f2ac74b498b48028cb68387c421e279",
 * });
 * ```
 */
export declare function getWorkersKvNamespace(args: GetWorkersKvNamespaceArgs, opts?: pulumi.InvokeOptions): Promise<GetWorkersKvNamespaceResult>;
/**
 * A collection of arguments for invoking getWorkersKvNamespace.
 */
export interface GetWorkersKvNamespaceArgs {
    /**
     * Identifier
     */
    accountId: string;
    filter?: inputs.GetWorkersKvNamespaceFilter;
    /**
     * Namespace identifier tag.
     */
    namespaceId?: string;
}
/**
 * A collection of values returned by getWorkersKvNamespace.
 */
export interface GetWorkersKvNamespaceResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * True if new beta namespace, with additional preview features.
     */
    readonly beta: boolean;
    readonly filter?: outputs.GetWorkersKvNamespaceFilter;
    /**
     * Namespace identifier tag.
     */
    readonly id: string;
    /**
     * Namespace identifier tag.
     */
    readonly namespaceId?: string;
    /**
     * True if keys written on the URL will be URL-decoded before storing. For example, if set to "true", a key written on the URL as "%3F" will be stored as "?".
     */
    readonly supportsUrlEncoding: boolean;
    /**
     * A human-readable string name for a Namespace.
     */
    readonly title: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersKvNamespace = cloudflare.getWorkersKvNamespace({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     namespaceId: "0f2ac74b498b48028cb68387c421e279",
 * });
 * ```
 */
export declare function getWorkersKvNamespaceOutput(args: GetWorkersKvNamespaceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWorkersKvNamespaceResult>;
/**
 * A collection of arguments for invoking getWorkersKvNamespace.
 */
export interface GetWorkersKvNamespaceOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    filter?: pulumi.Input<inputs.GetWorkersKvNamespaceFilterArgs>;
    /**
     * Namespace identifier tag.
     */
    namespaceId?: pulumi.Input<string>;
}
