import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersKvNamespaces = cloudflare.getWorkersKvNamespaces({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "asc",
 *     order: "id",
 * });
 * ```
 */
export declare function getWorkersKvNamespaces(args: GetWorkersKvNamespacesArgs, opts?: pulumi.InvokeOptions): Promise<GetWorkersKvNamespacesResult>;
/**
 * A collection of arguments for invoking getWorkersKvNamespaces.
 */
export interface GetWorkersKvNamespacesArgs {
    /**
     * Identifier
     */
    accountId: string;
    /**
     * Direction to order namespaces.
     * Available values: "asc", "desc".
     */
    direction?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Field to order results by.
     * Available values: "id", "title".
     */
    order?: string;
}
/**
 * A collection of values returned by getWorkersKvNamespaces.
 */
export interface GetWorkersKvNamespacesResult {
    /**
     * Identifier
     */
    readonly accountId: string;
    /**
     * Direction to order namespaces.
     * Available values: "asc", "desc".
     */
    readonly direction?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * Field to order results by.
     * Available values: "id", "title".
     */
    readonly order?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetWorkersKvNamespacesResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersKvNamespaces = cloudflare.getWorkersKvNamespaces({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     direction: "asc",
 *     order: "id",
 * });
 * ```
 */
export declare function getWorkersKvNamespacesOutput(args: GetWorkersKvNamespacesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWorkersKvNamespacesResult>;
/**
 * A collection of arguments for invoking getWorkersKvNamespaces.
 */
export interface GetWorkersKvNamespacesOutputArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * Direction to order namespaces.
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Field to order results by.
     * Available values: "id", "title".
     */
    order?: pulumi.Input<string>;
}
