import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersRoute = cloudflare.getWorkersRoute({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     routeId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getWorkersRoute(args: GetWorkersRouteArgs, opts?: pulumi.InvokeOptions): Promise<GetWorkersRouteResult>;
/**
 * A collection of arguments for invoking getWorkersRoute.
 */
export interface GetWorkersRouteArgs {
    /**
     * Identifier.
     */
    routeId?: string;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getWorkersRoute.
 */
export interface GetWorkersRouteResult {
    /**
     * Identifier.
     */
    readonly id: string;
    /**
     * Pattern to match incoming requests against. [Learn more](https://developers.cloudflare.com/workers/configuration/routing/routes/#matching-behavior).
     */
    readonly pattern: string;
    /**
     * Identifier.
     */
    readonly routeId?: string;
    /**
     * Name of the script to run if the route matches.
     */
    readonly script: string;
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersRoute = cloudflare.getWorkersRoute({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     routeId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getWorkersRouteOutput(args: GetWorkersRouteOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWorkersRouteResult>;
/**
 * A collection of arguments for invoking getWorkersRoute.
 */
export interface GetWorkersRouteOutputArgs {
    /**
     * Identifier.
     */
    routeId?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
