import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersRoutes = cloudflare.getWorkersRoutes({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getWorkersRoutes(args: GetWorkersRoutesArgs, opts?: pulumi.InvokeOptions): Promise<GetWorkersRoutesResult>;
/**
 * A collection of arguments for invoking getWorkersRoutes.
 */
export interface GetWorkersRoutesArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Identifier.
     */
    zoneId: string;
}
/**
 * A collection of values returned by getWorkersRoutes.
 */
export interface GetWorkersRoutesResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetWorkersRoutesResult[];
    /**
     * Identifier.
     */
    readonly zoneId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersRoutes = cloudflare.getWorkersRoutes({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getWorkersRoutesOutput(args: GetWorkersRoutesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWorkersRoutesResult>;
/**
 * A collection of arguments for invoking getWorkersRoutes.
 */
export interface GetWorkersRoutesOutputArgs {
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
