import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessApplications = cloudflare.getZeroTrustAccessApplications({
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 *     aud: "aud",
 *     domain: "domain",
 *     name: "name",
 *     search: "search",
 * });
 * ```
 */
export declare function getZeroTrustAccessApplications(args?: GetZeroTrustAccessApplicationsArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustAccessApplicationsResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessApplications.
 */
export interface GetZeroTrustAccessApplicationsArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: string;
    /**
     * The aud of the app.
     */
    aud?: string;
    /**
     * The domain of the app.
     */
    domain?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * The name of the app.
     */
    name?: string;
    /**
     * Search for apps by other listed query parameters.
     */
    search?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: string;
}
/**
 * A collection of values returned by getZeroTrustAccessApplications.
 */
export interface GetZeroTrustAccessApplicationsResult {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    readonly accountId?: string;
    /**
     * The aud of the app.
     */
    readonly aud?: string;
    /**
     * The domain of the app.
     */
    readonly domain?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The name of the app.
     */
    readonly name?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetZeroTrustAccessApplicationsResult[];
    /**
     * Search for apps by other listed query parameters.
     */
    readonly search?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    readonly zoneId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessApplications = cloudflare.getZeroTrustAccessApplications({
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 *     aud: "aud",
 *     domain: "domain",
 *     name: "name",
 *     search: "search",
 * });
 * ```
 */
export declare function getZeroTrustAccessApplicationsOutput(args?: GetZeroTrustAccessApplicationsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustAccessApplicationsResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessApplications.
 */
export interface GetZeroTrustAccessApplicationsOutputArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * The aud of the app.
     */
    aud?: pulumi.Input<string>;
    /**
     * The domain of the app.
     */
    domain?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * The name of the app.
     */
    name?: pulumi.Input<string>;
    /**
     * Search for apps by other listed query parameters.
     */
    search?: pulumi.Input<string>;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: pulumi.Input<string>;
}
