import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessCustomPage = cloudflare.getZeroTrustAccessCustomPage({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     customPageId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustAccessCustomPage(args: GetZeroTrustAccessCustomPageArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustAccessCustomPageResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessCustomPage.
 */
export interface GetZeroTrustAccessCustomPageArgs {
    /**
     * Identifier.
     */
    accountId: string;
    /**
     * UUID.
     */
    customPageId?: string;
}
/**
 * A collection of values returned by getZeroTrustAccessCustomPage.
 */
export interface GetZeroTrustAccessCustomPageResult {
    /**
     * Identifier.
     */
    readonly accountId: string;
    /**
     * Number of apps the custom page is assigned to.
     */
    readonly appCount: number;
    readonly createdAt: string;
    /**
     * Custom page HTML.
     */
    readonly customHtml: string;
    /**
     * UUID.
     */
    readonly customPageId?: string;
    /**
     * UUID.
     */
    readonly id: string;
    /**
     * Custom page name.
     */
    readonly name: string;
    /**
     * Custom page type.
     * Available values: "identityDenied", "forbidden".
     */
    readonly type: string;
    /**
     * UUID.
     */
    readonly uid: string;
    readonly updatedAt: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessCustomPage = cloudflare.getZeroTrustAccessCustomPage({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     customPageId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustAccessCustomPageOutput(args: GetZeroTrustAccessCustomPageOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustAccessCustomPageResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessCustomPage.
 */
export interface GetZeroTrustAccessCustomPageOutputArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * UUID.
     */
    customPageId?: pulumi.Input<string>;
}
