import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessGroups = cloudflare.getZeroTrustAccessGroups({
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 *     name: "name",
 *     search: "search",
 * });
 * ```
 */
export declare function getZeroTrustAccessGroups(args?: GetZeroTrustAccessGroupsArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustAccessGroupsResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessGroups.
 */
export interface GetZeroTrustAccessGroupsArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * The name of the group.
     */
    name?: string;
    /**
     * Search for groups by other listed query parameters.
     */
    search?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: string;
}
/**
 * A collection of values returned by getZeroTrustAccessGroups.
 */
export interface GetZeroTrustAccessGroupsResult {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    readonly accountId?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The name of the group.
     */
    readonly name?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetZeroTrustAccessGroupsResult[];
    /**
     * Search for groups by other listed query parameters.
     */
    readonly search?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    readonly zoneId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessGroups = cloudflare.getZeroTrustAccessGroups({
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 *     name: "name",
 *     search: "search",
 * });
 * ```
 */
export declare function getZeroTrustAccessGroupsOutput(args?: GetZeroTrustAccessGroupsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustAccessGroupsResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessGroups.
 */
export interface GetZeroTrustAccessGroupsOutputArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * The name of the group.
     */
    name?: pulumi.Input<string>;
    /**
     * Search for groups by other listed query parameters.
     */
    search?: pulumi.Input<string>;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: pulumi.Input<string>;
}
