import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessIdentityProviders = cloudflare.getZeroTrustAccessIdentityProviders({
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 *     scimEnabled: "scim_enabled",
 * });
 * ```
 */
export declare function getZeroTrustAccessIdentityProviders(args?: GetZeroTrustAccessIdentityProvidersArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustAccessIdentityProvidersResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessIdentityProviders.
 */
export interface GetZeroTrustAccessIdentityProvidersArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Indicates to Access to only retrieve identity providers that have the System for Cross-Domain Identity Management (SCIM) enabled.
     */
    scimEnabled?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: string;
}
/**
 * A collection of values returned by getZeroTrustAccessIdentityProviders.
 */
export interface GetZeroTrustAccessIdentityProvidersResult {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    readonly accountId?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetZeroTrustAccessIdentityProvidersResult[];
    /**
     * Indicates to Access to only retrieve identity providers that have the System for Cross-Domain Identity Management (SCIM) enabled.
     */
    readonly scimEnabled?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    readonly zoneId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessIdentityProviders = cloudflare.getZeroTrustAccessIdentityProviders({
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 *     scimEnabled: "scim_enabled",
 * });
 * ```
 */
export declare function getZeroTrustAccessIdentityProvidersOutput(args?: GetZeroTrustAccessIdentityProvidersOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustAccessIdentityProvidersResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessIdentityProviders.
 */
export interface GetZeroTrustAccessIdentityProvidersOutputArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Indicates to Access to only retrieve identity providers that have the System for Cross-Domain Identity Management (SCIM) enabled.
     */
    scimEnabled?: pulumi.Input<string>;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: pulumi.Input<string>;
}
