import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessInfrastructureTargets = cloudflare.getZeroTrustAccessInfrastructureTargets({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     createdAfter: "2019-12-27T18:11:19.117Z",
 *     createdBefore: "2019-12-27T18:11:19.117Z",
 *     direction: "asc",
 *     hostname: "hostname",
 *     hostnameContains: "hostname_contains",
 *     ipLike: "ip_like",
 *     ipV4: "ip_v4",
 *     ipV6: "ip_v6",
 *     ips: ["string"],
 *     ipv4End: "ipv4_end",
 *     ipv4Start: "ipv4_start",
 *     ipv6End: "ipv6_end",
 *     ipv6Start: "ipv6_start",
 *     modifiedAfter: "2019-12-27T18:11:19.117Z",
 *     modifiedBefore: "2019-12-27T18:11:19.117Z",
 *     order: "hostname",
 *     targetIds: ["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
 *     virtualNetworkId: "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
 * });
 * ```
 */
export declare function getZeroTrustAccessInfrastructureTargets(args: GetZeroTrustAccessInfrastructureTargetsArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustAccessInfrastructureTargetsResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessInfrastructureTargets.
 */
export interface GetZeroTrustAccessInfrastructureTargetsArgs {
    /**
     * Account identifier
     */
    accountId: string;
    /**
     * Date and time at which the target was created after (inclusive)
     */
    createdAfter?: string;
    /**
     * Date and time at which the target was created before (inclusive)
     */
    createdBefore?: string;
    /**
     * The sorting direction.
     * Available values: "asc", "desc".
     */
    direction?: string;
    /**
     * Hostname of a target
     */
    hostname?: string;
    /**
     * Partial match to the hostname of a target
     */
    hostnameContains?: string;
    /**
     * Filters for targets whose IP addresses look like the specified string.
     * Supports `*` as a wildcard character
     */
    ipLike?: string;
    /**
     * IPv4 address of the target
     */
    ipV4?: string;
    /**
     * IPv6 address of the target
     */
    ipV6?: string;
    /**
     * Filters for targets that have any of the following IP addresses. Specify
     * `ips` multiple times in query parameter to build list of candidates.
     */
    ips?: string[];
    /**
     * Defines an IPv4 filter range's ending value (inclusive). Requires
     * `ipv4Start` to be specified as well.
     */
    ipv4End?: string;
    /**
     * Defines an IPv4 filter range's starting value (inclusive). Requires
     * `ipv4End` to be specified as well.
     */
    ipv4Start?: string;
    /**
     * Defines an IPv6 filter range's ending value (inclusive). Requires
     * `ipv6Start` to be specified as well.
     */
    ipv6End?: string;
    /**
     * Defines an IPv6 filter range's starting value (inclusive). Requires
     * `ipv6End` to be specified as well.
     */
    ipv6Start?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * Date and time at which the target was modified after (inclusive)
     */
    modifiedAfter?: string;
    /**
     * Date and time at which the target was modified before (inclusive)
     */
    modifiedBefore?: string;
    /**
     * The field to sort by.
     * Available values: "hostname", "createdAt".
     */
    order?: string;
    /**
     * Filters for targets that have any of the following UUIDs. Specify
     * `targetIds` multiple times in query parameter to build list of
     * candidates.
     */
    targetIds?: string[];
    /**
     * Private virtual network identifier of the target
     */
    virtualNetworkId?: string;
}
/**
 * A collection of values returned by getZeroTrustAccessInfrastructureTargets.
 */
export interface GetZeroTrustAccessInfrastructureTargetsResult {
    /**
     * Account identifier
     */
    readonly accountId: string;
    /**
     * Date and time at which the target was created after (inclusive)
     */
    readonly createdAfter?: string;
    /**
     * Date and time at which the target was created before (inclusive)
     */
    readonly createdBefore?: string;
    /**
     * The sorting direction.
     * Available values: "asc", "desc".
     */
    readonly direction?: string;
    /**
     * Hostname of a target
     */
    readonly hostname?: string;
    /**
     * Partial match to the hostname of a target
     */
    readonly hostnameContains?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Filters for targets whose IP addresses look like the specified string.
     * Supports `*` as a wildcard character
     */
    readonly ipLike?: string;
    /**
     * IPv4 address of the target
     */
    readonly ipV4?: string;
    /**
     * IPv6 address of the target
     */
    readonly ipV6?: string;
    /**
     * Filters for targets that have any of the following IP addresses. Specify
     * `ips` multiple times in query parameter to build list of candidates.
     */
    readonly ips?: string[];
    /**
     * Defines an IPv4 filter range's ending value (inclusive). Requires
     * `ipv4Start` to be specified as well.
     */
    readonly ipv4End?: string;
    /**
     * Defines an IPv4 filter range's starting value (inclusive). Requires
     * `ipv4End` to be specified as well.
     */
    readonly ipv4Start?: string;
    /**
     * Defines an IPv6 filter range's ending value (inclusive). Requires
     * `ipv6Start` to be specified as well.
     */
    readonly ipv6End?: string;
    /**
     * Defines an IPv6 filter range's starting value (inclusive). Requires
     * `ipv6End` to be specified as well.
     */
    readonly ipv6Start?: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * Date and time at which the target was modified after (inclusive)
     */
    readonly modifiedAfter?: string;
    /**
     * Date and time at which the target was modified before (inclusive)
     */
    readonly modifiedBefore?: string;
    /**
     * The field to sort by.
     * Available values: "hostname", "createdAt".
     */
    readonly order?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetZeroTrustAccessInfrastructureTargetsResult[];
    /**
     * Filters for targets that have any of the following UUIDs. Specify
     * `targetIds` multiple times in query parameter to build list of
     * candidates.
     */
    readonly targetIds?: string[];
    /**
     * Private virtual network identifier of the target
     */
    readonly virtualNetworkId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessInfrastructureTargets = cloudflare.getZeroTrustAccessInfrastructureTargets({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     createdAfter: "2019-12-27T18:11:19.117Z",
 *     createdBefore: "2019-12-27T18:11:19.117Z",
 *     direction: "asc",
 *     hostname: "hostname",
 *     hostnameContains: "hostname_contains",
 *     ipLike: "ip_like",
 *     ipV4: "ip_v4",
 *     ipV6: "ip_v6",
 *     ips: ["string"],
 *     ipv4End: "ipv4_end",
 *     ipv4Start: "ipv4_start",
 *     ipv6End: "ipv6_end",
 *     ipv6Start: "ipv6_start",
 *     modifiedAfter: "2019-12-27T18:11:19.117Z",
 *     modifiedBefore: "2019-12-27T18:11:19.117Z",
 *     order: "hostname",
 *     targetIds: ["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
 *     virtualNetworkId: "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
 * });
 * ```
 */
export declare function getZeroTrustAccessInfrastructureTargetsOutput(args: GetZeroTrustAccessInfrastructureTargetsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustAccessInfrastructureTargetsResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessInfrastructureTargets.
 */
export interface GetZeroTrustAccessInfrastructureTargetsOutputArgs {
    /**
     * Account identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * Date and time at which the target was created after (inclusive)
     */
    createdAfter?: pulumi.Input<string>;
    /**
     * Date and time at which the target was created before (inclusive)
     */
    createdBefore?: pulumi.Input<string>;
    /**
     * The sorting direction.
     * Available values: "asc", "desc".
     */
    direction?: pulumi.Input<string>;
    /**
     * Hostname of a target
     */
    hostname?: pulumi.Input<string>;
    /**
     * Partial match to the hostname of a target
     */
    hostnameContains?: pulumi.Input<string>;
    /**
     * Filters for targets whose IP addresses look like the specified string.
     * Supports `*` as a wildcard character
     */
    ipLike?: pulumi.Input<string>;
    /**
     * IPv4 address of the target
     */
    ipV4?: pulumi.Input<string>;
    /**
     * IPv6 address of the target
     */
    ipV6?: pulumi.Input<string>;
    /**
     * Filters for targets that have any of the following IP addresses. Specify
     * `ips` multiple times in query parameter to build list of candidates.
     */
    ips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Defines an IPv4 filter range's ending value (inclusive). Requires
     * `ipv4Start` to be specified as well.
     */
    ipv4End?: pulumi.Input<string>;
    /**
     * Defines an IPv4 filter range's starting value (inclusive). Requires
     * `ipv4End` to be specified as well.
     */
    ipv4Start?: pulumi.Input<string>;
    /**
     * Defines an IPv6 filter range's ending value (inclusive). Requires
     * `ipv6Start` to be specified as well.
     */
    ipv6End?: pulumi.Input<string>;
    /**
     * Defines an IPv6 filter range's starting value (inclusive). Requires
     * `ipv6End` to be specified as well.
     */
    ipv6Start?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * Date and time at which the target was modified after (inclusive)
     */
    modifiedAfter?: pulumi.Input<string>;
    /**
     * Date and time at which the target was modified before (inclusive)
     */
    modifiedBefore?: pulumi.Input<string>;
    /**
     * The field to sort by.
     * Available values: "hostname", "createdAt".
     */
    order?: pulumi.Input<string>;
    /**
     * Filters for targets that have any of the following UUIDs. Specify
     * `targetIds` multiple times in query parameter to build list of
     * candidates.
     */
    targetIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Private virtual network identifier of the target
     */
    virtualNetworkId?: pulumi.Input<string>;
}
