import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessMtlsCertificate = cloudflare.getZeroTrustAccessMtlsCertificate({
 *     certificateId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 * });
 * ```
 */
export declare function getZeroTrustAccessMtlsCertificate(args?: GetZeroTrustAccessMtlsCertificateArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustAccessMtlsCertificateResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessMtlsCertificate.
 */
export interface GetZeroTrustAccessMtlsCertificateArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: string;
    /**
     * UUID.
     */
    certificateId?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: string;
}
/**
 * A collection of values returned by getZeroTrustAccessMtlsCertificate.
 */
export interface GetZeroTrustAccessMtlsCertificateResult {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    readonly accountId?: string;
    /**
     * The hostnames of the applications that will use this certificate.
     */
    readonly associatedHostnames: string[];
    /**
     * UUID.
     */
    readonly certificateId?: string;
    readonly createdAt: string;
    readonly expiresOn: string;
    /**
     * The MD5 fingerprint of the certificate.
     */
    readonly fingerprint: string;
    /**
     * UUID.
     */
    readonly id: string;
    /**
     * The name of the certificate.
     */
    readonly name: string;
    readonly updatedAt: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    readonly zoneId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessMtlsCertificate = cloudflare.getZeroTrustAccessMtlsCertificate({
 *     certificateId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 * });
 * ```
 */
export declare function getZeroTrustAccessMtlsCertificateOutput(args?: GetZeroTrustAccessMtlsCertificateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustAccessMtlsCertificateResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessMtlsCertificate.
 */
export interface GetZeroTrustAccessMtlsCertificateOutputArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * UUID.
     */
    certificateId?: pulumi.Input<string>;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: pulumi.Input<string>;
}
