import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessMtlsCertificates = cloudflare.getZeroTrustAccessMtlsCertificates({
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 * });
 * ```
 */
export declare function getZeroTrustAccessMtlsCertificates(args?: GetZeroTrustAccessMtlsCertificatesArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustAccessMtlsCertificatesResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessMtlsCertificates.
 */
export interface GetZeroTrustAccessMtlsCertificatesArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: string;
}
/**
 * A collection of values returned by getZeroTrustAccessMtlsCertificates.
 */
export interface GetZeroTrustAccessMtlsCertificatesResult {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    readonly accountId?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetZeroTrustAccessMtlsCertificatesResult[];
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    readonly zoneId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessMtlsCertificates = cloudflare.getZeroTrustAccessMtlsCertificates({
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 * });
 * ```
 */
export declare function getZeroTrustAccessMtlsCertificatesOutput(args?: GetZeroTrustAccessMtlsCertificatesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustAccessMtlsCertificatesResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessMtlsCertificates.
 */
export interface GetZeroTrustAccessMtlsCertificatesOutputArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: pulumi.Input<string>;
}
