import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessMtlsHostnameSettings = cloudflare.getZeroTrustAccessMtlsHostnameSettings({
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 * });
 * ```
 */
export declare function getZeroTrustAccessMtlsHostnameSettings(args?: GetZeroTrustAccessMtlsHostnameSettingsArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustAccessMtlsHostnameSettingsResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessMtlsHostnameSettings.
 */
export interface GetZeroTrustAccessMtlsHostnameSettingsArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: string;
}
/**
 * A collection of values returned by getZeroTrustAccessMtlsHostnameSettings.
 */
export interface GetZeroTrustAccessMtlsHostnameSettingsResult {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    readonly accountId?: string;
    /**
     * Request client certificates for this hostname in China. Can only be set to true if this zone is china network enabled.
     */
    readonly chinaNetwork: boolean;
    /**
     * Client Certificate Forwarding is a feature that takes the client cert provided by the eyeball to the edge, and forwards it to the origin as a HTTP header to allow logging on the origin.
     */
    readonly clientCertificateForwarding: boolean;
    /**
     * The hostname that these settings apply to.
     */
    readonly hostname: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    readonly zoneId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessMtlsHostnameSettings = cloudflare.getZeroTrustAccessMtlsHostnameSettings({
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 * });
 * ```
 */
export declare function getZeroTrustAccessMtlsHostnameSettingsOutput(args?: GetZeroTrustAccessMtlsHostnameSettingsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustAccessMtlsHostnameSettingsResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessMtlsHostnameSettings.
 */
export interface GetZeroTrustAccessMtlsHostnameSettingsOutputArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: pulumi.Input<string>;
}
