import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessPolicies = cloudflare.getZeroTrustAccessPolicies({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getZeroTrustAccessPolicies(args: GetZeroTrustAccessPoliciesArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustAccessPoliciesResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessPolicies.
 */
export interface GetZeroTrustAccessPoliciesArgs {
    /**
     * Identifier.
     */
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
}
/**
 * A collection of values returned by getZeroTrustAccessPolicies.
 */
export interface GetZeroTrustAccessPoliciesResult {
    /**
     * Identifier.
     */
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetZeroTrustAccessPoliciesResult[];
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessPolicies = cloudflare.getZeroTrustAccessPolicies({
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getZeroTrustAccessPoliciesOutput(args: GetZeroTrustAccessPoliciesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustAccessPoliciesResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessPolicies.
 */
export interface GetZeroTrustAccessPoliciesOutputArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
}
