import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessServiceTokens = cloudflare.getZeroTrustAccessServiceTokens({
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 *     name: "name",
 *     search: "search",
 * });
 * ```
 */
export declare function getZeroTrustAccessServiceTokens(args?: GetZeroTrustAccessServiceTokensArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustAccessServiceTokensResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessServiceTokens.
 */
export interface GetZeroTrustAccessServiceTokensArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * The name of the service token.
     */
    name?: string;
    /**
     * Search for service tokens by other listed query parameters.
     */
    search?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: string;
}
/**
 * A collection of values returned by getZeroTrustAccessServiceTokens.
 */
export interface GetZeroTrustAccessServiceTokensResult {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    readonly accountId?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The name of the service token.
     */
    readonly name?: string;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetZeroTrustAccessServiceTokensResult[];
    /**
     * Search for service tokens by other listed query parameters.
     */
    readonly search?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    readonly zoneId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessServiceTokens = cloudflare.getZeroTrustAccessServiceTokens({
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 *     name: "name",
 *     search: "search",
 * });
 * ```
 */
export declare function getZeroTrustAccessServiceTokensOutput(args?: GetZeroTrustAccessServiceTokensOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustAccessServiceTokensResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessServiceTokens.
 */
export interface GetZeroTrustAccessServiceTokensOutputArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * The name of the service token.
     */
    name?: pulumi.Input<string>;
    /**
     * Search for service tokens by other listed query parameters.
     */
    search?: pulumi.Input<string>;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: pulumi.Input<string>;
}
