import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessShortLivedCertificate = cloudflare.getZeroTrustAccessShortLivedCertificate({
 *     appId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 * });
 * ```
 */
export declare function getZeroTrustAccessShortLivedCertificate(args: GetZeroTrustAccessShortLivedCertificateArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustAccessShortLivedCertificateResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessShortLivedCertificate.
 */
export interface GetZeroTrustAccessShortLivedCertificateArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: string;
    /**
     * UUID.
     */
    appId: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: string;
}
/**
 * A collection of values returned by getZeroTrustAccessShortLivedCertificate.
 */
export interface GetZeroTrustAccessShortLivedCertificateResult {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    readonly accountId?: string;
    /**
     * UUID.
     */
    readonly appId: string;
    /**
     * The Application Audience (AUD) tag. Identifies the application associated with the CA.
     */
    readonly aud: string;
    /**
     * The ID of the CA.
     */
    readonly id: string;
    /**
     * The public key to add to your SSH server configuration.
     */
    readonly publicKey: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    readonly zoneId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessShortLivedCertificate = cloudflare.getZeroTrustAccessShortLivedCertificate({
 *     appId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 *     accountId: "account_id",
 *     zoneId: "zone_id",
 * });
 * ```
 */
export declare function getZeroTrustAccessShortLivedCertificateOutput(args: GetZeroTrustAccessShortLivedCertificateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustAccessShortLivedCertificateResult>;
/**
 * A collection of arguments for invoking getZeroTrustAccessShortLivedCertificate.
 */
export interface GetZeroTrustAccessShortLivedCertificateOutputArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * UUID.
     */
    appId: pulumi.Input<string>;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: pulumi.Input<string>;
}
