import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDeviceCustomProfile = cloudflare.getZeroTrustDeviceCustomProfile({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     policyId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustDeviceCustomProfile(args: GetZeroTrustDeviceCustomProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustDeviceCustomProfileResult>;
/**
 * A collection of arguments for invoking getZeroTrustDeviceCustomProfile.
 */
export interface GetZeroTrustDeviceCustomProfileArgs {
    accountId: string;
    policyId?: string;
}
/**
 * A collection of values returned by getZeroTrustDeviceCustomProfile.
 */
export interface GetZeroTrustDeviceCustomProfileResult {
    readonly accountId: string;
    /**
     * Whether to allow the user to switch WARP between modes.
     */
    readonly allowModeSwitch: boolean;
    /**
     * Whether to receive update notifications when a new version of the client is available.
     */
    readonly allowUpdates: boolean;
    /**
     * Whether to allow devices to leave the organization.
     */
    readonly allowedToLeave: boolean;
    /**
     * The amount of time in seconds to reconnect after having been disabled.
     */
    readonly autoConnect: number;
    /**
     * Turn on the captive portal after the specified amount of time.
     */
    readonly captivePortal: number;
    /**
     * Whether the policy is the default policy for an account.
     */
    readonly default: boolean;
    /**
     * A description of the policy.
     */
    readonly description: string;
    /**
     * If the `dnsServer` field of a fallback domain is not present, the client will fall back to a best guess of the default/system DNS resolvers unless this policy option is set to `true`.
     */
    readonly disableAutoFallback: boolean;
    /**
     * Whether the policy will be applied to matching devices.
     */
    readonly enabled: boolean;
    /**
     * Whether to add Microsoft IPs to Split Tunnel exclusions.
     */
    readonly excludeOfficeIps: boolean;
    /**
     * List of routes excluded in the WARP client's tunnel.
     */
    readonly excludes: outputs.GetZeroTrustDeviceCustomProfileExclude[];
    readonly fallbackDomains: outputs.GetZeroTrustDeviceCustomProfileFallbackDomain[];
    readonly gatewayUniqueId: string;
    /**
     * The ID of this resource.
     */
    readonly id: string;
    /**
     * List of routes included in the WARP client's tunnel.
     */
    readonly includes: outputs.GetZeroTrustDeviceCustomProfileInclude[];
    /**
     * The amount of time in minutes a user is allowed access to their LAN. A value of 0 will allow LAN access until the next WARP reconnection, such as a reboot or a laptop waking from sleep. Note that this field is omitted from the response if null or unset.
     */
    readonly lanAllowMinutes: number;
    /**
     * The size of the subnet for the local access network. Note that this field is omitted from the response if null or unset.
     */
    readonly lanAllowSubnetSize: number;
    /**
     * The wirefilter expression to match devices. Available values: "identity.email", "identity.groups.id", "identity.groups.name", "identity.groups.email", "identity.service*token*uuid", "identity.saml_attributes", "network", "os.name", "os.version".
     */
    readonly match: string;
    /**
     * The name of the device settings profile.
     */
    readonly name: string;
    readonly policyId: string;
    /**
     * The precedence of the policy. Lower values indicate higher precedence. Policies will be evaluated in ascending order of this field.
     */
    readonly precedence: number;
    /**
     * Determines if the operating system will register WARP's local interface IP with your on-premises DNS server.
     */
    readonly registerInterfaceIpWithDns: boolean;
    /**
     * Determines whether the WARP client indicates to SCCM that it is inside a VPN boundary. (Windows only).
     */
    readonly sccmVpnBoundarySupport: boolean;
    readonly serviceModeV2: outputs.GetZeroTrustDeviceCustomProfileServiceModeV2;
    /**
     * The URL to launch when the Send Feedback button is clicked.
     */
    readonly supportUrl: string;
    /**
     * Whether to allow the user to turn off the WARP switch and disconnect the client.
     */
    readonly switchLocked: boolean;
    readonly targetTests: outputs.GetZeroTrustDeviceCustomProfileTargetTest[];
    /**
     * Determines which tunnel protocol to use.
     */
    readonly tunnelProtocol: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDeviceCustomProfile = cloudflare.getZeroTrustDeviceCustomProfile({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     policyId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustDeviceCustomProfileOutput(args: GetZeroTrustDeviceCustomProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustDeviceCustomProfileResult>;
/**
 * A collection of arguments for invoking getZeroTrustDeviceCustomProfile.
 */
export interface GetZeroTrustDeviceCustomProfileOutputArgs {
    accountId: pulumi.Input<string>;
    policyId?: pulumi.Input<string>;
}
