import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDeviceDefaultProfile = cloudflare.getZeroTrustDeviceDefaultProfile({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 * });
 * ```
 */
export declare function getZeroTrustDeviceDefaultProfile(args: GetZeroTrustDeviceDefaultProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustDeviceDefaultProfileResult>;
/**
 * A collection of arguments for invoking getZeroTrustDeviceDefaultProfile.
 */
export interface GetZeroTrustDeviceDefaultProfileArgs {
    accountId: string;
}
/**
 * A collection of values returned by getZeroTrustDeviceDefaultProfile.
 */
export interface GetZeroTrustDeviceDefaultProfileResult {
    readonly accountId: string;
    /**
     * Whether to allow the user to switch WARP between modes.
     */
    readonly allowModeSwitch: boolean;
    /**
     * Whether to receive update notifications when a new version of the client is available.
     */
    readonly allowUpdates: boolean;
    /**
     * Whether to allow devices to leave the organization.
     */
    readonly allowedToLeave: boolean;
    /**
     * The amount of time in seconds to reconnect after having been disabled.
     */
    readonly autoConnect: number;
    /**
     * Turn on the captive portal after the specified amount of time.
     */
    readonly captivePortal: number;
    /**
     * Whether the policy will be applied to matching devices.
     */
    readonly default: boolean;
    /**
     * If the `dnsServer` field of a fallback domain is not present, the client will fall back to a best guess of the default/system DNS resolvers unless this policy option is set to `true`.
     */
    readonly disableAutoFallback: boolean;
    /**
     * Whether the policy will be applied to matching devices.
     */
    readonly enabled: boolean;
    /**
     * Whether to add Microsoft IPs to Split Tunnel exclusions.
     */
    readonly excludeOfficeIps: boolean;
    /**
     * List of routes excluded in the WARP client's tunnel.
     */
    readonly excludes: outputs.GetZeroTrustDeviceDefaultProfileExclude[];
    readonly fallbackDomains: outputs.GetZeroTrustDeviceDefaultProfileFallbackDomain[];
    readonly gatewayUniqueId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * List of routes included in the WARP client's tunnel.
     */
    readonly includes: outputs.GetZeroTrustDeviceDefaultProfileInclude[];
    /**
     * Determines if the operating system will register WARP's local interface IP with your on-premises DNS server.
     */
    readonly registerInterfaceIpWithDns: boolean;
    /**
     * Determines whether the WARP client indicates to SCCM that it is inside a VPN boundary. (Windows only).
     */
    readonly sccmVpnBoundarySupport: boolean;
    readonly serviceModeV2: outputs.GetZeroTrustDeviceDefaultProfileServiceModeV2;
    /**
     * The URL to launch when the Send Feedback button is clicked.
     */
    readonly supportUrl: string;
    /**
     * Whether to allow the user to turn off the WARP switch and disconnect the client.
     */
    readonly switchLocked: boolean;
    /**
     * Determines which tunnel protocol to use.
     */
    readonly tunnelProtocol: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDeviceDefaultProfile = cloudflare.getZeroTrustDeviceDefaultProfile({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 * });
 * ```
 */
export declare function getZeroTrustDeviceDefaultProfileOutput(args: GetZeroTrustDeviceDefaultProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustDeviceDefaultProfileResult>;
/**
 * A collection of arguments for invoking getZeroTrustDeviceDefaultProfile.
 */
export interface GetZeroTrustDeviceDefaultProfileOutputArgs {
    accountId: pulumi.Input<string>;
}
