import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDeviceManagedNetworks = cloudflare.getZeroTrustDeviceManagedNetworks({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     networkId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustDeviceManagedNetworks(args: GetZeroTrustDeviceManagedNetworksArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustDeviceManagedNetworksResult>;
/**
 * A collection of arguments for invoking getZeroTrustDeviceManagedNetworks.
 */
export interface GetZeroTrustDeviceManagedNetworksArgs {
    accountId: string;
    /**
     * API UUID.
     */
    networkId?: string;
}
/**
 * A collection of values returned by getZeroTrustDeviceManagedNetworks.
 */
export interface GetZeroTrustDeviceManagedNetworksResult {
    readonly accountId: string;
    /**
     * The configuration object containing information for the WARP client to detect the managed network.
     */
    readonly config: outputs.GetZeroTrustDeviceManagedNetworksConfig;
    /**
     * API UUID.
     */
    readonly id: string;
    /**
     * The name of the device managed network. This name must be unique.
     */
    readonly name: string;
    /**
     * API UUID.
     */
    readonly networkId: string;
    /**
     * The type of device managed network.
     * Available values: "tls".
     */
    readonly type: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDeviceManagedNetworks = cloudflare.getZeroTrustDeviceManagedNetworks({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     networkId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustDeviceManagedNetworksOutput(args: GetZeroTrustDeviceManagedNetworksOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustDeviceManagedNetworksResult>;
/**
 * A collection of arguments for invoking getZeroTrustDeviceManagedNetworks.
 */
export interface GetZeroTrustDeviceManagedNetworksOutputArgs {
    accountId: pulumi.Input<string>;
    /**
     * API UUID.
     */
    networkId?: pulumi.Input<string>;
}
