import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDevicePostureIntegration = cloudflare.getZeroTrustDevicePostureIntegration({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     integrationId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustDevicePostureIntegration(args: GetZeroTrustDevicePostureIntegrationArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustDevicePostureIntegrationResult>;
/**
 * A collection of arguments for invoking getZeroTrustDevicePostureIntegration.
 */
export interface GetZeroTrustDevicePostureIntegrationArgs {
    accountId: string;
    /**
     * API UUID.
     */
    integrationId?: string;
}
/**
 * A collection of values returned by getZeroTrustDevicePostureIntegration.
 */
export interface GetZeroTrustDevicePostureIntegrationResult {
    readonly accountId: string;
    /**
     * The configuration object containing third-party integration information.
     */
    readonly config: outputs.GetZeroTrustDevicePostureIntegrationConfig;
    /**
     * API UUID.
     */
    readonly id: string;
    /**
     * API UUID.
     */
    readonly integrationId?: string;
    /**
     * The interval between each posture check with the third-party API. Use `m` for minutes (e.g. `5m`) and `h` for hours (e.g. `12h`).
     */
    readonly interval: string;
    /**
     * The name of the device posture integration.
     */
    readonly name: string;
    /**
     * The type of device posture integration.
     * Available values: "workspace*one", "crowdstrike*s2s", "uptycs", "intune", "kolide", "tanium*s2s", "sentinelone*s2s", "customS2s".
     */
    readonly type: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDevicePostureIntegration = cloudflare.getZeroTrustDevicePostureIntegration({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     integrationId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustDevicePostureIntegrationOutput(args: GetZeroTrustDevicePostureIntegrationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustDevicePostureIntegrationResult>;
/**
 * A collection of arguments for invoking getZeroTrustDevicePostureIntegration.
 */
export interface GetZeroTrustDevicePostureIntegrationOutputArgs {
    accountId: pulumi.Input<string>;
    /**
     * API UUID.
     */
    integrationId?: pulumi.Input<string>;
}
