import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDexTest = cloudflare.getZeroTrustDexTest({
 *     accountId: "01a7362d577a6c3019a474fd6f485823",
 *     dexTestId: "372e67954025e0ba6aaa6d586b9e0b59",
 * });
 * ```
 */
export declare function getZeroTrustDexTest(args: GetZeroTrustDexTestArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustDexTestResult>;
/**
 * A collection of arguments for invoking getZeroTrustDexTest.
 */
export interface GetZeroTrustDexTestArgs {
    accountId: string;
    /**
     * The unique identifier for the test.
     */
    dexTestId?: string;
}
/**
 * A collection of values returned by getZeroTrustDexTest.
 */
export interface GetZeroTrustDexTestResult {
    readonly accountId: string;
    /**
     * The configuration object which contains the details for the WARP client to conduct the test.
     */
    readonly data: outputs.GetZeroTrustDexTestData;
    /**
     * Additional details about the test.
     */
    readonly description: string;
    /**
     * The unique identifier for the test.
     */
    readonly dexTestId?: string;
    /**
     * Determines whether or not the test is active.
     */
    readonly enabled: boolean;
    /**
     * The unique identifier for the test.
     */
    readonly id: string;
    /**
     * How often the test will run.
     */
    readonly interval: string;
    /**
     * The name of the DEX test. Must be unique.
     */
    readonly name: string;
    /**
     * DEX rules targeted by this test
     */
    readonly targetPolicies: outputs.GetZeroTrustDexTestTargetPolicy[];
    readonly targeted: boolean;
    /**
     * The unique identifier for the test.
     */
    readonly testId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDexTest = cloudflare.getZeroTrustDexTest({
 *     accountId: "01a7362d577a6c3019a474fd6f485823",
 *     dexTestId: "372e67954025e0ba6aaa6d586b9e0b59",
 * });
 * ```
 */
export declare function getZeroTrustDexTestOutput(args: GetZeroTrustDexTestOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustDexTestResult>;
/**
 * A collection of arguments for invoking getZeroTrustDexTest.
 */
export interface GetZeroTrustDexTestOutputArgs {
    accountId: pulumi.Input<string>;
    /**
     * The unique identifier for the test.
     */
    dexTestId?: pulumi.Input<string>;
}
