import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDlpEntry = cloudflare.getZeroTrustDlpEntry({
 *     accountId: "account_id",
 *     entryId: "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
 * });
 * ```
 */
export declare function getZeroTrustDlpEntry(args: GetZeroTrustDlpEntryArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustDlpEntryResult>;
/**
 * A collection of arguments for invoking getZeroTrustDlpEntry.
 */
export interface GetZeroTrustDlpEntryArgs {
    accountId: string;
    entryId?: string;
}
/**
 * A collection of values returned by getZeroTrustDlpEntry.
 */
export interface GetZeroTrustDlpEntryResult {
    readonly accountId: string;
    /**
     * Only applies to custom word lists.
     * Determines if the words should be matched in a case-sensitive manner
     * Cannot be set to false if secret is true
     */
    readonly caseSensitive: boolean;
    readonly confidence: outputs.GetZeroTrustDlpEntryConfidence;
    readonly createdAt: string;
    readonly enabled: boolean;
    readonly entryId?: string;
    /**
     * The ID of this resource.
     */
    readonly id: string;
    readonly name: string;
    readonly pattern: outputs.GetZeroTrustDlpEntryPattern;
    readonly profileId: string;
    readonly secret: boolean;
    /**
     * Available values: "custom", "predefined", "integration", "exact*data", "word*list".
     */
    readonly type: string;
    readonly updatedAt: string;
    readonly wordList: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDlpEntry = cloudflare.getZeroTrustDlpEntry({
 *     accountId: "account_id",
 *     entryId: "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
 * });
 * ```
 */
export declare function getZeroTrustDlpEntryOutput(args: GetZeroTrustDlpEntryOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustDlpEntryResult>;
/**
 * A collection of arguments for invoking getZeroTrustDlpEntry.
 */
export interface GetZeroTrustDlpEntryOutputArgs {
    accountId: pulumi.Input<string>;
    entryId?: pulumi.Input<string>;
}
