import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDnsLocation = cloudflare.getZeroTrustDnsLocation({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     locationId: "ed35569b41ce4d1facfe683550f54086",
 * });
 * ```
 */
export declare function getZeroTrustDnsLocation(args: GetZeroTrustDnsLocationArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustDnsLocationResult>;
/**
 * A collection of arguments for invoking getZeroTrustDnsLocation.
 */
export interface GetZeroTrustDnsLocationArgs {
    accountId: string;
    locationId?: string;
}
/**
 * A collection of values returned by getZeroTrustDnsLocation.
 */
export interface GetZeroTrustDnsLocationResult {
    readonly accountId: string;
    /**
     * True if the location is the default location.
     */
    readonly clientDefault: boolean;
    readonly createdAt: string;
    /**
     * The identifier of the pair of IPv4 addresses assigned to this location.
     */
    readonly dnsDestinationIpsId: string;
    /**
     * The uuid identifier of the IPv6 block brought to the gateway, so that this location's IPv6 address is allocated from the Bring Your Own Ipv6(BYOIPv6) block and not from the standard CloudFlare IPv6 block.
     */
    readonly dnsDestinationIpv6BlockId: string;
    /**
     * The DNS over HTTPS domain to send DNS requests to. This field is auto-generated by Gateway.
     */
    readonly dohSubdomain: string;
    /**
     * True if the location needs to resolve EDNS queries.
     */
    readonly ecsSupport: boolean;
    /**
     * The destination endpoints configured for this location. When updating a location, if this field is absent or set with null, the endpoints configuration remains unchanged.
     */
    readonly endpoints: outputs.GetZeroTrustDnsLocationEndpoints;
    /**
     * The ID of this resource.
     */
    readonly id: string;
    /**
     * IPV6 destination ip assigned to this location. DNS requests sent to this IP will counted as the request under this location. This field is auto-generated by Gateway.
     */
    readonly ip: string;
    /**
     * The primary destination IPv4 address from the pair identified by the dns*destination*ips_id. This field is read-only.
     */
    readonly ipv4Destination: string;
    /**
     * The backup destination IPv4 address from the pair identified by the dns*destination*ips_id. This field is read-only.
     */
    readonly ipv4DestinationBackup: string;
    readonly locationId?: string;
    /**
     * The name of the location.
     */
    readonly name: string;
    /**
     * A list of network ranges that requests from this location would originate from. A non-empty list is only effective if the ipv4 endpoint is enabled for this location.
     */
    readonly networks: outputs.GetZeroTrustDnsLocationNetwork[];
    readonly updatedAt: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDnsLocation = cloudflare.getZeroTrustDnsLocation({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     locationId: "ed35569b41ce4d1facfe683550f54086",
 * });
 * ```
 */
export declare function getZeroTrustDnsLocationOutput(args: GetZeroTrustDnsLocationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustDnsLocationResult>;
/**
 * A collection of arguments for invoking getZeroTrustDnsLocation.
 */
export interface GetZeroTrustDnsLocationOutputArgs {
    accountId: pulumi.Input<string>;
    locationId?: pulumi.Input<string>;
}
