import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustGatewayCertificate = cloudflare.getZeroTrustGatewayCertificate({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     certificateId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustGatewayCertificate(args: GetZeroTrustGatewayCertificateArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustGatewayCertificateResult>;
/**
 * A collection of arguments for invoking getZeroTrustGatewayCertificate.
 */
export interface GetZeroTrustGatewayCertificateArgs {
    accountId: string;
    /**
     * Certificate UUID tag.
     */
    certificateId?: string;
}
/**
 * A collection of values returned by getZeroTrustGatewayCertificate.
 */
export interface GetZeroTrustGatewayCertificateResult {
    readonly accountId: string;
    /**
     * The deployment status of the certificate on Cloudflare's edge. Certificates in the 'available' (previously called 'active') state may be used for Gateway TLS interception.
     * Available values: "pending*deployment", "available", "pending*deletion", "inactive".
     */
    readonly bindingStatus: string;
    /**
     * The CA certificate
     */
    readonly certificate: string;
    /**
     * Certificate UUID tag.
     */
    readonly certificateId?: string;
    readonly createdAt: string;
    readonly expiresOn: string;
    /**
     * The SHA256 fingerprint of the certificate.
     */
    readonly fingerprint: string;
    /**
     * Certificate UUID tag.
     */
    readonly id: string;
    /**
     * Use this certificate for Gateway TLS interception
     */
    readonly inUse: boolean;
    /**
     * The organization that issued the certificate.
     */
    readonly issuerOrg: string;
    /**
     * The entire issuer field of the certificate.
     */
    readonly issuerRaw: string;
    /**
     * The type of certificate, either BYO-PKI (custom) or Gateway-managed.
     * Available values: "custom", "gatewayManaged".
     */
    readonly type: string;
    readonly updatedAt: string;
    readonly uploadedOn: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustGatewayCertificate = cloudflare.getZeroTrustGatewayCertificate({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     certificateId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustGatewayCertificateOutput(args: GetZeroTrustGatewayCertificateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustGatewayCertificateResult>;
/**
 * A collection of arguments for invoking getZeroTrustGatewayCertificate.
 */
export interface GetZeroTrustGatewayCertificateOutputArgs {
    accountId: pulumi.Input<string>;
    /**
     * Certificate UUID tag.
     */
    certificateId?: pulumi.Input<string>;
}
