import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustGatewayPolicy = cloudflare.getZeroTrustGatewayPolicy({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     ruleId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustGatewayPolicy(args: GetZeroTrustGatewayPolicyArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustGatewayPolicyResult>;
/**
 * A collection of arguments for invoking getZeroTrustGatewayPolicy.
 */
export interface GetZeroTrustGatewayPolicyArgs {
    accountId: string;
    /**
     * The API resource UUID.
     */
    ruleId?: string;
}
/**
 * A collection of values returned by getZeroTrustGatewayPolicy.
 */
export interface GetZeroTrustGatewayPolicyResult {
    readonly accountId: string;
    /**
     * The action to preform when the associated traffic, identity, and device posture expressions are either absent or evaluate to `true`.
     * Available values: "on", "off", "allow", "block", "scan", "noscan", "safesearch", "ytrestricted", "isolate", "noisolate", "override", "l4Override", "egress", "resolve", "quarantine", "redirect".
     */
    readonly action: string;
    readonly createdAt: string;
    /**
     * Date of deletion, if any.
     */
    readonly deletedAt: string;
    /**
     * The description of the rule.
     */
    readonly description: string;
    /**
     * The wirefilter expression used for device posture check matching.
     */
    readonly devicePosture: string;
    /**
     * True if the rule is enabled.
     */
    readonly enabled: boolean;
    /**
     * The expiration time stamp and default duration of a DNS policy. Takes
     * precedence over the policy's `schedule` configuration, if any.
     */
    readonly expiration: outputs.GetZeroTrustGatewayPolicyExpiration;
    readonly filters: string[];
    readonly id: string;
    readonly identity: string;
    readonly name: string;
    readonly precedence: number;
    /**
     * The API resource UUID.
     */
    readonly ruleId?: string;
    readonly ruleSettings: outputs.GetZeroTrustGatewayPolicyRuleSettings;
    readonly schedule: outputs.GetZeroTrustGatewayPolicySchedule;
    readonly traffic: string;
    readonly updatedAt: string;
    readonly version: number;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustGatewayPolicy = cloudflare.getZeroTrustGatewayPolicy({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     ruleId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustGatewayPolicyOutput(args: GetZeroTrustGatewayPolicyOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustGatewayPolicyResult>;
/**
 * A collection of arguments for invoking getZeroTrustGatewayPolicy.
 */
export interface GetZeroTrustGatewayPolicyOutputArgs {
    accountId: pulumi.Input<string>;
    /**
     * The API resource UUID.
     */
    ruleId?: pulumi.Input<string>;
}
