import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustList = cloudflare.getZeroTrustList({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     listId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustList(args: GetZeroTrustListArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustListResult>;
/**
 * A collection of arguments for invoking getZeroTrustList.
 */
export interface GetZeroTrustListArgs {
    accountId: string;
    filter?: inputs.GetZeroTrustListFilter;
    /**
     * API Resource UUID tag.
     */
    listId?: string;
}
/**
 * A collection of values returned by getZeroTrustList.
 */
export interface GetZeroTrustListResult {
    readonly accountId: string;
    readonly createdAt: string;
    /**
     * The description of the list.
     */
    readonly description: string;
    readonly filter?: outputs.GetZeroTrustListFilter;
    /**
     * API Resource UUID tag.
     */
    readonly id: string;
    /**
     * The items in the list.
     */
    readonly items: outputs.GetZeroTrustListItem[];
    /**
     * The number of items in the list.
     */
    readonly listCount: number;
    /**
     * API Resource UUID tag.
     */
    readonly listId?: string;
    /**
     * The name of the list.
     */
    readonly name: string;
    /**
     * The type of list.
     * Available values: "SERIAL", "URL", "DOMAIN", "EMAIL", "IP".
     */
    readonly type: string;
    readonly updatedAt: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustList = cloudflare.getZeroTrustList({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     listId: "f174e90a-fafe-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustListOutput(args: GetZeroTrustListOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustListResult>;
/**
 * A collection of arguments for invoking getZeroTrustList.
 */
export interface GetZeroTrustListOutputArgs {
    accountId: pulumi.Input<string>;
    filter?: pulumi.Input<inputs.GetZeroTrustListFilterArgs>;
    /**
     * API Resource UUID tag.
     */
    listId?: pulumi.Input<string>;
}
