import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustLists = cloudflare.getZeroTrustLists({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     type: "SERIAL",
 * });
 * ```
 */
export declare function getZeroTrustLists(args: GetZeroTrustListsArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustListsResult>;
/**
 * A collection of arguments for invoking getZeroTrustLists.
 */
export interface GetZeroTrustListsArgs {
    accountId: string;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: number;
    /**
     * The type of list.
     * Available values: "SERIAL", "URL", "DOMAIN", "EMAIL", "IP".
     */
    type?: string;
}
/**
 * A collection of values returned by getZeroTrustLists.
 */
export interface GetZeroTrustListsResult {
    readonly accountId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Max items to fetch, default: 1000
     */
    readonly maxItems?: number;
    /**
     * The items returned by the data source
     */
    readonly results: outputs.GetZeroTrustListsResult[];
    /**
     * The type of list.
     * Available values: "SERIAL", "URL", "DOMAIN", "EMAIL", "IP".
     */
    readonly type?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustLists = cloudflare.getZeroTrustLists({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     type: "SERIAL",
 * });
 * ```
 */
export declare function getZeroTrustListsOutput(args: GetZeroTrustListsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustListsResult>;
/**
 * A collection of arguments for invoking getZeroTrustLists.
 */
export interface GetZeroTrustListsOutputArgs {
    accountId: pulumi.Input<string>;
    /**
     * Max items to fetch, default: 1000
     */
    maxItems?: pulumi.Input<number>;
    /**
     * The type of list.
     * Available values: "SERIAL", "URL", "DOMAIN", "EMAIL", "IP".
     */
    type?: pulumi.Input<string>;
}
