import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustRiskScoringIntegration = cloudflare.getZeroTrustRiskScoringIntegration({
 *     accountId: "account_id",
 *     integrationId: "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
 * });
 * ```
 */
export declare function getZeroTrustRiskScoringIntegration(args: GetZeroTrustRiskScoringIntegrationArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustRiskScoringIntegrationResult>;
/**
 * A collection of arguments for invoking getZeroTrustRiskScoringIntegration.
 */
export interface GetZeroTrustRiskScoringIntegrationArgs {
    accountId: string;
    integrationId?: string;
}
/**
 * A collection of values returned by getZeroTrustRiskScoringIntegration.
 */
export interface GetZeroTrustRiskScoringIntegrationResult {
    readonly accountId: string;
    /**
     * The Cloudflare account tag.
     */
    readonly accountTag: string;
    /**
     * Whether this integration is enabled and should export changes in risk score.
     */
    readonly active: boolean;
    /**
     * When the integration was created in RFC3339 format.
     */
    readonly createdAt: string;
    /**
     * The ID of this resource.
     */
    readonly id: string;
    readonly integrationId?: string;
    /**
     * Available values: "Okta".
     */
    readonly integrationType: string;
    /**
     * A reference ID defined by the client.
     * Should be set to the Access-Okta IDP integration ID.
     * Useful when the risk-score integration needs to be associated with a secondary asset and recalled using that ID.
     */
    readonly referenceId: string;
    /**
     * The base URL for the tenant. E.g. "https://tenant.okta.com".
     */
    readonly tenantUrl: string;
    /**
     * The URL for the Shared Signals Framework configuration, e.g. "/.well-known/sse-configuration/{integration*uuid}/". https://openid.net/specs/openid-sse-framework-1*0.html#rfc.section.6.2.1.
     */
    readonly wellKnownUrl: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustRiskScoringIntegration = cloudflare.getZeroTrustRiskScoringIntegration({
 *     accountId: "account_id",
 *     integrationId: "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
 * });
 * ```
 */
export declare function getZeroTrustRiskScoringIntegrationOutput(args: GetZeroTrustRiskScoringIntegrationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustRiskScoringIntegrationResult>;
/**
 * A collection of arguments for invoking getZeroTrustRiskScoringIntegration.
 */
export interface GetZeroTrustRiskScoringIntegrationOutputArgs {
    accountId: pulumi.Input<string>;
    integrationId?: pulumi.Input<string>;
}
