import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustTunnelCloudflaredRoute = cloudflare.getZeroTrustTunnelCloudflaredRoute({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     routeId: "f70ff985-a4ef-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustTunnelCloudflaredRoute(args: GetZeroTrustTunnelCloudflaredRouteArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustTunnelCloudflaredRouteResult>;
/**
 * A collection of arguments for invoking getZeroTrustTunnelCloudflaredRoute.
 */
export interface GetZeroTrustTunnelCloudflaredRouteArgs {
    /**
     * Cloudflare account ID
     */
    accountId: string;
    filter?: inputs.GetZeroTrustTunnelCloudflaredRouteFilter;
    /**
     * UUID of the route.
     */
    routeId?: string;
}
/**
 * A collection of values returned by getZeroTrustTunnelCloudflaredRoute.
 */
export interface GetZeroTrustTunnelCloudflaredRouteResult {
    /**
     * Cloudflare account ID
     */
    readonly accountId: string;
    /**
     * Optional remark describing the route.
     */
    readonly comment: string;
    /**
     * Timestamp of when the resource was created.
     */
    readonly createdAt: string;
    /**
     * Timestamp of when the resource was deleted. If `null`, the resource has not been deleted.
     */
    readonly deletedAt: string;
    readonly filter?: outputs.GetZeroTrustTunnelCloudflaredRouteFilter;
    /**
     * UUID of the route.
     */
    readonly id: string;
    /**
     * The private IPv4 or IPv6 range connected by the route, in CIDR notation.
     */
    readonly network: string;
    /**
     * UUID of the route.
     */
    readonly routeId?: string;
    /**
     * UUID of the tunnel.
     */
    readonly tunnelId: string;
    /**
     * UUID of the virtual network.
     */
    readonly virtualNetworkId: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustTunnelCloudflaredRoute = cloudflare.getZeroTrustTunnelCloudflaredRoute({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     routeId: "f70ff985-a4ef-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustTunnelCloudflaredRouteOutput(args: GetZeroTrustTunnelCloudflaredRouteOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustTunnelCloudflaredRouteResult>;
/**
 * A collection of arguments for invoking getZeroTrustTunnelCloudflaredRoute.
 */
export interface GetZeroTrustTunnelCloudflaredRouteOutputArgs {
    /**
     * Cloudflare account ID
     */
    accountId: pulumi.Input<string>;
    filter?: pulumi.Input<inputs.GetZeroTrustTunnelCloudflaredRouteFilterArgs>;
    /**
     * UUID of the route.
     */
    routeId?: pulumi.Input<string>;
}
