import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustTunnelCloudflaredVirtualNetwork = cloudflare.getZeroTrustTunnelCloudflaredVirtualNetwork({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     virtualNetworkId: "f70ff985-a4ef-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustTunnelCloudflaredVirtualNetwork(args: GetZeroTrustTunnelCloudflaredVirtualNetworkArgs, opts?: pulumi.InvokeOptions): Promise<GetZeroTrustTunnelCloudflaredVirtualNetworkResult>;
/**
 * A collection of arguments for invoking getZeroTrustTunnelCloudflaredVirtualNetwork.
 */
export interface GetZeroTrustTunnelCloudflaredVirtualNetworkArgs {
    /**
     * Cloudflare account ID
     */
    accountId: string;
    filter?: inputs.GetZeroTrustTunnelCloudflaredVirtualNetworkFilter;
    /**
     * UUID of the virtual network.
     */
    virtualNetworkId?: string;
}
/**
 * A collection of values returned by getZeroTrustTunnelCloudflaredVirtualNetwork.
 */
export interface GetZeroTrustTunnelCloudflaredVirtualNetworkResult {
    /**
     * Cloudflare account ID
     */
    readonly accountId: string;
    /**
     * Optional remark describing the virtual network.
     */
    readonly comment: string;
    /**
     * Timestamp of when the resource was created.
     */
    readonly createdAt: string;
    /**
     * Timestamp of when the resource was deleted. If `null`, the resource has not been deleted.
     */
    readonly deletedAt: string;
    readonly filter?: outputs.GetZeroTrustTunnelCloudflaredVirtualNetworkFilter;
    /**
     * UUID of the virtual network.
     */
    readonly id: string;
    /**
     * If `true`, this virtual network is the default for the account.
     */
    readonly isDefaultNetwork: boolean;
    /**
     * A user-friendly name for the virtual network.
     */
    readonly name: string;
    /**
     * UUID of the virtual network.
     */
    readonly virtualNetworkId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustTunnelCloudflaredVirtualNetwork = cloudflare.getZeroTrustTunnelCloudflaredVirtualNetwork({
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     virtualNetworkId: "f70ff985-a4ef-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 */
export declare function getZeroTrustTunnelCloudflaredVirtualNetworkOutput(args: GetZeroTrustTunnelCloudflaredVirtualNetworkOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZeroTrustTunnelCloudflaredVirtualNetworkResult>;
/**
 * A collection of arguments for invoking getZeroTrustTunnelCloudflaredVirtualNetwork.
 */
export interface GetZeroTrustTunnelCloudflaredVirtualNetworkOutputArgs {
    /**
     * Cloudflare account ID
     */
    accountId: pulumi.Input<string>;
    filter?: pulumi.Input<inputs.GetZeroTrustTunnelCloudflaredVirtualNetworkFilterArgs>;
    /**
     * UUID of the virtual network.
     */
    virtualNetworkId?: pulumi.Input<string>;
}
