import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZone = cloudflare.getZone({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getZone(args?: GetZoneArgs, opts?: pulumi.InvokeOptions): Promise<GetZoneResult>;
/**
 * A collection of arguments for invoking getZone.
 */
export interface GetZoneArgs {
    filter?: inputs.GetZoneFilter;
    zoneId?: string;
}
/**
 * A collection of values returned by getZone.
 */
export interface GetZoneResult {
    readonly account: outputs.GetZoneAccount;
    readonly activatedOn: string;
    readonly cnameSuffix: string;
    readonly createdOn: string;
    readonly developmentMode: number;
    readonly filter?: outputs.GetZoneFilter;
    readonly id: string;
    readonly meta: outputs.GetZoneMeta;
    readonly modifiedOn: string;
    readonly name: string;
    readonly nameServers: string[];
    readonly originalDnshost: string;
    readonly originalNameServers: string[];
    readonly originalRegistrar: string;
    readonly owner: outputs.GetZoneOwner;
    readonly paused: boolean;
    /**
     * @deprecated This attribute is deprecated.
     */
    readonly permissions: string[];
    /**
     * @deprecated This attribute is deprecated.
     */
    readonly plan: outputs.GetZonePlan;
    readonly status: string;
    readonly tenant: outputs.GetZoneTenant;
    readonly tenantUnit: outputs.GetZoneTenantUnit;
    readonly type: string;
    readonly vanityNameServers: string[];
    readonly verificationKey: string;
    readonly zoneId?: string;
}
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZone = cloudflare.getZone({
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 * });
 * ```
 */
export declare function getZoneOutput(args?: GetZoneOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetZoneResult>;
/**
 * A collection of arguments for invoking getZone.
 */
export interface GetZoneOutputArgs {
    filter?: pulumi.Input<inputs.GetZoneFilterArgs>;
    zoneId?: pulumi.Input<string>;
}
