import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/keylessCertificate:KeylessCertificate example '<zone_id>/<keyless_certificate_id>'
 * ```
 */
export declare class KeylessCertificate extends pulumi.CustomResource {
    /**
     * Get an existing KeylessCertificate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: KeylessCertificateState, opts?: pulumi.CustomResourceOptions): KeylessCertificate;
    /**
     * Returns true if the given object is an instance of KeylessCertificate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is KeylessCertificate;
    /**
     * A ubiquitous bundle has the highest probability of being verified everywhere, even by clients using outdated or unusual trust stores. An optimal bundle uses the shortest chain and newest intermediates. And the force bundle verifies the chain, but does not otherwise modify it.
     * Available values: "ubiquitous", "optimal", "force".
     */
    readonly bundleMethod: pulumi.Output<string>;
    /**
     * The zone's SSL certificate or SSL certificate and intermediate(s).
     */
    readonly certificate: pulumi.Output<string>;
    /**
     * When the Keyless SSL was created.
     */
    readonly createdOn: pulumi.Output<string>;
    /**
     * Whether or not the Keyless SSL is on or off.
     *
     * @deprecated This attribute is deprecated.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * The keyless SSL name.
     */
    readonly host: pulumi.Output<string>;
    /**
     * When the Keyless SSL was last modified.
     */
    readonly modifiedOn: pulumi.Output<string>;
    /**
     * The keyless SSL name.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * Available permissions for the Keyless SSL for the current user requesting the item.
     */
    readonly permissions: pulumi.Output<string[]>;
    /**
     * The keyless SSL port used to communicate between Cloudflare and the client's Keyless SSL server.
     */
    readonly port: pulumi.Output<number>;
    /**
     * Status of the Keyless SSL.
     * Available values: "active", "deleted".
     */
    readonly status: pulumi.Output<string>;
    /**
     * Configuration for using Keyless SSL through a Cloudflare Tunnel
     */
    readonly tunnel: pulumi.Output<outputs.KeylessCertificateTunnel | undefined>;
    /**
     * Identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a KeylessCertificate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: KeylessCertificateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering KeylessCertificate resources.
 */
export interface KeylessCertificateState {
    /**
     * A ubiquitous bundle has the highest probability of being verified everywhere, even by clients using outdated or unusual trust stores. An optimal bundle uses the shortest chain and newest intermediates. And the force bundle verifies the chain, but does not otherwise modify it.
     * Available values: "ubiquitous", "optimal", "force".
     */
    bundleMethod?: pulumi.Input<string>;
    /**
     * The zone's SSL certificate or SSL certificate and intermediate(s).
     */
    certificate?: pulumi.Input<string>;
    /**
     * When the Keyless SSL was created.
     */
    createdOn?: pulumi.Input<string>;
    /**
     * Whether or not the Keyless SSL is on or off.
     *
     * @deprecated This attribute is deprecated.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * The keyless SSL name.
     */
    host?: pulumi.Input<string>;
    /**
     * When the Keyless SSL was last modified.
     */
    modifiedOn?: pulumi.Input<string>;
    /**
     * The keyless SSL name.
     */
    name?: pulumi.Input<string>;
    /**
     * Available permissions for the Keyless SSL for the current user requesting the item.
     */
    permissions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The keyless SSL port used to communicate between Cloudflare and the client's Keyless SSL server.
     */
    port?: pulumi.Input<number>;
    /**
     * Status of the Keyless SSL.
     * Available values: "active", "deleted".
     */
    status?: pulumi.Input<string>;
    /**
     * Configuration for using Keyless SSL through a Cloudflare Tunnel
     */
    tunnel?: pulumi.Input<inputs.KeylessCertificateTunnel>;
    /**
     * Identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a KeylessCertificate resource.
 */
export interface KeylessCertificateArgs {
    /**
     * A ubiquitous bundle has the highest probability of being verified everywhere, even by clients using outdated or unusual trust stores. An optimal bundle uses the shortest chain and newest intermediates. And the force bundle verifies the chain, but does not otherwise modify it.
     * Available values: "ubiquitous", "optimal", "force".
     */
    bundleMethod?: pulumi.Input<string>;
    /**
     * The zone's SSL certificate or SSL certificate and intermediate(s).
     */
    certificate: pulumi.Input<string>;
    /**
     * Whether or not the Keyless SSL is on or off.
     *
     * @deprecated This attribute is deprecated.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * The keyless SSL name.
     */
    host: pulumi.Input<string>;
    /**
     * The keyless SSL name.
     */
    name?: pulumi.Input<string>;
    /**
     * The keyless SSL port used to communicate between Cloudflare and the client's Keyless SSL server.
     */
    port?: pulumi.Input<number>;
    /**
     * Configuration for using Keyless SSL through a Cloudflare Tunnel
     */
    tunnel?: pulumi.Input<inputs.KeylessCertificateTunnel>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
