import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleLeakedCredentialCheckRule = new cloudflare.LeakedCredentialCheckRule("example_leaked_credential_check_rule", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     password: "lookup_json_string(http.request.body.raw, \"secret\")",
 *     username: "lookup_json_string(http.request.body.raw, \"user\")",
 * });
 * ```
 */
export declare class LeakedCredentialCheckRule extends pulumi.CustomResource {
    /**
     * Get an existing LeakedCredentialCheckRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LeakedCredentialCheckRuleState, opts?: pulumi.CustomResourceOptions): LeakedCredentialCheckRule;
    /**
     * Returns true if the given object is an instance of LeakedCredentialCheckRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LeakedCredentialCheckRule;
    /**
     * Defines ehe ruleset expression to use in matching the password in a request.
     */
    readonly password: pulumi.Output<string | undefined>;
    /**
     * Defines the ruleset expression to use in matching the username in a request.
     */
    readonly username: pulumi.Output<string | undefined>;
    /**
     * Defines an identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a LeakedCredentialCheckRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LeakedCredentialCheckRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LeakedCredentialCheckRule resources.
 */
export interface LeakedCredentialCheckRuleState {
    /**
     * Defines ehe ruleset expression to use in matching the password in a request.
     */
    password?: pulumi.Input<string>;
    /**
     * Defines the ruleset expression to use in matching the username in a request.
     */
    username?: pulumi.Input<string>;
    /**
     * Defines an identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a LeakedCredentialCheckRule resource.
 */
export interface LeakedCredentialCheckRuleArgs {
    /**
     * Defines ehe ruleset expression to use in matching the password in a request.
     */
    password?: pulumi.Input<string>;
    /**
     * Defines the ruleset expression to use in matching the username in a request.
     */
    username?: pulumi.Input<string>;
    /**
     * Defines an identifier.
     */
    zoneId: pulumi.Input<string>;
}
