import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleListItem = new cloudflare.ListItem("example_list_item", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     listId: "2c0fc9fa937b11eaa1b71c4d701ab86e",
 *     ip: "10.0.0.1",
 * });
 * ```
 */
export declare class ListItem extends pulumi.CustomResource {
    /**
     * Get an existing ListItem resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ListItemState, opts?: pulumi.CustomResourceOptions): ListItem;
    /**
     * Returns true if the given object is an instance of ListItem.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ListItem;
    /**
     * Defines an identifier.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * A non-negative 32 bit integer
     */
    readonly asn: pulumi.Output<number | undefined>;
    /**
     * An informative summary of the list item.
     */
    readonly comment: pulumi.Output<string | undefined>;
    /**
     * The RFC 3339 timestamp of when the item was created.
     */
    readonly createdOn: pulumi.Output<string>;
    /**
     * Valid characters for hostnames are ASCII(7) letters from a to z, the digits from 0 to 9, wildcards (*), and the hyphen (-).
     */
    readonly hostname: pulumi.Output<outputs.ListItemHostname | undefined>;
    /**
     * An IPv4 address, an IPv4 CIDR, or an IPv6 CIDR. IPv6 CIDRs are limited to a maximum of /64.
     */
    readonly ip: pulumi.Output<string | undefined>;
    /**
     * The unique ID of the list.
     */
    readonly listId: pulumi.Output<string>;
    /**
     * The RFC 3339 timestamp of when the item was last modified.
     */
    readonly modifiedOn: pulumi.Output<string>;
    /**
     * The unique operation ID of the asynchronous action.
     */
    readonly operationId: pulumi.Output<string>;
    /**
     * The definition of the redirect.
     */
    readonly redirect: pulumi.Output<outputs.ListItemRedirect | undefined>;
    /**
     * Create a ListItem resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ListItemArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ListItem resources.
 */
export interface ListItemState {
    /**
     * Defines an identifier.
     */
    accountId?: pulumi.Input<string>;
    /**
     * A non-negative 32 bit integer
     */
    asn?: pulumi.Input<number>;
    /**
     * An informative summary of the list item.
     */
    comment?: pulumi.Input<string>;
    /**
     * The RFC 3339 timestamp of when the item was created.
     */
    createdOn?: pulumi.Input<string>;
    /**
     * Valid characters for hostnames are ASCII(7) letters from a to z, the digits from 0 to 9, wildcards (*), and the hyphen (-).
     */
    hostname?: pulumi.Input<inputs.ListItemHostname>;
    /**
     * An IPv4 address, an IPv4 CIDR, or an IPv6 CIDR. IPv6 CIDRs are limited to a maximum of /64.
     */
    ip?: pulumi.Input<string>;
    /**
     * The unique ID of the list.
     */
    listId?: pulumi.Input<string>;
    /**
     * The RFC 3339 timestamp of when the item was last modified.
     */
    modifiedOn?: pulumi.Input<string>;
    /**
     * The unique operation ID of the asynchronous action.
     */
    operationId?: pulumi.Input<string>;
    /**
     * The definition of the redirect.
     */
    redirect?: pulumi.Input<inputs.ListItemRedirect>;
}
/**
 * The set of arguments for constructing a ListItem resource.
 */
export interface ListItemArgs {
    /**
     * Defines an identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * A non-negative 32 bit integer
     */
    asn?: pulumi.Input<number>;
    /**
     * An informative summary of the list item.
     */
    comment?: pulumi.Input<string>;
    /**
     * Valid characters for hostnames are ASCII(7) letters from a to z, the digits from 0 to 9, wildcards (*), and the hyphen (-).
     */
    hostname?: pulumi.Input<inputs.ListItemHostname>;
    /**
     * An IPv4 address, an IPv4 CIDR, or an IPv6 CIDR. IPv6 CIDRs are limited to a maximum of /64.
     */
    ip?: pulumi.Input<string>;
    /**
     * The unique ID of the list.
     */
    listId: pulumi.Input<string>;
    /**
     * The definition of the redirect.
     */
    redirect?: pulumi.Input<inputs.ListItemRedirect>;
}
