import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/magicTransitSiteLan:MagicTransitSiteLan example '<account_id>/<site_id>/<lan_id>'
 * ```
 */
export declare class MagicTransitSiteLan extends pulumi.CustomResource {
    /**
     * Get an existing MagicTransitSiteLan resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: MagicTransitSiteLanState, opts?: pulumi.CustomResourceOptions): MagicTransitSiteLan;
    /**
     * Returns true if the given object is an instance of MagicTransitSiteLan.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MagicTransitSiteLan;
    /**
     * Identifier
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * mark true to use this LAN for HA probing. only works for site with HA turned on. only one LAN can be set as the ha_link.
     */
    readonly haLink: pulumi.Output<boolean | undefined>;
    readonly name: pulumi.Output<string | undefined>;
    readonly nat: pulumi.Output<outputs.MagicTransitSiteLanNat | undefined>;
    readonly physport: pulumi.Output<number>;
    readonly routedSubnets: pulumi.Output<outputs.MagicTransitSiteLanRoutedSubnet[] | undefined>;
    /**
     * Identifier
     */
    readonly siteId: pulumi.Output<string>;
    /**
     * If the site is not configured in high availability mode, this configuration is optional (if omitted, use DHCP). However, if in high availability mode, static*address is required along with secondary and virtual address.
     */
    readonly staticAddressing: pulumi.Output<outputs.MagicTransitSiteLanStaticAddressing | undefined>;
    /**
     * VLAN ID. Use zero for untagged.
     */
    readonly vlanTag: pulumi.Output<number | undefined>;
    /**
     * Create a MagicTransitSiteLan resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MagicTransitSiteLanArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering MagicTransitSiteLan resources.
 */
export interface MagicTransitSiteLanState {
    /**
     * Identifier
     */
    accountId?: pulumi.Input<string>;
    /**
     * mark true to use this LAN for HA probing. only works for site with HA turned on. only one LAN can be set as the ha_link.
     */
    haLink?: pulumi.Input<boolean>;
    name?: pulumi.Input<string>;
    nat?: pulumi.Input<inputs.MagicTransitSiteLanNat>;
    physport?: pulumi.Input<number>;
    routedSubnets?: pulumi.Input<pulumi.Input<inputs.MagicTransitSiteLanRoutedSubnet>[]>;
    /**
     * Identifier
     */
    siteId?: pulumi.Input<string>;
    /**
     * If the site is not configured in high availability mode, this configuration is optional (if omitted, use DHCP). However, if in high availability mode, static*address is required along with secondary and virtual address.
     */
    staticAddressing?: pulumi.Input<inputs.MagicTransitSiteLanStaticAddressing>;
    /**
     * VLAN ID. Use zero for untagged.
     */
    vlanTag?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a MagicTransitSiteLan resource.
 */
export interface MagicTransitSiteLanArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * mark true to use this LAN for HA probing. only works for site with HA turned on. only one LAN can be set as the ha_link.
     */
    haLink?: pulumi.Input<boolean>;
    name?: pulumi.Input<string>;
    nat?: pulumi.Input<inputs.MagicTransitSiteLanNat>;
    physport: pulumi.Input<number>;
    routedSubnets?: pulumi.Input<pulumi.Input<inputs.MagicTransitSiteLanRoutedSubnet>[]>;
    /**
     * Identifier
     */
    siteId: pulumi.Input<string>;
    /**
     * If the site is not configured in high availability mode, this configuration is optional (if omitted, use DHCP). However, if in high availability mode, static*address is required along with secondary and virtual address.
     */
    staticAddressing?: pulumi.Input<inputs.MagicTransitSiteLanStaticAddressing>;
    /**
     * VLAN ID. Use zero for untagged.
     */
    vlanTag?: pulumi.Input<number>;
}
