import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/magicWanStaticRoute:MagicWanStaticRoute example '<account_id>/<route_id>'
 * ```
 */
export declare class MagicWanStaticRoute extends pulumi.CustomResource {
    /**
     * Get an existing MagicWanStaticRoute resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: MagicWanStaticRouteState, opts?: pulumi.CustomResourceOptions): MagicWanStaticRoute;
    /**
     * Returns true if the given object is an instance of MagicWanStaticRoute.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MagicWanStaticRoute;
    /**
     * Identifier
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * When the route was created.
     */
    readonly createdOn: pulumi.Output<string>;
    /**
     * An optional human provided description of the static route.
     */
    readonly description: pulumi.Output<string | undefined>;
    readonly modified: pulumi.Output<boolean>;
    /**
     * When the route was last modified.
     */
    readonly modifiedOn: pulumi.Output<string>;
    readonly modifiedRoute: pulumi.Output<outputs.MagicWanStaticRouteModifiedRoute>;
    /**
     * The next-hop IP Address for the static route.
     */
    readonly nexthop: pulumi.Output<string>;
    /**
     * IP Prefix in Classless Inter-Domain Routing format.
     */
    readonly prefix: pulumi.Output<string>;
    /**
     * Priority of the static route.
     */
    readonly priority: pulumi.Output<number>;
    readonly route: pulumi.Output<outputs.MagicWanStaticRouteRoute>;
    /**
     * Used only for ECMP routes.
     */
    readonly scope: pulumi.Output<outputs.MagicWanStaticRouteScope | undefined>;
    /**
     * Optional weight of the ECMP scope - if provided.
     */
    readonly weight: pulumi.Output<number | undefined>;
    /**
     * Create a MagicWanStaticRoute resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MagicWanStaticRouteArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering MagicWanStaticRoute resources.
 */
export interface MagicWanStaticRouteState {
    /**
     * Identifier
     */
    accountId?: pulumi.Input<string>;
    /**
     * When the route was created.
     */
    createdOn?: pulumi.Input<string>;
    /**
     * An optional human provided description of the static route.
     */
    description?: pulumi.Input<string>;
    modified?: pulumi.Input<boolean>;
    /**
     * When the route was last modified.
     */
    modifiedOn?: pulumi.Input<string>;
    modifiedRoute?: pulumi.Input<inputs.MagicWanStaticRouteModifiedRoute>;
    /**
     * The next-hop IP Address for the static route.
     */
    nexthop?: pulumi.Input<string>;
    /**
     * IP Prefix in Classless Inter-Domain Routing format.
     */
    prefix?: pulumi.Input<string>;
    /**
     * Priority of the static route.
     */
    priority?: pulumi.Input<number>;
    route?: pulumi.Input<inputs.MagicWanStaticRouteRoute>;
    /**
     * Used only for ECMP routes.
     */
    scope?: pulumi.Input<inputs.MagicWanStaticRouteScope>;
    /**
     * Optional weight of the ECMP scope - if provided.
     */
    weight?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a MagicWanStaticRoute resource.
 */
export interface MagicWanStaticRouteArgs {
    /**
     * Identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * An optional human provided description of the static route.
     */
    description?: pulumi.Input<string>;
    /**
     * The next-hop IP Address for the static route.
     */
    nexthop: pulumi.Input<string>;
    /**
     * IP Prefix in Classless Inter-Domain Routing format.
     */
    prefix: pulumi.Input<string>;
    /**
     * Priority of the static route.
     */
    priority: pulumi.Input<number>;
    route?: pulumi.Input<inputs.MagicWanStaticRouteRoute>;
    /**
     * Used only for ECMP routes.
     */
    scope?: pulumi.Input<inputs.MagicWanStaticRouteScope>;
    /**
     * Optional weight of the ECMP scope - if provided.
     */
    weight?: pulumi.Input<number>;
}
