import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleOriginCaCertificate = new cloudflare.OriginCaCertificate("example_origin_ca_certificate", {
 *     csr: `  -----BEGIN CERTIFICATE REQUEST-----
 *   MIICxzCCAa8CAQAwSDELMAkGA1UEBhMCVVMxFjAUBgNVBAgTDVNhbiBGcmFuY2lz
 *   Y28xCzAJBgNVBAcTAkNBMRQwEgYDVQQDEwtleGFtcGxlLm5ldDCCASIwDQYJKoZI
 *   hvcNAQEBBQADggEPADCCAQoCggEBALxejtu4b+jPdFeFi6OUsye8TYJQBm3WfCvL
 *   Hu5EvijMO/4Z2TImwASbwUF7Ir8OLgH+mGlQZeqyNvGoSOMEaZVXcYfpR1hlVak8
 *   4GGVr+04IGfOCqaBokaBFIwzclGZbzKmLGwIQioNxGfqFm6RGYGA3be2Je2iseBc
 *   N8GV1wYmvYE0RR+yWweJCTJ157exyRzu7sVxaEW9F87zBQLyOnwXc64rflXslRqi
 *   g7F7w5IaQYOl8yvmk/jEPCAha7fkiUfEpj4N12+oPRiMvleJF98chxjD4MH39c5I
 *   uOslULhrWunfh7GB1jwWNA9y44H0snrf+xvoy2TcHmxvma9Eln8CAwEAAaA6MDgG
 *   CSqGSIb3DQEJDjErMCkwJwYDVR0RBCAwHoILZXhhbXBsZS5uZXSCD3d3dy5leGFt
 *   cGxlLm5ldDANBgkqhkiG9w0BAQsFAAOCAQEAcBaX6dOnI8ncARrI9ZSF2AJX+8mx
 *   pTHY2+Y2C0VvrVDGMtbBRH8R9yMbqWtlxeeNGf//LeMkSKSFa4kbpdx226lfui8/
 *   auRDBTJGx2R1ccUxmLZXx4my0W5iIMxunu+kez+BDlu7bTT2io0uXMRHue4i6quH
 *   yc5ibxvbJMjR7dqbcanVE10/34oprzXQsJ/VmSuZNXtjbtSKDlmcpw6To/eeAJ+J
 *   hXykcUihvHyG4A1m2R6qpANBjnA0pHexfwM/SgfzvpbvUg0T1ubmer8BgTwCKIWs
 *   dcWYTthM51JIqRBfNqy4QcBnX+GY05yltEEswQI55wdiS3CjTTA67sdbcQ==
 *   -----END CERTIFICATE REQUEST-----
 * `,
 *     hostnames: [
 *         "example.com",
 *         "*.example.com",
 *     ],
 *     requestType: "origin-rsa",
 *     requestedValidity: 5475,
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/originCaCertificate:OriginCaCertificate example '<certificate_id>'
 * ```
 */
export declare class OriginCaCertificate extends pulumi.CustomResource {
    /**
     * Get an existing OriginCaCertificate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: OriginCaCertificateState, opts?: pulumi.CustomResourceOptions): OriginCaCertificate;
    /**
     * Returns true if the given object is an instance of OriginCaCertificate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is OriginCaCertificate;
    /**
     * The Origin CA certificate. Will be newline-encoded.
     */
    readonly certificate: pulumi.Output<string>;
    /**
     * The Certificate Signing Request (CSR). Must be newline-encoded.
     */
    readonly csr: pulumi.Output<string | undefined>;
    /**
     * When the certificate will expire.
     */
    readonly expiresOn: pulumi.Output<string>;
    /**
     * Array of hostnames or wildcard names (e.g., *.example.com) bound to the certificate.
     */
    readonly hostnames: pulumi.Output<string[] | undefined>;
    /**
     * Signature type desired on certificate ("origin-rsa" (rsa), "origin-ecc" (ecdsa), or "keyless-certificate" (for Keyless SSL servers).
     * Available values: "origin-rsa", "origin-ecc", "keyless-certificate".
     */
    readonly requestType: pulumi.Output<string | undefined>;
    /**
     * The number of days for which the certificate should be valid.
     * Available values: 7, 30, 90, 365, 730, 1095, 5475.
     */
    readonly requestedValidity: pulumi.Output<number>;
    /**
     * Create a OriginCaCertificate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: OriginCaCertificateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering OriginCaCertificate resources.
 */
export interface OriginCaCertificateState {
    /**
     * The Origin CA certificate. Will be newline-encoded.
     */
    certificate?: pulumi.Input<string>;
    /**
     * The Certificate Signing Request (CSR). Must be newline-encoded.
     */
    csr?: pulumi.Input<string>;
    /**
     * When the certificate will expire.
     */
    expiresOn?: pulumi.Input<string>;
    /**
     * Array of hostnames or wildcard names (e.g., *.example.com) bound to the certificate.
     */
    hostnames?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Signature type desired on certificate ("origin-rsa" (rsa), "origin-ecc" (ecdsa), or "keyless-certificate" (for Keyless SSL servers).
     * Available values: "origin-rsa", "origin-ecc", "keyless-certificate".
     */
    requestType?: pulumi.Input<string>;
    /**
     * The number of days for which the certificate should be valid.
     * Available values: 7, 30, 90, 365, 730, 1095, 5475.
     */
    requestedValidity?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a OriginCaCertificate resource.
 */
export interface OriginCaCertificateArgs {
    /**
     * The Certificate Signing Request (CSR). Must be newline-encoded.
     */
    csr?: pulumi.Input<string>;
    /**
     * Array of hostnames or wildcard names (e.g., *.example.com) bound to the certificate.
     */
    hostnames?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Signature type desired on certificate ("origin-rsa" (rsa), "origin-ecc" (ecdsa), or "keyless-certificate" (for Keyless SSL servers).
     * Available values: "origin-rsa", "origin-ecc", "keyless-certificate".
     */
    requestType?: pulumi.Input<string>;
    /**
     * The number of days for which the certificate should be valid.
     * Available values: 7, 30, 90, 365, 730, 1095, 5475.
     */
    requestedValidity?: pulumi.Input<number>;
}
