import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleQueue = new cloudflare.Queue("example_queue", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     queueName: "example-queue",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/queue:Queue example '<account_id>/<queue_id>'
 * ```
 */
export declare class Queue extends pulumi.CustomResource {
    /**
     * Get an existing Queue resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: QueueState, opts?: pulumi.CustomResourceOptions): Queue;
    /**
     * Returns true if the given object is an instance of Queue.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Queue;
    /**
     * A Resource identifier.
     */
    readonly accountId: pulumi.Output<string>;
    readonly consumers: pulumi.Output<outputs.QueueConsumer[]>;
    readonly consumersTotalCount: pulumi.Output<number>;
    readonly createdOn: pulumi.Output<string>;
    readonly modifiedOn: pulumi.Output<string>;
    readonly producers: pulumi.Output<outputs.QueueProducer[]>;
    readonly producersTotalCount: pulumi.Output<number>;
    readonly queueId: pulumi.Output<string>;
    readonly queueName: pulumi.Output<string>;
    readonly settings: pulumi.Output<outputs.QueueSettings>;
    /**
     * Create a Queue resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: QueueArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Queue resources.
 */
export interface QueueState {
    /**
     * A Resource identifier.
     */
    accountId?: pulumi.Input<string>;
    consumers?: pulumi.Input<pulumi.Input<inputs.QueueConsumer>[]>;
    consumersTotalCount?: pulumi.Input<number>;
    createdOn?: pulumi.Input<string>;
    modifiedOn?: pulumi.Input<string>;
    producers?: pulumi.Input<pulumi.Input<inputs.QueueProducer>[]>;
    producersTotalCount?: pulumi.Input<number>;
    queueId?: pulumi.Input<string>;
    queueName?: pulumi.Input<string>;
    settings?: pulumi.Input<inputs.QueueSettings>;
}
/**
 * The set of arguments for constructing a Queue resource.
 */
export interface QueueArgs {
    /**
     * A Resource identifier.
     */
    accountId: pulumi.Input<string>;
    queueName: pulumi.Input<string>;
    settings?: pulumi.Input<inputs.QueueSettings>;
}
