import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2BucketEventNotification = new cloudflare.R2BucketEventNotification("example_r2_bucket_event_notification", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 *     queueId: "queue_id",
 *     rules: [{
 *         actions: [
 *             "PutObject",
 *             "CopyObject",
 *         ],
 *         description: "Notifications from source bucket to queue",
 *         prefix: "img/",
 *         suffix: ".jpeg",
 *     }],
 * });
 * ```
 */
export declare class R2BucketEventNotification extends pulumi.CustomResource {
    /**
     * Get an existing R2BucketEventNotification resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: R2BucketEventNotificationState, opts?: pulumi.CustomResourceOptions): R2BucketEventNotification;
    /**
     * Returns true if the given object is an instance of R2BucketEventNotification.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is R2BucketEventNotification;
    /**
     * Account ID.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Name of the bucket.
     */
    readonly bucketName: pulumi.Output<string>;
    /**
     * Jurisdiction of the bucket
     */
    readonly jurisdiction: pulumi.Output<string>;
    /**
     * Queue ID.
     */
    readonly queueId: pulumi.Output<string | undefined>;
    /**
     * List of queues associated with the bucket.
     */
    readonly queues: pulumi.Output<outputs.R2BucketEventNotificationQueue[]>;
    /**
     * Array of rules to drive notifications.
     */
    readonly rules: pulumi.Output<outputs.R2BucketEventNotificationRule[] | undefined>;
    /**
     * Create a R2BucketEventNotification resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: R2BucketEventNotificationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering R2BucketEventNotification resources.
 */
export interface R2BucketEventNotificationState {
    /**
     * Account ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName?: pulumi.Input<string>;
    /**
     * Jurisdiction of the bucket
     */
    jurisdiction?: pulumi.Input<string>;
    /**
     * Queue ID.
     */
    queueId?: pulumi.Input<string>;
    /**
     * List of queues associated with the bucket.
     */
    queues?: pulumi.Input<pulumi.Input<inputs.R2BucketEventNotificationQueue>[]>;
    /**
     * Array of rules to drive notifications.
     */
    rules?: pulumi.Input<pulumi.Input<inputs.R2BucketEventNotificationRule>[]>;
}
/**
 * The set of arguments for constructing a R2BucketEventNotification resource.
 */
export interface R2BucketEventNotificationArgs {
    /**
     * Account ID.
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName: pulumi.Input<string>;
    /**
     * Jurisdiction of the bucket
     */
    jurisdiction?: pulumi.Input<string>;
    /**
     * Queue ID.
     */
    queueId?: pulumi.Input<string>;
    /**
     * Array of rules to drive notifications.
     */
    rules?: pulumi.Input<pulumi.Input<inputs.R2BucketEventNotificationRule>[]>;
}
