import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleR2BucketLock = new cloudflare.R2BucketLock("example_r2_bucket_lock", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     bucketName: "example-bucket",
 *     rules: [{
 *         id: "Lock all objects for 24 hours",
 *         condition: {
 *             maxAgeSeconds: 100,
 *             type: "Age",
 *         },
 *         enabled: true,
 *         prefix: "prefix",
 *     }],
 * });
 * ```
 */
export declare class R2BucketLock extends pulumi.CustomResource {
    /**
     * Get an existing R2BucketLock resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: R2BucketLockState, opts?: pulumi.CustomResourceOptions): R2BucketLock;
    /**
     * Returns true if the given object is an instance of R2BucketLock.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is R2BucketLock;
    /**
     * Account ID.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Name of the bucket.
     */
    readonly bucketName: pulumi.Output<string>;
    /**
     * Jurisdiction of the bucket
     */
    readonly jurisdiction: pulumi.Output<string>;
    readonly rules: pulumi.Output<outputs.R2BucketLockRule[] | undefined>;
    /**
     * Create a R2BucketLock resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: R2BucketLockArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering R2BucketLock resources.
 */
export interface R2BucketLockState {
    /**
     * Account ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName?: pulumi.Input<string>;
    /**
     * Jurisdiction of the bucket
     */
    jurisdiction?: pulumi.Input<string>;
    rules?: pulumi.Input<pulumi.Input<inputs.R2BucketLockRule>[]>;
}
/**
 * The set of arguments for constructing a R2BucketLock resource.
 */
export interface R2BucketLockArgs {
    /**
     * Account ID.
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName: pulumi.Input<string>;
    /**
     * Jurisdiction of the bucket
     */
    jurisdiction?: pulumi.Input<string>;
    rules?: pulumi.Input<pulumi.Input<inputs.R2BucketLockRule>[]>;
}
