import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 */
export declare class R2BucketSippy extends pulumi.CustomResource {
    /**
     * Get an existing R2BucketSippy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: R2BucketSippyState, opts?: pulumi.CustomResourceOptions): R2BucketSippy;
    /**
     * Returns true if the given object is an instance of R2BucketSippy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is R2BucketSippy;
    /**
     * Account ID.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Name of the bucket.
     */
    readonly bucketName: pulumi.Output<string>;
    /**
     * R2 bucket to copy objects to.
     */
    readonly destination: pulumi.Output<outputs.R2BucketSippyDestination | undefined>;
    /**
     * State of Sippy for this bucket.
     */
    readonly enabled: pulumi.Output<boolean>;
    /**
     * Jurisdiction of the bucket
     */
    readonly jurisdiction: pulumi.Output<string>;
    /**
     * AWS S3 bucket to copy objects from.
     */
    readonly source: pulumi.Output<outputs.R2BucketSippySource | undefined>;
    /**
     * Create a R2BucketSippy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: R2BucketSippyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering R2BucketSippy resources.
 */
export interface R2BucketSippyState {
    /**
     * Account ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName?: pulumi.Input<string>;
    /**
     * R2 bucket to copy objects to.
     */
    destination?: pulumi.Input<inputs.R2BucketSippyDestination>;
    /**
     * State of Sippy for this bucket.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * Jurisdiction of the bucket
     */
    jurisdiction?: pulumi.Input<string>;
    /**
     * AWS S3 bucket to copy objects from.
     */
    source?: pulumi.Input<inputs.R2BucketSippySource>;
}
/**
 * The set of arguments for constructing a R2BucketSippy resource.
 */
export interface R2BucketSippyArgs {
    /**
     * Account ID.
     */
    accountId: pulumi.Input<string>;
    /**
     * Name of the bucket.
     */
    bucketName: pulumi.Input<string>;
    /**
     * R2 bucket to copy objects to.
     */
    destination?: pulumi.Input<inputs.R2BucketSippyDestination>;
    /**
     * Jurisdiction of the bucket
     */
    jurisdiction?: pulumi.Input<string>;
    /**
     * AWS S3 bucket to copy objects from.
     */
    source?: pulumi.Input<inputs.R2BucketSippySource>;
}
