import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/record:Record example '<zone_id>/<dns_record_id>'
 * ```
 *
 * @deprecated cloudflare.index/record.Record has been deprecated in favor of cloudflare.index/dnsrecord.DnsRecord
 */
export declare class Record extends pulumi.CustomResource {
    /**
     * Get an existing Record resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RecordState, opts?: pulumi.CustomResourceOptions): Record;
    /**
     * Returns true if the given object is an instance of Record.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Record;
    /**
     * Comments or notes about the DNS record. This field has no effect on DNS responses.
     */
    readonly comment: pulumi.Output<string>;
    /**
     * When the record comment was last modified. Omitted if there is no comment.
     */
    readonly commentModifiedOn: pulumi.Output<string>;
    /**
     * A valid IPv4 address.
     */
    readonly content: pulumi.Output<string>;
    /**
     * When the record was created.
     */
    readonly createdOn: pulumi.Output<string>;
    /**
     * Components of a CAA record.
     */
    readonly data: pulumi.Output<outputs.RecordData | undefined>;
    /**
     * Extra Cloudflare-specific information about the record.
     */
    readonly meta: pulumi.Output<string>;
    /**
     * When the record was last modified.
     */
    readonly modifiedOn: pulumi.Output<string>;
    /**
     * DNS record name (or @ for the zone apex) in Punycode.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Required for MX, SRV and URI records; unused by other record types. Records with lower priorities are preferred.
     */
    readonly priority: pulumi.Output<number | undefined>;
    /**
     * Whether the record can be proxied by Cloudflare or not.
     */
    readonly proxiable: pulumi.Output<boolean>;
    /**
     * Whether the record is receiving the performance and security benefits of Cloudflare.
     */
    readonly proxied: pulumi.Output<boolean>;
    /**
     * Settings for the DNS record.
     */
    readonly settings: pulumi.Output<outputs.RecordSettings>;
    /**
     * Custom tags for the DNS record. This field has no effect on DNS responses.
     */
    readonly tags: pulumi.Output<string[]>;
    /**
     * When the record tags were last modified. Omitted if there are no tags.
     */
    readonly tagsModifiedOn: pulumi.Output<string>;
    /**
     * Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'. Value must be between 60 and 86400, with the minimum reduced to 30 for Enterprise zones.
     */
    readonly ttl: pulumi.Output<number>;
    /**
     * Record type.
     * Available values: "A", "AAAA", "CAA", "CERT", "CNAME", "DNSKEY", "DS", "HTTPS", "LOC", "MX", "NAPTR", "NS", "OPENPGPKEY", "PTR", "SMIMEA", "SRV", "SSHFP", "SVCB", "TLSA", "TXT", "URI".
     */
    readonly type: pulumi.Output<string>;
    /**
     * Identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a Record resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    /** @deprecated cloudflare.index/record.Record has been deprecated in favor of cloudflare.index/dnsrecord.DnsRecord */
    constructor(name: string, args: RecordArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Record resources.
 */
export interface RecordState {
    /**
     * Comments or notes about the DNS record. This field has no effect on DNS responses.
     */
    comment?: pulumi.Input<string>;
    /**
     * When the record comment was last modified. Omitted if there is no comment.
     */
    commentModifiedOn?: pulumi.Input<string>;
    /**
     * A valid IPv4 address.
     */
    content?: pulumi.Input<string>;
    /**
     * When the record was created.
     */
    createdOn?: pulumi.Input<string>;
    /**
     * Components of a CAA record.
     */
    data?: pulumi.Input<inputs.RecordData>;
    /**
     * Extra Cloudflare-specific information about the record.
     */
    meta?: pulumi.Input<string>;
    /**
     * When the record was last modified.
     */
    modifiedOn?: pulumi.Input<string>;
    /**
     * DNS record name (or @ for the zone apex) in Punycode.
     */
    name?: pulumi.Input<string>;
    /**
     * Required for MX, SRV and URI records; unused by other record types. Records with lower priorities are preferred.
     */
    priority?: pulumi.Input<number>;
    /**
     * Whether the record can be proxied by Cloudflare or not.
     */
    proxiable?: pulumi.Input<boolean>;
    /**
     * Whether the record is receiving the performance and security benefits of Cloudflare.
     */
    proxied?: pulumi.Input<boolean>;
    /**
     * Settings for the DNS record.
     */
    settings?: pulumi.Input<inputs.RecordSettings>;
    /**
     * Custom tags for the DNS record. This field has no effect on DNS responses.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * When the record tags were last modified. Omitted if there are no tags.
     */
    tagsModifiedOn?: pulumi.Input<string>;
    /**
     * Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'. Value must be between 60 and 86400, with the minimum reduced to 30 for Enterprise zones.
     */
    ttl?: pulumi.Input<number>;
    /**
     * Record type.
     * Available values: "A", "AAAA", "CAA", "CERT", "CNAME", "DNSKEY", "DS", "HTTPS", "LOC", "MX", "NAPTR", "NS", "OPENPGPKEY", "PTR", "SMIMEA", "SRV", "SSHFP", "SVCB", "TLSA", "TXT", "URI".
     */
    type?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Record resource.
 */
export interface RecordArgs {
    /**
     * Comments or notes about the DNS record. This field has no effect on DNS responses.
     */
    comment?: pulumi.Input<string>;
    /**
     * A valid IPv4 address.
     */
    content?: pulumi.Input<string>;
    /**
     * Components of a CAA record.
     */
    data?: pulumi.Input<inputs.RecordData>;
    /**
     * DNS record name (or @ for the zone apex) in Punycode.
     */
    name: pulumi.Input<string>;
    /**
     * Required for MX, SRV and URI records; unused by other record types. Records with lower priorities are preferred.
     */
    priority?: pulumi.Input<number>;
    /**
     * Whether the record is receiving the performance and security benefits of Cloudflare.
     */
    proxied?: pulumi.Input<boolean>;
    /**
     * Settings for the DNS record.
     */
    settings?: pulumi.Input<inputs.RecordSettings>;
    /**
     * Custom tags for the DNS record. This field has no effect on DNS responses.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'. Value must be between 60 and 86400, with the minimum reduced to 30 for Enterprise zones.
     */
    ttl: pulumi.Input<number>;
    /**
     * Record type.
     * Available values: "A", "AAAA", "CAA", "CERT", "CNAME", "DNSKEY", "DS", "HTTPS", "LOC", "MX", "NAPTR", "NS", "OPENPGPKEY", "PTR", "SMIMEA", "SRV", "SSHFP", "SVCB", "TLSA", "TXT", "URI".
     */
    type: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
