import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleRegionalTieredCache = new cloudflare.RegionalTieredCache("example_regional_tiered_cache", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     value: "on",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/regionalTieredCache:RegionalTieredCache example '<zone_id>'
 * ```
 */
export declare class RegionalTieredCache extends pulumi.CustomResource {
    /**
     * Get an existing RegionalTieredCache resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RegionalTieredCacheState, opts?: pulumi.CustomResourceOptions): RegionalTieredCache;
    /**
     * Returns true if the given object is an instance of RegionalTieredCache.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RegionalTieredCache;
    /**
     * Whether the setting is editable
     */
    readonly editable: pulumi.Output<boolean>;
    /**
     * Last time this setting was modified.
     */
    readonly modifiedOn: pulumi.Output<string>;
    /**
     * Value of the Regional Tiered Cache zone setting.
     * Available values: "on", "off".
     */
    readonly value: pulumi.Output<string>;
    /**
     * Identifier
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a RegionalTieredCache resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RegionalTieredCacheArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering RegionalTieredCache resources.
 */
export interface RegionalTieredCacheState {
    /**
     * Whether the setting is editable
     */
    editable?: pulumi.Input<boolean>;
    /**
     * Last time this setting was modified.
     */
    modifiedOn?: pulumi.Input<string>;
    /**
     * Value of the Regional Tiered Cache zone setting.
     * Available values: "on", "off".
     */
    value?: pulumi.Input<string>;
    /**
     * Identifier
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a RegionalTieredCache resource.
 */
export interface RegionalTieredCacheArgs {
    /**
     * Value of the Regional Tiered Cache zone setting.
     * Available values: "on", "off".
     */
    value?: pulumi.Input<string>;
    /**
     * Identifier
     */
    zoneId: pulumi.Input<string>;
}
