import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustRiskBehavior = new cloudflare.ZeroTrustRiskBehavior("example_zero_trust_risk_behavior", {
 *     accountId: "account_id",
 *     behaviors: {
 *         foo: {
 *             enabled: true,
 *             riskLevel: "low",
 *         },
 *     },
 * });
 * ```
 *
 * @deprecated cloudflare.index/riskbehavior.RiskBehavior has been deprecated in favor of cloudflare.index/zerotrustriskbehavior.ZeroTrustRiskBehavior
 */
export declare class RiskBehavior extends pulumi.CustomResource {
    /**
     * Get an existing RiskBehavior resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RiskBehaviorState, opts?: pulumi.CustomResourceOptions): RiskBehavior;
    /**
     * Returns true if the given object is an instance of RiskBehavior.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RiskBehavior;
    readonly accountId: pulumi.Output<string>;
    readonly behaviors: pulumi.Output<{
        [key: string]: outputs.RiskBehaviorBehaviors;
    }>;
    /**
     * Create a RiskBehavior resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    /** @deprecated cloudflare.index/riskbehavior.RiskBehavior has been deprecated in favor of cloudflare.index/zerotrustriskbehavior.ZeroTrustRiskBehavior */
    constructor(name: string, args: RiskBehaviorArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering RiskBehavior resources.
 */
export interface RiskBehaviorState {
    accountId?: pulumi.Input<string>;
    behaviors?: pulumi.Input<{
        [key: string]: pulumi.Input<inputs.RiskBehaviorBehaviors>;
    }>;
}
/**
 * The set of arguments for constructing a RiskBehavior resource.
 */
export interface RiskBehaviorArgs {
    accountId: pulumi.Input<string>;
    behaviors: pulumi.Input<{
        [key: string]: pulumi.Input<inputs.RiskBehaviorBehaviors>;
    }>;
}
