import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleStream = new cloudflare.Stream("example_stream", {accountId: "023e105f4ecef8ad9ca31a8372d0c353"});
 * ```
 */
export declare class Stream extends pulumi.CustomResource {
    /**
     * Get an existing Stream resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: StreamState, opts?: pulumi.CustomResourceOptions): Stream;
    /**
     * Returns true if the given object is an instance of Stream.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Stream;
    /**
     * The account identifier tag.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Lists the origins allowed to display the video. Enter allowed origin domains in an array and use `*` for wildcard subdomains. Empty arrays allow the video to be viewed on any origin.
     */
    readonly allowedOrigins: pulumi.Output<string[] | undefined>;
    /**
     * The date and time the media item was created.
     */
    readonly created: pulumi.Output<string>;
    /**
     * A user-defined identifier for the media creator.
     */
    readonly creator: pulumi.Output<string | undefined>;
    /**
     * The duration of the video in seconds. A value of `-1` means the duration is unknown. The duration becomes available after the upload and before the video is ready.
     */
    readonly duration: pulumi.Output<number>;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    readonly identifier: pulumi.Output<string | undefined>;
    readonly input: pulumi.Output<outputs.StreamInput>;
    /**
     * The live input ID used to upload a video with Stream Live.
     */
    readonly liveInput: pulumi.Output<string>;
    /**
     * The maximum duration in seconds for a video upload. Can be set for a video that is not yet uploaded to limit its duration. Uploads that exceed the specified duration will fail during processing. A value of `-1` means the value is unknown.
     */
    readonly maxDurationSeconds: pulumi.Output<number | undefined>;
    /**
     * A user modifiable key-value store used to reference other systems of record for managing videos.
     */
    readonly meta: pulumi.Output<string | undefined>;
    /**
     * The date and time the media item was last modified.
     */
    readonly modified: pulumi.Output<string>;
    readonly playback: pulumi.Output<outputs.StreamPlayback>;
    /**
     * The video's preview page URI. This field is omitted until encoding is complete.
     */
    readonly preview: pulumi.Output<string>;
    /**
     * Indicates whether the video is playable. The field is empty if the video is not ready for viewing or the live stream is still in progress.
     */
    readonly readyToStream: pulumi.Output<boolean>;
    /**
     * Indicates the time at which the video became playable. The field is empty if the video is not ready for viewing or the live stream is still in progress.
     */
    readonly readyToStreamAt: pulumi.Output<string>;
    /**
     * Indicates whether the video can be a accessed using the UID. When set to `true`, a signed token must be generated with a signing key to view the video.
     */
    readonly requireSignedUrls: pulumi.Output<boolean>;
    /**
     * Indicates the date and time at which the video will be deleted. Omit the field to indicate no change, or include with a `null` value to remove an existing scheduled deletion. If specified, must be at least 30 days from upload time.
     */
    readonly scheduledDeletion: pulumi.Output<string | undefined>;
    /**
     * The size of the media item in bytes.
     */
    readonly size: pulumi.Output<number>;
    /**
     * Specifies a detailed status for a video. If the `state` is `inprogress` or `error`, the `step` field returns `encoding` or `manifest`. If the `state` is `inprogress`, `pctComplete` returns a number between 0 and 100 to indicate the approximate percent of completion. If the `state` is `error`, `errorReasonCode` and `errorReasonText` provide additional details.
     */
    readonly status: pulumi.Output<outputs.StreamStatus>;
    /**
     * The media item's thumbnail URI. This field is omitted until encoding is complete.
     */
    readonly thumbnail: pulumi.Output<string>;
    /**
     * The timestamp for a thumbnail image calculated as a percentage value of the video's duration. To convert from a second-wise timestamp to a percentage, divide the desired timestamp by the total duration of the video.  If this value is not set, the default thumbnail image is taken from 0s of the video.
     */
    readonly thumbnailTimestampPct: pulumi.Output<number>;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    readonly uid: pulumi.Output<string>;
    /**
     * The date and time when the video upload URL is no longer valid for direct user uploads.
     */
    readonly uploadExpiry: pulumi.Output<string | undefined>;
    /**
     * The date and time the media item was uploaded.
     */
    readonly uploaded: pulumi.Output<string>;
    readonly watermark: pulumi.Output<outputs.StreamWatermark>;
    /**
     * Create a Stream resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: StreamArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Stream resources.
 */
export interface StreamState {
    /**
     * The account identifier tag.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Lists the origins allowed to display the video. Enter allowed origin domains in an array and use `*` for wildcard subdomains. Empty arrays allow the video to be viewed on any origin.
     */
    allowedOrigins?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The date and time the media item was created.
     */
    created?: pulumi.Input<string>;
    /**
     * A user-defined identifier for the media creator.
     */
    creator?: pulumi.Input<string>;
    /**
     * The duration of the video in seconds. A value of `-1` means the duration is unknown. The duration becomes available after the upload and before the video is ready.
     */
    duration?: pulumi.Input<number>;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    identifier?: pulumi.Input<string>;
    input?: pulumi.Input<inputs.StreamInput>;
    /**
     * The live input ID used to upload a video with Stream Live.
     */
    liveInput?: pulumi.Input<string>;
    /**
     * The maximum duration in seconds for a video upload. Can be set for a video that is not yet uploaded to limit its duration. Uploads that exceed the specified duration will fail during processing. A value of `-1` means the value is unknown.
     */
    maxDurationSeconds?: pulumi.Input<number>;
    /**
     * A user modifiable key-value store used to reference other systems of record for managing videos.
     */
    meta?: pulumi.Input<string>;
    /**
     * The date and time the media item was last modified.
     */
    modified?: pulumi.Input<string>;
    playback?: pulumi.Input<inputs.StreamPlayback>;
    /**
     * The video's preview page URI. This field is omitted until encoding is complete.
     */
    preview?: pulumi.Input<string>;
    /**
     * Indicates whether the video is playable. The field is empty if the video is not ready for viewing or the live stream is still in progress.
     */
    readyToStream?: pulumi.Input<boolean>;
    /**
     * Indicates the time at which the video became playable. The field is empty if the video is not ready for viewing or the live stream is still in progress.
     */
    readyToStreamAt?: pulumi.Input<string>;
    /**
     * Indicates whether the video can be a accessed using the UID. When set to `true`, a signed token must be generated with a signing key to view the video.
     */
    requireSignedUrls?: pulumi.Input<boolean>;
    /**
     * Indicates the date and time at which the video will be deleted. Omit the field to indicate no change, or include with a `null` value to remove an existing scheduled deletion. If specified, must be at least 30 days from upload time.
     */
    scheduledDeletion?: pulumi.Input<string>;
    /**
     * The size of the media item in bytes.
     */
    size?: pulumi.Input<number>;
    /**
     * Specifies a detailed status for a video. If the `state` is `inprogress` or `error`, the `step` field returns `encoding` or `manifest`. If the `state` is `inprogress`, `pctComplete` returns a number between 0 and 100 to indicate the approximate percent of completion. If the `state` is `error`, `errorReasonCode` and `errorReasonText` provide additional details.
     */
    status?: pulumi.Input<inputs.StreamStatus>;
    /**
     * The media item's thumbnail URI. This field is omitted until encoding is complete.
     */
    thumbnail?: pulumi.Input<string>;
    /**
     * The timestamp for a thumbnail image calculated as a percentage value of the video's duration. To convert from a second-wise timestamp to a percentage, divide the desired timestamp by the total duration of the video.  If this value is not set, the default thumbnail image is taken from 0s of the video.
     */
    thumbnailTimestampPct?: pulumi.Input<number>;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    uid?: pulumi.Input<string>;
    /**
     * The date and time when the video upload URL is no longer valid for direct user uploads.
     */
    uploadExpiry?: pulumi.Input<string>;
    /**
     * The date and time the media item was uploaded.
     */
    uploaded?: pulumi.Input<string>;
    watermark?: pulumi.Input<inputs.StreamWatermark>;
}
/**
 * The set of arguments for constructing a Stream resource.
 */
export interface StreamArgs {
    /**
     * The account identifier tag.
     */
    accountId: pulumi.Input<string>;
    /**
     * Lists the origins allowed to display the video. Enter allowed origin domains in an array and use `*` for wildcard subdomains. Empty arrays allow the video to be viewed on any origin.
     */
    allowedOrigins?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A user-defined identifier for the media creator.
     */
    creator?: pulumi.Input<string>;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    identifier?: pulumi.Input<string>;
    /**
     * The maximum duration in seconds for a video upload. Can be set for a video that is not yet uploaded to limit its duration. Uploads that exceed the specified duration will fail during processing. A value of `-1` means the value is unknown.
     */
    maxDurationSeconds?: pulumi.Input<number>;
    /**
     * A user modifiable key-value store used to reference other systems of record for managing videos.
     */
    meta?: pulumi.Input<string>;
    /**
     * Indicates whether the video can be a accessed using the UID. When set to `true`, a signed token must be generated with a signing key to view the video.
     */
    requireSignedUrls?: pulumi.Input<boolean>;
    /**
     * Indicates the date and time at which the video will be deleted. Omit the field to indicate no change, or include with a `null` value to remove an existing scheduled deletion. If specified, must be at least 30 days from upload time.
     */
    scheduledDeletion?: pulumi.Input<string>;
    /**
     * The timestamp for a thumbnail image calculated as a percentage value of the video's duration. To convert from a second-wise timestamp to a percentage, divide the desired timestamp by the total duration of the video.  If this value is not set, the default thumbnail image is taken from 0s of the video.
     */
    thumbnailTimestampPct?: pulumi.Input<number>;
    /**
     * The date and time when the video upload URL is no longer valid for direct user uploads.
     */
    uploadExpiry?: pulumi.Input<string>;
}
