import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleStreamDownload = new cloudflare.StreamDownload("example_stream_download", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     identifier: "ea95132c15732412d22c1476fa83f27a",
 * });
 * ```
 */
export declare class StreamDownload extends pulumi.CustomResource {
    /**
     * Get an existing StreamDownload resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: StreamDownloadState, opts?: pulumi.CustomResourceOptions): StreamDownload;
    /**
     * Returns true if the given object is an instance of StreamDownload.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is StreamDownload;
    /**
     * Identifier.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    readonly identifier: pulumi.Output<string>;
    /**
     * Create a StreamDownload resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: StreamDownloadArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering StreamDownload resources.
 */
export interface StreamDownloadState {
    /**
     * Identifier.
     */
    accountId?: pulumi.Input<string>;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    identifier?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a StreamDownload resource.
 */
export interface StreamDownloadArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * A Cloudflare-generated unique identifier for a media item.
     */
    identifier: pulumi.Input<string>;
}
