import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustTunnelCloudflaredRoute = new cloudflare.ZeroTrustTunnelCloudflaredRoute("example_zero_trust_tunnel_cloudflared_route", {
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     network: "172.16.0.0/16",
 *     tunnelId: "f70ff985-a4ef-4643-bbbc-4a0ed4fc8415",
 *     comment: "Example comment for this route.",
 *     virtualNetworkId: "f70ff985-a4ef-4643-bbbc-4a0ed4fc8415",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/tunnelRoute:TunnelRoute example '<account_id>/<route_id>'
 * ```
 *
 * @deprecated cloudflare.index/tunnelroute.TunnelRoute has been deprecated in favor of cloudflare.index/zerotrusttunnelcloudflaredroute.ZeroTrustTunnelCloudflaredRoute
 */
export declare class TunnelRoute extends pulumi.CustomResource {
    /**
     * Get an existing TunnelRoute resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: TunnelRouteState, opts?: pulumi.CustomResourceOptions): TunnelRoute;
    /**
     * Returns true if the given object is an instance of TunnelRoute.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TunnelRoute;
    /**
     * Cloudflare account ID
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Optional remark describing the route.
     */
    readonly comment: pulumi.Output<string | undefined>;
    /**
     * Timestamp of when the resource was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * Timestamp of when the resource was deleted. If `null`, the resource has not been deleted.
     */
    readonly deletedAt: pulumi.Output<string>;
    /**
     * The private IPv4 or IPv6 range connected by the route, in CIDR notation.
     */
    readonly network: pulumi.Output<string>;
    /**
     * UUID of the tunnel.
     */
    readonly tunnelId: pulumi.Output<string>;
    /**
     * UUID of the virtual network.
     */
    readonly virtualNetworkId: pulumi.Output<string>;
    /**
     * Create a TunnelRoute resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    /** @deprecated cloudflare.index/tunnelroute.TunnelRoute has been deprecated in favor of cloudflare.index/zerotrusttunnelcloudflaredroute.ZeroTrustTunnelCloudflaredRoute */
    constructor(name: string, args: TunnelRouteArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering TunnelRoute resources.
 */
export interface TunnelRouteState {
    /**
     * Cloudflare account ID
     */
    accountId?: pulumi.Input<string>;
    /**
     * Optional remark describing the route.
     */
    comment?: pulumi.Input<string>;
    /**
     * Timestamp of when the resource was created.
     */
    createdAt?: pulumi.Input<string>;
    /**
     * Timestamp of when the resource was deleted. If `null`, the resource has not been deleted.
     */
    deletedAt?: pulumi.Input<string>;
    /**
     * The private IPv4 or IPv6 range connected by the route, in CIDR notation.
     */
    network?: pulumi.Input<string>;
    /**
     * UUID of the tunnel.
     */
    tunnelId?: pulumi.Input<string>;
    /**
     * UUID of the virtual network.
     */
    virtualNetworkId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a TunnelRoute resource.
 */
export interface TunnelRouteArgs {
    /**
     * Cloudflare account ID
     */
    accountId: pulumi.Input<string>;
    /**
     * Optional remark describing the route.
     */
    comment?: pulumi.Input<string>;
    /**
     * The private IPv4 or IPv6 range connected by the route, in CIDR notation.
     */
    network: pulumi.Input<string>;
    /**
     * UUID of the tunnel.
     */
    tunnelId: pulumi.Input<string>;
    /**
     * UUID of the virtual network.
     */
    virtualNetworkId?: pulumi.Input<string>;
}
