import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleUrlNormalizationSettings = new cloudflare.UrlNormalizationSettings("example_url_normalization_settings", {
 *     zoneId: "9f1839b6152d298aca64c4e906b6d074",
 *     scope: "incoming",
 *     type: "cloudflare",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/urlNormalizationSettings:UrlNormalizationSettings example '<zone_id>'
 * ```
 */
export declare class UrlNormalizationSettings extends pulumi.CustomResource {
    /**
     * Get an existing UrlNormalizationSettings resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: UrlNormalizationSettingsState, opts?: pulumi.CustomResourceOptions): UrlNormalizationSettings;
    /**
     * Returns true if the given object is an instance of UrlNormalizationSettings.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UrlNormalizationSettings;
    /**
     * The scope of the URL normalization.
     * Available values: "incoming", "both".
     */
    readonly scope: pulumi.Output<string>;
    /**
     * The type of URL normalization performed by Cloudflare.
     * Available values: "cloudflare", "rfc3986".
     */
    readonly type: pulumi.Output<string>;
    /**
     * The unique ID of the zone.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a UrlNormalizationSettings resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: UrlNormalizationSettingsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering UrlNormalizationSettings resources.
 */
export interface UrlNormalizationSettingsState {
    /**
     * The scope of the URL normalization.
     * Available values: "incoming", "both".
     */
    scope?: pulumi.Input<string>;
    /**
     * The type of URL normalization performed by Cloudflare.
     * Available values: "cloudflare", "rfc3986".
     */
    type?: pulumi.Input<string>;
    /**
     * The unique ID of the zone.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a UrlNormalizationSettings resource.
 */
export interface UrlNormalizationSettingsArgs {
    /**
     * The scope of the URL normalization.
     * Available values: "incoming", "both".
     */
    scope: pulumi.Input<string>;
    /**
     * The type of URL normalization performed by Cloudflare.
     * Available values: "cloudflare", "rfc3986".
     */
    type: pulumi.Input<string>;
    /**
     * The unique ID of the zone.
     */
    zoneId: pulumi.Input<string>;
}
