import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleUser = new cloudflare.User("example_user", {
 *     country: "US",
 *     firstName: "John",
 *     lastName: "Appleseed",
 *     telephone: "+1 123-123-1234",
 *     zipcode: "12345",
 * });
 * ```
 */
export declare class User extends pulumi.CustomResource {
    /**
     * Get an existing User resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: UserState, opts?: pulumi.CustomResourceOptions): User;
    /**
     * Returns true if the given object is an instance of User.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is User;
    /**
     * The country in which the user lives.
     */
    readonly country: pulumi.Output<string | undefined>;
    /**
     * User's first name
     */
    readonly firstName: pulumi.Output<string | undefined>;
    /**
     * User's last name
     */
    readonly lastName: pulumi.Output<string | undefined>;
    /**
     * User's telephone number
     */
    readonly telephone: pulumi.Output<string | undefined>;
    /**
     * The zipcode or postal code where the user lives.
     */
    readonly zipcode: pulumi.Output<string | undefined>;
    /**
     * Create a User resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: UserArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering User resources.
 */
export interface UserState {
    /**
     * The country in which the user lives.
     */
    country?: pulumi.Input<string>;
    /**
     * User's first name
     */
    firstName?: pulumi.Input<string>;
    /**
     * User's last name
     */
    lastName?: pulumi.Input<string>;
    /**
     * User's telephone number
     */
    telephone?: pulumi.Input<string>;
    /**
     * The zipcode or postal code where the user lives.
     */
    zipcode?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a User resource.
 */
export interface UserArgs {
    /**
     * The country in which the user lives.
     */
    country?: pulumi.Input<string>;
    /**
     * User's first name
     */
    firstName?: pulumi.Input<string>;
    /**
     * User's last name
     */
    lastName?: pulumi.Input<string>;
    /**
     * User's telephone number
     */
    telephone?: pulumi.Input<string>;
    /**
     * The zipcode or postal code where the user lives.
     */
    zipcode?: pulumi.Input<string>;
}
