import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleUserAgentBlockingRule = new cloudflare.UserAgentBlockingRule("example_user_agent_blocking_rule", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     configuration: {
 *         target: "ip",
 *         value: "198.51.100.4",
 *     },
 *     mode: "challenge",
 * });
 * ```
 */
export declare class UserAgentBlockingRule extends pulumi.CustomResource {
    /**
     * Get an existing UserAgentBlockingRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: UserAgentBlockingRuleState, opts?: pulumi.CustomResourceOptions): UserAgentBlockingRule;
    /**
     * Returns true if the given object is an instance of UserAgentBlockingRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UserAgentBlockingRule;
    /**
     * The rule configuration.
     */
    readonly configuration: pulumi.Output<outputs.UserAgentBlockingRuleConfiguration>;
    /**
     * The action to apply to a matched request.
     * Available values: "block", "challenge", "whitelist", "js*challenge", "managed*challenge".
     */
    readonly mode: pulumi.Output<string>;
    /**
     * The unique identifier of the User Agent Blocking rule.
     */
    readonly uaRuleId: pulumi.Output<string | undefined>;
    /**
     * Defines an identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a UserAgentBlockingRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: UserAgentBlockingRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering UserAgentBlockingRule resources.
 */
export interface UserAgentBlockingRuleState {
    /**
     * The rule configuration.
     */
    configuration?: pulumi.Input<inputs.UserAgentBlockingRuleConfiguration>;
    /**
     * The action to apply to a matched request.
     * Available values: "block", "challenge", "whitelist", "js*challenge", "managed*challenge".
     */
    mode?: pulumi.Input<string>;
    /**
     * The unique identifier of the User Agent Blocking rule.
     */
    uaRuleId?: pulumi.Input<string>;
    /**
     * Defines an identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a UserAgentBlockingRule resource.
 */
export interface UserAgentBlockingRuleArgs {
    /**
     * The rule configuration.
     */
    configuration: pulumi.Input<inputs.UserAgentBlockingRuleConfiguration>;
    /**
     * The action to apply to a matched request.
     * Available values: "block", "challenge", "whitelist", "js*challenge", "managed*challenge".
     */
    mode: pulumi.Input<string>;
    /**
     * The unique identifier of the User Agent Blocking rule.
     */
    uaRuleId?: pulumi.Input<string>;
    /**
     * Defines an identifier.
     */
    zoneId: pulumi.Input<string>;
}
