import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersCustomDomain = new cloudflare.WorkersCustomDomain("example_workers_custom_domain", {
 *     accountId: "9a7806061c88ada191ed06f989cc3dac",
 *     environment: "production",
 *     hostname: "foo.example.com",
 *     service: "foo",
 *     zoneId: "593c9c94de529bbbfaac7c53ced0447d",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/workerDomain:WorkerDomain example '<account_id>/<domain_id>'
 * ```
 *
 * @deprecated cloudflare.index/workerdomain.WorkerDomain has been deprecated in favor of cloudflare.index/workerscustomdomain.WorkersCustomDomain
 */
export declare class WorkerDomain extends pulumi.CustomResource {
    /**
     * Get an existing WorkerDomain resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: WorkerDomainState, opts?: pulumi.CustomResourceOptions): WorkerDomain;
    /**
     * Returns true if the given object is an instance of WorkerDomain.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WorkerDomain;
    /**
     * Identifer of the account.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Worker environment associated with the zone and hostname.
     */
    readonly environment: pulumi.Output<string>;
    /**
     * Hostname of the Worker Domain.
     */
    readonly hostname: pulumi.Output<string>;
    /**
     * Worker service associated with the zone and hostname.
     */
    readonly service: pulumi.Output<string>;
    /**
     * Identifier of the zone.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Name of the zone.
     */
    readonly zoneName: pulumi.Output<string>;
    /**
     * Create a WorkerDomain resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    /** @deprecated cloudflare.index/workerdomain.WorkerDomain has been deprecated in favor of cloudflare.index/workerscustomdomain.WorkersCustomDomain */
    constructor(name: string, args: WorkerDomainArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering WorkerDomain resources.
 */
export interface WorkerDomainState {
    /**
     * Identifer of the account.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Worker environment associated with the zone and hostname.
     */
    environment?: pulumi.Input<string>;
    /**
     * Hostname of the Worker Domain.
     */
    hostname?: pulumi.Input<string>;
    /**
     * Worker service associated with the zone and hostname.
     */
    service?: pulumi.Input<string>;
    /**
     * Identifier of the zone.
     */
    zoneId?: pulumi.Input<string>;
    /**
     * Name of the zone.
     */
    zoneName?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a WorkerDomain resource.
 */
export interface WorkerDomainArgs {
    /**
     * Identifer of the account.
     */
    accountId: pulumi.Input<string>;
    /**
     * Worker environment associated with the zone and hostname.
     */
    environment: pulumi.Input<string>;
    /**
     * Hostname of the Worker Domain.
     */
    hostname: pulumi.Input<string>;
    /**
     * Worker service associated with the zone and hostname.
     */
    service: pulumi.Input<string>;
    /**
     * Identifier of the zone.
     */
    zoneId: pulumi.Input<string>;
}
