import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/workersCronTrigger:WorkersCronTrigger example '<account_id>/<script_name>'
 * ```
 */
export declare class WorkersCronTrigger extends pulumi.CustomResource {
    /**
     * Get an existing WorkersCronTrigger resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: WorkersCronTriggerState, opts?: pulumi.CustomResourceOptions): WorkersCronTrigger;
    /**
     * Returns true if the given object is an instance of WorkersCronTrigger.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WorkersCronTrigger;
    /**
     * Identifier.
     */
    readonly accountId: pulumi.Output<string>;
    readonly schedules: pulumi.Output<outputs.WorkersCronTriggerSchedule[]>;
    /**
     * Name of the script, used in URLs and route configuration.
     */
    readonly scriptName: pulumi.Output<string>;
    /**
     * Create a WorkersCronTrigger resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WorkersCronTriggerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering WorkersCronTrigger resources.
 */
export interface WorkersCronTriggerState {
    /**
     * Identifier.
     */
    accountId?: pulumi.Input<string>;
    schedules?: pulumi.Input<pulumi.Input<inputs.WorkersCronTriggerSchedule>[]>;
    /**
     * Name of the script, used in URLs and route configuration.
     */
    scriptName?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a WorkersCronTrigger resource.
 */
export interface WorkersCronTriggerArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    schedules: pulumi.Input<pulumi.Input<inputs.WorkersCronTriggerSchedule>[]>;
    /**
     * Name of the script, used in URLs and route configuration.
     */
    scriptName: pulumi.Input<string>;
}
