import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersForPlatformsDispatchNamespace = new cloudflare.WorkersForPlatformsDispatchNamespace("example_workers_for_platforms_dispatch_namespace", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     name: "my-dispatch-namespace",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/workersForPlatformsDispatchNamespace:WorkersForPlatformsDispatchNamespace example '<account_id>/<dispatch_namespace>'
 * ```
 */
export declare class WorkersForPlatformsDispatchNamespace extends pulumi.CustomResource {
    /**
     * Get an existing WorkersForPlatformsDispatchNamespace resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: WorkersForPlatformsDispatchNamespaceState, opts?: pulumi.CustomResourceOptions): WorkersForPlatformsDispatchNamespace;
    /**
     * Returns true if the given object is an instance of WorkersForPlatformsDispatchNamespace.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WorkersForPlatformsDispatchNamespace;
    /**
     * Identifier.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Identifier.
     */
    readonly createdBy: pulumi.Output<string>;
    /**
     * When the script was created.
     */
    readonly createdOn: pulumi.Output<string>;
    /**
     * Identifier.
     */
    readonly modifiedBy: pulumi.Output<string>;
    /**
     * When the script was last modified.
     */
    readonly modifiedOn: pulumi.Output<string>;
    /**
     * The name of the dispatch namespace.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * API Resource UUID tag.
     */
    readonly namespaceId: pulumi.Output<string>;
    /**
     * Name of the Workers for Platforms dispatch namespace.
     */
    readonly namespaceName: pulumi.Output<string>;
    /**
     * The current number of scripts in this Dispatch Namespace.
     */
    readonly scriptCount: pulumi.Output<number>;
    /**
     * Create a WorkersForPlatformsDispatchNamespace resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WorkersForPlatformsDispatchNamespaceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering WorkersForPlatformsDispatchNamespace resources.
 */
export interface WorkersForPlatformsDispatchNamespaceState {
    /**
     * Identifier.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    createdBy?: pulumi.Input<string>;
    /**
     * When the script was created.
     */
    createdOn?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    modifiedBy?: pulumi.Input<string>;
    /**
     * When the script was last modified.
     */
    modifiedOn?: pulumi.Input<string>;
    /**
     * The name of the dispatch namespace.
     */
    name?: pulumi.Input<string>;
    /**
     * API Resource UUID tag.
     */
    namespaceId?: pulumi.Input<string>;
    /**
     * Name of the Workers for Platforms dispatch namespace.
     */
    namespaceName?: pulumi.Input<string>;
    /**
     * The current number of scripts in this Dispatch Namespace.
     */
    scriptCount?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a WorkersForPlatformsDispatchNamespace resource.
 */
export interface WorkersForPlatformsDispatchNamespaceArgs {
    /**
     * Identifier.
     */
    accountId: pulumi.Input<string>;
    /**
     * The name of the dispatch namespace.
     */
    name?: pulumi.Input<string>;
}
