import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleWorkersRoute = new cloudflare.WorkersRoute("example_workers_route", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     pattern: "example.com/*",
 *     script: "my-workers-script",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/workersRoute:WorkersRoute example '<zone_id>/<route_id>'
 * ```
 */
export declare class WorkersRoute extends pulumi.CustomResource {
    /**
     * Get an existing WorkersRoute resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: WorkersRouteState, opts?: pulumi.CustomResourceOptions): WorkersRoute;
    /**
     * Returns true if the given object is an instance of WorkersRoute.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WorkersRoute;
    /**
     * Pattern to match incoming requests against. [Learn more](https://developers.cloudflare.com/workers/configuration/routing/routes/#matching-behavior).
     */
    readonly pattern: pulumi.Output<string>;
    /**
     * Name of the script to run if the route matches.
     */
    readonly script: pulumi.Output<string | undefined>;
    /**
     * Identifier.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a WorkersRoute resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WorkersRouteArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering WorkersRoute resources.
 */
export interface WorkersRouteState {
    /**
     * Pattern to match incoming requests against. [Learn more](https://developers.cloudflare.com/workers/configuration/routing/routes/#matching-behavior).
     */
    pattern?: pulumi.Input<string>;
    /**
     * Name of the script to run if the route matches.
     */
    script?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a WorkersRoute resource.
 */
export interface WorkersRouteArgs {
    /**
     * Pattern to match incoming requests against. [Learn more](https://developers.cloudflare.com/workers/configuration/routing/routes/#matching-behavior).
     */
    pattern: pulumi.Input<string>;
    /**
     * Name of the script to run if the route matches.
     */
    script?: pulumi.Input<string>;
    /**
     * Identifier.
     */
    zoneId: pulumi.Input<string>;
}
