import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustAccessInfrastructureTarget = new cloudflare.ZeroTrustAccessInfrastructureTarget("example_zero_trust_access_infrastructure_target", {
 *     accountId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     hostname: "infra-access-target",
 *     ip: {
 *         ipv4: {
 *             ipAddr: "187.26.29.249",
 *             virtualNetworkId: "c77b744e-acc8-428f-9257-6878c046ed55",
 *         },
 *         ipv6: {
 *             ipAddr: "64c0:64e8:f0b4:8dbf:7104:72b0:ec8f:f5e0",
 *             virtualNetworkId: "c77b744e-acc8-428f-9257-6878c046ed55",
 *         },
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/zeroTrustAccessInfrastructureTarget:ZeroTrustAccessInfrastructureTarget example '<account_id>/<target_id>'
 * ```
 */
export declare class ZeroTrustAccessInfrastructureTarget extends pulumi.CustomResource {
    /**
     * Get an existing ZeroTrustAccessInfrastructureTarget resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZeroTrustAccessInfrastructureTargetState, opts?: pulumi.CustomResourceOptions): ZeroTrustAccessInfrastructureTarget;
    /**
     * Returns true if the given object is an instance of ZeroTrustAccessInfrastructureTarget.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZeroTrustAccessInfrastructureTarget;
    /**
     * Account identifier
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Date and time at which the target was created
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * A non-unique field that refers to a target. Case insensitive, maximum
     * length of 255 characters, supports the use of special characters dash
     * and period, does not support spaces, and must start and end with an
     * alphanumeric character.
     */
    readonly hostname: pulumi.Output<string>;
    /**
     * The IPv4/IPv6 address that identifies where to reach a target
     */
    readonly ip: pulumi.Output<outputs.ZeroTrustAccessInfrastructureTargetIp>;
    /**
     * Date and time at which the target was modified
     */
    readonly modifiedAt: pulumi.Output<string>;
    /**
     * Create a ZeroTrustAccessInfrastructureTarget resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZeroTrustAccessInfrastructureTargetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZeroTrustAccessInfrastructureTarget resources.
 */
export interface ZeroTrustAccessInfrastructureTargetState {
    /**
     * Account identifier
     */
    accountId?: pulumi.Input<string>;
    /**
     * Date and time at which the target was created
     */
    createdAt?: pulumi.Input<string>;
    /**
     * A non-unique field that refers to a target. Case insensitive, maximum
     * length of 255 characters, supports the use of special characters dash
     * and period, does not support spaces, and must start and end with an
     * alphanumeric character.
     */
    hostname?: pulumi.Input<string>;
    /**
     * The IPv4/IPv6 address that identifies where to reach a target
     */
    ip?: pulumi.Input<inputs.ZeroTrustAccessInfrastructureTargetIp>;
    /**
     * Date and time at which the target was modified
     */
    modifiedAt?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ZeroTrustAccessInfrastructureTarget resource.
 */
export interface ZeroTrustAccessInfrastructureTargetArgs {
    /**
     * Account identifier
     */
    accountId: pulumi.Input<string>;
    /**
     * A non-unique field that refers to a target. Case insensitive, maximum
     * length of 255 characters, supports the use of special characters dash
     * and period, does not support spaces, and must start and end with an
     * alphanumeric character.
     */
    hostname: pulumi.Input<string>;
    /**
     * The IPv4/IPv6 address that identifies where to reach a target
     */
    ip: pulumi.Input<inputs.ZeroTrustAccessInfrastructureTargetIp>;
}
