import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 */
export declare class ZeroTrustAccessMtlsHostnameSettings extends pulumi.CustomResource {
    /**
     * Get an existing ZeroTrustAccessMtlsHostnameSettings resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZeroTrustAccessMtlsHostnameSettingsState, opts?: pulumi.CustomResourceOptions): ZeroTrustAccessMtlsHostnameSettings;
    /**
     * Returns true if the given object is an instance of ZeroTrustAccessMtlsHostnameSettings.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZeroTrustAccessMtlsHostnameSettings;
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    readonly accountId: pulumi.Output<string | undefined>;
    /**
     * Request client certificates for this hostname in China. Can only be set to true if this zone is china network enabled.
     */
    readonly chinaNetwork: pulumi.Output<boolean>;
    /**
     * Client Certificate Forwarding is a feature that takes the client cert provided by the eyeball to the edge, and forwards it to the origin as a HTTP header to allow logging on the origin.
     */
    readonly clientCertificateForwarding: pulumi.Output<boolean>;
    /**
     * The hostname that these settings apply to.
     */
    readonly hostname: pulumi.Output<string>;
    readonly settings: pulumi.Output<outputs.ZeroTrustAccessMtlsHostnameSettingsSetting[]>;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    readonly zoneId: pulumi.Output<string | undefined>;
    /**
     * Create a ZeroTrustAccessMtlsHostnameSettings resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZeroTrustAccessMtlsHostnameSettingsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZeroTrustAccessMtlsHostnameSettings resources.
 */
export interface ZeroTrustAccessMtlsHostnameSettingsState {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Request client certificates for this hostname in China. Can only be set to true if this zone is china network enabled.
     */
    chinaNetwork?: pulumi.Input<boolean>;
    /**
     * Client Certificate Forwarding is a feature that takes the client cert provided by the eyeball to the edge, and forwards it to the origin as a HTTP header to allow logging on the origin.
     */
    clientCertificateForwarding?: pulumi.Input<boolean>;
    /**
     * The hostname that these settings apply to.
     */
    hostname?: pulumi.Input<string>;
    settings?: pulumi.Input<pulumi.Input<inputs.ZeroTrustAccessMtlsHostnameSettingsSetting>[]>;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ZeroTrustAccessMtlsHostnameSettings resource.
 */
export interface ZeroTrustAccessMtlsHostnameSettingsArgs {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    accountId?: pulumi.Input<string>;
    settings: pulumi.Input<pulumi.Input<inputs.ZeroTrustAccessMtlsHostnameSettingsSetting>[]>;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zoneId?: pulumi.Input<string>;
}
