import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDeviceCustomProfile = new cloudflare.ZeroTrustDeviceCustomProfile("example_zero_trust_device_custom_profile", {
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     match: "identity.email == \"test@cloudflare.com\"",
 *     name: "Allow Developers",
 *     precedence: 100,
 *     allowModeSwitch: true,
 *     allowUpdates: true,
 *     allowedToLeave: true,
 *     autoConnect: 0,
 *     captivePortal: 180,
 *     description: "Policy for test teams.",
 *     disableAutoFallback: true,
 *     enabled: true,
 *     excludes: [{
 *         address: "192.0.2.0/24",
 *         description: "Exclude testing domains from the tunnel",
 *     }],
 *     excludeOfficeIps: true,
 *     includes: [{
 *         address: "192.0.2.0/24",
 *         description: "Include testing domains in the tunnel",
 *     }],
 *     lanAllowMinutes: 30,
 *     lanAllowSubnetSize: 24,
 *     registerInterfaceIpWithDns: true,
 *     sccmVpnBoundarySupport: false,
 *     serviceModeV2: {
 *         mode: "proxy",
 *         port: 3000,
 *     },
 *     supportUrl: "https://1.1.1.1/help",
 *     switchLocked: true,
 *     tunnelProtocol: "wireguard",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/zeroTrustDeviceCustomProfile:ZeroTrustDeviceCustomProfile example '<account_id>/<policy_id>'
 * ```
 */
export declare class ZeroTrustDeviceCustomProfile extends pulumi.CustomResource {
    /**
     * Get an existing ZeroTrustDeviceCustomProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZeroTrustDeviceCustomProfileState, opts?: pulumi.CustomResourceOptions): ZeroTrustDeviceCustomProfile;
    /**
     * Returns true if the given object is an instance of ZeroTrustDeviceCustomProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZeroTrustDeviceCustomProfile;
    readonly accountId: pulumi.Output<string>;
    /**
     * Whether to allow the user to switch WARP between modes.
     */
    readonly allowModeSwitch: pulumi.Output<boolean | undefined>;
    /**
     * Whether to receive update notifications when a new version of the client is available.
     */
    readonly allowUpdates: pulumi.Output<boolean | undefined>;
    /**
     * Whether to allow devices to leave the organization.
     */
    readonly allowedToLeave: pulumi.Output<boolean | undefined>;
    /**
     * The amount of time in seconds to reconnect after having been disabled.
     */
    readonly autoConnect: pulumi.Output<number | undefined>;
    /**
     * Turn on the captive portal after the specified amount of time.
     */
    readonly captivePortal: pulumi.Output<number | undefined>;
    /**
     * Whether the policy is the default policy for an account.
     */
    readonly default: pulumi.Output<boolean>;
    /**
     * A description of the policy.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * If the `dnsServer` field of a fallback domain is not present, the client will fall back to a best guess of the default/system DNS resolvers unless this policy option is set to `true`.
     */
    readonly disableAutoFallback: pulumi.Output<boolean | undefined>;
    /**
     * Whether the policy will be applied to matching devices.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * Whether to add Microsoft IPs to Split Tunnel exclusions.
     */
    readonly excludeOfficeIps: pulumi.Output<boolean | undefined>;
    /**
     * List of routes excluded in the WARP client's tunnel. Both 'exclude' and 'include' cannot be set in the same request.
     */
    readonly excludes: pulumi.Output<outputs.ZeroTrustDeviceCustomProfileExclude[] | undefined>;
    readonly fallbackDomains: pulumi.Output<outputs.ZeroTrustDeviceCustomProfileFallbackDomain[]>;
    readonly gatewayUniqueId: pulumi.Output<string>;
    /**
     * List of routes included in the WARP client's tunnel. Both 'exclude' and 'include' cannot be set in the same request.
     */
    readonly includes: pulumi.Output<outputs.ZeroTrustDeviceCustomProfileInclude[] | undefined>;
    /**
     * The amount of time in minutes a user is allowed access to their LAN. A value of 0 will allow LAN access until the next WARP reconnection, such as a reboot or a laptop waking from sleep. Note that this field is omitted from the response if null or unset.
     */
    readonly lanAllowMinutes: pulumi.Output<number | undefined>;
    /**
     * The size of the subnet for the local access network. Note that this field is omitted from the response if null or unset.
     */
    readonly lanAllowSubnetSize: pulumi.Output<number | undefined>;
    /**
     * The wirefilter expression to match devices. Available values: "identity.email", "identity.groups.id", "identity.groups.name", "identity.groups.email", "identity.service*token*uuid", "identity.saml_attributes", "network", "os.name", "os.version".
     */
    readonly match: pulumi.Output<string>;
    /**
     * The name of the device settings profile.
     */
    readonly name: pulumi.Output<string>;
    readonly policyId: pulumi.Output<string>;
    /**
     * The precedence of the policy. Lower values indicate higher precedence. Policies will be evaluated in ascending order of this field.
     */
    readonly precedence: pulumi.Output<number>;
    /**
     * Determines if the operating system will register WARP's local interface IP with your on-premises DNS server.
     */
    readonly registerInterfaceIpWithDns: pulumi.Output<boolean | undefined>;
    /**
     * Determines whether the WARP client indicates to SCCM that it is inside a VPN boundary. (Windows only).
     */
    readonly sccmVpnBoundarySupport: pulumi.Output<boolean | undefined>;
    readonly serviceModeV2: pulumi.Output<outputs.ZeroTrustDeviceCustomProfileServiceModeV2 | undefined>;
    /**
     * The URL to launch when the Send Feedback button is clicked.
     */
    readonly supportUrl: pulumi.Output<string | undefined>;
    /**
     * Whether to allow the user to turn off the WARP switch and disconnect the client.
     */
    readonly switchLocked: pulumi.Output<boolean | undefined>;
    readonly targetTests: pulumi.Output<outputs.ZeroTrustDeviceCustomProfileTargetTest[]>;
    /**
     * Determines which tunnel protocol to use.
     */
    readonly tunnelProtocol: pulumi.Output<string | undefined>;
    /**
     * Create a ZeroTrustDeviceCustomProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZeroTrustDeviceCustomProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZeroTrustDeviceCustomProfile resources.
 */
export interface ZeroTrustDeviceCustomProfileState {
    accountId?: pulumi.Input<string>;
    /**
     * Whether to allow the user to switch WARP between modes.
     */
    allowModeSwitch?: pulumi.Input<boolean>;
    /**
     * Whether to receive update notifications when a new version of the client is available.
     */
    allowUpdates?: pulumi.Input<boolean>;
    /**
     * Whether to allow devices to leave the organization.
     */
    allowedToLeave?: pulumi.Input<boolean>;
    /**
     * The amount of time in seconds to reconnect after having been disabled.
     */
    autoConnect?: pulumi.Input<number>;
    /**
     * Turn on the captive portal after the specified amount of time.
     */
    captivePortal?: pulumi.Input<number>;
    /**
     * Whether the policy is the default policy for an account.
     */
    default?: pulumi.Input<boolean>;
    /**
     * A description of the policy.
     */
    description?: pulumi.Input<string>;
    /**
     * If the `dnsServer` field of a fallback domain is not present, the client will fall back to a best guess of the default/system DNS resolvers unless this policy option is set to `true`.
     */
    disableAutoFallback?: pulumi.Input<boolean>;
    /**
     * Whether the policy will be applied to matching devices.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * Whether to add Microsoft IPs to Split Tunnel exclusions.
     */
    excludeOfficeIps?: pulumi.Input<boolean>;
    /**
     * List of routes excluded in the WARP client's tunnel. Both 'exclude' and 'include' cannot be set in the same request.
     */
    excludes?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDeviceCustomProfileExclude>[]>;
    fallbackDomains?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDeviceCustomProfileFallbackDomain>[]>;
    gatewayUniqueId?: pulumi.Input<string>;
    /**
     * List of routes included in the WARP client's tunnel. Both 'exclude' and 'include' cannot be set in the same request.
     */
    includes?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDeviceCustomProfileInclude>[]>;
    /**
     * The amount of time in minutes a user is allowed access to their LAN. A value of 0 will allow LAN access until the next WARP reconnection, such as a reboot or a laptop waking from sleep. Note that this field is omitted from the response if null or unset.
     */
    lanAllowMinutes?: pulumi.Input<number>;
    /**
     * The size of the subnet for the local access network. Note that this field is omitted from the response if null or unset.
     */
    lanAllowSubnetSize?: pulumi.Input<number>;
    /**
     * The wirefilter expression to match devices. Available values: "identity.email", "identity.groups.id", "identity.groups.name", "identity.groups.email", "identity.service*token*uuid", "identity.saml_attributes", "network", "os.name", "os.version".
     */
    match?: pulumi.Input<string>;
    /**
     * The name of the device settings profile.
     */
    name?: pulumi.Input<string>;
    policyId?: pulumi.Input<string>;
    /**
     * The precedence of the policy. Lower values indicate higher precedence. Policies will be evaluated in ascending order of this field.
     */
    precedence?: pulumi.Input<number>;
    /**
     * Determines if the operating system will register WARP's local interface IP with your on-premises DNS server.
     */
    registerInterfaceIpWithDns?: pulumi.Input<boolean>;
    /**
     * Determines whether the WARP client indicates to SCCM that it is inside a VPN boundary. (Windows only).
     */
    sccmVpnBoundarySupport?: pulumi.Input<boolean>;
    serviceModeV2?: pulumi.Input<inputs.ZeroTrustDeviceCustomProfileServiceModeV2>;
    /**
     * The URL to launch when the Send Feedback button is clicked.
     */
    supportUrl?: pulumi.Input<string>;
    /**
     * Whether to allow the user to turn off the WARP switch and disconnect the client.
     */
    switchLocked?: pulumi.Input<boolean>;
    targetTests?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDeviceCustomProfileTargetTest>[]>;
    /**
     * Determines which tunnel protocol to use.
     */
    tunnelProtocol?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ZeroTrustDeviceCustomProfile resource.
 */
export interface ZeroTrustDeviceCustomProfileArgs {
    accountId: pulumi.Input<string>;
    /**
     * Whether to allow the user to switch WARP between modes.
     */
    allowModeSwitch?: pulumi.Input<boolean>;
    /**
     * Whether to receive update notifications when a new version of the client is available.
     */
    allowUpdates?: pulumi.Input<boolean>;
    /**
     * Whether to allow devices to leave the organization.
     */
    allowedToLeave?: pulumi.Input<boolean>;
    /**
     * The amount of time in seconds to reconnect after having been disabled.
     */
    autoConnect?: pulumi.Input<number>;
    /**
     * Turn on the captive portal after the specified amount of time.
     */
    captivePortal?: pulumi.Input<number>;
    /**
     * A description of the policy.
     */
    description?: pulumi.Input<string>;
    /**
     * If the `dnsServer` field of a fallback domain is not present, the client will fall back to a best guess of the default/system DNS resolvers unless this policy option is set to `true`.
     */
    disableAutoFallback?: pulumi.Input<boolean>;
    /**
     * Whether the policy will be applied to matching devices.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * Whether to add Microsoft IPs to Split Tunnel exclusions.
     */
    excludeOfficeIps?: pulumi.Input<boolean>;
    /**
     * List of routes excluded in the WARP client's tunnel. Both 'exclude' and 'include' cannot be set in the same request.
     */
    excludes?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDeviceCustomProfileExclude>[]>;
    /**
     * List of routes included in the WARP client's tunnel. Both 'exclude' and 'include' cannot be set in the same request.
     */
    includes?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDeviceCustomProfileInclude>[]>;
    /**
     * The amount of time in minutes a user is allowed access to their LAN. A value of 0 will allow LAN access until the next WARP reconnection, such as a reboot or a laptop waking from sleep. Note that this field is omitted from the response if null or unset.
     */
    lanAllowMinutes?: pulumi.Input<number>;
    /**
     * The size of the subnet for the local access network. Note that this field is omitted from the response if null or unset.
     */
    lanAllowSubnetSize?: pulumi.Input<number>;
    /**
     * The wirefilter expression to match devices. Available values: "identity.email", "identity.groups.id", "identity.groups.name", "identity.groups.email", "identity.service*token*uuid", "identity.saml_attributes", "network", "os.name", "os.version".
     */
    match: pulumi.Input<string>;
    /**
     * The name of the device settings profile.
     */
    name: pulumi.Input<string>;
    /**
     * The precedence of the policy. Lower values indicate higher precedence. Policies will be evaluated in ascending order of this field.
     */
    precedence: pulumi.Input<number>;
    /**
     * Determines if the operating system will register WARP's local interface IP with your on-premises DNS server.
     */
    registerInterfaceIpWithDns?: pulumi.Input<boolean>;
    /**
     * Determines whether the WARP client indicates to SCCM that it is inside a VPN boundary. (Windows only).
     */
    sccmVpnBoundarySupport?: pulumi.Input<boolean>;
    serviceModeV2?: pulumi.Input<inputs.ZeroTrustDeviceCustomProfileServiceModeV2>;
    /**
     * The URL to launch when the Send Feedback button is clicked.
     */
    supportUrl?: pulumi.Input<string>;
    /**
     * Whether to allow the user to turn off the WARP switch and disconnect the client.
     */
    switchLocked?: pulumi.Input<boolean>;
    /**
     * Determines which tunnel protocol to use.
     */
    tunnelProtocol?: pulumi.Input<string>;
}
