import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/zeroTrustDevicePostureIntegration:ZeroTrustDevicePostureIntegration example '<account_id>/<integration_id>'
 * ```
 */
export declare class ZeroTrustDevicePostureIntegration extends pulumi.CustomResource {
    /**
     * Get an existing ZeroTrustDevicePostureIntegration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZeroTrustDevicePostureIntegrationState, opts?: pulumi.CustomResourceOptions): ZeroTrustDevicePostureIntegration;
    /**
     * Returns true if the given object is an instance of ZeroTrustDevicePostureIntegration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZeroTrustDevicePostureIntegration;
    readonly accountId: pulumi.Output<string>;
    /**
     * The configuration object containing third-party integration information.
     */
    readonly config: pulumi.Output<outputs.ZeroTrustDevicePostureIntegrationConfig>;
    /**
     * The interval between each posture check with the third-party API. Use `m` for minutes (e.g. `5m`) and `h` for hours (e.g. `12h`).
     */
    readonly interval: pulumi.Output<string>;
    /**
     * The name of the device posture integration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The type of device posture integration.
     * Available values: "workspace*one", "crowdstrike*s2s", "uptycs", "intune", "kolide", "tanium*s2s", "sentinelone*s2s", "customS2s".
     */
    readonly type: pulumi.Output<string>;
    /**
     * Create a ZeroTrustDevicePostureIntegration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZeroTrustDevicePostureIntegrationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZeroTrustDevicePostureIntegration resources.
 */
export interface ZeroTrustDevicePostureIntegrationState {
    accountId?: pulumi.Input<string>;
    /**
     * The configuration object containing third-party integration information.
     */
    config?: pulumi.Input<inputs.ZeroTrustDevicePostureIntegrationConfig>;
    /**
     * The interval between each posture check with the third-party API. Use `m` for minutes (e.g. `5m`) and `h` for hours (e.g. `12h`).
     */
    interval?: pulumi.Input<string>;
    /**
     * The name of the device posture integration.
     */
    name?: pulumi.Input<string>;
    /**
     * The type of device posture integration.
     * Available values: "workspace*one", "crowdstrike*s2s", "uptycs", "intune", "kolide", "tanium*s2s", "sentinelone*s2s", "customS2s".
     */
    type?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ZeroTrustDevicePostureIntegration resource.
 */
export interface ZeroTrustDevicePostureIntegrationArgs {
    accountId: pulumi.Input<string>;
    /**
     * The configuration object containing third-party integration information.
     */
    config: pulumi.Input<inputs.ZeroTrustDevicePostureIntegrationConfig>;
    /**
     * The interval between each posture check with the third-party API. Use `m` for minutes (e.g. `5m`) and `h` for hours (e.g. `12h`).
     */
    interval: pulumi.Input<string>;
    /**
     * The name of the device posture integration.
     */
    name: pulumi.Input<string>;
    /**
     * The type of device posture integration.
     * Available values: "workspace*one", "crowdstrike*s2s", "uptycs", "intune", "kolide", "tanium*s2s", "sentinelone*s2s", "customS2s".
     */
    type: pulumi.Input<string>;
}
