import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/zeroTrustDlpCustomProfile:ZeroTrustDlpCustomProfile example '<account_id>/<profile_id>'
 * ```
 */
export declare class ZeroTrustDlpCustomProfile extends pulumi.CustomResource {
    /**
     * Get an existing ZeroTrustDlpCustomProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZeroTrustDlpCustomProfileState, opts?: pulumi.CustomResourceOptions): ZeroTrustDlpCustomProfile;
    /**
     * Returns true if the given object is an instance of ZeroTrustDlpCustomProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZeroTrustDlpCustomProfile;
    readonly accountId: pulumi.Output<string>;
    readonly aiContextEnabled: pulumi.Output<boolean | undefined>;
    /**
     * Related DLP policies will trigger when the match count exceeds the number set.
     */
    readonly allowedMatchCount: pulumi.Output<number>;
    readonly confidenceThreshold: pulumi.Output<string | undefined>;
    /**
     * Scan the context of predefined entries to only return matches surrounded by keywords.
     */
    readonly contextAwareness: pulumi.Output<outputs.ZeroTrustDlpCustomProfileContextAwareness | undefined>;
    /**
     * When the profile was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The description of the profile.
     */
    readonly description: pulumi.Output<string | undefined>;
    readonly entries: pulumi.Output<outputs.ZeroTrustDlpCustomProfileEntry[] | undefined>;
    readonly name: pulumi.Output<string | undefined>;
    readonly ocrEnabled: pulumi.Output<boolean | undefined>;
    /**
     * Whether this profile can be accessed by anyone.
     */
    readonly openAccess: pulumi.Output<boolean>;
    readonly profiles: pulumi.Output<outputs.ZeroTrustDlpCustomProfileProfile[]>;
    /**
     * Entries from other profiles (e.g. pre-defined Cloudflare profiles, or your Microsoft Information Protection profiles).
     */
    readonly sharedEntries: pulumi.Output<outputs.ZeroTrustDlpCustomProfileSharedEntry[] | undefined>;
    /**
     * Available values: "custom", "predefined", "integration".
     */
    readonly type: pulumi.Output<string>;
    /**
     * When the profile was lasted updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a ZeroTrustDlpCustomProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZeroTrustDlpCustomProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZeroTrustDlpCustomProfile resources.
 */
export interface ZeroTrustDlpCustomProfileState {
    accountId?: pulumi.Input<string>;
    aiContextEnabled?: pulumi.Input<boolean>;
    /**
     * Related DLP policies will trigger when the match count exceeds the number set.
     */
    allowedMatchCount?: pulumi.Input<number>;
    confidenceThreshold?: pulumi.Input<string>;
    /**
     * Scan the context of predefined entries to only return matches surrounded by keywords.
     */
    contextAwareness?: pulumi.Input<inputs.ZeroTrustDlpCustomProfileContextAwareness>;
    /**
     * When the profile was created.
     */
    createdAt?: pulumi.Input<string>;
    /**
     * The description of the profile.
     */
    description?: pulumi.Input<string>;
    entries?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDlpCustomProfileEntry>[]>;
    name?: pulumi.Input<string>;
    ocrEnabled?: pulumi.Input<boolean>;
    /**
     * Whether this profile can be accessed by anyone.
     */
    openAccess?: pulumi.Input<boolean>;
    profiles?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDlpCustomProfileProfile>[]>;
    /**
     * Entries from other profiles (e.g. pre-defined Cloudflare profiles, or your Microsoft Information Protection profiles).
     */
    sharedEntries?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDlpCustomProfileSharedEntry>[]>;
    /**
     * Available values: "custom", "predefined", "integration".
     */
    type?: pulumi.Input<string>;
    /**
     * When the profile was lasted updated.
     */
    updatedAt?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ZeroTrustDlpCustomProfile resource.
 */
export interface ZeroTrustDlpCustomProfileArgs {
    accountId: pulumi.Input<string>;
    aiContextEnabled?: pulumi.Input<boolean>;
    /**
     * Related DLP policies will trigger when the match count exceeds the number set.
     */
    allowedMatchCount?: pulumi.Input<number>;
    confidenceThreshold?: pulumi.Input<string>;
    /**
     * Scan the context of predefined entries to only return matches surrounded by keywords.
     */
    contextAwareness?: pulumi.Input<inputs.ZeroTrustDlpCustomProfileContextAwareness>;
    /**
     * The description of the profile.
     */
    description?: pulumi.Input<string>;
    entries?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDlpCustomProfileEntry>[]>;
    name?: pulumi.Input<string>;
    ocrEnabled?: pulumi.Input<boolean>;
    profiles?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDlpCustomProfileProfile>[]>;
    /**
     * Entries from other profiles (e.g. pre-defined Cloudflare profiles, or your Microsoft Information Protection profiles).
     */
    sharedEntries?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDlpCustomProfileSharedEntry>[]>;
}
