import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDlpDataset = new cloudflare.ZeroTrustDlpDataset("example_zero_trust_dlp_dataset", {
 *     accountId: "account_id",
 *     name: "name",
 *     caseSensitive: true,
 *     description: "description",
 *     encodingVersion: 0,
 *     secret: true,
 * });
 * ```
 */
export declare class ZeroTrustDlpDataset extends pulumi.CustomResource {
    /**
     * Get an existing ZeroTrustDlpDataset resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZeroTrustDlpDatasetState, opts?: pulumi.CustomResourceOptions): ZeroTrustDlpDataset;
    /**
     * Returns true if the given object is an instance of ZeroTrustDlpDataset.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZeroTrustDlpDataset;
    readonly accountId: pulumi.Output<string>;
    /**
     * Only applies to custom word lists.
     * Determines if the words should be matched in a case-sensitive manner
     * Cannot be set to false if `secret` is true or undefined
     */
    readonly caseSensitive: pulumi.Output<boolean | undefined>;
    readonly columns: pulumi.Output<outputs.ZeroTrustDlpDatasetColumn[]>;
    readonly createdAt: pulumi.Output<string>;
    readonly dataset: pulumi.Output<outputs.ZeroTrustDlpDatasetDataset>;
    readonly datasetId: pulumi.Output<string | undefined>;
    /**
     * The description of the dataset.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Dataset encoding version
     */
    readonly encodingVersion: pulumi.Output<number | undefined>;
    readonly maxCells: pulumi.Output<number>;
    readonly name: pulumi.Output<string>;
    readonly numCells: pulumi.Output<number>;
    /**
     * Generate a secret dataset. If true, the response will include a secret to use with the EDM encoder. If false, the
     * response has no secret and the dataset is uploaded in plaintext.
     */
    readonly secret: pulumi.Output<boolean | undefined>;
    /**
     * Available values: "empty", "uploading", "processing", "failed", "complete".
     */
    readonly status: pulumi.Output<string>;
    /**
     * When the dataset was last updated. This includes name or description changes as well as uploads.
     */
    readonly updatedAt: pulumi.Output<string>;
    readonly uploads: pulumi.Output<outputs.ZeroTrustDlpDatasetUpload[]>;
    /**
     * The version to use when uploading the dataset.
     */
    readonly version: pulumi.Output<number>;
    /**
     * Create a ZeroTrustDlpDataset resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZeroTrustDlpDatasetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZeroTrustDlpDataset resources.
 */
export interface ZeroTrustDlpDatasetState {
    accountId?: pulumi.Input<string>;
    /**
     * Only applies to custom word lists.
     * Determines if the words should be matched in a case-sensitive manner
     * Cannot be set to false if `secret` is true or undefined
     */
    caseSensitive?: pulumi.Input<boolean>;
    columns?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDlpDatasetColumn>[]>;
    createdAt?: pulumi.Input<string>;
    dataset?: pulumi.Input<inputs.ZeroTrustDlpDatasetDataset>;
    datasetId?: pulumi.Input<string>;
    /**
     * The description of the dataset.
     */
    description?: pulumi.Input<string>;
    /**
     * Dataset encoding version
     */
    encodingVersion?: pulumi.Input<number>;
    maxCells?: pulumi.Input<number>;
    name?: pulumi.Input<string>;
    numCells?: pulumi.Input<number>;
    /**
     * Generate a secret dataset. If true, the response will include a secret to use with the EDM encoder. If false, the
     * response has no secret and the dataset is uploaded in plaintext.
     */
    secret?: pulumi.Input<boolean>;
    /**
     * Available values: "empty", "uploading", "processing", "failed", "complete".
     */
    status?: pulumi.Input<string>;
    /**
     * When the dataset was last updated. This includes name or description changes as well as uploads.
     */
    updatedAt?: pulumi.Input<string>;
    uploads?: pulumi.Input<pulumi.Input<inputs.ZeroTrustDlpDatasetUpload>[]>;
    /**
     * The version to use when uploading the dataset.
     */
    version?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a ZeroTrustDlpDataset resource.
 */
export interface ZeroTrustDlpDatasetArgs {
    accountId: pulumi.Input<string>;
    /**
     * Only applies to custom word lists.
     * Determines if the words should be matched in a case-sensitive manner
     * Cannot be set to false if `secret` is true or undefined
     */
    caseSensitive?: pulumi.Input<boolean>;
    datasetId?: pulumi.Input<string>;
    /**
     * The description of the dataset.
     */
    description?: pulumi.Input<string>;
    /**
     * Dataset encoding version
     */
    encodingVersion?: pulumi.Input<number>;
    name: pulumi.Input<string>;
    /**
     * Generate a secret dataset. If true, the response will include a secret to use with the EDM encoder. If false, the
     * response has no secret and the dataset is uploaded in plaintext.
     */
    secret?: pulumi.Input<boolean>;
}
