import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustDlpEntry = new cloudflare.ZeroTrustDlpEntry("example_zero_trust_dlp_entry", {
 *     accountId: "account_id",
 *     enabled: true,
 *     name: "name",
 *     pattern: {
 *         regex: "regex",
 *         validation: "luhn",
 *     },
 *     profileId: "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/zeroTrustDlpEntry:ZeroTrustDlpEntry example '<account_id>/<entry_id>'
 * ```
 */
export declare class ZeroTrustDlpEntry extends pulumi.CustomResource {
    /**
     * Get an existing ZeroTrustDlpEntry resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZeroTrustDlpEntryState, opts?: pulumi.CustomResourceOptions): ZeroTrustDlpEntry;
    /**
     * Returns true if the given object is an instance of ZeroTrustDlpEntry.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZeroTrustDlpEntry;
    readonly accountId: pulumi.Output<string>;
    /**
     * Only applies to custom word lists.
     * Determines if the words should be matched in a case-sensitive manner
     * Cannot be set to false if secret is true
     */
    readonly caseSensitive: pulumi.Output<boolean>;
    readonly confidence: pulumi.Output<outputs.ZeroTrustDlpEntryConfidence>;
    readonly createdAt: pulumi.Output<string>;
    readonly enabled: pulumi.Output<boolean>;
    readonly name: pulumi.Output<string>;
    readonly pattern: pulumi.Output<outputs.ZeroTrustDlpEntryPattern>;
    readonly profileId: pulumi.Output<string>;
    readonly secret: pulumi.Output<boolean>;
    /**
     * Available values: "custom", "predefined", "integration".
     */
    readonly type: pulumi.Output<string | undefined>;
    readonly updatedAt: pulumi.Output<string>;
    readonly wordList: pulumi.Output<string>;
    /**
     * Create a ZeroTrustDlpEntry resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZeroTrustDlpEntryArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZeroTrustDlpEntry resources.
 */
export interface ZeroTrustDlpEntryState {
    accountId?: pulumi.Input<string>;
    /**
     * Only applies to custom word lists.
     * Determines if the words should be matched in a case-sensitive manner
     * Cannot be set to false if secret is true
     */
    caseSensitive?: pulumi.Input<boolean>;
    confidence?: pulumi.Input<inputs.ZeroTrustDlpEntryConfidence>;
    createdAt?: pulumi.Input<string>;
    enabled?: pulumi.Input<boolean>;
    name?: pulumi.Input<string>;
    pattern?: pulumi.Input<inputs.ZeroTrustDlpEntryPattern>;
    profileId?: pulumi.Input<string>;
    secret?: pulumi.Input<boolean>;
    /**
     * Available values: "custom", "predefined", "integration".
     */
    type?: pulumi.Input<string>;
    updatedAt?: pulumi.Input<string>;
    wordList?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ZeroTrustDlpEntry resource.
 */
export interface ZeroTrustDlpEntryArgs {
    accountId: pulumi.Input<string>;
    enabled: pulumi.Input<boolean>;
    name: pulumi.Input<string>;
    pattern: pulumi.Input<inputs.ZeroTrustDlpEntryPattern>;
    profileId: pulumi.Input<string>;
    /**
     * Available values: "custom", "predefined", "integration".
     */
    type?: pulumi.Input<string>;
}
