import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustGatewayCertificate = new cloudflare.ZeroTrustGatewayCertificate("example_zero_trust_gateway_certificate", {
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     validityPeriodDays: 1826,
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/zeroTrustGatewayCertificate:ZeroTrustGatewayCertificate example '<account_id>/<certificate_id>'
 * ```
 */
export declare class ZeroTrustGatewayCertificate extends pulumi.CustomResource {
    /**
     * Get an existing ZeroTrustGatewayCertificate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZeroTrustGatewayCertificateState, opts?: pulumi.CustomResourceOptions): ZeroTrustGatewayCertificate;
    /**
     * Returns true if the given object is an instance of ZeroTrustGatewayCertificate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZeroTrustGatewayCertificate;
    readonly accountId: pulumi.Output<string>;
    /**
     * The deployment status of the certificate on Cloudflare's edge. Certificates in the 'available' (previously called 'active') state may be used for Gateway TLS interception.
     * Available values: "pending*deployment", "available", "pending*deletion", "inactive".
     */
    readonly bindingStatus: pulumi.Output<string>;
    /**
     * The CA certificate
     */
    readonly certificate: pulumi.Output<string>;
    readonly createdAt: pulumi.Output<string>;
    readonly expiresOn: pulumi.Output<string>;
    /**
     * The SHA256 fingerprint of the certificate.
     */
    readonly fingerprint: pulumi.Output<string>;
    /**
     * Use this certificate for Gateway TLS interception
     */
    readonly inUse: pulumi.Output<boolean>;
    /**
     * The organization that issued the certificate.
     */
    readonly issuerOrg: pulumi.Output<string>;
    /**
     * The entire issuer field of the certificate.
     */
    readonly issuerRaw: pulumi.Output<string>;
    /**
     * The type of certificate, either BYO-PKI (custom) or Gateway-managed.
     * Available values: "custom", "gatewayManaged".
     */
    readonly type: pulumi.Output<string>;
    readonly updatedAt: pulumi.Output<string>;
    readonly uploadedOn: pulumi.Output<string>;
    readonly validityPeriodDays: pulumi.Output<number | undefined>;
    /**
     * Create a ZeroTrustGatewayCertificate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZeroTrustGatewayCertificateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZeroTrustGatewayCertificate resources.
 */
export interface ZeroTrustGatewayCertificateState {
    accountId?: pulumi.Input<string>;
    /**
     * The deployment status of the certificate on Cloudflare's edge. Certificates in the 'available' (previously called 'active') state may be used for Gateway TLS interception.
     * Available values: "pending*deployment", "available", "pending*deletion", "inactive".
     */
    bindingStatus?: pulumi.Input<string>;
    /**
     * The CA certificate
     */
    certificate?: pulumi.Input<string>;
    createdAt?: pulumi.Input<string>;
    expiresOn?: pulumi.Input<string>;
    /**
     * The SHA256 fingerprint of the certificate.
     */
    fingerprint?: pulumi.Input<string>;
    /**
     * Use this certificate for Gateway TLS interception
     */
    inUse?: pulumi.Input<boolean>;
    /**
     * The organization that issued the certificate.
     */
    issuerOrg?: pulumi.Input<string>;
    /**
     * The entire issuer field of the certificate.
     */
    issuerRaw?: pulumi.Input<string>;
    /**
     * The type of certificate, either BYO-PKI (custom) or Gateway-managed.
     * Available values: "custom", "gatewayManaged".
     */
    type?: pulumi.Input<string>;
    updatedAt?: pulumi.Input<string>;
    uploadedOn?: pulumi.Input<string>;
    validityPeriodDays?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a ZeroTrustGatewayCertificate resource.
 */
export interface ZeroTrustGatewayCertificateArgs {
    accountId: pulumi.Input<string>;
    validityPeriodDays?: pulumi.Input<number>;
}
