import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustGatewayLogging = new cloudflare.ZeroTrustGatewayLogging("example_zero_trust_gateway_logging", {
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     redactPii: true,
 *     settingsByRuleType: {
 *         dns: {
 *             logAll: false,
 *             logBlocks: true,
 *         },
 *         http: {
 *             logAll: false,
 *             logBlocks: true,
 *         },
 *         l4: {
 *             logAll: false,
 *             logBlocks: true,
 *         },
 *     },
 * });
 * ```
 */
export declare class ZeroTrustGatewayLogging extends pulumi.CustomResource {
    /**
     * Get an existing ZeroTrustGatewayLogging resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZeroTrustGatewayLoggingState, opts?: pulumi.CustomResourceOptions): ZeroTrustGatewayLogging;
    /**
     * Returns true if the given object is an instance of ZeroTrustGatewayLogging.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZeroTrustGatewayLogging;
    readonly accountId: pulumi.Output<string>;
    /**
     * Redact personally identifiable information from activity logging (PII fields are: source IP, user email, user ID, device ID, URL, referrer, user agent).
     */
    readonly redactPii: pulumi.Output<boolean>;
    /**
     * Logging settings by rule type.
     */
    readonly settingsByRuleType: pulumi.Output<outputs.ZeroTrustGatewayLoggingSettingsByRuleType>;
    /**
     * Create a ZeroTrustGatewayLogging resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZeroTrustGatewayLoggingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZeroTrustGatewayLogging resources.
 */
export interface ZeroTrustGatewayLoggingState {
    accountId?: pulumi.Input<string>;
    /**
     * Redact personally identifiable information from activity logging (PII fields are: source IP, user email, user ID, device ID, URL, referrer, user agent).
     */
    redactPii?: pulumi.Input<boolean>;
    /**
     * Logging settings by rule type.
     */
    settingsByRuleType?: pulumi.Input<inputs.ZeroTrustGatewayLoggingSettingsByRuleType>;
}
/**
 * The set of arguments for constructing a ZeroTrustGatewayLogging resource.
 */
export interface ZeroTrustGatewayLoggingArgs {
    accountId: pulumi.Input<string>;
    /**
     * Redact personally identifiable information from activity logging (PII fields are: source IP, user email, user ID, device ID, URL, referrer, user agent).
     */
    redactPii?: pulumi.Input<boolean>;
    /**
     * Logging settings by rule type.
     */
    settingsByRuleType?: pulumi.Input<inputs.ZeroTrustGatewayLoggingSettingsByRuleType>;
}
