import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/zeroTrustLocalFallbackDomain:ZeroTrustLocalFallbackDomain example '<account_id>/<policy_id>'
 * ```
 *
 * @deprecated cloudflare.index/zerotrustlocalfallbackdomain.ZeroTrustLocalFallbackDomain has been deprecated in favor of cloudflare.index/zerotrustdevicecustomprofilelocaldomainfallback.ZeroTrustDeviceCustomProfileLocalDomainFallback
 */
export declare class ZeroTrustLocalFallbackDomain extends pulumi.CustomResource {
    /**
     * Get an existing ZeroTrustLocalFallbackDomain resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZeroTrustLocalFallbackDomainState, opts?: pulumi.CustomResourceOptions): ZeroTrustLocalFallbackDomain;
    /**
     * Returns true if the given object is an instance of ZeroTrustLocalFallbackDomain.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZeroTrustLocalFallbackDomain;
    readonly accountId: pulumi.Output<string>;
    /**
     * A description of the fallback domain, displayed in the client UI.
     */
    readonly description: pulumi.Output<string>;
    /**
     * A list of IP addresses to handle domain resolution.
     */
    readonly dnsServers: pulumi.Output<string[]>;
    readonly domains: pulumi.Output<outputs.ZeroTrustLocalFallbackDomainDomain[]>;
    readonly policyId: pulumi.Output<string>;
    /**
     * The domain suffix to match when resolving locally.
     */
    readonly suffix: pulumi.Output<string>;
    /**
     * Create a ZeroTrustLocalFallbackDomain resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    /** @deprecated cloudflare.index/zerotrustlocalfallbackdomain.ZeroTrustLocalFallbackDomain has been deprecated in favor of cloudflare.index/zerotrustdevicecustomprofilelocaldomainfallback.ZeroTrustDeviceCustomProfileLocalDomainFallback */
    constructor(name: string, args: ZeroTrustLocalFallbackDomainArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZeroTrustLocalFallbackDomain resources.
 */
export interface ZeroTrustLocalFallbackDomainState {
    accountId?: pulumi.Input<string>;
    /**
     * A description of the fallback domain, displayed in the client UI.
     */
    description?: pulumi.Input<string>;
    /**
     * A list of IP addresses to handle domain resolution.
     */
    dnsServers?: pulumi.Input<pulumi.Input<string>[]>;
    domains?: pulumi.Input<pulumi.Input<inputs.ZeroTrustLocalFallbackDomainDomain>[]>;
    policyId?: pulumi.Input<string>;
    /**
     * The domain suffix to match when resolving locally.
     */
    suffix?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ZeroTrustLocalFallbackDomain resource.
 */
export interface ZeroTrustLocalFallbackDomainArgs {
    accountId: pulumi.Input<string>;
    domains: pulumi.Input<pulumi.Input<inputs.ZeroTrustLocalFallbackDomainDomain>[]>;
    policyId: pulumi.Input<string>;
}
