import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustTunnelCloudflared = new cloudflare.ZeroTrustTunnelCloudflared("example_zero_trust_tunnel_cloudflared", {
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     name: "blog",
 *     configSrc: "cloudflare",
 *     tunnelSecret: "AQIDBAUGBwgBAgMEBQYHCAECAwQFBgcIAQIDBAUGBwg=",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/zeroTrustTunnelCloudflared:ZeroTrustTunnelCloudflared example '<account_id>/<tunnel_id>'
 * ```
 */
export declare class ZeroTrustTunnelCloudflared extends pulumi.CustomResource {
    /**
     * Get an existing ZeroTrustTunnelCloudflared resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZeroTrustTunnelCloudflaredState, opts?: pulumi.CustomResourceOptions): ZeroTrustTunnelCloudflared;
    /**
     * Returns true if the given object is an instance of ZeroTrustTunnelCloudflared.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZeroTrustTunnelCloudflared;
    /**
     * Cloudflare account ID
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Cloudflare account ID
     */
    readonly accountTag: pulumi.Output<string>;
    /**
     * Indicates if this is a locally or remotely configured tunnel. If `local`, manage the tunnel using a YAML file on the origin machine. If `cloudflare`, manage the tunnel on the Zero Trust dashboard.
     * Available values: "local", "cloudflare".
     */
    readonly configSrc: pulumi.Output<string>;
    /**
     * The Cloudflare Tunnel connections between your origin and Cloudflare's edge.
     */
    readonly connections: pulumi.Output<outputs.ZeroTrustTunnelCloudflaredConnection[]>;
    /**
     * Timestamp of when the tunnel established at least one connection to Cloudflare's edge. If `null`, the tunnel is inactive.
     */
    readonly connsActiveAt: pulumi.Output<string>;
    /**
     * Timestamp of when the tunnel became inactive (no connections to Cloudflare's edge). If `null`, the tunnel is active.
     */
    readonly connsInactiveAt: pulumi.Output<string>;
    /**
     * Timestamp of when the resource was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * Timestamp of when the resource was deleted. If `null`, the resource has not been deleted.
     */
    readonly deletedAt: pulumi.Output<string>;
    /**
     * Metadata associated with the tunnel.
     */
    readonly metadata: pulumi.Output<string>;
    /**
     * A user-friendly name for a tunnel.
     */
    readonly name: pulumi.Output<string>;
    /**
     * If `true`, the tunnel can be configured remotely from the Zero Trust dashboard. If `false`, the tunnel must be configured locally on the origin machine.
     */
    readonly remoteConfig: pulumi.Output<boolean>;
    /**
     * The status of the tunnel. Valid values are `inactive` (tunnel has never been run), `degraded` (tunnel is active and able to serve traffic but in an unhealthy state), `healthy` (tunnel is active and able to serve traffic), or `down` (tunnel can not serve traffic as it has no connections to the Cloudflare Edge).
     * Available values: "inactive", "degraded", "healthy", "down".
     */
    readonly status: pulumi.Output<string>;
    /**
     * The type of tunnel.
     * Available values: "cfd*tunnel", "warp*connector", "warp", "magic", "ipSec", "gre", "cni".
     */
    readonly tunType: pulumi.Output<string>;
    /**
     * Sets the password required to run a locally-managed tunnel. Must be at least 32 bytes and encoded as a base64 string.
     */
    readonly tunnelSecret: pulumi.Output<string | undefined>;
    /**
     * Create a ZeroTrustTunnelCloudflared resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZeroTrustTunnelCloudflaredArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZeroTrustTunnelCloudflared resources.
 */
export interface ZeroTrustTunnelCloudflaredState {
    /**
     * Cloudflare account ID
     */
    accountId?: pulumi.Input<string>;
    /**
     * Cloudflare account ID
     */
    accountTag?: pulumi.Input<string>;
    /**
     * Indicates if this is a locally or remotely configured tunnel. If `local`, manage the tunnel using a YAML file on the origin machine. If `cloudflare`, manage the tunnel on the Zero Trust dashboard.
     * Available values: "local", "cloudflare".
     */
    configSrc?: pulumi.Input<string>;
    /**
     * The Cloudflare Tunnel connections between your origin and Cloudflare's edge.
     */
    connections?: pulumi.Input<pulumi.Input<inputs.ZeroTrustTunnelCloudflaredConnection>[]>;
    /**
     * Timestamp of when the tunnel established at least one connection to Cloudflare's edge. If `null`, the tunnel is inactive.
     */
    connsActiveAt?: pulumi.Input<string>;
    /**
     * Timestamp of when the tunnel became inactive (no connections to Cloudflare's edge). If `null`, the tunnel is active.
     */
    connsInactiveAt?: pulumi.Input<string>;
    /**
     * Timestamp of when the resource was created.
     */
    createdAt?: pulumi.Input<string>;
    /**
     * Timestamp of when the resource was deleted. If `null`, the resource has not been deleted.
     */
    deletedAt?: pulumi.Input<string>;
    /**
     * Metadata associated with the tunnel.
     */
    metadata?: pulumi.Input<string>;
    /**
     * A user-friendly name for a tunnel.
     */
    name?: pulumi.Input<string>;
    /**
     * If `true`, the tunnel can be configured remotely from the Zero Trust dashboard. If `false`, the tunnel must be configured locally on the origin machine.
     */
    remoteConfig?: pulumi.Input<boolean>;
    /**
     * The status of the tunnel. Valid values are `inactive` (tunnel has never been run), `degraded` (tunnel is active and able to serve traffic but in an unhealthy state), `healthy` (tunnel is active and able to serve traffic), or `down` (tunnel can not serve traffic as it has no connections to the Cloudflare Edge).
     * Available values: "inactive", "degraded", "healthy", "down".
     */
    status?: pulumi.Input<string>;
    /**
     * The type of tunnel.
     * Available values: "cfd*tunnel", "warp*connector", "warp", "magic", "ipSec", "gre", "cni".
     */
    tunType?: pulumi.Input<string>;
    /**
     * Sets the password required to run a locally-managed tunnel. Must be at least 32 bytes and encoded as a base64 string.
     */
    tunnelSecret?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ZeroTrustTunnelCloudflared resource.
 */
export interface ZeroTrustTunnelCloudflaredArgs {
    /**
     * Cloudflare account ID
     */
    accountId: pulumi.Input<string>;
    /**
     * Indicates if this is a locally or remotely configured tunnel. If `local`, manage the tunnel using a YAML file on the origin machine. If `cloudflare`, manage the tunnel on the Zero Trust dashboard.
     * Available values: "local", "cloudflare".
     */
    configSrc?: pulumi.Input<string>;
    /**
     * A user-friendly name for a tunnel.
     */
    name: pulumi.Input<string>;
    /**
     * Sets the password required to run a locally-managed tunnel. Must be at least 32 bytes and encoded as a base64 string.
     */
    tunnelSecret?: pulumi.Input<string>;
}
