import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZeroTrustTunnelCloudflaredVirtualNetwork = new cloudflare.ZeroTrustTunnelCloudflaredVirtualNetwork("example_zero_trust_tunnel_cloudflared_virtual_network", {
 *     accountId: "699d98642c564d2e855e9661899b7252",
 *     name: "us-east-1-vpc",
 *     comment: "Staging VPC for data science",
 *     isDefault: true,
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/zeroTrustTunnelCloudflaredVirtualNetwork:ZeroTrustTunnelCloudflaredVirtualNetwork example '<account_id>/<virtual_network_id>'
 * ```
 */
export declare class ZeroTrustTunnelCloudflaredVirtualNetwork extends pulumi.CustomResource {
    /**
     * Get an existing ZeroTrustTunnelCloudflaredVirtualNetwork resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZeroTrustTunnelCloudflaredVirtualNetworkState, opts?: pulumi.CustomResourceOptions): ZeroTrustTunnelCloudflaredVirtualNetwork;
    /**
     * Returns true if the given object is an instance of ZeroTrustTunnelCloudflaredVirtualNetwork.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZeroTrustTunnelCloudflaredVirtualNetwork;
    /**
     * Cloudflare account ID
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * Optional remark describing the virtual network.
     */
    readonly comment: pulumi.Output<string | undefined>;
    /**
     * Timestamp of when the resource was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * Timestamp of when the resource was deleted. If `null`, the resource has not been deleted.
     */
    readonly deletedAt: pulumi.Output<string>;
    /**
     * If `true`, this virtual network is the default for the account.
     */
    readonly isDefault: pulumi.Output<boolean | undefined>;
    /**
     * If `true`, this virtual network is the default for the account.
     */
    readonly isDefaultNetwork: pulumi.Output<boolean | undefined>;
    /**
     * A user-friendly name for the virtual network.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a ZeroTrustTunnelCloudflaredVirtualNetwork resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZeroTrustTunnelCloudflaredVirtualNetworkArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZeroTrustTunnelCloudflaredVirtualNetwork resources.
 */
export interface ZeroTrustTunnelCloudflaredVirtualNetworkState {
    /**
     * Cloudflare account ID
     */
    accountId?: pulumi.Input<string>;
    /**
     * Optional remark describing the virtual network.
     */
    comment?: pulumi.Input<string>;
    /**
     * Timestamp of when the resource was created.
     */
    createdAt?: pulumi.Input<string>;
    /**
     * Timestamp of when the resource was deleted. If `null`, the resource has not been deleted.
     */
    deletedAt?: pulumi.Input<string>;
    /**
     * If `true`, this virtual network is the default for the account.
     */
    isDefault?: pulumi.Input<boolean>;
    /**
     * If `true`, this virtual network is the default for the account.
     */
    isDefaultNetwork?: pulumi.Input<boolean>;
    /**
     * A user-friendly name for the virtual network.
     */
    name?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ZeroTrustTunnelCloudflaredVirtualNetwork resource.
 */
export interface ZeroTrustTunnelCloudflaredVirtualNetworkArgs {
    /**
     * Cloudflare account ID
     */
    accountId: pulumi.Input<string>;
    /**
     * Optional remark describing the virtual network.
     */
    comment?: pulumi.Input<string>;
    /**
     * If `true`, this virtual network is the default for the account.
     */
    isDefault?: pulumi.Input<boolean>;
    /**
     * If `true`, this virtual network is the default for the account.
     */
    isDefaultNetwork?: pulumi.Input<boolean>;
    /**
     * A user-friendly name for the virtual network.
     */
    name: pulumi.Input<string>;
}
