import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZoneCacheReserve = new cloudflare.ZoneCacheReserve("example_zone_cache_reserve", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     value: "on",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/zoneCacheReserve:ZoneCacheReserve example '<zone_id>'
 * ```
 */
export declare class ZoneCacheReserve extends pulumi.CustomResource {
    /**
     * Get an existing ZoneCacheReserve resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZoneCacheReserveState, opts?: pulumi.CustomResourceOptions): ZoneCacheReserve;
    /**
     * Returns true if the given object is an instance of ZoneCacheReserve.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZoneCacheReserve;
    /**
     * Whether the setting is editable
     */
    readonly editable: pulumi.Output<boolean>;
    /**
     * Last time this setting was modified.
     */
    readonly modifiedOn: pulumi.Output<string>;
    /**
     * Value of the Cache Reserve zone setting.
     * Available values: "on", "off".
     */
    readonly value: pulumi.Output<string>;
    /**
     * Identifier
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a ZoneCacheReserve resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZoneCacheReserveArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZoneCacheReserve resources.
 */
export interface ZoneCacheReserveState {
    /**
     * Whether the setting is editable
     */
    editable?: pulumi.Input<boolean>;
    /**
     * Last time this setting was modified.
     */
    modifiedOn?: pulumi.Input<string>;
    /**
     * Value of the Cache Reserve zone setting.
     * Available values: "on", "off".
     */
    value?: pulumi.Input<string>;
    /**
     * Identifier
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ZoneCacheReserve resource.
 */
export interface ZoneCacheReserveArgs {
    /**
     * Value of the Cache Reserve zone setting.
     * Available values: "on", "off".
     */
    value?: pulumi.Input<string>;
    /**
     * Identifier
     */
    zoneId: pulumi.Input<string>;
}
