import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as cloudflare from "@pulumi/cloudflare";
 *
 * const exampleZoneSetting = new cloudflare.ZoneSetting("example_zone_setting", {
 *     zoneId: "023e105f4ecef8ad9ca31a8372d0c353",
 *     settingId: "always_online",
 *     enabled: true,
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 * $ pulumi import cloudflare:index/zoneSetting:ZoneSetting example '<zone_id>/<setting_id>'
 * ```
 */
export declare class ZoneSetting extends pulumi.CustomResource {
    /**
     * Get an existing ZoneSetting resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZoneSettingState, opts?: pulumi.CustomResourceOptions): ZoneSetting;
    /**
     * Returns true if the given object is an instance of ZoneSetting.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZoneSetting;
    /**
     * Whether or not this setting can be modified for this zone (based on your Cloudflare plan level).
     */
    readonly editable: pulumi.Output<boolean>;
    /**
     * ssl-recommender enrollment setting.
     */
    readonly enabled: pulumi.Output<boolean>;
    /**
     * last time this setting was modified.
     */
    readonly modifiedOn: pulumi.Output<string>;
    /**
     * Setting name
     */
    readonly settingId: pulumi.Output<string>;
    /**
     * Value of the zone setting.
     * Notes: The interval (in seconds) from when development mode expires (positive integer) or last expired (negative integer) for the domain. If development mode has never been enabled, this value is false.
     */
    readonly timeRemaining: pulumi.Output<number>;
    /**
     * Current value of the zone setting.
     */
    readonly value: pulumi.Output<any>;
    /**
     * Identifier
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a ZoneSetting resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZoneSettingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZoneSetting resources.
 */
export interface ZoneSettingState {
    /**
     * Whether or not this setting can be modified for this zone (based on your Cloudflare plan level).
     */
    editable?: pulumi.Input<boolean>;
    /**
     * ssl-recommender enrollment setting.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * last time this setting was modified.
     */
    modifiedOn?: pulumi.Input<string>;
    /**
     * Setting name
     */
    settingId?: pulumi.Input<string>;
    /**
     * Value of the zone setting.
     * Notes: The interval (in seconds) from when development mode expires (positive integer) or last expired (negative integer) for the domain. If development mode has never been enabled, this value is false.
     */
    timeRemaining?: pulumi.Input<number>;
    /**
     * Current value of the zone setting.
     */
    value?: any;
    /**
     * Identifier
     */
    zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ZoneSetting resource.
 */
export interface ZoneSettingArgs {
    /**
     * ssl-recommender enrollment setting.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * Setting name
     */
    settingId: pulumi.Input<string>;
    /**
     * Current value of the zone setting.
     */
    value: any;
    /**
     * Identifier
     */
    zoneId: pulumi.Input<string>;
}
