import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * ## Example Usage
 */
export declare class ZoneSubscription extends pulumi.CustomResource {
    /**
     * Get an existing ZoneSubscription resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ZoneSubscriptionState, opts?: pulumi.CustomResourceOptions): ZoneSubscription;
    /**
     * Returns true if the given object is an instance of ZoneSubscription.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZoneSubscription;
    /**
     * How often the subscription is renewed automatically.
     * Available values: "weekly", "monthly", "quarterly", "yearly".
     */
    readonly frequency: pulumi.Output<string | undefined>;
    /**
     * Subscription identifier tag.
     */
    readonly identifier: pulumi.Output<string>;
    /**
     * The rate plan applied to the subscription.
     */
    readonly ratePlan: pulumi.Output<outputs.ZoneSubscriptionRatePlan | undefined>;
    /**
     * Create a ZoneSubscription resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ZoneSubscriptionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ZoneSubscription resources.
 */
export interface ZoneSubscriptionState {
    /**
     * How often the subscription is renewed automatically.
     * Available values: "weekly", "monthly", "quarterly", "yearly".
     */
    frequency?: pulumi.Input<string>;
    /**
     * Subscription identifier tag.
     */
    identifier?: pulumi.Input<string>;
    /**
     * The rate plan applied to the subscription.
     */
    ratePlan?: pulumi.Input<inputs.ZoneSubscriptionRatePlan>;
}
/**
 * The set of arguments for constructing a ZoneSubscription resource.
 */
export interface ZoneSubscriptionArgs {
    /**
     * How often the subscription is renewed automatically.
     * Available values: "weekly", "monthly", "quarterly", "yearly".
     */
    frequency?: pulumi.Input<string>;
    /**
     * Subscription identifier tag.
     */
    identifier: pulumi.Input<string>;
    /**
     * The rate plan applied to the subscription.
     */
    ratePlan?: pulumi.Input<inputs.ZoneSubscriptionRatePlan>;
}
